@@ -1,61 +1,33 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2001,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
  * $Log: PParse.cpp,v $
+ * Revision 1.18  2004/09/08 13:55:32  peiyongz
+ * Apache License Version 2.0
+ *
+ * Revision 1.17  2004/09/02 14:59:29  cargilld
+ * Add OutOfMemoryException block to samples.
+ *
+ * Revision 1.16  2003/08/07 21:21:38  neilg
+ * fix segmentation faults that may arise when the parser throws exceptions during document parsing.  In general, XMLPlatformUtils::Terminate() should not be called from within a catch statement.
+ *
+ * Revision 1.15  2003/05/30 09:36:35  gareth
+ * Use new macros for iostream.h and std:: issues.
+ *
  * Revision 1.14  2002/04/17 20:18:08  tng
  * [Bug 7493] The word "occured" is misspelled and it is a global error.
  *
@@ -140,7 +112,7 @@
 #include <xercesc/framework/XMLPScanToken.hpp>
 #include <xercesc/parsers/SAXParser.hpp>
 #include "PParse.hpp"
-
+#include <xercesc/util/OutOfMemoryException.hpp>
 
 // ---------------------------------------------------------------------------
 //  Local data
@@ -174,7 +146,7 @@ static SAXParser::ValSchemes    valScheme       = SAXParser::Val_Auto;
 // ---------------------------------------------------------------------------
 static void usage()
 {
-    cout << "\nUsage:\n"
+    XERCES_STD_QUALIFIER cout << "\nUsage:\n"
             "    PParse [options] <XML file>\n\n"
             "This program demonstrates the progressive parse capabilities of\n"
 	         "the parser system. It allows you to do a scanFirst() call followed by\n"
@@ -189,7 +161,7 @@ static void usage()
             "      -f            - Enable full schema constraint checking [default is off].\n"
             "      -?            - Show this help.\n\n"
             "  * = Default if not provided explicitly.\n"
-         <<  endl;
+         <<  XERCES_STD_QUALIFIER endl;
 }
 
 
@@ -207,8 +179,8 @@ int main(int argC, char* argV[])
 
     catch (const XMLException& toCatch)
     {
-         cerr << "Error during initialization! :\n"
-              << StrX(toCatch.getMessage()) << endl;
+         XERCES_STD_QUALIFIER cerr << "Error during initialization! :\n"
+              << StrX(toCatch.getMessage()) << XERCES_STD_QUALIFIER endl;
          return 1;
     }
 
@@ -248,7 +220,7 @@ int main(int argC, char* argV[])
                 valScheme = SAXParser::Val_Always;
             else
             {
-                cerr << "Unknown -v= value: " << parm << endl;
+                XERCES_STD_QUALIFIER cerr << "Unknown -v= value: " << parm << XERCES_STD_QUALIFIER endl;
                 XMLPlatformUtils::Terminate();
                 return 2;
             }
@@ -270,8 +242,8 @@ int main(int argC, char* argV[])
         }
         else
         {
-            cerr << "Unknown option '" << argV[parmInd]
-                << "', ignoring it\n" << endl;
+            XERCES_STD_QUALIFIER cerr << "Unknown option '" << argV[parmInd]
+                << "', ignoring it\n" << XERCES_STD_QUALIFIER endl;
         }
     }
 
@@ -307,6 +279,7 @@ int main(int argC, char* argV[])
     //  for. When it does, we fall out then.
     //
     unsigned long duration;
+    int errorCode = 0;
     try
     {
         // Create a progressive scan token
@@ -315,7 +288,7 @@ int main(int argC, char* argV[])
         const unsigned long startMillis = XMLPlatformUtils::getCurrentMillis();
         if (!parser->parseFirst(xmlFile, token))
         {
-            cerr << "scanFirst() failed\n" << endl;
+            XERCES_STD_QUALIFIER cerr << "scanFirst() failed\n" << XERCES_STD_QUALIFIER endl;
             XMLPlatformUtils::Terminate();
             return 1;
         }
@@ -341,24 +314,31 @@ int main(int argC, char* argV[])
         //
         parser->parseReset(token);
     }
-
+    catch (const OutOfMemoryException&)
+    {
+        XERCES_STD_QUALIFIER cerr << "OutOfMemoryException" << XERCES_STD_QUALIFIER endl;
+        errorCode = 5;
+    }
     catch (const XMLException& toCatch)
     {
-        cerr << "\nAn error occurred: '" << xmlFile << "'\n"
+        XERCES_STD_QUALIFIER cerr << "\nAn error occurred: '" << xmlFile << "'\n"
              << "Exception message is: \n"
              << StrX(toCatch.getMessage())
-             << "\n" << endl;
-        XMLPlatformUtils::Terminate();
-        return 4;
+             << "\n" << XERCES_STD_QUALIFIER endl;
+        errorCode = 4;
     }
 
+    if(errorCode) {
+        XMLPlatformUtils::Terminate();
+        return errorCode;
+    }
 
     if (!errorCount) {
-        cout << xmlFile << ": " << duration << " ms ("
+        XERCES_STD_QUALIFIER cout << xmlFile << ": " << duration << " ms ("
             << handler.getElementCount() << " elems, "
             << handler.getAttrCount() << " attrs, "
             << handler.getSpaceCount() << " spaces, "
-            << handler.getCharacterCount() << " chars)" << endl;
+            << handler.getCharacterCount() << " chars)" << XERCES_STD_QUALIFIER endl;
     }
 
     //
