@@ -1,61 +1,30 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2004 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2004,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
  * $Log: SCMPrint.cpp,v $
+ * Revision 1.5  2004/09/28 04:42:21  cargilld
+ * Update sample to use an error handler and only generate xsmodel when a schema document has been loaded successfully.
+ *
+ * Revision 1.4  2004/09/08 13:55:34  peiyongz
+ * Apache License Version 2.0
+ *
+ * Revision 1.3  2004/09/02 14:59:29  cargilld
+ * Add OutOfMemoryException block to samples.
+ *
  * Revision 1.2  2004/02/12 13:58:58  cargilld
  * Fix build errors.
  *
@@ -87,7 +56,8 @@
 #endif
 #include <stdlib.h>
 #include <string.h>
-
+#include <xercesc/util/OutOfMemoryException.hpp>
+#include <xercesc/sax2/DefaultHandler.hpp>
 
 XERCES_CPP_NAMESPACE_USE
 
@@ -150,6 +120,73 @@ inline XERCES_STD_QUALIFIER ostream& operator<<(XERCES_STD_QUALIFIER ostream& ta
     return target;
 }
 
+class SCMPrintHandler : public DefaultHandler
+{
+public:
+    // -----------------------------------------------------------------------
+    //  Constructors and Destructor
+    // -----------------------------------------------------------------------
+    SCMPrintHandler();
+    ~SCMPrintHandler();
+
+    bool getSawErrors() const
+    {
+        return fSawErrors;
+    }
+
+	void warning(const SAXParseException& exc);
+    void error(const SAXParseException& exc);
+    void fatalError(const SAXParseException& exc);
+    void resetErrors();
+
+
+private:
+    bool            fSawErrors;
+};
+
+SCMPrintHandler::SCMPrintHandler() :
+    fSawErrors(false)
+{
+}
+
+SCMPrintHandler::~SCMPrintHandler()
+{
+}
+
+// ---------------------------------------------------------------------------
+//  SCMPrintHandler: Overrides of the SAX ErrorHandler interface
+// ---------------------------------------------------------------------------
+void SCMPrintHandler::error(const SAXParseException& e)
+{
+    fSawErrors = true;
+    XERCES_STD_QUALIFIER cerr << "\nError at file " << StrX(e.getSystemId())
+		 << ", line " << e.getLineNumber()
+		 << ", char " << e.getColumnNumber()
+         << "\n  Message: " << StrX(e.getMessage()) << XERCES_STD_QUALIFIER endl;
+}
+
+void SCMPrintHandler::fatalError(const SAXParseException& e)
+{
+    fSawErrors = true;
+    XERCES_STD_QUALIFIER cerr << "\nFatal Error at file " << StrX(e.getSystemId())
+		 << ", line " << e.getLineNumber()
+		 << ", char " << e.getColumnNumber()
+         << "\n  Message: " << StrX(e.getMessage()) << XERCES_STD_QUALIFIER endl;
+}
+
+void SCMPrintHandler::warning(const SAXParseException& e)
+{
+    XERCES_STD_QUALIFIER cerr << "\nWarning at file " << StrX(e.getSystemId())
+		 << ", line " << e.getLineNumber()
+		 << ", char " << e.getColumnNumber()
+         << "\n  Message: " << StrX(e.getMessage()) << XERCES_STD_QUALIFIER endl;
+}
+
+void SCMPrintHandler::resetErrors()
+{
+    fSawErrors = false;
+}
+
 // ---------------------------------------------------------------------------
 //  Local helper methods
 // ---------------------------------------------------------------------------
@@ -253,9 +290,13 @@ int main(int argC, char* argV[])
         parser->setFeature(XMLUni::fgSAX2CoreNameSpacePrefixes, false);
 	    parser->setFeature(XMLUni::fgSAX2CoreValidation, true);
 	    parser->setFeature(XMLUni::fgXercesDynamic, true);
+        parser->setProperty(XMLUni::fgXercesScannerName, (void *)XMLUni::fgSGXMLScanner);
 
+        SCMPrintHandler handler;    
+        parser->setErrorHandler(&handler);
 
         bool more = true;
+        bool parsedOneSchemaOkay = false;
         XERCES_STD_QUALIFIER ifstream fin;
 
         // the input is a list file
@@ -268,7 +309,7 @@ int main(int argC, char* argV[])
         }
 
         while (more)
-        {
+        {            
             char fURI[1000];
             //initialize the array to zeros
             memset(fURI,0,sizeof(fURI));
@@ -292,34 +333,55 @@ int main(int argC, char* argV[])
             }
 
             parser->loadGrammar(xsdFile, Grammar::SchemaGrammarType, true);
+            if (handler.getSawErrors())
+            {
+                handler.resetErrors();
+            }
+            else
+            {
+                parsedOneSchemaOkay = true;
+            }
         }
 
-        XERCES_STD_QUALIFIER cout << "********** Printing out information from Schema **********" << "\n\n";
+        if (parsedOneSchemaOkay)
+        {
+            XERCES_STD_QUALIFIER cout << "********** Printing out information from Schema **********" << "\n\n";
 
-        XSModel *xsModel = grammarPool->getXSModel();
-        if (xsModel)
-        {    
-            StringList *namespaces = xsModel->getNamespaces();
-            for (unsigned i = 0; i < namespaces->size(); i++) {
+            XSModel *xsModel = grammarPool->getXSModel();
+            if (xsModel)
+            {    
+                StringList *namespaces = xsModel->getNamespaces();
+                for (unsigned i = 0; i < namespaces->size(); i++) {
     
-                XERCES_STD_QUALIFIER cout << "Processing Namespace:   ";
-                const XMLCh *nameSpace = namespaces->elementAt(i);
-                if (nameSpace && (XMLString::stringLen(nameSpace)>0))
-                    XERCES_STD_QUALIFIER cout << StrX(nameSpace);
-                XERCES_STD_QUALIFIER cout << "\n============================================" << XERCES_STD_QUALIFIER endl << XERCES_STD_QUALIFIER endl;
+                    XERCES_STD_QUALIFIER cout << "Processing Namespace:   ";
+                    const XMLCh *nameSpace = namespaces->elementAt(i);
+                    if (nameSpace && (XMLString::stringLen(nameSpace)>0))
+                        XERCES_STD_QUALIFIER cout << StrX(nameSpace);
+                    XERCES_STD_QUALIFIER cout << "\n============================================" << XERCES_STD_QUALIFIER endl << XERCES_STD_QUALIFIER endl;
 
-                processElements(xsModel->getComponentsByNamespace(XSConstants::ELEMENT_DECLARATION,
+                    processElements(xsModel->getComponentsByNamespace(XSConstants::ELEMENT_DECLARATION,
                                                                   nameSpace));
-                processTypeDefinitions(xsModel->getComponentsByNamespace(XSConstants::TYPE_DEFINITION,
+                    processTypeDefinitions(xsModel->getComponentsByNamespace(XSConstants::TYPE_DEFINITION,
                                                                          nameSpace));
-            }   
+                }   
+            }
+            else
+            {
+                XERCES_STD_QUALIFIER cout << "No XSModel to print" << "\n\n";
+            }
         }
         else
         {
-            XERCES_STD_QUALIFIER cout << "No XSModel to print" << "\n\n";
+            XERCES_STD_QUALIFIER cout << "Did not parse a schema document cleanly so not printing Schema for Schema XSModel information";
         }
+        
         XERCES_STD_QUALIFIER cout << XERCES_STD_QUALIFIER endl;
     }
+    catch (const OutOfMemoryException&)
+    {
+        XERCES_STD_QUALIFIER cerr << "OutOfMemoryException during parsing: '" << xsdFile << "'\n" << XERCES_STD_QUALIFIER endl;
+        errorCode = 6;
+    }
     catch (const XMLException& e)
     {
         XERCES_STD_QUALIFIER cerr << "\nError during parsing: '" << xsdFile << "'\n"
