@@ -1,62 +1,22 @@
-#!perl
 #
-# The Apache Software License, Version 1.1
+# Copyright 1999-2002,2004 The Apache Software Foundation.
+# 
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+# 
+#      http://www.apache.org/licenses/LICENSE-2.0
+# 
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 #
-# Copyright (c) 1999-2002 The Apache Software Foundation.  All rights
-# reserved.
-#
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions
-# are met:
-#
-# 1. Redistributions of source code must retain the above copyright
-#    notice, this list of conditions and the following disclaimer.
-#
-# 2. Redistributions in binary form must reproduce the above copyright
-#    notice, this list of conditions and the following disclaimer in
-#    the documentation and/or other materials provided with the
-#    distribution.
-#
-# 3. The end-user documentation included with the redistribution,
-#    if any, must include the following acknowledgment:
-#       "This product includes software developed by the
-#        Apache Software Foundation (http://www.apache.org/)."
-#    Alternately, this acknowledgment may appear in the software itself,
-#    if and wherever such third-party acknowledgments normally appear.
-#
-# 4. The names "Xerces" and "Apache Software Foundation" must
-#    not be used to endorse or promote products derived from this
-#    software without prior written permission. For written
-#    permission, please contact apache\@apache.org.
-#
-# 5. Products derived from this software may not be called "Apache",
-#    nor may "Apache" appear in their name, without prior written
-#    permission of the Apache Software Foundation.
-#
-# THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
-# WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
-# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-# DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
-# ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
-# USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
-# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
-# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
-# OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-# SUCH DAMAGE.
-# ====================================================================
-#
-# This software consists of voluntary contributions made by many
-# individuals on behalf of the Apache Software Foundation, and was
-# originally based on software copyright (c) 1999, International
-# Business Machines, Inc., http://www.ibm.com .  For more information
-# on the Apache Software Foundation, please see
-# <http://www.apache.org/>.
 #
 
 #
-# $Id: sanityTest.pl,v 1.22 2004/01/31 11:07:12 cargilld Exp $
+# $Id: sanityTest.pl,v 1.26 2004/09/08 13:55:35 peiyongz Exp $
 #
 
 
@@ -188,6 +148,9 @@ system ("XSerializerTest -v=never  personal-schema.xml");
 system ("XSerializerTest -v=always personal-schema.xml");
 system ("XSerializerTest -v=always -f personal-schema.xml");
 
+#  Run XSValueTest
+system ("XSValueTest");
+
 #  Run InitTestTerm
 system ("InitTermTest");
 print  ("1");
@@ -200,21 +163,35 @@ system ("InitTermTest -n -s -f personal-schema.xml");
 #  Run ThreadTest
 system ("ThreadTest");
 print  ("1");
-system ("ThreadTest -parser=sax -quiet -threads 10 -time 20 personal.xml");
+system ("ThreadTest -parser=sax -v=never -quiet -threads 10 -time 20 personal.xml");
 print  ("2");
-system ("ThreadTest -parser=dom -quiet -threads 10 -time 20 personal.xml");
+system ("ThreadTest -parser=dom -v=never -quiet -threads 10 -time 20 personal.xml");
 print  ("3");
-system ("ThreadTest -parser=sax -v -quiet -threads 10 -time 20 personal.xml");
+system ("ThreadTest -parser=sax2 -v=never -quiet -threads 10 -time 20 personal.xml");
 print  ("4");
-system ("ThreadTest -parser=dom -v -quiet -threads 10 -time 20 personal.xml");
+system ("ThreadTest -parser=sax -v=always -quiet -threads 10 -time 20 personal.xml");
 print  ("5");
-system ("ThreadTest -parser=sax -n -s -v -quiet -threads 10 -time 20 personal-schema.xml");
+system ("ThreadTest -parser=dom -v=always -quiet -threads 10 -time 20 personal.xml");
 print  ("6");
-system ("ThreadTest -parser=dom -n -s -v -quiet -threads 10 -time 20 personal-schema.xml");
+system ("ThreadTest -parser=sax2 -v=always -quiet -threads 10 -time 20 personal.xml");
 print  ("7");
-system ("ThreadTest -parser=sax -n -s -f -v -quiet -threads 10 -time 20 personal-schema.xml");
+system ("ThreadTest -parser=sax -gc -v=always -quiet -threads 10 -time 20 personal.xml");
 print  ("8");
-system ("ThreadTest -parser=dom -n -s -f -v -quiet -threads 10 -time 20 personal-schema.xml");
+system ("ThreadTest -parser=dom -gc -v=always -quiet -threads 10 -time 20 personal.xml");
+print  ("9");
+system ("ThreadTest -parser=sax2 -gc -v=always -quiet -threads 10 -time 20 personal.xml");
+print  ("10");
+system ("ThreadTest -parser=sax -n -s -f -v=always -quiet -threads 10 -time 20 personal-schema.xml");
+print  ("11");
+system ("ThreadTest -parser=dom -n -s -f -v=always -quiet -threads 10 -time 20 personal-schema.xml");
+print  ("12");
+system ("ThreadTest -parser=sax2 -n -s -f -v=always -quiet -threads 10 -time 20 personal-schema.xml");
+print  ("13");
+system ("ThreadTest -parser=sax -gc -n -s -f -v=always -quiet -threads 10 -time 20 personal-schema.xml");
+print  ("14");
+system ("ThreadTest -parser=dom -gc -n -s -f -v=always -quiet -threads 10 -time 20 personal-schema.xml");
+print  ("15");
+system ("ThreadTest -parser=sax2 -gc -n -s -f -v=always -quiet -threads 10 -time 20 personal-schema.xml");
 
 #  Run MemHandlerTest
 system ("MemHandlerTest");
