@@ -1,68 +1,29 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2001,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: XMLDOMDocument.cpp,v 1.4 2003/12/02 14:33:13 amassari Exp $
+ * $Id: XMLDOMDocument.cpp,v 1.8 2004/09/08 13:55:35 peiyongz Exp $
  */
 
 #include "stdafx.h"
 
-#include <xercesc/dom/deprecated/DOMParser.hpp>
+#include <xercesc/parsers/XercesDOMParser.hpp>
 #include <xercesc/sax/SAXParseException.hpp>
 #include <xercesc/framework/MemBufInputSource.hpp>
+#include <xercesc/dom/DOMImplementation.hpp>
 
 #include "xml4com.h"
 #include "XMLDOMDocument.h"
@@ -80,7 +41,6 @@
 #include "XMLDOMAttribute.h"
 #include "XMLDOMEntityReference.h"
 #include "BindStatusCallback.h"
-#include <xercesc/dom/deprecated/DocumentImpl.hpp>
 
 // I need to make sure the file is registered with long filenames
 HRESULT WINAPI CXMLDOMDocument::UpdateRegistry(BOOL bRegister)
@@ -110,7 +70,7 @@ HRESULT WINAPI CXMLDOMDocument::UpdateRegistry(BOOL bRegister)
 }
 
 CXMLDOMDocument::CXMLDOMDocument()
-	:m_Document					()
+	:m_Document					(NULL)
 	,m_bValidate				(false)
 	,m_lReadyState				(0)
 	,m_url						(_T(""))
@@ -126,6 +86,7 @@ CXMLDOMDocument::CXMLDOMDocument()
 	,m_bParseError				(false)
 	,m_bThreadValidate			(false)
 	,m_bPreserveWhiteSpace      (false)
+    ,m_TmpDocument              (NULL)
 {
 }
 
@@ -144,7 +105,7 @@ HRESULT CXMLDOMDocument::FinalConstruct()
 	m_pParseError->AddRef();
 	m_pIXMLDOMDocument = this;
 
-	m_Document = DOM_Document::createDocument();
+    m_Document = DOMImplementation::getImplementation()->createDocument();
 
 	return hr;
 }
@@ -175,6 +136,10 @@ void CXMLDOMDocument::FinalRelease()
 		m_pOnTransformNode = NULL;
 	}
 
+    if(m_Document)
+        delete m_Document;
+    m_Document = NULL;
+
 	DestroyWindow();
 }
 
@@ -223,6 +188,8 @@ LRESULT CXMLDOMDocument::OnReadyStateChange(UINT uMsg, WPARAM wParam, LPARAM lPa
 	if (m_lReadyState != 4)
 		return 1L;
 
+    if(m_Document)
+        delete m_Document;
 	m_Document = m_TmpDocument;
 	m_TmpDocument = 0;
 	
@@ -255,12 +222,12 @@ STDMETHODIMP CXMLDOMDocument::get_doctype(IXMLDOMDocumentType  **pVal)
 		return E_POINTER;
 
 	*pVal = NULL;
-	DOM_DocumentType doctype = m_Document.getDoctype();
+	DOMDocumentType* doctype = m_Document->getDoctype();
 
 	//
 	//   if the document had no doctype then return a null object
 	//
-	if(doctype.isNull())
+	if(doctype==NULL)
 		return S_OK;
 
 	CXMLDOMDocumentTypeObj *pObj = NULL;
@@ -332,9 +299,9 @@ STDMETHODIMP CXMLDOMDocument::get_documentElement(IXMLDOMElement  * *pVal)
 
 	try
 	{
-		pObj->element = m_Document.getDocumentElement();
+		pObj->element = m_Document->getDocumentElement();
 	}
-	catch(DOM_DOMException& ex)
+	catch(DOMException& ex)
 	{
 		pObj->Release();
 		return MakeHRESULT(ex);
@@ -357,17 +324,17 @@ STDMETHODIMP CXMLDOMDocument::putref_documentElement(IXMLDOMElement  *newVal)
 {
 	ATLTRACE(_T("CXMLDOMDocument::putref_documentElement\n"));
 
-	DOM_Element elem;
+	DOMElement* elem;
 
 	try
 	{
-		elem = m_Document.getDocumentElement();
-		if (NULL == newVal && !elem.isNull()) {
-			m_Document.removeChild(elem);
+		elem = m_Document->getDocumentElement();
+		if (NULL == newVal && elem!=NULL) {
+			m_Document->removeChild(elem);
 			return S_OK;
 		}
 	}
-	catch(DOM_DOMException& ex)
+	catch(DOMException& ex)
 	{
 		return MakeHRESULT(ex);
 	}
@@ -385,18 +352,18 @@ STDMETHODIMP CXMLDOMDocument::putref_documentElement(IXMLDOMElement  *newVal)
 	if (S_OK != hr)
 		return hr;
 
-	DOM_Node *pNewValNode = reinterpret_cast<DOM_Node*> (id);
+	DOMNode *pNewValNode = reinterpret_cast<DOMNode*> (id);
 	if (NULL == pNewValNode)
 		return E_INVALIDARG;
 
 	try
 	{
-		if(elem.isNull())
-			m_Document.appendChild(*pNewValNode);
+		if(elem==NULL)
+			m_Document->appendChild(pNewValNode);
 		else
-			m_Document.replaceChild(*pNewValNode, elem);
+			m_Document->replaceChild(pNewValNode, elem);
 	}
-	catch(DOM_DOMException& ex)
+	catch(DOMException& ex)
 	{
 		return MakeHRESULT(ex);
 	}
@@ -427,9 +394,9 @@ STDMETHODIMP CXMLDOMDocument::createElement(BSTR tagName, IXMLDOMElement  **pVal
 
 	try
 	{
-		pObj->element = m_Document.createElement(tagName);
+		pObj->element = m_Document->createElement(tagName);
 	}
-	catch(DOM_DOMException& ex)
+	catch(DOMException& ex)
 	{
 		pObj->Release();
 		return MakeHRESULT(ex);
@@ -467,9 +434,9 @@ STDMETHODIMP CXMLDOMDocument::createDocumentFragment(IXMLDOMDocumentFragment  **
 
 	try
 	{
-		pObj->documentFragment = m_Document.createDocumentFragment();
+		pObj->documentFragment = m_Document->createDocumentFragment();
 	}
-	catch(DOM_DOMException& ex)
+	catch(DOMException& ex)
 	{
 		pObj->Release();
 		return MakeHRESULT(ex);
@@ -507,9 +474,9 @@ STDMETHODIMP CXMLDOMDocument::createTextNode(BSTR data, IXMLDOMText  **pVal)
 
 	try
 	{
-		pObj->text = m_Document.createTextNode(data);
+		pObj->text = m_Document->createTextNode(data);
 	}
-	catch(DOM_DOMException& ex)
+	catch(DOMException& ex)
 	{
 		pObj->Release();
 		return MakeHRESULT(ex);
@@ -547,9 +514,9 @@ STDMETHODIMP CXMLDOMDocument::createComment(BSTR data, IXMLDOMComment  **comment
 
 	try
 	{
-		pObj->comment = m_Document.createComment(data);
+		pObj->comment = m_Document->createComment(data);
 	}
-	catch(DOM_DOMException& ex)
+	catch(DOMException& ex)
 	{
 		pObj->Release();
 		return MakeHRESULT(ex);
@@ -587,9 +554,9 @@ STDMETHODIMP CXMLDOMDocument::createCDATASection(BSTR data, IXMLDOMCDATASection
 
 	try
 	{
-		pObj->cdataSection = m_Document.createCDATASection(data);
+		pObj->cdataSection = m_Document->createCDATASection(data);
 	}
-	catch(DOM_DOMException& ex)
+	catch(DOMException& ex)
 	{
 		pObj->Release();
 		return MakeHRESULT(ex);
@@ -627,9 +594,9 @@ STDMETHODIMP CXMLDOMDocument::createProcessingInstruction(BSTR target, BSTR data
 
 	try
 	{
-		pObj->processingInstruction = m_Document.createProcessingInstruction(target, data);
+		pObj->processingInstruction = m_Document->createProcessingInstruction(target, data);
 	}
-	catch(DOM_DOMException& ex)
+	catch(DOMException& ex)
 	{
 		pObj->Release();
 		return MakeHRESULT(ex);
@@ -667,9 +634,9 @@ STDMETHODIMP CXMLDOMDocument::createAttribute(BSTR name, IXMLDOMAttribute  **att
 
 	try
 	{
-		pObj->attr = m_Document.createAttribute(name);
+		pObj->attr = m_Document->createAttribute(name);
 	}
-	catch(DOM_DOMException& ex)
+	catch(DOMException& ex)
 	{
 		pObj->Release();
 		return MakeHRESULT(ex);
@@ -707,9 +674,9 @@ STDMETHODIMP CXMLDOMDocument::createEntityReference(BSTR name, IXMLDOMEntityRefe
 
 	try
 	{
-		pObj->entityReference = m_Document.createEntityReference(name);
+		pObj->entityReference = m_Document->createEntityReference(name);
 	}
-	catch(DOM_DOMException& ex)
+	catch(DOMException& ex)
 	{
 		pObj->Release();
 		return MakeHRESULT(ex);
@@ -747,9 +714,9 @@ STDMETHODIMP CXMLDOMDocument::getElementsByTagName(BSTR tagName, IXMLDOMNodeList
 
 	try
 	{
-		pObj->m_container = m_Document.getElementsByTagName(tagName);
+		pObj->m_container = m_Document->getElementsByTagName(tagName);
 	}
-	catch(DOM_DOMException& ex)
+	catch(DOMException& ex)
 	{
 		pObj->Release();
 		return MakeHRESULT(ex);
@@ -815,59 +782,59 @@ STDMETHODIMP CXMLDOMDocument::createNode(VARIANT TYPE, BSTR name, BSTR namespace
 	switch(nodeType) {
 		case NODE_ELEMENT:
 		{
-			DOM_Element node;
+			DOMElement* node;
 			if (SysStringLen(namespaceURI) > 0)
-				node = m_Document.createElementNS(namespaceURI,name);
+				node = m_Document->createElementNS(namespaceURI,name);
 			else
-				node = m_Document.createElement(name);
+				node = m_Document->createElement(name);
 			
 			hr = wrapNode(m_pIXMLDOMDocument,node,IID_IXMLDOMNode,reinterpret_cast<LPVOID *> (pVal));
 			break;
 		}
 		case NODE_ATTRIBUTE:
 		{
-			DOM_Attr node;
+			DOMAttr* node;
 			if (SysStringLen(namespaceURI) > 0)
-				node = m_Document.createAttributeNS(namespaceURI,name);
+				node = m_Document->createAttributeNS(namespaceURI,name);
 			else
-				node = m_Document.createAttribute(name);
+				node = m_Document->createAttribute(name);
 
 			hr = wrapNode(m_pIXMLDOMDocument,node,IID_IXMLDOMNode,reinterpret_cast<LPVOID *> (pVal));
 			break;
 		}
 		case NODE_TEXT:
 		{
-			DOM_Text node = m_Document.createTextNode(OLESTR(""));
+			DOMText* node = m_Document->createTextNode(OLESTR(""));
 			hr = wrapNode(m_pIXMLDOMDocument,node,IID_IXMLDOMNode,reinterpret_cast<LPVOID *> (pVal));
 			break;
 		}
 		case NODE_CDATA_SECTION:
 		{
-			DOM_CDATASection node = m_Document.createCDATASection(OLESTR(""));
+			DOMCDATASection* node = m_Document->createCDATASection(OLESTR(""));
 			hr = wrapNode(m_pIXMLDOMDocument,node,IID_IXMLDOMNode,reinterpret_cast<LPVOID *> (pVal));
 			break;
 		}
 		case NODE_ENTITY_REFERENCE:
 		{
-			DOM_EntityReference node = m_Document.createEntityReference(name);
+			DOMEntityReference* node = m_Document->createEntityReference(name);
 			hr = wrapNode(m_pIXMLDOMDocument,node,IID_IXMLDOMNode,reinterpret_cast<LPVOID *> (pVal));
 			break;
 		}
 		case NODE_PROCESSING_INSTRUCTION:
 		{
-			DOM_ProcessingInstruction node = m_Document.createProcessingInstruction(name,OLESTR(""));
+			DOMProcessingInstruction* node = m_Document->createProcessingInstruction(name,OLESTR(""));
 			hr = wrapNode(m_pIXMLDOMDocument,node,IID_IXMLDOMNode,reinterpret_cast<LPVOID *> (pVal));
 			break;
 		}
 		case NODE_COMMENT:
 		{
-			DOM_Comment node = m_Document.createComment(OLESTR(""));
+			DOMComment* node = m_Document->createComment(OLESTR(""));
 			hr = wrapNode(m_pIXMLDOMDocument,node,IID_IXMLDOMNode,reinterpret_cast<LPVOID *> (pVal));
 			break;
 		}
 		case NODE_DOCUMENT_FRAGMENT:
 		{
-			DOM_DocumentFragment node = m_Document.createDocumentFragment();
+			DOMDocumentFragment* node = m_Document->createDocumentFragment();
 			hr = wrapNode(m_pIXMLDOMDocument,node,IID_IXMLDOMNode,reinterpret_cast<LPVOID *> (pVal));
 			break;
 		}
@@ -876,7 +843,7 @@ STDMETHODIMP CXMLDOMDocument::createNode(VARIANT TYPE, BSTR name, BSTR namespace
 			break;
 	}
 	}
-	catch(DOM_DOMException& ex)
+	catch(DOMException& ex)
 	{
 		hr = MakeHRESULT(ex);
 	}
@@ -900,9 +867,9 @@ STDMETHODIMP CXMLDOMDocument::nodeFromID(BSTR idString, IXMLDOMNode  **pVal)
 
 	try
 	{
-		hr = wrapNode(m_pIXMLDOMDocument, m_Document.getElementById(idString),IID_IXMLDOMNode,reinterpret_cast<LPVOID *> (pVal));
+		hr = wrapNode(m_pIXMLDOMDocument, m_Document->getElementById(idString),IID_IXMLDOMNode,reinterpret_cast<LPVOID *> (pVal));
 	}
-	catch(DOM_DOMException& ex)
+	catch(DOMException& ex)
 	{
 		return MakeHRESULT(ex);
 	}
@@ -1149,6 +1116,8 @@ STDMETHODIMP CXMLDOMDocument::load(VARIANT xmlSource, VARIANT_BOOL  *isSuccessfu
 	if (m_bParseError)
 		return hr;
 
+    if(m_Document)
+        delete m_Document;
 	m_Document = m_TmpDocument;
 	m_TmpDocument = 0;
 	
@@ -1336,6 +1305,8 @@ STDMETHODIMP CXMLDOMDocument::loadXML(BSTR bstrXML, VARIANT_BOOL  *isSuccessful)
 	if (m_bParseError)
 		return hr;
 
+    if(m_Document)
+        delete m_Document;
 	m_Document = m_TmpDocument;
 	m_TmpDocument = 0;
 	
@@ -1390,7 +1361,7 @@ UINT APIENTRY CXMLDOMDocument::ParseThread(void *pParm)
 		}
 	}
 
-	DOMParser parser;
+	XercesDOMParser parser;
 
 	//
 	//   If set to true then an node supporting IXMLDOMProcessingInstruction
@@ -1399,7 +1370,7 @@ UINT APIENTRY CXMLDOMDocument::ParseThread(void *pParm)
 	//   Setting to true in a custom DLL will better mimic
 	//      MSXML.DLL but at a cost of conformance errors
 	//      using David Brownell's suite
-	parser.setToCreateXMLDeclTypeNode(false);
+	//parser.setToCreateXMLDeclTypeNode(false);
 
 	parser.setIncludeIgnorableWhitespace(pThis->m_bPreserveWhiteSpace);
 
@@ -1411,7 +1382,7 @@ UINT APIENTRY CXMLDOMDocument::ParseThread(void *pParm)
 		//   this brings the COM component into better mimicry to MSXML
 		//      by not throwing a validation error when there is no DOCTYPE
 		//
-		parser.setValidationScheme(pThis->m_bThreadValidate ? DOMParser::Val_Auto : DOMParser::Val_Never);
+		parser.setValidationScheme(pThis->m_bThreadValidate ? AbstractDOMParser::Val_Auto : AbstractDOMParser::Val_Never);
 	}
 
 	if (!pThis->m_bParseError && !pThis->m_bAbort)
@@ -1445,7 +1416,7 @@ UINT APIENTRY CXMLDOMDocument::ParseThread(void *pParm)
 	}
 
 	if (!pThis->m_bParseError && !pThis->m_bAbort)
-		pThis->m_TmpDocument = parser.getDocument();
+		pThis->m_TmpDocument = parser.adoptDocument();
 
 	if (!pThis->m_bParseError && !pThis->m_bAbort && pThis->m_bAsync)
 		pThis->PostMessage(MSG_READY_STATE_CHANGE,4);
@@ -1467,16 +1438,16 @@ STDMETHODIMP CXMLDOMDocument::save(VARIANT location)
 	_bstr_t text;
 	
 	try {
-		DOM_NodeList childs = m_Document.getChildNodes();
-		int length = childs.getLength();
+		DOMNodeList* childs = m_Document->getChildNodes();
+		int length = childs->getLength();
 		for (int i=0; i < length; ++i) {
-			DOM_Node child = childs.item(i);
+			DOMNode* child = childs->item(i);
 			_bstr_t nodeText;
 			GetXML(child,nodeText);
 			text += nodeText;
 		}
 	}
-	catch(DOM_DOMException& ex)
+	catch(DOMException& ex)
 	{
 		return MakeHRESULT(ex);
 	}
@@ -1485,15 +1456,18 @@ STDMETHODIMP CXMLDOMDocument::save(VARIANT location)
 		return E_FAIL;
 	}
 
-	FILE* fp;
-	if ((fp = _tfopen(file, "wt")) == NULL) {
+	FILE* fp = _tfopen(file, "wt");
+	if (fp == NULL)
 		return E_FAIL;
-	}
 
-	if(text.length()>0)
-		_fputts(text, fp);
+	if(text.length()>0 && _fputts(text, fp)<0)
+    {
+        fclose(fp);
+        return E_FAIL;
+    }
 	
-	fclose(fp);
+	if(fclose(fp)!=0)
+        return E_FAIL;
 
 	return S_OK;
 }
