@@ -1,61 +1,27 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2001,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
  * $Log: XMLDOMDocument.h,v $
+ * Revision 1.9  2004/09/08 13:55:35  peiyongz
+ * Apache License Version 2.0
+ *
+ * Revision 1.8  2004/02/25 18:38:33  amassari
+ * The COM wrapper doesn't use the deprecated DOM anymore
+ *
  * Revision 1.7  2004/02/12 13:49:43  amassari
  * Updated version to 2.5
  *
@@ -104,7 +70,7 @@
 #ifndef ___xmldomdocument_h___
 #define ___xmldomdocument_h___
 
-#include <xercesc/dom/deprecated/DOM_Document.hpp>
+#include <xercesc/dom/DOMDocument.hpp>
 #include "IXMLDOMNodeImpl.h"
 
 #include "resource.h"       // main symbols
@@ -135,8 +101,8 @@ public:
 	HRESULT FinalConstruct();
 	void	FinalRelease();
 
-	virtual DOM_Node&   get_DOM_Node()			 { return m_Document;}
-	virtual DOMNodeType get_DOMNodeType() const  { return NODE_DOCUMENT; }
+	virtual DOMNode*        get_DOMNode()		    { return m_Document;}
+    virtual DOMNodeType     get_DOMNodeType() const { return NODE_DOCUMENT; }
 
 	virtual void resetErrors() {};
 
@@ -218,7 +184,7 @@ END_MSG_MAP()
 
 	bool IsAbort() const { return m_bAbort; }
 
-	DOM_Document		  m_Document;
+	XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument*		  m_Document;
 
 private:
 
@@ -236,7 +202,7 @@ private:
 	// thread data
 	_bstr_t				  m_FileName;
 	_bstr_t				  m_xml;
-	DOM_Document		  m_TmpDocument;
+	XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument*		  m_TmpDocument;
 	bool			      m_bParseError;
 	bool				  m_bThreadValidate;
 	bool                  m_bPreserveWhiteSpace;
