@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2002 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2002,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: DOMString.cpp,v 1.7 2003/05/22 02:26:50 knoaman Exp $
+ * $Id: DOMString.cpp,v 1.11 2004/09/28 10:56:04 amassari Exp $
  */
 
 #include <stdio.h>
@@ -97,6 +57,12 @@ XMLLCPTranscoder*  getDomConverter();
 static XMLLCPTranscoder* gDomConverter = 0;
 static XMLRegisterCleanup cleanupDomConverter;
 
+int DOMString::gLiveStringDataCount    = 0;
+int DOMString::gTotalStringDataCount   = 0;
+int DOMString::gLiveStringHandleCount  = 0;
+int DOMString::gTotalStringHandleCount = 0;
+
+
 XMLLCPTranscoder*  getDomConverter()
 {
     if (!gDomConverter)
@@ -173,18 +139,10 @@ DOMStringData *DOMStringData::allocateBuffer(unsigned int length)
         + length*sizeof(XMLCh);                //  extra elem because of stub
                                                //  array in DOMStringData struct.
     DOMStringData *buf = 0;
-    try {
-        buf = (DOMStringData *) XMLPlatformUtils::fgMemoryManager->allocate
+    buf = (DOMStringData *) XMLPlatformUtils::fgMemoryManager->allocate
         (
             sizeToAllocate * sizeof(char)
         );//new char[sizeToAllocate];
-    }
-    catch (...) {
-        ThrowXML(RuntimeException, XMLExcepts::Out_Of_Memory);
-    }
-    if (!buf)
-       ThrowXML(RuntimeException, XMLExcepts::Out_Of_Memory);
-
     XMLPlatformUtils::atomicIncrement(DOMString::gLiveStringDataCount);
     XMLPlatformUtils::atomicIncrement(DOMString::gTotalStringDataCount);
     buf->fBufferLength = length;
@@ -360,12 +318,6 @@ DOMStringHandle *DOMStringHandle::cloneStringHandle()
 //------------------------------------------------------------
 
 
-int DOMString::gLiveStringDataCount    = 0;
-int DOMString::gTotalStringDataCount   = 0;
-int DOMString::gLiveStringHandleCount  = 0;
-int DOMString::gTotalStringHandleCount = 0;
-
-
 DOMString::DOMString()
 {
     fHandle = 0;
