@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2001-2002 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 2001, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2001-2002,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: DOMAttrNSImpl.cpp,v 1.13 2004/01/29 11:44:26 cargilld Exp $
+ * $Id: DOMAttrNSImpl.cpp,v 1.16 2004/09/14 20:10:20 amassari Exp $
  */
 
 #include <xercesc/util/XMLUniDefs.hpp>
@@ -118,19 +78,12 @@ const XMLCh * DOMAttrNSImpl::getLocalName() const
 
 void DOMAttrNSImpl::setPrefix(const XMLCh *prefix)
 {
-    const XMLCh * xml = DOMNodeImpl::getXmlString();
-    const XMLCh * xmlURI = DOMNodeImpl::getXmlURIString();
     const XMLCh * xmlns = DOMNodeImpl::getXmlnsString();
-    const XMLCh * xmlnsURI = DOMNodeImpl::getXmlnsURIString();
 
     if (fNode.isReadOnly())
-        throw DOMException(DOMException::NO_MODIFICATION_ALLOWED_ERR,
-        0);
+        throw DOMException(DOMException::NO_MODIFICATION_ALLOWED_ERR, 0, GetDOMNodeMemoryManager);
     if (fNamespaceURI == 0 || fNamespaceURI[0] == chNull || XMLString::equals(fLocalName, xmlns))
-        throw DOMException(DOMException::NAMESPACE_ERR, 0);
-
-    if (prefix != 0 && !((DOMDocumentImpl *)this->getOwnerDocument())->isXMLName(prefix))
-        throw DOMException(DOMException::INVALID_CHARACTER_ERR,0);
+        throw DOMException(DOMException::NAMESPACE_ERR, 0, GetDOMNodeMemoryManager);
 
     if (prefix == 0 || prefix[0] == chNull) {
         fName = fLocalName;
@@ -138,14 +91,21 @@ void DOMAttrNSImpl::setPrefix(const XMLCh *prefix)
         return;
     }
 
+    if (!((DOMDocumentImpl *)this->getOwnerDocument())->isXMLName(prefix))
+        throw DOMException(DOMException::INVALID_CHARACTER_ERR,0, GetDOMNodeMemoryManager);
+
+    const XMLCh * xml = DOMNodeImpl::getXmlString();
+    const XMLCh * xmlURI = DOMNodeImpl::getXmlURIString();
+    const XMLCh * xmlnsURI = DOMNodeImpl::getXmlnsURIString();
+
     if (XMLString::equals(prefix, xml)&&
         !XMLString::equals(fNamespaceURI, xmlURI)||
         XMLString::equals(prefix, xmlns)&&
         !XMLString::equals(fNamespaceURI, xmlnsURI))
-        throw DOMException(DOMException::NAMESPACE_ERR, 0);
+        throw DOMException(DOMException::NAMESPACE_ERR, 0, GetDOMNodeMemoryManager);
 
     if (XMLString::indexOf(prefix, chColon) != -1) {
-        throw DOMException(DOMException::NAMESPACE_ERR, 0);
+        throw DOMException(DOMException::NAMESPACE_ERR, 0, GetDOMNodeMemoryManager);
     }
 
     this-> fPrefix = ((DOMDocumentImpl *)this->getOwnerDocument())->getPooledString(prefix);
@@ -178,7 +138,7 @@ void DOMAttrNSImpl::setPrefix(const XMLCh *prefix)
 void DOMAttrNSImpl::release()
 {
     if (fNode.isOwned() && !fNode.isToBeReleased())
-        throw DOMException(DOMException::INVALID_ACCESS_ERR,0);
+        throw DOMException(DOMException::INVALID_ACCESS_ERR,0, GetDOMNodeMemoryManager);
 
     DOMDocumentImpl* doc = (DOMDocumentImpl*) getOwnerDocument();
     if (doc) {
@@ -188,7 +148,7 @@ void DOMAttrNSImpl::release()
     }
     else {
         // shouldn't reach here
-        throw DOMException(DOMException::INVALID_ACCESS_ERR,0);
+        throw DOMException(DOMException::INVALID_ACCESS_ERR,0, GetDOMNodeMemoryManager);
     }
 }
 
@@ -216,13 +176,13 @@ void DOMAttrNSImpl::setName(const XMLCh* namespaceURI, const XMLCh* qualifiedNam
 
     int index = DOMDocumentImpl::indexofQualifiedName(qualifiedName);
     if (index < 0)
-        throw DOMException(DOMException::NAMESPACE_ERR, 0);
+        throw DOMException(DOMException::NAMESPACE_ERR, 0, GetDOMNodeMemoryManager);
 
     bool xmlnsAlone = false;	//true if attribute name is "xmlns"
     if (index == 0) {	//qualifiedName contains no ':'
         if (XMLString::equals(this->fName, xmlns)) {
             if (!XMLString::equals(namespaceURI, xmlnsURI))
-                throw DOMException(DOMException::NAMESPACE_ERR, 0);
+                throw DOMException(DOMException::NAMESPACE_ERR, 0, GetDOMNodeMemoryManager);
             xmlnsAlone = true;
         }
         this -> fPrefix = 0;
@@ -248,7 +208,7 @@ void DOMAttrNSImpl::setName(const XMLCh* namespaceURI, const XMLCh* qualifiedNam
 
         // Before we carry on, we should check if the prefix or localName are valid XMLName
         if (!((DOMDocumentImpl *)this->getOwnerDocument())->isXMLName(fPrefix) || !((DOMDocumentImpl *)this->getOwnerDocument())->isXMLName(fLocalName))
-            throw DOMException(DOMException::NAMESPACE_ERR, 0);
+            throw DOMException(DOMException::NAMESPACE_ERR, 0, GetDOMNodeMemoryManager);
     }
 
     // DOM Level 3: namespace URI is never empty string.
