@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2001-2002 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 2001, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2001-2002,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: DOMCharacterDataImpl.cpp,v 1.6 2003/05/15 18:25:54 knoaman Exp $
+ * $Id: DOMCharacterDataImpl.cpp,v 1.10 2004/09/08 13:55:51 peiyongz Exp $
  */
 
 #include "DOMCharacterDataImpl.hpp"
@@ -69,10 +29,9 @@
 
 XERCES_CPP_NAMESPACE_BEGIN
 
-
 DOMCharacterDataImpl::DOMCharacterDataImpl(DOMDocument *doc, const XMLCh *dat)
- : fDoc(0)
- , fDataBuf(0)
+ : fDataBuf(0)
+ , fDoc(0)
 {
     fDoc = (DOMDocumentImpl*)doc;
 
@@ -82,12 +41,12 @@ DOMCharacterDataImpl::DOMCharacterDataImpl(DOMDocument *doc, const XMLCh *dat)
     else
         fDataBuf->set(dat);
 
-};
+}
 
 
 DOMCharacterDataImpl::DOMCharacterDataImpl(const DOMCharacterDataImpl &other)
- : fDoc(0)
- , fDataBuf(0)
+ : fDataBuf(0)
+ , fDoc(0)
 {
     fDoc = (DOMDocumentImpl*)other.fDoc;
 
@@ -97,24 +56,23 @@ DOMCharacterDataImpl::DOMCharacterDataImpl(const DOMCharacterDataImpl &other)
     else
         fDataBuf->set(other.fDataBuf->getRawBuffer());
 
-};
+}
 
 
 DOMCharacterDataImpl::~DOMCharacterDataImpl() {
-};
+}
 
 
 const XMLCh * DOMCharacterDataImpl::getNodeValue() const
 {
     return fDataBuf->getRawBuffer();
-};
+}
 
 
 void DOMCharacterDataImpl::setNodeValue(const DOMNode *node, const XMLCh *value)
 {
     if (castToNodeImpl(node)->isReadOnly())
-        throw DOMException(DOMException::NO_MODIFICATION_ALLOWED_ERR,
-                               0);
+        throw DOMException(DOMException::NO_MODIFICATION_ALLOWED_ERR, 0, GetDOMCharacterDataImplMemoryManager);
     fDataBuf->set(value);
 
     if (node->getOwnerDocument() != 0) {
@@ -128,23 +86,23 @@ void DOMCharacterDataImpl::setNodeValue(const DOMNode *node, const XMLCh *value)
             }
         }
     }
-};
+}
 
 
 void DOMCharacterDataImpl::appendData(const DOMNode *node, const XMLCh *dat)
 {
     if(castToNodeImpl(node)->isReadOnly())
         throw DOMException(
-        DOMException::NO_MODIFICATION_ALLOWED_ERR, 0);
+        DOMException::NO_MODIFICATION_ALLOWED_ERR, 0, GetDOMCharacterDataImplMemoryManager);
 
     fDataBuf->append(dat);
-};
+}
 
 
 void DOMCharacterDataImpl::deleteData(const DOMNode *node, XMLSize_t offset, XMLSize_t count)
 {
     if (castToNodeImpl(node)->isReadOnly())
-        throw DOMException(DOMException::NO_MODIFICATION_ALLOWED_ERR, 0);
+        throw DOMException(DOMException::NO_MODIFICATION_ALLOWED_ERR, 0, GetDOMCharacterDataImplMemoryManager);
 
     // Note: the C++ XMLCh * operation throws the correct DOMExceptions
     //       when parameter values are bad.
@@ -152,7 +110,7 @@ void DOMCharacterDataImpl::deleteData(const DOMNode *node, XMLSize_t offset, XML
 
     XMLSize_t len = this->fDataBuf->getLen();
     if (offset > len || offset < 0 || count < 0)
-        throw DOMException(DOMException::INDEX_SIZE_ERR, 0);
+        throw DOMException(DOMException::INDEX_SIZE_ERR, 0, GetDOMCharacterDataImplMemoryManager);
 
 
 
@@ -201,14 +159,14 @@ void DOMCharacterDataImpl::deleteData(const DOMNode *node, XMLSize_t offset, XML
             }
         }
     }
-};
+}
 
 
 
 const XMLCh *DOMCharacterDataImpl::getData() const
 {
     return fDataBuf->getRawBuffer();
-};
+}
 
 
 //
@@ -217,7 +175,7 @@ const XMLCh *DOMCharacterDataImpl::getData() const
 XMLSize_t DOMCharacterDataImpl::getLength() const
 {
     return fDataBuf->getLen();
-};
+}
 
 
 
@@ -225,7 +183,7 @@ void DOMCharacterDataImpl::insertData(const DOMNode *node, XMLSize_t offset, con
 {
     if (castToNodeImpl(node)->isReadOnly())
         throw DOMException(
-        DOMException::NO_MODIFICATION_ALLOWED_ERR, 0);
+        DOMException::NO_MODIFICATION_ALLOWED_ERR, 0, GetDOMCharacterDataImplMemoryManager);
 
     // Note: the C++ XMLCh * operation throws the correct DOMExceptions
     //       when parameter values are bad.
@@ -233,7 +191,7 @@ void DOMCharacterDataImpl::insertData(const DOMNode *node, XMLSize_t offset, con
 
     XMLSize_t len = fDataBuf->getLen();
     if (offset > len || offset < 0)
-        throw DOMException(DOMException::INDEX_SIZE_ERR, 0);
+        throw DOMException(DOMException::INDEX_SIZE_ERR, 0, GetDOMCharacterDataImplMemoryManager);
 
     XMLSize_t datLen = XMLString::stringLen(dat);
 
@@ -278,11 +236,11 @@ void DOMCharacterDataImpl::replaceData(const DOMNode *node, XMLSize_t offset, XM
 {
     if (castToNodeImpl(node)->isReadOnly())
         throw DOMException(
-        DOMException::NO_MODIFICATION_ALLOWED_ERR, 0);
+        DOMException::NO_MODIFICATION_ALLOWED_ERR, 0, GetDOMCharacterDataImplMemoryManager);
 
     deleteData(node, offset, count);
     insertData(node, offset, dat);
-};
+}
 
 
 
@@ -290,7 +248,7 @@ void DOMCharacterDataImpl::replaceData(const DOMNode *node, XMLSize_t offset, XM
 void DOMCharacterDataImpl::setData(const DOMNode *node, const XMLCh *arg)
 {
     setNodeValue(node, arg);
-};
+}
 
 
 
@@ -308,13 +266,13 @@ const XMLCh * DOMCharacterDataImpl::substringData(const DOMNode *node, XMLSize_t
     XMLSize_t len = fDataBuf->getLen();
 
     if (offset > len || offset < 0 || count < 0)
-        throw DOMException(DOMException::INDEX_SIZE_ERR, 0);
+        throw DOMException(DOMException::INDEX_SIZE_ERR, 0, GetDOMCharacterDataImplMemoryManager);
 
 
     XMLCh* newString;
     XMLCh temp[4000];
     if (len >= 3999)
-        newString = (XMLCh*) XMLPlatformUtils::fgMemoryManager->allocate
+        newString = (XMLCh*) ((DOMDocumentImpl *)node->getOwnerDocument())->getMemoryManager()->allocate
         (
             (len + 1) * sizeof(XMLCh)
         );//new XMLCh[len+1];
@@ -327,11 +285,11 @@ const XMLCh * DOMCharacterDataImpl::substringData(const DOMNode *node, XMLSize_t
     const XMLCh* retString = ((DOMDocumentImpl *)node->getOwnerDocument())->getPooledString(newString);
 
     if (len >= 3999)
-        XMLPlatformUtils::fgMemoryManager->deallocate(newString);//delete[] newString;
+        ((DOMDocumentImpl *)node->getOwnerDocument())->getMemoryManager()->deallocate(newString);//delete[] newString;
 
     return retString;
 
-};
+}
 
 
 void DOMCharacterDataImpl::releaseBuffer() {
