@@ -1,58 +1,17 @@
 /*
- * The Apache Software License, Version 1.1
- *
- *
- * Copyright (c) 2003 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation and was
- * originally based on software copyright (c) 2001, International
- * Business Machines, Inc., http://www.apache.org.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2003,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 #include "DOMConfigurationImpl.hpp"
@@ -60,6 +19,7 @@
 #include <xercesc/util/XMLString.hpp>
 #include <xercesc/util/XMLUniDefs.hpp>
 #include <xercesc/dom/DOMException.hpp>
+#include <xercesc/util/Janitor.hpp>
 
 XERCES_CPP_NAMESPACE_BEGIN
 
@@ -119,8 +79,10 @@ const XMLCh DOMConfigurationImpl::fgSCHEMA_LOCATION[] = { chLatin_s, chLatin_c,
 
 const unsigned short DOMConfigurationImpl::fDEFAULT_VALUES = 0x2596;
 
-DOMConfigurationImpl::DOMConfigurationImpl(): featureValues(fDEFAULT_VALUES),
-                                              fErrorHandler(0), fSchemaType(0), fSchemaLocation(0) {
+DOMConfigurationImpl::DOMConfigurationImpl(MemoryManager* const manager): featureValues(fDEFAULT_VALUES),
+                                              fErrorHandler(0), fSchemaType(0), fSchemaLocation(0)
+, fMemoryManager(manager)
+ {
 }
 
 DOMConfigurationImpl::~DOMConfigurationImpl() {
@@ -128,11 +90,13 @@ DOMConfigurationImpl::~DOMConfigurationImpl() {
                                         
 void DOMConfigurationImpl::setParameter(const XMLCh* name, const void* value) {
 
-    XMLCh* lowerCaseName = XMLString::replicate(name);
+    XMLCh* lowerCaseName = XMLString::replicate(name, fMemoryManager);
+    ArrayJanitor<XMLCh> janName(lowerCaseName, fMemoryManager);
+
     XMLString::lowerCase(lowerCaseName);
 
     if(!canSetParameter(lowerCaseName, value)) {
-        throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0);
+        throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0, fMemoryManager);
     }
 
     bool isBooleanParameter = true;
@@ -158,7 +122,7 @@ void DOMConfigurationImpl::setParameter(const XMLCh* name, const void* value) {
         } else if (XMLString::equals(lowerCaseName, fgSCHEMA_LOCATION)) {
             fSchemaLocation = (XMLCh*)value;
         } else {  // canSetParameter above should take care of this case
-            throw DOMException(DOMException::NOT_FOUND_ERR, 0);
+            throw DOMException(DOMException::NOT_FOUND_ERR, 0, fMemoryManager);
         }
     }
 
@@ -169,7 +133,10 @@ void DOMConfigurationImpl::setParameter(const XMLCh* name, const void* value) {
 // --------------------------------------
 
 const void* DOMConfigurationImpl::getParameter(const XMLCh* name) const {
-    XMLCh* lowerCaseName = XMLString::replicate(name);
+
+    XMLCh* lowerCaseName = XMLString::replicate(name, fMemoryManager);
+    ArrayJanitor<XMLCh> janName(lowerCaseName, fMemoryManager);
+
     XMLString::lowerCase(lowerCaseName);
 
     bool isBooleanParameter = true;
@@ -195,7 +162,7 @@ const void* DOMConfigurationImpl::getParameter(const XMLCh* name) const {
         } else if (XMLString::equals(lowerCaseName, fgSCHEMA_LOCATION)) {
             return fSchemaLocation;
         } else {
-            throw DOMException(DOMException::NOT_FOUND_ERR, 0);
+            throw DOMException(DOMException::NOT_FOUND_ERR, 0, fMemoryManager);
         }
     }
 
@@ -218,7 +185,9 @@ bool DOMConfigurationImpl::canSetParameter(const XMLCh* name, const void* value)
     // if value is null, return true
     if(value == 0) return true;
 
-    XMLCh* lowerCaseName = XMLString::replicate(name);
+    XMLCh* lowerCaseName = XMLString::replicate(name, fMemoryManager);
+    ArrayJanitor<XMLCh> janName(lowerCaseName, fMemoryManager);
+    
     XMLString::lowerCase(lowerCaseName);
     
     bool isBooleanParameter = true;
@@ -294,7 +263,9 @@ bool DOMConfigurationImpl::canSetParameter(const XMLCh* name, const void* value)
 // -------------------------------------------
 
 DOMConfigurationImpl::DOMConfigurationFeature DOMConfigurationImpl::getFeatureFlag(const XMLCh* name) const {
-    XMLCh* lowerCaseName = XMLString::replicate(name);
+    XMLCh* lowerCaseName = XMLString::replicate(name, fMemoryManager);
+    ArrayJanitor<XMLCh> janName(lowerCaseName, fMemoryManager);
+    
     XMLString::lowerCase(lowerCaseName);
   
     if(XMLString::equals(lowerCaseName, fgCANONICAL_FORM)) {
@@ -326,7 +297,7 @@ DOMConfigurationImpl::DOMConfigurationFeature DOMConfigurationImpl::getFeatureFl
     } else if (XMLString::equals(lowerCaseName, fgWHITESPACE_IN_ELEMENT_CONTENT)) {
         return FEATURE_WHITESPACE_IN_ELEMENT_CONTENT;
     } else {
-        throw DOMException(DOMException::NOT_FOUND_ERR, 0);
+        throw DOMException(DOMException::NOT_FOUND_ERR, 0, fMemoryManager);
     }
         
 }
