@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2001-2003 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 2001, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2001-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: DOMDocumentImpl.cpp,v 1.52 2004/01/29 11:44:26 cargilld Exp $
+ * $Id: DOMDocumentImpl.cpp,v 1.58 2004/09/08 13:55:51 peiyongz Exp $
  */
 #include "DOMDocumentImpl.hpp"
 #include "DOMCasts.hpp"
@@ -71,7 +31,6 @@
 #include "XSDElementNSImpl.hpp"
 #include "DOMEntityImpl.hpp"
 #include "DOMEntityReferenceImpl.hpp"
-#include "DOMNamedNodeMapImpl.hpp"
 #include "DOMNormalizer.hpp"
 #include "DOMNotationImpl.hpp"
 #include "DOMProcessingInstructionImpl.hpp"
@@ -110,6 +69,7 @@ DOMDocumentImpl::DOMDocumentImpl(MemoryManager* const manager)
       fVersion(0),
       fDocumentURI(0),
       fDOMConfiguration(0),
+      fUserDataTableKeys(17, manager),
       fUserDataTable(0),
       fCurrentBlock(0),      
       fFreePtr(0),
@@ -145,6 +105,7 @@ DOMDocumentImpl::DOMDocumentImpl(const XMLCh *fNamespaceURI,
       fVersion(0),
       fDocumentURI(0),
       fDOMConfiguration(0),
+      fUserDataTableKeys(17, manager),
       fUserDataTable(0),
       fCurrentBlock(0),      
       fFreePtr(0),
@@ -169,7 +130,7 @@ DOMDocumentImpl::DOMDocumentImpl(const XMLCh *fNamespaceURI,
         if (qualifiedName)
             appendChild(createElementNS(fNamespaceURI, qualifiedName));  //root element
         else if (fNamespaceURI)
-            throw DOMException(DOMException::NAMESPACE_ERR, 0);
+            throw DOMException(DOMException::NAMESPACE_ERR, 0, getMemoryManager());
     }
     catch(const OutOfMemoryException&)
     {
@@ -191,7 +152,7 @@ void DOMDocumentImpl::setDocumentType(DOMDocumentType *doctype)
     //   ownerDocument will be set, but the DocType won't yet be a child of the document.
     if (doctype->getOwnerDocument() != 0 && doctype->getOwnerDocument() != this)
         throw DOMException(    //one doctype can belong to only one DOMDocumentImpl
-        DOMException::WRONG_DOCUMENT_ERR, 0);
+        DOMException::WRONG_DOCUMENT_ERR, 0, getMemoryManager());
 
     DOMDocumentTypeImpl* doctypeImpl = (DOMDocumentTypeImpl*) doctype;
     doctypeImpl->setOwnerDocument(this);
@@ -238,10 +199,13 @@ DOMDocumentImpl::~DOMDocumentImpl()
 
 DOMNode *DOMDocumentImpl::cloneNode(bool deep) const {
 
-    // Note:  the cloned document node goes on the system heap.  All other
-    //   nodes added to the new document will go on that document's heap,
-    //   but we need to construct the document first, before its heap exists.
+    // Note:  the cloned document node goes on the same heap we live in.
     DOMDocumentImpl *newdoc = new (fMemoryManager) DOMDocumentImpl(fMemoryManager);
+    if(fEncoding && *fEncoding)
+        newdoc->setEncoding(fEncoding);
+    if(fVersion && *fVersion)
+        newdoc->setVersion(fVersion);
+    newdoc->setStandalone(fStandalone);
 
     // then the children by _importing_ them
     if (deep)
@@ -276,7 +240,7 @@ DOMDocument * DOMDocumentImpl::getOwnerDocument() const {
 DOMAttr *DOMDocumentImpl::createAttribute(const XMLCh *nam)
 {
     if(!nam || !isXMLName(nam))
-        throw DOMException(DOMException::INVALID_CHARACTER_ERR,0);
+        throw DOMException(DOMException::INVALID_CHARACTER_ERR,0, getMemoryManager());
     return new (this, DOMDocumentImpl::ATTR_OBJECT) DOMAttrImpl(this,nam);
 }
 
@@ -306,7 +270,7 @@ DOMDocumentType *DOMDocumentImpl::createDocumentType(const XMLCh *nam)
 {
     if (!nam || !isXMLName(nam))
         throw DOMException(
-        DOMException::INVALID_CHARACTER_ERR, 0);
+        DOMException::INVALID_CHARACTER_ERR, 0, getMemoryManager());
 
     return new (this, DOMDocumentImpl::DOCUMENT_TYPE_OBJECT) DOMDocumentTypeImpl(this, nam, false);
 }
@@ -320,7 +284,7 @@ DOMDocumentType *
 {
     if (!qualifiedName || !isXMLName(qualifiedName))
         throw DOMException(
-        DOMException::INVALID_CHARACTER_ERR, 0);
+        DOMException::INVALID_CHARACTER_ERR, 0, getMemoryManager());
 
     return new (this, DOMDocumentImpl::DOCUMENT_TYPE_OBJECT) DOMDocumentTypeImpl(this, qualifiedName, publicId, systemId, false);
 }
@@ -330,7 +294,7 @@ DOMDocumentType *
 DOMElement *DOMDocumentImpl::createElement(const XMLCh *tagName)
 {
     if(!tagName || !isXMLName(tagName))
-        throw DOMException(DOMException::INVALID_CHARACTER_ERR,0);
+        throw DOMException(DOMException::INVALID_CHARACTER_ERR,0, getMemoryManager());
 
     return new (this, DOMDocumentImpl::ELEMENT_OBJECT) DOMElementImpl(this,tagName);
 }
@@ -348,7 +312,7 @@ DOMEntity *DOMDocumentImpl::createEntity(const XMLCh *nam)
 {
     if (!nam || !isXMLName(nam))
         throw DOMException(
-        DOMException::INVALID_CHARACTER_ERR, 0);
+        DOMException::INVALID_CHARACTER_ERR, 0, getMemoryManager());
 
     return new (this, DOMDocumentImpl::ENTITY_OBJECT) DOMEntityImpl(this, nam);
 }
@@ -359,7 +323,7 @@ DOMEntityReference *DOMDocumentImpl::createEntityReference(const XMLCh *nam)
 {
     if (!nam || !isXMLName(nam))
         throw DOMException(
-        DOMException::INVALID_CHARACTER_ERR, 0);
+        DOMException::INVALID_CHARACTER_ERR, 0, getMemoryManager());
 
     return new (this, DOMDocumentImpl::ENTITY_REFERENCE_OBJECT) DOMEntityReferenceImpl(this, nam);
 }
@@ -368,7 +332,7 @@ DOMEntityReference *DOMDocumentImpl::createEntityReferenceByParser(const XMLCh *
 {
     if (!nam || !isXMLName(nam))
         throw DOMException(
-        DOMException::INVALID_CHARACTER_ERR, 0);
+        DOMException::INVALID_CHARACTER_ERR, 0, getMemoryManager());
 
     return new (this, DOMDocumentImpl::ENTITY_REFERENCE_OBJECT) DOMEntityReferenceImpl(this, nam, false);
 }
@@ -377,7 +341,7 @@ DOMNotation *DOMDocumentImpl::createNotation(const XMLCh *nam)
 {
     if (!nam || !isXMLName(nam))
         throw DOMException(
-        DOMException::INVALID_CHARACTER_ERR, 0);
+        DOMException::INVALID_CHARACTER_ERR, 0, getMemoryManager());
 
     return new (this, DOMDocumentImpl::NOTATION_OBJECT) DOMNotationImpl(this, nam);
 }
@@ -388,7 +352,7 @@ DOMProcessingInstruction *DOMDocumentImpl::createProcessingInstruction(
                                           const XMLCh *target, const XMLCh *data)
 {
     if(!target || !isXMLName(target))
-        throw DOMException(DOMException::INVALID_CHARACTER_ERR,0);
+        throw DOMException(DOMException::INVALID_CHARACTER_ERR,0, getMemoryManager());
     return new (this, DOMDocumentImpl::PROCESSING_INSTRUCTION_OBJECT) DOMProcessingInstructionImpl(this,target,data);
 }
 
@@ -405,7 +369,7 @@ DOMNodeIterator* DOMDocumentImpl::createNodeIterator (
           DOMNode *root, unsigned long whatToShow, DOMNodeFilter* filter, bool entityReferenceExpansion)
 {
     if (!root) {
-        throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0);
+        throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0, getMemoryManager());
         return 0;
     }
 
@@ -444,21 +408,21 @@ void DOMDocumentImpl::removeNodeIterator(DOMNodeIteratorImpl* nodeIterator)
 
 const DOMXPathExpression* DOMDocumentImpl::createExpression(const XMLCh *, const DOMXPathNSResolver *)
 {
-    throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0);
+    throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0, getMemoryManager());
     return 0;
 }
 
 const DOMXPathNSResolver* DOMDocumentImpl::createNSResolver(DOMNode *)
 
 {
-    throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0);
+    throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0, getMemoryManager());
     return 0;
 }
 
 void* DOMDocumentImpl::evaluate(const XMLCh *, DOMNode *, const DOMXPathNSResolver *, 
                            unsigned short, void* ) 
 {
-    throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0);
+    throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0, getMemoryManager());
     return 0;
 }
 
@@ -467,7 +431,7 @@ void* DOMDocumentImpl::evaluate(const XMLCh *, DOMNode *, const DOMXPathNSResolv
 DOMTreeWalker* DOMDocumentImpl::createTreeWalker (DOMNode *root, unsigned long whatToShow, DOMNodeFilter* filter, bool entityReferenceExpansion)
 {
     if (!root) {
-        throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0);
+        throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0, getMemoryManager());
         return 0;
     }
 
@@ -511,7 +475,7 @@ DOMNode *DOMDocumentImpl::insertBefore(DOMNode *newChild, DOMNode *refChild)
         ||
         (newChild->getNodeType() == DOMNode::DOCUMENT_TYPE_NODE  && fDocType!=0)
         )
-        throw DOMException(DOMException::HIERARCHY_REQUEST_ERR,0);
+        throw DOMException(DOMException::HIERARCHY_REQUEST_ERR,0, getMemoryManager());
 
     // if the newChild is a documenttype node created from domimplementation, set the ownerDoc first
     if ((newChild->getNodeType() == DOMNode::DOCUMENT_TYPE_NODE) && !newChild->getOwnerDocument())
@@ -602,7 +566,7 @@ DOMElement *DOMDocumentImpl::createElementNS(const XMLCh *fNamespaceURI,
     const XMLCh *qualifiedName)
 {
     if(!qualifiedName || !isXMLName(qualifiedName))
-        throw DOMException(DOMException::INVALID_CHARACTER_ERR,0);
+        throw DOMException(DOMException::INVALID_CHARACTER_ERR,0, getMemoryManager());
     //XMLCh * pooledTagName = this->fNamePool->getPooledString(qualifiedName);
     return new (this, DOMDocumentImpl::ELEMENT_NS_OBJECT) DOMElementNSImpl(this, fNamespaceURI, qualifiedName);
 }
@@ -613,7 +577,7 @@ DOMElement *DOMDocumentImpl::createElementNS(const XMLCh *fNamespaceURI,
                                               const XMLSSize_t columnNo)
 {
     if(!qualifiedName || !isXMLName(qualifiedName))
-        throw DOMException(DOMException::INVALID_CHARACTER_ERR,0);
+        throw DOMException(DOMException::INVALID_CHARACTER_ERR,0, getMemoryManager());
 
     return new (this) XSDElementNSImpl(this, fNamespaceURI, qualifiedName, lineNo, columnNo);
 }
@@ -623,7 +587,7 @@ DOMAttr *DOMDocumentImpl::createAttributeNS(const XMLCh *fNamespaceURI,
     const XMLCh *qualifiedName)
 {
     if(!qualifiedName || !isXMLName(qualifiedName))
-        throw DOMException(DOMException::INVALID_CHARACTER_ERR,0);
+        throw DOMException(DOMException::INVALID_CHARACTER_ERR,0, getMemoryManager());
     return new (this, DOMDocumentImpl::ATTR_NS_OBJECT) DOMAttrNSImpl(this, fNamespaceURI, qualifiedName);
 }
 
@@ -979,7 +943,7 @@ void DOMDocumentImpl::setVersion(const XMLCh* version){
     if ((version && *version) &&
         !XMLString::equals(version, XMLUni::fgVersion1_0) &&
         !XMLString::equals(version, XMLUni::fgVersion1_1))
-        throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0);
+        throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0, getMemoryManager());
 
     fVersion = cloneString(version);
 }
@@ -1008,7 +972,7 @@ void DOMDocumentImpl::setStrictErrorChecking(bool strictErrorChecking) {
 }
 
 DOMNode* DOMDocumentImpl::adoptNode(DOMNode*) {
-    throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0);
+    throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0, getMemoryManager());
     return 0;
 }
 
@@ -1060,7 +1024,7 @@ DOMNode *DOMDocumentImpl::importNode(DOMNode *source, bool deep, bool cloningDoc
                             newelement->setAttributeNodeNS(nattr);
 
                         // if the imported attribute is of ID type, register the new node in fNodeIDMap
-                        if (castToNodeImpl(attr)->isIdAttr()) {
+                        if (attr->isId()) {
                             castToNodeImpl(nattr)->isIdAttr(true);
                             if (!fNodeIDMap)
                                  fNodeIDMap = new (this) DOMNodeIDMap(500, this);
@@ -1120,7 +1084,7 @@ DOMNode *DOMDocumentImpl::importNode(DOMNode *source, bool deep, bool cloningDoc
             // unless this is used as part of cloning a Document
             // forbid it for the sake of being compliant to the DOM spec
             if (!cloningDoc)
-                throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0);
+                throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0, getMemoryManager());
 
             DOMDocumentType *srcdoctype = (DOMDocumentType *)source;
             DOMDocumentType *newdoctype = (DOMDocumentType *)
@@ -1142,6 +1106,11 @@ DOMNode *DOMDocumentImpl::importNode(DOMNode *source, bool deep, bool cloningDoc
                     tmap->setNamedItem(importNode(smap->item(i), true, false));
                 }
             }
+            const XMLCh* intSubset=srcdoctype->getInternalSubset();
+            if(intSubset != 0) {
+                ((DOMDocumentTypeImpl *)newdoctype)->setInternalSubset(intSubset);
+            }
+
             // NOTE: At this time, the DOM definition of DocumentType
             // doesn't cover Elements and their Attributes. domimpl's
             // extentions in that area will not be preserved, even if
@@ -1168,7 +1137,7 @@ DOMNode *DOMDocumentImpl::importNode(DOMNode *source, bool deep, bool cloningDoc
 
     case DOMNode::DOCUMENT_NODE : // Document can't be child of Document
     default:                       // Unknown node type
-        throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0);
+        throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0, getMemoryManager());
     }
 
     // If deep, replicate and attach the kids.
@@ -1196,48 +1165,37 @@ DOMNode *DOMDocumentImpl::importNode(DOMNode *source, bool deep, bool cloningDoc
 void* DOMDocumentImpl::setUserData(DOMNodeImpl* n, const XMLCh* key, void* data, DOMUserDataHandler* handler)
 {
     void* oldData = 0;
-    DOMNodeUserDataTable* node_userDataTable = 0;
+    unsigned int keyId=fUserDataTableKeys.addOrFind(key);
 
     if (!fUserDataTable) {
         // create the table on heap so that it can be cleaned in destructor
-        //fUserDataTable = new (this) RefHashTableOf<DOMNodeUserDataTable>(29, true, new HashPtr());
-        fUserDataTable = new (fMemoryManager) RefHashTableOf<DOMNodeUserDataTable>
+        fUserDataTable = new (fMemoryManager) RefHash2KeysTableOf<DOMUserDataRecord>
         (
-            29
+            109
             , true
             , new (fMemoryManager) HashPtr()
             , fMemoryManager
         );
     }
     else {
-        node_userDataTable = fUserDataTable->get((void*)n);
-        DOMUserDataRecord* oldDataRecord = 0;
+        DOMUserDataRecord* oldDataRecord = fUserDataTable->get((void*)n, keyId);
 
-        if (node_userDataTable) {
-            oldDataRecord = node_userDataTable->get((void*)key);
-
-            if (oldDataRecord) {
-                oldData = oldDataRecord->getKey();
-                node_userDataTable->removeKey((void*)key);
-            }
+        if (oldDataRecord) {
+            oldData = oldDataRecord->getKey();
+            fUserDataTable->removeKey((void*)n, keyId);
         }
     }
 
     if (data) {
 
-        // create the DOMNodeUserDataTable if not exists
-        // create on the heap and adopted by the hashtable which will delete it upon removal.
-        if (!node_userDataTable) {
-            node_userDataTable  = new (fMemoryManager) RefHashTableOf<DOMUserDataRecord>(29, true, fMemoryManager);
-            fUserDataTable->put(n, node_userDataTable);
-        }
-
         // clone the key first, and create the DOMUserDataRecord
         // create on the heap and adopted by the hashtable which will delete it upon removal.
-        node_userDataTable->put((void*)getPooledString(key), new (fMemoryManager) DOMUserDataRecord(data, handler));
+        fUserDataTable->put((void*)n, keyId, new (fMemoryManager) DOMUserDataRecord(data, handler));
     }
     else {
-        if (node_userDataTable->isEmpty())
+        RefHash2KeysTableOfEnumerator<DOMUserDataRecord> enumKeys(fUserDataTable, false, fMemoryManager);
+        enumKeys.setPrimaryKey(n);
+        if (!enumKeys.hasMoreElements())
             n->hasUserData(false);
     }
 
@@ -1247,10 +1205,9 @@ void* DOMDocumentImpl::setUserData(DOMNodeImpl* n, const XMLCh* key, void* data,
 void* DOMDocumentImpl::getUserData(const DOMNodeImpl* n, const XMLCh* key) const
 {
     if (fUserDataTable) {
-        DOMNodeUserDataTable*  node_userDataTable = fUserDataTable->get((void*)n);
-
-        if (node_userDataTable) {
-            DOMUserDataRecord* dataRecord = node_userDataTable->get((void*)key);
+        unsigned int keyId=fUserDataTableKeys.getId(key);
+        if(keyId!=0) {
+            DOMUserDataRecord* dataRecord = fUserDataTable->get((void*)n, keyId);
             if (dataRecord)
                 return dataRecord->getKey();
         }
@@ -1262,32 +1219,30 @@ void* DOMDocumentImpl::getUserData(const DOMNodeImpl* n, const XMLCh* key) const
 void DOMDocumentImpl::callUserDataHandlers(const DOMNodeImpl* n, DOMUserDataHandler::DOMOperationType operation, const DOMNode* src, const DOMNode* dst) const
 {
     if (fUserDataTable) {
-        DOMNodeUserDataTable*  node_userDataTable = fUserDataTable->get((void*)n);
+        RefHash2KeysTableOfEnumerator<DOMUserDataRecord> userDataEnum(fUserDataTable, false, fMemoryManager);
+        userDataEnum.setPrimaryKey(n);
+        while (userDataEnum.hasMoreElements()) {
+            // get the key
+            void* key;
+            int key2;
+            userDataEnum.nextElementKey(key,key2);
 
-        if (node_userDataTable) {
-            RefHashTableOfEnumerator<DOMUserDataRecord> userDataEnum(node_userDataTable, false, fMemoryManager);
+            // get the DOMUserDataRecord
+            DOMUserDataRecord* userDataRecord = fUserDataTable->get((void*)n,key2);
 
-            // walk through the entire node_userDataTable table
-            while (userDataEnum.hasMoreElements()) {
-                // get the key
-                XMLCh* key = (XMLCh*) userDataEnum.nextElementKey();
+            // get the handler
+            DOMUserDataHandler* handler = userDataRecord->getValue();
 
-                // get the DOMUserDataRecord
-                DOMUserDataRecord* userDataRecord = node_userDataTable->get((void*)key);
-
-                // get the handler
-                DOMUserDataHandler* handler = userDataRecord->getValue();
-
-                if (handler) {
-                    // get the data
-                    void* data = userDataRecord->getKey();
-                    handler->handle(operation, key, data, src, dst);
-                }
-
-                // if the operation is deleted, we in fact should remove the data from the table
-                if (operation == DOMUserDataHandler::NODE_DELETED)
-                    node_userDataTable->removeKey((void*)key);
+            if (handler) {
+                // get the data
+                void* data = userDataRecord->getKey();
+                const XMLCh* userKey = fUserDataTableKeys.getValueForId(key2);
+                handler->handle(operation, userKey, data, src, dst);
             }
+
+            // if the operation is deleted, we in fact should remove the data from the table
+            if (operation == DOMUserDataHandler::NODE_DELETED)
+                fUserDataTable->removeKey((void*)n,key2);
         }
     }
 }
@@ -1307,9 +1262,9 @@ DOMNode* DOMDocumentImpl::renameNode(DOMNode* n, const XMLCh* namespaceURI, cons
 {
     if (n->getOwnerDocument() != this)
         if (n->getNodeType() == DOCUMENT_NODE)
-            throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0);
+            throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0, getMemoryManager());
         else
-            throw DOMException(DOMException::WRONG_DOCUMENT_ERR, 0);
+            throw DOMException(DOMException::WRONG_DOCUMENT_ERR, 0, getMemoryManager());
 
     switch (n->getNodeType()) {
         case ELEMENT_NODE:
@@ -1317,7 +1272,7 @@ DOMNode* DOMDocumentImpl::renameNode(DOMNode* n, const XMLCh* namespaceURI, cons
         case ATTRIBUTE_NODE:
             return ((DOMAttrImpl*)n)->rename(namespaceURI, name);
         default:
-            throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0);
+            throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0, getMemoryManager());
     }
 
     return 0;
