@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2001-2002 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 2001, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2001-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: DOMNodeImpl.cpp,v 1.26 2003/10/23 21:19:58 amassari Exp $
+ * $Id: DOMNodeImpl.cpp,v 1.34 2004/09/08 13:55:52 peiyongz Exp $
  */
 
 // This class doesn't support having any children, and implements the behavior
@@ -80,6 +40,8 @@
 
 XERCES_CPP_NAMESPACE_BEGIN
 
+//Though DOMNodeImpl does not derivate from DOMNode, it shares
+//the same GetDOMNodeMemoryManager
 
 const unsigned short DOMNodeImpl::READONLY     = 0x1<<0;
 const unsigned short DOMNodeImpl::SYNCDATA     = 0x1<<1;
@@ -98,22 +60,28 @@ const unsigned short DOMNodeImpl::TOBERELEASED = 0x1<<12;
 // -----------------------------------------------------------------------
 //  Reset the singleton gEmptyNodeList
 // -----------------------------------------------------------------------
-static DOMNodeListImpl *gEmptyNodeList;  // make a singleton empty node list
+static DOMNodeListImpl *gEmptyNodeList = 0;  // make a singleton empty node list
+static XMLMutex* gEmptyNodeListMutex = 0;
+static XMLRegisterCleanup emptyNodeListCleanup;
+
 static void reinitEmptyNodeList()
 {
     delete gEmptyNodeList;
     gEmptyNodeList = 0;
+
+    delete gEmptyNodeListMutex;
+    gEmptyNodeListMutex = 0;
 }
 
 // -----------------------------------------------------------------------
 //  DOMNodeImpl Functions
 // -----------------------------------------------------------------------
 DOMNodeImpl::DOMNodeImpl(DOMNode *ownerNode)
+:  fOwnerNode(ownerNode)
 {
     this->flags = 0;
-    // as long as we do not have any owner, fOwnerNode is our ownerDocument
-    fOwnerNode  = ownerNode;
-};
+    // as long as we do not have any owner, fOwnerNode is our ownerDocument    
+}
 
 // This only makes a shallow copy, cloneChildren must also be called for a
 // deep clone
@@ -125,64 +93,72 @@ DOMNodeImpl::DOMNodeImpl(const DOMNodeImpl &other)
     // Need to break the association w/ original parent
     this->fOwnerNode = other.getOwnerDocument();
     this->isOwned(false);
-};
+}
 
 
 
 DOMNodeImpl::~DOMNodeImpl() {
-};
+}
 
 
-DOMNode * DOMNodeImpl::appendChild(DOMNode *newChild)
+DOMNode * DOMNodeImpl::appendChild(DOMNode *)
 {
     // Only node types that don't allow children will use this default function.
     //   Others will go to DOMParentNode::appendChild.
-    throw DOMException(DOMException::HIERARCHY_REQUEST_ERR,0);
+    throw DOMException(DOMException::HIERARCHY_REQUEST_ERR,0, GetDOMNodeMemoryManager);
     return 0;
     //  return insertBefore(newChild, 0);
-};
+}
 
 
 DOMNamedNodeMap * DOMNodeImpl::getAttributes() const {
     return 0;                   // overridden in ElementImpl
-};
+}
 
 
 DOMNodeList *DOMNodeImpl::getChildNodes() const {
-    static XMLRegisterCleanup emptyNodeListCleanup;
 
-    if (gEmptyNodeList == 0)
+    if (!gEmptyNodeList)
     {
-        DOMNodeList *t = new DOMNodeListImpl(0);
-        if (XMLPlatformUtils::compareAndSwap((void **)&gEmptyNodeList, t, 0) != 0)
+        if (!gEmptyNodeListMutex)
         {
-            delete t;
-        }
-        else
-        {
-            emptyNodeListCleanup.registerCleanup(reinitEmptyNodeList);
+            XMLMutexLock lock(XMLPlatformUtils::fgAtomicMutex);
+			
+            if (!gEmptyNodeListMutex)
+                gEmptyNodeListMutex = new XMLMutex;
         }
 
+        // Use a faux scope to synchronize while we do this
+        {
+            XMLMutexLock lock(gEmptyNodeListMutex);
+
+            if (!gEmptyNodeList)
+            {
+                gEmptyNodeList = new DOMNodeListImpl(0);
+                emptyNodeListCleanup.registerCleanup(reinitEmptyNodeList);
+            }
+        }
     }
+
     return (DOMNodeList *)gEmptyNodeList;
-};
+}
 
 
 
 DOMNode * DOMNodeImpl::getFirstChild() const {
     return 0;                   // overridden in ParentNode
-};
+}
 
 
 DOMNode * DOMNodeImpl::getLastChild() const
 {
     return 0;                   // overridden in ParentNode
-};
+}
 
 
 DOMNode * DOMNodeImpl::getNextSibling() const {
     return 0;                // overridden in ChildNode
-};
+}
 
 
 const XMLCh * DOMNodeImpl::getNodeValue() const {
@@ -219,7 +195,7 @@ DOMDocument *DOMNodeImpl::getOwnerDocument() const
         assert (fOwnerNode->getNodeType() == DOMNode::DOCUMENT_NODE);
         return  (DOMDocument *)fOwnerNode;
     }
-};
+}
 
 
 void DOMNodeImpl::setOwnerDocument(DOMDocument *doc) {
@@ -235,46 +211,46 @@ void DOMNodeImpl::setOwnerDocument(DOMDocument *doc) {
 DOMNode * DOMNodeImpl::getParentNode() const
 {
     return 0;                // overridden in ChildNode
-};
+}
 
 
 DOMNode*  DOMNodeImpl::getPreviousSibling() const
 {
     return 0;                // overridden in ChildNode
-};
+}
 
 bool DOMNodeImpl::hasChildNodes() const
 {
     return false;
-};
+}
 
 
 
-DOMNode *DOMNodeImpl::insertBefore(DOMNode *newChild, DOMNode *refChild) {
-    throw DOMException(DOMException::HIERARCHY_REQUEST_ERR, 0);
+DOMNode *DOMNodeImpl::insertBefore(DOMNode *, DOMNode *) {
+    throw DOMException(DOMException::HIERARCHY_REQUEST_ERR, 0, GetDOMNodeMemoryManager);
     return 0;
-};
+}
 
 
-DOMNode *DOMNodeImpl::removeChild(DOMNode *oldChild)
+DOMNode *DOMNodeImpl::removeChild(DOMNode *)
 {
-    throw DOMException(DOMException::NOT_FOUND_ERR, 0);
+    throw DOMException(DOMException::NOT_FOUND_ERR, 0, GetDOMNodeMemoryManager);
     return 0;
-};
+}
 
 
-DOMNode *DOMNodeImpl::replaceChild(DOMNode *newChild, DOMNode *oldChild)
+DOMNode *DOMNodeImpl::replaceChild(DOMNode *, DOMNode *)
 {
-    throw DOMException(DOMException::HIERARCHY_REQUEST_ERR,0);
+    throw DOMException(DOMException::HIERARCHY_REQUEST_ERR,0, GetDOMNodeMemoryManager);
     return 0;
-};
+}
 
 
 
-void DOMNodeImpl::setNodeValue(const XMLCh *val)
+void DOMNodeImpl::setNodeValue(const XMLCh *)
 {
     // Default behavior is to do nothing, overridden in some subclasses
-};
+}
 
 
 
@@ -312,7 +288,7 @@ void DOMNodeImpl::setReadOnly(bool readOnl, bool deep)
 void DOMNodeImpl::normalize()
 {
     // does nothing by default, overridden by subclasses
-};
+}
 
 
 bool DOMNodeImpl::isSupported(const XMLCh *feature, const XMLCh *version) const
@@ -336,41 +312,24 @@ const XMLCh *DOMNodeImpl::getLocalName() const
 }
 
 
-void DOMNodeImpl::setPrefix(const XMLCh *fPrefix)
+void DOMNodeImpl::setPrefix(const XMLCh *)
 {
-    throw DOMException(DOMException::NAMESPACE_ERR, 0);
+    throw DOMException(DOMException::NAMESPACE_ERR, 0, GetDOMNodeMemoryManager);
 }
 
 
 bool DOMNodeImpl::hasAttributes() const {
     return 0;                   // overridden in ElementImpl
-};
+}
 
 
 
 
 
-static const XMLCh s_xml[] = {chLatin_x, chLatin_m, chLatin_l, chNull};
-static const XMLCh s_xmlURI[] =    // "http://www.w3.org/XML/1998/namespace"
-    { chLatin_h, chLatin_t, chLatin_t, chLatin_p, chColon, chForwardSlash, chForwardSlash,
-      chLatin_w, chLatin_w, chLatin_w, chPeriod, chLatin_w, chDigit_3, chPeriod,
-      chLatin_o, chLatin_r, chLatin_g, chForwardSlash, chLatin_X, chLatin_M, chLatin_L, chForwardSlash,
-      chDigit_1, chDigit_9, chDigit_9, chDigit_8, chForwardSlash,
-      chLatin_n, chLatin_a, chLatin_m, chLatin_e, chLatin_s, chLatin_p, chLatin_a, chLatin_c, chLatin_e,
-      chNull};
-static const XMLCh s_xmlns[] = {chLatin_x, chLatin_m, chLatin_l, chLatin_n, chLatin_s, chNull};
-static const XMLCh s_xmlnsURI[] = // "http://www.w3.org/2000/xmlns/"
-    {  chLatin_h, chLatin_t, chLatin_t, chLatin_p, chColon, chForwardSlash, chForwardSlash,
-       chLatin_w, chLatin_w, chLatin_w, chPeriod, chLatin_w, chDigit_3, chPeriod,
-       chLatin_o, chLatin_r, chLatin_g, chForwardSlash,
-       chDigit_2, chDigit_0, chDigit_0, chDigit_0, chForwardSlash,
-       chLatin_x, chLatin_m, chLatin_l, chLatin_n, chLatin_s, chForwardSlash, chNull};
-
-
-const XMLCh *DOMNodeImpl::getXmlString()      {return s_xml;};
-const XMLCh *DOMNodeImpl::getXmlURIString()   {return s_xmlURI;};
-const XMLCh *DOMNodeImpl::getXmlnsString()    {return s_xmlns;};
-const XMLCh *DOMNodeImpl::getXmlnsURIString() {return s_xmlnsURI;};
+const XMLCh *DOMNodeImpl::getXmlString()      {return XMLUni::fgXMLString;}
+const XMLCh *DOMNodeImpl::getXmlURIString()   {return XMLUni::fgXMLURIName;}
+const XMLCh *DOMNodeImpl::getXmlnsString()    {return XMLUni::fgXMLNSString;}
+const XMLCh *DOMNodeImpl::getXmlnsURIString() {return XMLUni::fgXMLNSURIName;}
 
 //Return a URI mapped from the given prefix and namespaceURI as below
 //    prefix   namespaceURI    output
@@ -384,34 +343,16 @@ const XMLCh *DOMNodeImpl::getXmlnsURIString() {return s_xmlnsURI;};
 const XMLCh* DOMNodeImpl::mapPrefix(const XMLCh *prefix,
                                      const XMLCh *namespaceURI, short nType)
 {
-
-    static const XMLCh s_xml[] = {chLatin_x, chLatin_m, chLatin_l, chNull};
-    static const XMLCh s_xmlURI[] =    // "http://www.w3.org/XML/1998/namespace"
-    { chLatin_h, chLatin_t, chLatin_t, chLatin_p, chColon, chForwardSlash, chForwardSlash,
-      chLatin_w, chLatin_w, chLatin_w, chPeriod, chLatin_w, chDigit_3, chPeriod,
-      chLatin_o, chLatin_r, chLatin_g, chForwardSlash, chLatin_X, chLatin_M, chLatin_L, chForwardSlash,
-      chDigit_1, chDigit_9, chDigit_9, chDigit_8, chForwardSlash,
-      chLatin_n, chLatin_a, chLatin_m, chLatin_e, chLatin_s, chLatin_p, chLatin_a, chLatin_c, chLatin_e,
-      chNull};
-    static const XMLCh s_xmlns[] = {chLatin_x, chLatin_m, chLatin_l, chLatin_n, chLatin_s, chNull};
-    static const XMLCh s_xmlnsURI[] = // "http://www.w3.org/2000/xmlns/"
-    {  chLatin_h, chLatin_t, chLatin_t, chLatin_p, chColon, chForwardSlash, chForwardSlash,
-       chLatin_w, chLatin_w, chLatin_w, chPeriod, chLatin_w, chDigit_3, chPeriod,
-       chLatin_o, chLatin_r, chLatin_g, chForwardSlash,
-       chDigit_2, chDigit_0, chDigit_0, chDigit_0, chForwardSlash,
-       chLatin_x, chLatin_m, chLatin_l, chLatin_n, chLatin_s, chForwardSlash, chNull};
-
-
     if (prefix == 0)
         return namespaceURI;
 
-    if (XMLString::equals(prefix, s_xml))  {
-        if (XMLString::equals(namespaceURI, s_xmlURI))
-            return s_xmlURI;
+    if (XMLString::equals(prefix, XMLUni::fgXMLString))  {
+        if (XMLString::equals(namespaceURI, XMLUni::fgXMLURIName))
+            return XMLUni::fgXMLURIName;
         throw DOMException(DOMException::NAMESPACE_ERR, 0);
-    } else if (nType == DOMNode::ATTRIBUTE_NODE && XMLString::equals(prefix, s_xmlns)) {
-        if (XMLString::equals(namespaceURI, s_xmlnsURI))
-            return s_xmlnsURI;
+    } else if (nType == DOMNode::ATTRIBUTE_NODE && XMLString::equals(prefix, XMLUni::fgXMLNSString)) {
+        if (XMLString::equals(namespaceURI, XMLUni::fgXMLNSURIName))
+            return XMLUni::fgXMLNSURIName;
         throw DOMException(DOMException::NAMESPACE_ERR, 0);
     } else if (namespaceURI == 0 || *namespaceURI == 0) {
         throw DOMException(DOMException::NAMESPACE_ERR, 0);
@@ -579,10 +520,10 @@ const XMLCh* DOMNodeImpl::lookupNamespacePrefix(const XMLCh* const namespaceURI,
 
                 ns = attr->getNamespaceURI();
 
-                if (ns != 0 && XMLString::equals(ns, s_xmlnsURI)) {
+                if (ns != 0 && XMLString::equals(ns, XMLUni::fgXMLNSURIName)) {
                     // DOM Level 2 nodes
-                    if ((useDefault && XMLString::equals(attr->getNodeName(), s_xmlns)) ||
-                        (attrPrefix != 0 && XMLString::equals(attrPrefix, s_xmlns)) &&
+                    if ((useDefault && XMLString::equals(attr->getNodeName(), XMLUni::fgXMLNSString)) ||
+                        (attrPrefix != 0 && XMLString::equals(attrPrefix, XMLUni::fgXMLNSString)) &&
                         XMLString::equals(value, namespaceURI)) {
                         const XMLCh* localname= attr->getLocalName();
                         const XMLCh* foundNamespace = el->lookupNamespaceURI(localname);
@@ -629,14 +570,14 @@ const XMLCh* DOMNodeImpl::lookupNamespaceURI(const XMLCh* specifiedPrefix) const
                     const XMLCh *value = attr->getNodeValue();
                     ns = attr->getNamespaceURI();
 
-                    if (ns != 0 && XMLString::equals(ns, s_xmlnsURI)) {
+                    if (ns != 0 && XMLString::equals(ns, XMLUni::fgXMLNSURIName)) {
                         // at this point we are dealing with DOM Level 2 nodes only
                         if (specifiedPrefix == 0 &&
-                            XMLString::equals(attr->getNodeName(), s_xmlns)) {
+                            XMLString::equals(attr->getNodeName(), XMLUni::fgXMLNSString)) {
                             // default namespace
                             return value;
                         } else if (attrPrefix != 0 &&
-                                   XMLString::equals(attrPrefix, s_xmlns) &&
+                                   XMLString::equals(attrPrefix, XMLUni::fgXMLNSString) &&
                                    XMLString::equals(attr->getLocalName(), specifiedPrefix)) {
                             // non default namespace
                             return value;
@@ -1050,7 +991,52 @@ const XMLCh*    DOMNodeImpl::getTextContent(XMLCh* pzBuffer, unsigned int& rnBuf
 }
 
 void DOMNodeImpl::setTextContent(const XMLCh* textContent){
-    throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0);
+    DOMNode *thisNode = castToNode(this);
+    switch (thisNode->getNodeType()) 
+    {
+        case DOMNode::ELEMENT_NODE:
+        case DOMNode::ENTITY_NODE:
+        case DOMNode::ENTITY_REFERENCE_NODE:
+        case DOMNode::DOCUMENT_FRAGMENT_NODE:
+            {
+                if (isReadOnly())
+                  throw DOMException(DOMException::NO_MODIFICATION_ALLOWED_ERR, 0, GetDOMNodeMemoryManager);
+
+                // Remove all childs
+                DOMNode* current = thisNode->getFirstChild();
+                while (current != NULL) 
+                {
+                    thisNode->removeChild(current);
+                    current = thisNode->getFirstChild();
+                }
+                if (textContent != NULL) 
+                {
+                    // Add textnode containing data
+                    current = ((DOMDocumentImpl*)thisNode->getOwnerDocument())->createTextNode(textContent);
+                    thisNode->appendChild(current);
+                }
+            }
+            break;
+
+        case DOMNode::ATTRIBUTE_NODE:
+        case DOMNode::TEXT_NODE:
+        case DOMNode::CDATA_SECTION_NODE:
+        case DOMNode::COMMENT_NODE:
+        case DOMNode::PROCESSING_INSTRUCTION_NODE:
+            if (isReadOnly())
+                throw DOMException(DOMException::NO_MODIFICATION_ALLOWED_ERR, 0, GetDOMNodeMemoryManager);
+
+            thisNode->setNodeValue(textContent);
+            break;
+
+        case DOMNode::DOCUMENT_NODE:
+        case DOMNode::DOCUMENT_TYPE_NODE:
+        case DOMNode::NOTATION_NODE:
+            break;
+
+        default:
+            throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0, GetDOMNodeMemoryManager);
+    }
 }
 
 
@@ -1068,7 +1054,7 @@ bool DOMNodeImpl::isDefaultNamespace(const XMLCh* namespaceURI) const{
 
         if (thisNode->hasAttributes()) {
             DOMElement *elem = (DOMElement *)thisNode;
-            DOMNode *attr = elem->getAttributeNodeNS(s_xmlnsURI, s_xmlns);
+            DOMNode *attr = elem->getAttributeNodeNS(XMLUni::fgXMLNSURIName, XMLUni::fgXMLNSString);
             if (attr != 0) {
                 const XMLCh *value = attr->getNodeValue();
                 return XMLString::equals(namespaceURI, value);
@@ -1109,8 +1095,8 @@ bool DOMNodeImpl::isDefaultNamespace(const XMLCh* namespaceURI) const{
     }
 }
 
-DOMNode*         DOMNodeImpl::getInterface(const XMLCh* feature)      {
-    throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0);
+DOMNode*         DOMNodeImpl::getInterface(const XMLCh*)      {
+    throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0, GetDOMNodeMemoryManager);
     return 0;
 }
 
@@ -1119,7 +1105,7 @@ DOMNode*         DOMNodeImpl::getInterface(const XMLCh* feature)      {
 void DOMNodeImpl::release()
 {
     // shouldn't reach here
-    throw DOMException(DOMException::INVALID_ACCESS_ERR,0);
+    throw DOMException(DOMException::INVALID_ACCESS_ERR,0, GetDOMNodeMemoryManager);
 }
 
 XERCES_CPP_NAMESPACE_END
