@@ -1,62 +1,49 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2002 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their featName, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2002-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: DOMWriterImpl.cpp,v 1.46 2003/11/24 19:52:22 neilg Exp $
+ * $Id: DOMWriterImpl.cpp,v 1.55 2004/09/08 13:55:52 peiyongz Exp $
  * $Log: DOMWriterImpl.cpp,v $
+ * Revision 1.55  2004/09/08 13:55:52  peiyongz
+ * Apache License Version 2.0
+ *
+ * Revision 1.54  2004/07/06 15:16:57  amassari
+ * Fix for jira#1238: DOMWriter was creating an XMLFormatter without propagating the memory manager
+ *
+ * Revision 1.53  2004/05/10 08:03:25  amassari
+ * Performance: push a new map on the namespace stack only when an element has a xmlns attribute
+ *
+ * Revision 1.52  2004/04/01 22:05:32  peiyongz
+ * invoke DOMException with Memory Manager
+ *
+ * Revision 1.51  2004/01/29 11:44:27  cargilld
+ * Code cleanup changes to get rid of various compiler diagnostic messages.
+ *
+ * Revision 1.50  2004/01/20 23:23:57  peiyongz
+ * patch to Bug#25751
+ *
+ * Revision 1.49  2004/01/13 20:47:42  knoaman
+ * Remove unnecessary local static data
+ *
+ * Revision 1.48  2004/01/13 16:34:20  cargilld
+ * Misc memory management changes.
+ *
+ * Revision 1.47  2003/12/17 00:18:33  cargilld
+ * Update to memory management so that the static memory manager (one used to call Initialize) is only for static data.
+ *
  * Revision 1.46  2003/11/24 19:52:22  neilg
  * fix a typo
  *
@@ -435,20 +422,8 @@ static const XMLByte  BOM_utf16le[] = {(XMLByte)0xFF, (XMLByte)0xFE, (XMLByte) 0
 static const XMLByte  BOM_ucs4be[]  = {(XMLByte)0x00, (XMLByte)0x00, (XMLByte)0xFE, (XMLByte)0xFF, (XMLByte) 0};
 static const XMLByte  BOM_ucs4le[]  = {(XMLByte)0xFF, (XMLByte)0xFE, (XMLByte)0x00, (XMLByte)0x00, (XMLByte) 0};
 
-static const XMLCh s_xmlnsURI[] = // "http://www.w3.org/2000/xmlns/"
-    {  chLatin_h, chLatin_t, chLatin_t, chLatin_p, chColon, chForwardSlash, chForwardSlash,
-       chLatin_w, chLatin_w, chLatin_w, chPeriod, chLatin_w, chDigit_3, chPeriod,
-       chLatin_o, chLatin_r, chLatin_g, chForwardSlash,
-       chDigit_2, chDigit_0, chDigit_0, chDigit_0, chForwardSlash,
-       chLatin_x, chLatin_m, chLatin_l, chLatin_n, chLatin_s, chForwardSlash, chNull};
-static const XMLCh s_xmlns[] = {chLatin_x, chLatin_m, chLatin_l, chLatin_n, chLatin_s, chNull};
-static const XMLCh s_xmlURI[] =    // "http://www.w3.org/XML/1998/namespace"
-    { chLatin_h, chLatin_t, chLatin_t, chLatin_p, chColon, chForwardSlash, chForwardSlash,
-      chLatin_w, chLatin_w, chLatin_w, chPeriod, chLatin_w, chDigit_3, chPeriod,
-      chLatin_o, chLatin_r, chLatin_g, chForwardSlash, chLatin_X, chLatin_M, chLatin_L, chForwardSlash,
-      chDigit_1, chDigit_9, chDigit_9, chDigit_8, chForwardSlash,
-      chLatin_n, chLatin_a, chLatin_m, chLatin_e, chLatin_s, chLatin_p, chLatin_a, chLatin_c, chLatin_e,
-      chNull};
+static bool lineFeedInTextNodePrinted = false;
+static int  lastWhiteSpaceInTextNode = 0;
 
 //
 // Notification of the error though error handler
@@ -537,11 +512,25 @@ void DOMWriterImpl::setFeature(const XMLCh* const featName
     if (!canSetFeature(featureId, state))
     {
         XMLCh  tmpbuf[256];
+        unsigned int strLen = XMLString::stringLen(gFeature) +
+                              XMLString::stringLen(featName) +
+                              XMLString::stringLen(gCantSet) +
+                              XMLString::stringLen(gFalse);
+
         XMLString::copyString(tmpbuf, gFeature);
-        XMLString::catString(tmpbuf, featName);
+        if (strLen < 256)
+        {
+            XMLString::catString(tmpbuf, featName);
+        }
+        else
+        {
+            // truncate the featurename to fit into the 256 buffer
+            XMLString::copyNString(tmpbuf+XMLString::stringLen(gFeature),
+                                   featName, 200);
+        }
         XMLString::catString(tmpbuf, gCantSet);
         XMLString::catString(tmpbuf, state? gTrue : gFalse);
-        throw DOMException(DOMException::NOT_SUPPORTED_ERR, tmpbuf);
+        throw DOMException(DOMException::NOT_SUPPORTED_ERR, tmpbuf, fMemoryManager);
     }
     else
         setFeature(featureId, state);
@@ -625,7 +614,8 @@ bool DOMWriterImpl::writeNode(XMLFormatTarget* const destination
                                      ,fDocumentVersion
                                      ,destination
                                      ,XMLFormatter::NoEscapes
-                                     ,XMLFormatter::UnRep_CharRef);
+                                     ,XMLFormatter::UnRep_CharRef
+                                     ,fMemoryManager);
     }
     catch (const TranscodingException& e)
     {
@@ -846,11 +836,45 @@ void DOMWriterImpl::processNode(const DOMNode* const nodeToWrite, int level)
             if (checkFilter(nodeToWrite) != DOMNodeFilter::FILTER_ACCEPT)
                 break;
 
-            // Pretty-print skips whitespace-only text nodes unless whitespace-in-element is set.
-            if (getFeature(FORMAT_PRETTY_PRINT_ID) && !getFeature(WHITESPACE_IN_ELEMENT_CONTENT_ID))
+            if (getFeature(FORMAT_PRETTY_PRINT_ID))
             {
+                lineFeedInTextNodePrinted = false;
+                lastWhiteSpaceInTextNode = 0;
+
                 if(XMLString::isAllWhiteSpace(nodeValue))
-                    break;
+                {
+                    // skips whitespace-only text nodes unless whitespace-in-element is set.
+                    if (!getFeature(WHITESPACE_IN_ELEMENT_CONTENT_ID))
+                    {
+                        break;
+                    }
+                    else        
+                    {
+                        //
+                        // we need to trace if newline(s) have been printed out
+                        // to avoid generate extra newline for pretty printing,
+                        // as well as the number of whitespaces after the last
+                        // newline character to do indentation properly.
+                        //
+                        int pos = XMLString::lastIndexOf(nodeValue, chLF);
+                        if (-1 != pos)
+                        {
+                            lineFeedInTextNodePrinted = true;
+                            lastWhiteSpaceInTextNode = lent - pos;
+                        }
+                        else
+                        {
+                            // for those platforms using chCR alone as
+                            // a newline character
+                            pos = XMLString::lastIndexOf(nodeValue, chCR);
+                            if (-1 != pos)
+                            {
+                                lineFeedInTextNodePrinted = true;
+                                lastWhiteSpaceInTextNode = lent - pos;
+                            }
+                        }
+                    }
+                }
             }
 
             setURCharRef();      // character data
@@ -942,18 +966,25 @@ void DOMWriterImpl::processNode(const DOMNode* const nodeToWrite, int level)
             if ( filterAction == DOMNodeFilter::FILTER_REJECT)
                 break;
 
-            if(level == 1)
+            if (!lineFeedInTextNodePrinted)
+            {
+                if(level == 1)
+                    printNewLine();
+
                 printNewLine();
+            }
+            else
+            {
+                lineFeedInTextNodePrinted = false;
+            }
 
-            printNewLine();
             printIndent(level);
 
             //track the line number the current node begins on
             int nodeLine = fCurrentLine;
 
             // add an entry in the namespace stack
-            RefHashTableOf<XMLCh>* namespaceMap=new (fMemoryManager) RefHashTableOf<XMLCh>(12, false, fMemoryManager);
-            fNamespaceStack->addElement(namespaceMap);
+            RefHashTableOf<XMLCh>* namespaceMap=NULL;
 
             if ( filterAction == DOMNodeFilter::FILTER_ACCEPT)
             {
@@ -994,9 +1025,14 @@ void DOMWriterImpl::processNode(const DOMNode* const nodeToWrite, int level)
                     }
                     if(!bPrefixDeclared)
                     {
+                        if(namespaceMap==NULL)
+                        {
+                            namespaceMap=new (fMemoryManager) RefHashTableOf<XMLCh>(12, false, fMemoryManager);
+                            fNamespaceStack->addElement(namespaceMap);
+                        }
                         namespaceMap->put((void*)prefix,(XMLCh*)nodeToWrite->getNamespaceURI());
                         *fFormatter  << XMLFormatter::NoEscapes
-                                     << chSpace << s_xmlns;
+                                     << chSpace << XMLUni::fgXMLNSString;
                         if(!XMLString::equals(prefix,XMLUni::fgZeroLenString))
                             *fFormatter  << chColon << prefix;
                         *fFormatter  << chEqual << chDoubleQuote
@@ -1044,16 +1080,21 @@ void DOMWriterImpl::processNode(const DOMNode* const nodeToWrite, int level)
                     const XMLCh* ns = attribute->getNamespaceURI();
                     if (ns != 0 )
                     {
-                        if(XMLString::equals(ns, s_xmlnsURI)) 
+                        if(XMLString::equals(ns, XMLUni::fgXMLNSURIName)) 
                         {
+                            if(namespaceMap==NULL)
+                            {
+                                namespaceMap=new (fMemoryManager) RefHashTableOf<XMLCh>(12, false, fMemoryManager);
+                                fNamespaceStack->addElement(namespaceMap);
+                            }
 			                const XMLCh* nsPrefix = attribute->getLocalName();
-                            if(XMLString::equals(attribute->getNodeName(),s_xmlns))
+                            if(XMLString::equals(attribute->getNodeName(),XMLUni::fgXMLNSString))
 								nsPrefix = XMLUni::fgZeroLenString;
 							if(namespaceMap->containsKey((void*)nsPrefix))
 								continue;
                             namespaceMap->put((void*)attribute->getLocalName(),(XMLCh*)attribute->getNodeValue());
                         }
-                        else if(!XMLString::equals(ns, s_xmlURI)) 
+                        else if(!XMLString::equals(ns, XMLUni::fgXMLURIName)) 
                         {
                             // check if the namespace for the current node is already defined
                             const XMLCh* prefix = attribute->getPrefix();
@@ -1072,9 +1113,14 @@ void DOMWriterImpl::processNode(const DOMNode* const nodeToWrite, int level)
                                 }
                                 if(!bPrefixDeclared)
                                 {
+                                    if(namespaceMap==NULL)
+                                    {
+                                        namespaceMap=new (fMemoryManager) RefHashTableOf<XMLCh>(12, false, fMemoryManager);
+                                        fNamespaceStack->addElement(namespaceMap);
+                                    }
                                     namespaceMap->put((void*)prefix,(XMLCh*)attribute->getNamespaceURI());
                                     *fFormatter  << XMLFormatter::NoEscapes
-                                                 << chSpace << s_xmlns << chColon << prefix
+                                                 << chSpace << XMLUni::fgXMLNSString << chColon << prefix
                                                  << chEqual << chDoubleQuote
                                                  << XMLFormatter::AttrEscapes
                                                  << attribute->getNamespaceURI()
@@ -1124,7 +1170,14 @@ void DOMWriterImpl::processNode(const DOMNode* const nodeToWrite, int level)
                     //this node then print a new line and indent
                     if(nodeLine != fCurrentLine)
                     {
-                        printNewLine();
+                        if (!lineFeedInTextNodePrinted)
+                        {
+                            printNewLine();
+                        }
+                        else
+                        {
+                            lineFeedInTextNodePrinted = false;
+                        }
 
                         if(nodeLine != fCurrentLine && level == 0)
                             printNewLine();
@@ -1159,7 +1212,8 @@ void DOMWriterImpl::processNode(const DOMNode* const nodeToWrite, int level)
             }
 
             // remove the namespace map at this level
-            fNamespaceStack->removeLastElement();
+            if(namespaceMap!=NULL)
+                fNamespaceStack->removeLastElement();
 
             break;
         }
@@ -1307,7 +1361,7 @@ void DOMWriterImpl::processNode(const DOMNode* const nodeToWrite, int level)
 
     case DOMNode::DOCUMENT_TYPE_NODE:  // Not to be shown to Filter
         {
-            const DOMDocumentType *doctype = (const DOMDocumentType *)nodeToWrite;;
+            const DOMDocumentType *doctype = (const DOMDocumentType *)nodeToWrite;
 
             fFormatter->setEscapeFlags(XMLFormatter::NoEscapes);
 
@@ -1411,7 +1465,7 @@ void DOMWriterImpl::processNode(const DOMNode* const nodeToWrite, int level)
 
 }
 
-bool DOMWriterImpl::customNodeSerialize(const DOMNode* const nodeToWrite, int level) {
+bool DOMWriterImpl::customNodeSerialize(const DOMNode* const, int) {
     return false;
 }
 
@@ -1440,7 +1494,7 @@ bool DOMWriterImpl::checkFeature(const XMLCh* const featName
     if (!featName || !*featName)
     {
         if (toThrow)
-            throw DOMException(DOMException::NOT_FOUND_ERR, 0);
+            throw DOMException(DOMException::NOT_FOUND_ERR, 0, fMemoryManager);
 
         return false;
     }
@@ -1473,7 +1527,7 @@ bool DOMWriterImpl::checkFeature(const XMLCh* const featName
     if (featureId == INVALID_FEATURE_ID)
     {
         if (toThrow)
-            throw DOMException(DOMException::NOT_FOUND_ERR, featName);
+            throw DOMException(DOMException::NOT_FOUND_ERR, featName, fMemoryManager);
 
         return false;
     }
@@ -1612,7 +1666,7 @@ void DOMWriterImpl::procUnrepCharInCdataSection(const XMLCh*   const nodeValue
     //  the chars done.
     //
     const XMLCh*    srcPtr = nodeValue;
-    const XMLCh*    endPtr = nodeValue +  XMLString::stringLen(nodeValue);;
+    const XMLCh*    endPtr = nodeValue +  XMLString::stringLen(nodeValue);
 
     // Set up the common part of the buffer that we build char refs into
     XMLCh tmpBuf[32];
@@ -1673,7 +1727,7 @@ void DOMWriterImpl::procUnrepCharInCdataSection(const XMLCh*   const nodeValue
             while (srcPtr < endPtr)
             {
                 // Build a char ref for the current char
-                XMLString::binToText(*srcPtr, &tmpBuf[3], 8, 16);
+                XMLString::binToText(*srcPtr, &tmpBuf[3], 8, 16, fMemoryManager);
                 const unsigned int bufLen = XMLString::stringLen(tmpBuf);
                 tmpBuf[bufLen] = chSemiColon;
                 tmpBuf[bufLen+1] = chNull;
@@ -1720,6 +1774,15 @@ void DOMWriterImpl::printIndent(int level) const
 {
     if (getFeature(FORMAT_PRETTY_PRINT_ID))
     {
+        if (lastWhiteSpaceInTextNode)
+        {
+            level -= lastWhiteSpaceInTextNode/2; // two chSpaces equals one indent level
+            lastWhiteSpaceInTextNode = 0;
+            // if lastWhiteSpaceInTextNode/2 is greater than level, then
+            // it means too many spaces have been written to the
+            // output stream and we can no longer indent properly
+        }
+
         for(int i = 0; i < level; i++)
             *fFormatter << chSpace << chSpace;
     }
