@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2003 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /**
- * $Id: XMLAttr.cpp,v 1.5 2003/05/18 14:02:04 knoaman Exp $
+ * $Id: XMLAttr.cpp,v 1.8 2004/09/08 13:55:58 peiyongz Exp $
  */
 
 
@@ -64,6 +24,7 @@
 // ---------------------------------------------------------------------------
 #include <xercesc/framework/XMLAttr.hpp>
 #include <xercesc/framework/MemoryManager.hpp>
+#include <xercesc/util/OutOfMemoryException.hpp>
 
 XERCES_CPP_NAMESPACE_BEGIN
 
@@ -78,6 +39,8 @@ XMLAttr::XMLAttr(MemoryManager* const manager) :
     , fValue(0)
     , fAttName(0)
     , fMemoryManager(manager)
+    , fDatatypeValidator(0)
+    , fIsSchemaValidated(false)
 {
     fAttName = new (fMemoryManager) QName(fMemoryManager);
 }
@@ -88,7 +51,9 @@ XMLAttr::XMLAttr(   const   unsigned int        uriId
                     , const XMLCh* const        attrValue
                     , const XMLAttDef::AttTypes type
                     , const bool                specified
-                    , MemoryManager* const      manager) :
+                    , MemoryManager* const      manager 
+                    , DatatypeValidator * datatypeValidator
+                    , const bool isSchema ):
 
       fSpecified(specified)
     , fType(type)
@@ -96,6 +61,8 @@ XMLAttr::XMLAttr(   const   unsigned int        uriId
     , fValue(0)
     , fAttName(0)
     , fMemoryManager(manager)
+    , fDatatypeValidator(datatypeValidator)
+    , fIsSchemaValidated(isSchema)
 {
     try
     {
@@ -106,6 +73,10 @@ XMLAttr::XMLAttr(   const   unsigned int        uriId
         fAttName = new (fMemoryManager) QName(attrPrefix, attrName, uriId, fMemoryManager);
         setValue(attrValue);
     }
+    catch(const OutOfMemoryException&)
+    {
+        throw;
+    }
     catch(...)
     {
         cleanUp();
@@ -117,7 +88,9 @@ XMLAttr::XMLAttr(   const   unsigned int        uriId
                     , const XMLCh* const        attrValue
                     , const XMLAttDef::AttTypes type
                     , const bool                specified
-                    , MemoryManager* const      manager) :
+                    , MemoryManager* const      manager 
+                    , DatatypeValidator * datatypeValidator
+                    , const bool isSchema ):
 
       fSpecified(specified)
     , fType(type)
@@ -125,6 +98,8 @@ XMLAttr::XMLAttr(   const   unsigned int        uriId
     , fValue(0)
     , fAttName(0)
     , fMemoryManager(manager)
+    , fDatatypeValidator(datatypeValidator)
+    , fIsSchemaValidated(isSchema)
 {
     try
     {
@@ -133,6 +108,10 @@ XMLAttr::XMLAttr(   const   unsigned int        uriId
         fAttName = new (fMemoryManager) QName(rawName, uriId, fMemoryManager);
         setValue(attrValue);
     }
+    catch(const OutOfMemoryException&)
+    {
+        throw;
+    }
     catch(...)
     {
         cleanUp();
