@@ -1,61 +1,33 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2003 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2003,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
  * $Log: XSModel.cpp,v $
+ * Revision 1.24  2004/09/08 13:56:08  peiyongz
+ * Apache License Version 2.0
+ *
+ * Revision 1.23  2004/06/09 17:01:48  gareth
+ * Fixed null pointer bug. Patch by John Snelson.
+ *
+ * Revision 1.22  2004/05/04 19:12:42  cargilld
+ * Enable IDs to work on all kinds of schema components
+ *
+ * Revision 1.21  2004/05/04 19:02:40  cargilld
+ * Enable IDs to work on all kinds of schema components
+ *
  * Revision 1.20  2004/02/05 18:09:53  cargilld
  * Fix a seg fault with PSVI and set basetype of anysimpletype to be anytype.
  *
@@ -149,8 +121,6 @@ XSModel::XSModel( XMLGrammarPool *grammarPool
     : fMemoryManager(manager)
     , fNamespaceStringList(0)
     , fXSNamespaceItemList(0)
-    , fElementDeclarationVector(0)
-    , fAttributeDeclarationVector(0)
     , fURIStringPool(0)
     , fXSAnnotationList(0)
     , fHashNamespace(0)
@@ -195,13 +165,12 @@ XSModel::XSModel( XMLGrammarPool *grammarPool
                 fComponentMap[i] = 0;
                 break;
         }
+        fIdVector[i] = new (fMemoryManager) RefVectorOf<XSObject>(30, false, fMemoryManager);
     }
 
     fNamespaceStringList        = new (manager) RefArrayVectorOf <XMLCh>(10, true, manager);
     fXSNamespaceItemList        = new (manager) RefVectorOf <XSNamespaceItem>(10, true, manager);
     fXSAnnotationList           = new (manager) RefVectorOf <XSAnnotation> (10, false, manager);
-    fElementDeclarationVector   = new (manager) RefVectorOf<XSElementDeclaration> (30, false, manager);
-    fAttributeDeclarationVector = new (manager) RefVectorOf<XSAttributeDeclaration>  (20, false, manager);
     fHashNamespace              = new (manager) RefHashTableOf<XSNamespaceItem> (11, false, manager);
 
     // Loop through all grammars in the grammar pool to create the XSNamespaceItem's
@@ -262,8 +231,6 @@ XSModel::XSModel( XSModel *baseModel
     : fMemoryManager(manager)
     , fNamespaceStringList(0)
     , fXSNamespaceItemList(0)
-    , fElementDeclarationVector(0)
-    , fAttributeDeclarationVector(0)
     , fURIStringPool(0)
     , fXSAnnotationList(0)
     , fHashNamespace(0)    
@@ -309,14 +276,13 @@ XSModel::XSModel( XSModel *baseModel
                 fComponentMap[i] = 0;
                 break;
         }
+        fIdVector[i] = new (fMemoryManager) RefVectorOf<XSObject>(30, false, fMemoryManager);
     }
 
     fNamespaceStringList        = new (manager) RefArrayVectorOf <XMLCh>(10, true, manager);
     fXSNamespaceItemList        = new (manager) RefVectorOf <XSNamespaceItem>(10, false, manager);
     fDeleteNamespace            = new (manager) RefVectorOf <XSNamespaceItem>(10, true, manager);
-    fXSAnnotationList           = new (manager) RefVectorOf <XSAnnotation> (10, false, manager);
-    fElementDeclarationVector   = new (manager) RefVectorOf<XSElementDeclaration> (30, false, manager);
-    fAttributeDeclarationVector = new (manager) RefVectorOf<XSAttributeDeclaration>  (20, false, manager);
+    fXSAnnotationList           = new (manager) RefVectorOf <XSAnnotation> (10, false, manager); 
     fHashNamespace              = new (manager) RefHashTableOf<XSNamespaceItem> (11, false, manager);
 
     if (fParent)
@@ -357,16 +323,12 @@ XSModel::XSModel( XSModel *baseModel
                     }
                 break;
             }
+            for (unsigned int j=0; j<fParent->fIdVector[i]->size(); j++)
+            {
+                fIdVector[i]->addElement(fParent->fIdVector[i]->elementAt(j));
+            }
         }
 
-        for (i=0; i<fParent->fElementDeclarationVector->size(); i++)
-        {
-            fElementDeclarationVector->addElement(fParent->fElementDeclarationVector->elementAt(i));
-        }
-        for (i=0; i<fParent->fAttributeDeclarationVector->size(); i++)
-        {
-            fAttributeDeclarationVector->addElement(fParent->fAttributeDeclarationVector->elementAt(i));
-        }
         for (i=0; i<fParent->fXSAnnotationList->size(); i++)
         {
             fXSAnnotationList->addElement(fParent->fXSAnnotationList->elementAt(i));
@@ -446,6 +408,7 @@ XSModel::~XSModel()
                 delete fComponentMap[i];
                 break;
         }
+        delete fIdVector[i];
     }
 
     delete fNamespaceStringList;
@@ -453,8 +416,6 @@ XSModel::~XSModel()
     delete fXSAnnotationList;
     delete fHashNamespace;
     delete fObjFactory;
-    delete fElementDeclarationVector;
-    delete fAttributeDeclarationVector;
 
     if (fDeleteNamespace)
         delete fDeleteNamespace;
@@ -466,6 +427,14 @@ XSModel::~XSModel()
 // ---------------------------------------------------------------------------
 //  XSModel: Helper methods
 // ---------------------------------------------------------------------------
+void XSModel::addComponentToIdVector(XSObject* const component,
+                                     int componentIndex)
+{
+    component->setId(fIdVector[componentIndex]->size());
+    fIdVector[componentIndex]->addElement(component);
+}
+
+
 void XSModel::addComponentToNamespace(XSNamespaceItem* const namespaceItem,
                                       XSObject* const component,
                                       int componentIndex,
@@ -542,21 +511,22 @@ XSModel::addS4SToXSModel(XSNamespaceItem* const namespaceItem,
 void XSModel::addGrammarToXSModel(XSNamespaceItem* namespaceItem)
 {
     // Loop through top-level attribute declarations in the grammar...
-    RefHashTableOfEnumerator<XMLAttDef> attrEnum = RefHashTableOfEnumerator<XMLAttDef> (namespaceItem->fGrammar->getAttributeDeclRegistry(), false, fMemoryManager);
-    while (attrEnum.hasMoreElements())
-    {
-        XSAttributeDeclaration* xsAttrDecl = fObjFactory->addOrFind
-        (
-            (SchemaAttDef*) &(attrEnum.nextElement()), this
-        );
+    RefHashTableOf<XMLAttDef>* attDeclRegistry = namespaceItem->fGrammar->getAttributeDeclRegistry();
+    if(attDeclRegistry) {
+        RefHashTableOfEnumerator<XMLAttDef> attrEnum = RefHashTableOfEnumerator<XMLAttDef> (attDeclRegistry, false, fMemoryManager);
+        while (attrEnum.hasMoreElements())
+        {
+            XSAttributeDeclaration* xsAttrDecl = fObjFactory->addOrFind
+            (
+                (SchemaAttDef*) &(attrEnum.nextElement()), this
+            );
 
-        xsAttrDecl->setId(fAttributeDeclarationVector->size());
-        fAttributeDeclarationVector->addElement(xsAttrDecl);
-        addComponentToNamespace
-        (
-            namespaceItem, xsAttrDecl, XSConstants::ATTRIBUTE_DECLARATION - 1
-        );
-    } // end of attribute loop
+            addComponentToNamespace
+            (
+                namespaceItem, xsAttrDecl, XSConstants::ATTRIBUTE_DECLARATION - 1
+            );
+        } // end of attribute loop
+    }
 
     // Loop through top-level elements in the grammar...
     RefHash3KeysIdPoolEnumerator<SchemaElementDecl> elemEnum = namespaceItem->fGrammar->getElemEnumerator();    
@@ -570,8 +540,6 @@ void XSModel::addGrammarToXSModel(XSNamespaceItem* namespaceItem)
                 &curElem, this
             );
 
-            xsElemDecl->setId(fElementDeclarationVector->size());
-            fElementDeclarationVector->addElement(xsElemDecl);
             addComponentToNamespace
             (
                 namespaceItem, xsElemDecl, XSConstants::ELEMENT_DECLARATION -1
@@ -600,50 +568,59 @@ void XSModel::addGrammarToXSModel(XSNamespaceItem* namespaceItem)
     }
 
     // Loop through top-level COMPLEX type definitions in the grammar...
-    RefHashTableOfEnumerator<ComplexTypeInfo> complexEnum = RefHashTableOfEnumerator<ComplexTypeInfo> (namespaceItem->fGrammar->getComplexTypeRegistry(), false, fMemoryManager);
-    while (complexEnum.hasMoreElements())
-    {
-        ComplexTypeInfo&  curComplex = complexEnum.nextElement();
-        if (!curComplex.getAnonymous())
+    RefHashTableOf<ComplexTypeInfo>* complexTypeRegistry = namespaceItem->fGrammar->getComplexTypeRegistry();
+    if(complexTypeRegistry) {
+        RefHashTableOfEnumerator<ComplexTypeInfo> complexEnum = RefHashTableOfEnumerator<ComplexTypeInfo> (complexTypeRegistry, false, fMemoryManager);
+        while (complexEnum.hasMoreElements())
+        {
+            ComplexTypeInfo&  curComplex = complexEnum.nextElement();
+            if (!curComplex.getAnonymous())
+            {
+                addComponentToNamespace
+                (
+                    namespaceItem
+                    , fObjFactory->addOrFind(&curComplex, this)
+                    , XSConstants::TYPE_DEFINITION - 1
+                );
+            }
+        }  // end of type definition loop
+    }
+
+    // Loop through top-level attribute group definitions in the grammar...
+    RefHashTableOf<XercesAttGroupInfo>* attGroupInfoRegistry = namespaceItem->fGrammar->getAttGroupInfoRegistry();
+    if(attGroupInfoRegistry) {
+        RefHashTableOfEnumerator<XercesAttGroupInfo> attrGroupEnum = RefHashTableOfEnumerator<XercesAttGroupInfo> (attGroupInfoRegistry, false, fMemoryManager);
+        while (attrGroupEnum.hasMoreElements())
         {
             addComponentToNamespace
             (
                 namespaceItem
-                , fObjFactory->addOrFind(&curComplex, this)
-                , XSConstants::TYPE_DEFINITION - 1
+                , fObjFactory->createXSAttGroupDefinition
+                  (
+                      &(attrGroupEnum.nextElement()), this
+                  )
+                , XSConstants::ATTRIBUTE_GROUP_DEFINITION - 1
             );
-        }
-    }  // end of type definition loop
-
-    // Loop through top-level attribute group definitions in the grammar...
-    RefHashTableOfEnumerator<XercesAttGroupInfo> attrGroupEnum = RefHashTableOfEnumerator<XercesAttGroupInfo> (namespaceItem->fGrammar->getAttGroupInfoRegistry(), false, fMemoryManager);
-    while (attrGroupEnum.hasMoreElements())
-    {
-        addComponentToNamespace
-        (
-            namespaceItem
-            , fObjFactory->createXSAttGroupDefinition
-              (
-                  &(attrGroupEnum.nextElement()), this
-              )
-            , XSConstants::ATTRIBUTE_GROUP_DEFINITION - 1
-        );
-    } // end of attribute group loop
+        } // end of attribute group loop
+    }
 
     // Loop through top-level model group definitions in the grammar...
-    RefHashTableOfEnumerator<XercesGroupInfo> modelGroupEnum = RefHashTableOfEnumerator<XercesGroupInfo> (namespaceItem->fGrammar->getGroupInfoRegistry(), false, fMemoryManager);
-    while (modelGroupEnum.hasMoreElements())
-    {
-        addComponentToNamespace
-        (
-            namespaceItem
-            , fObjFactory->createXSModelGroupDefinition
-              (
-                  &(modelGroupEnum.nextElement()), this
-              )
-            , XSConstants::MODEL_GROUP_DEFINITION - 1
-        );
-    } // end of model group loop
+    RefHashTableOf<XercesGroupInfo>* groupInfoRegistry = namespaceItem->fGrammar->getGroupInfoRegistry();
+    if(groupInfoRegistry) {
+        RefHashTableOfEnumerator<XercesGroupInfo> modelGroupEnum = RefHashTableOfEnumerator<XercesGroupInfo> (groupInfoRegistry, false, fMemoryManager);
+        while (modelGroupEnum.hasMoreElements())
+        {
+            addComponentToNamespace
+            (
+                namespaceItem
+                , fObjFactory->createXSModelGroupDefinition
+                  (
+                      &(modelGroupEnum.nextElement()), this
+                  )
+                , XSConstants::MODEL_GROUP_DEFINITION - 1
+            );
+        } // end of model group loop
+    }
 
     // Loop through notations in the grammar...    
     NameIdPoolEnumerator<XMLNotationDecl> notationEnum = namespaceItem->fGrammar->getNotationEnumerator();
@@ -665,6 +642,7 @@ void XSModel::addGrammarToXSModel(XSNamespaceItem* namespaceItem)
     {
         fXSAnnotationList->addElement(annot);
         namespaceItem->fXSAnnotationList->addElement(annot);
+        addComponentToIdVector(annot, XSConstants::ANNOTATION -1);
         annot = annot->getNext();
     } // end of annotation loop
 }
@@ -870,17 +848,9 @@ XSNotationDeclaration *XSModel::getNotationDeclaration(const XMLCh *name
 XSObject *XSModel::getXSObjectById(unsigned int  compId
             , XSConstants::COMPONENT_TYPE compType)
 {
-    // only elements & attributes have id's
-    switch(compType) {
-        case XSConstants::ELEMENT_DECLARATION:
-            if (compId < fElementDeclarationVector->size())
-                return fElementDeclarationVector->elementAt(compId);
-            break;    
-        case XSConstants::ATTRIBUTE_DECLARATION:
-            if (compId < fAttributeDeclarationVector->size())
-                return fAttributeDeclarationVector->elementAt(compId);
-            break;
-    }
+    if (compId < fIdVector[compType -1]->size())
+        return fIdVector[compType -1]->elementAt(compId);
+
     return 0;
 }
 
