@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2000 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2000,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: ReaderMgr.cpp,v 1.15 2003/05/18 14:02:04 knoaman Exp $
+ * $Id: ReaderMgr.cpp,v 1.28 2004/09/08 13:56:13 peiyongz Exp $
  */
 
 // ---------------------------------------------------------------------------
@@ -69,6 +29,7 @@
 #include <xercesc/util/XMLURL.hpp>
 #include <xercesc/util/XMLUniDefs.hpp>
 #include <xercesc/util/XMLUni.hpp>
+#include <xercesc/util/XMLUri.hpp>
 #include <xercesc/sax/InputSource.hpp>
 #include <xercesc/framework/LocalFileInputSource.hpp>
 #include <xercesc/framework/URLInputSource.hpp>
@@ -78,6 +39,8 @@
 #include <xercesc/framework/XMLEntityHandler.hpp>
 #include <xercesc/internal/EndOfEntityException.hpp>
 #include <xercesc/internal/ReaderMgr.hpp>
+#include <xercesc/util/OutOfMemoryException.hpp>
+#include <xercesc/util/XMLResourceIdentifier.hpp>
 
 XERCES_CPP_NAMESPACE_BEGIN
 
@@ -283,7 +246,7 @@ bool ReaderMgr::skipIfQuote(XMLCh& chGotten)
 }
 
 
-bool ReaderMgr::skipPastSpaces()
+bool ReaderMgr::skipPastSpaces(bool inDecl)
 {
     bool skippedSomething = false;
     bool tmpFlag;
@@ -294,7 +257,7 @@ bool ReaderMgr::skipPastSpaces()
         //  it hit a non-space, break out. Else we have to pop another entity
         //  and keep going.
         //
-        if (fCurReader->skipSpaces(tmpFlag))
+        if (fCurReader->skipSpaces(tmpFlag, inDecl))
             break;
 
         if (tmpFlag)
@@ -307,7 +270,6 @@ bool ReaderMgr::skipPastSpaces()
     return (tmpFlag || skippedSomething);
 }
 
-
 void ReaderMgr::skipQuotedString(const XMLCh quoteCh)
 {
     XMLCh nextCh;
@@ -401,7 +363,7 @@ void ReaderMgr::cleanStackBackTo(const unsigned int readerNum)
             break;
 
         if (fReaderStack->empty())
-            ThrowXML(RuntimeException, XMLExcepts::RdrMgr_ReaderIdNotFound);
+            ThrowXMLwithMemMgr(RuntimeException, XMLExcepts::RdrMgr_ReaderIdNotFound, fMemoryManager);
 
         delete fCurReader;
         fCurReader = fReaderStack->pop();
@@ -411,7 +373,7 @@ void ReaderMgr::cleanStackBackTo(const unsigned int readerNum)
 
 
 XMLReader* ReaderMgr::createReader( const   InputSource&        src
-                                    , const bool                xmlDecl
+                                    , const bool                
                                     , const XMLReader::RefFrom  refFrom
                                     , const XMLReader::Types    type
                                     , const XMLReader::Sources  source
@@ -474,7 +436,10 @@ XMLReader* ReaderMgr::createReader( const   InputSource&        src
                 );
         }
     }
-
+    catch(const OutOfMemoryException&)
+    {
+        throw;
+    }
     catch (...) //NetAccessorException&
     {
         delete newStream;
@@ -502,6 +467,11 @@ XMLReader* ReaderMgr::createReader( const   XMLCh* const        sysId
                                     ,       InputSource*&       srcToFill
                                     , const bool                calcSrcOfs)
 {
+    //Normalize sysId 
+    XMLBuffer normalizedSysId(1023, fMemoryManager);
+    XMLString::removeChar(sysId, 0xFFFF, normalizedSysId);
+    const XMLCh* normalizedURI = normalizedSysId.getRawBuffer();
+
     // Create a buffer for expanding the system id
     XMLBuffer expSysId(1023, fMemoryManager);
 
@@ -511,23 +481,23 @@ XMLReader* ReaderMgr::createReader( const   XMLCh* const        sysId
     //
     if (fEntityHandler)
     {
-        if (!fEntityHandler->expandSystemId(sysId, expSysId))
-            expSysId.set(sysId);
+        if (!fEntityHandler->expandSystemId(normalizedURI, expSysId))
+            expSysId.set(normalizedURI);
     }
      else
     {
-        expSysId.set(sysId);
+        expSysId.set(normalizedURI);
     }
 
     // Call the entity resolver interface to get an input source
     srcToFill = 0;
     if (fEntityHandler)
     {
-        srcToFill = fEntityHandler->resolveEntity
-        (
-            pubId
-            , expSysId.getRawBuffer()
-        );
+        LastExtEntityInfo lastInfo;
+        getLastExtEntityInfo(lastInfo);
+        XMLResourceIdentifier resourceIdentifier(XMLResourceIdentifier::ExternalEntity,
+                            expSysId.getRawBuffer(), XMLUni::fgZeroLenString, pubId, lastInfo.systemId);
+        srcToFill = fEntityHandler->resolveEntity(&resourceIdentifier);
     }
 
     //
@@ -539,20 +509,25 @@ XMLReader* ReaderMgr::createReader( const   XMLCh* const        sysId
         LastExtEntityInfo lastInfo;
         getLastExtEntityInfo(lastInfo);
 
+// Keep this #if 0 block as it was exposing a threading problem on AIX.
+// Got rid of the problem by changing XMLURL to not throw malformedurl
+// exceptions.        
+#if 0
         try
         {
-            XMLURL urlTmp(lastInfo.systemId, expSysId.getRawBuffer());
+            XMLURL urlTmp(lastInfo.systemId, expSysId.getRawBuffer(), fMemoryManager);
             if (urlTmp.isRelative())
             {
-                ThrowXML
+                ThrowXMLwithMemMgr
                 (
                     MalformedURLException
                     , XMLExcepts::URL_NoProtocolPresent
+                    , fMemoryManager
                 );
             }
             else {
                 if (fStandardUriConformant && urlTmp.hasInvalidChar())
-                    ThrowXML(MalformedURLException, XMLExcepts::URL_MalformedURL);
+                    ThrowXMLwithMemMgr(MalformedURLException, XMLExcepts::URL_MalformedURL, fMemoryManager);
                 srcToFill = new (fMemoryManager) URLInputSource(urlTmp, fMemoryManager);
             }
         }
@@ -570,6 +545,33 @@ XMLReader* ReaderMgr::createReader( const   XMLCh* const        sysId
             else
                 throw e;
         }
+#else
+        XMLURL urlTmp(fMemoryManager);
+        if ((!urlTmp.setURL(lastInfo.systemId, expSysId.getRawBuffer(), urlTmp)) ||
+            (urlTmp.isRelative()))
+        {
+            if (!fStandardUriConformant)
+            {
+                XMLBuffer resolvedSysId(1023, fMemoryManager);
+                XMLUri::normalizeURI(expSysId.getRawBuffer(), resolvedSysId);
+
+                srcToFill = new (fMemoryManager) LocalFileInputSource
+                (
+                    lastInfo.systemId
+                    , resolvedSysId.getRawBuffer()
+                    , fMemoryManager
+                );
+            }
+            else
+                ThrowXMLwithMemMgr(MalformedURLException, XMLExcepts::URL_MalformedURL, fMemoryManager);            
+        }
+        else
+        {
+            if (fStandardUriConformant && urlTmp.hasInvalidChar())
+                ThrowXMLwithMemMgr(MalformedURLException, XMLExcepts::URL_MalformedURL, fMemoryManager);
+            srcToFill = new (fMemoryManager) URLInputSource(urlTmp, fMemoryManager);
+        }        
+#endif
     }
 
     // Put a janitor on the input source
@@ -612,6 +614,11 @@ XMLReader* ReaderMgr::createReader( const   XMLCh* const        baseURI
                                     ,       InputSource*&       srcToFill
                                     , const bool                calcSrcOfs)
 {
+    //Normalize sysId 
+    XMLBuffer normalizedSysId(1023, fMemoryManager);
+    XMLString::removeChar(sysId, 0xFFFF, normalizedSysId);
+    const XMLCh* normalizedURI = normalizedSysId.getRawBuffer();
+
     // Create a buffer for expanding the system id
     XMLBuffer expSysId(1023, fMemoryManager);
 
@@ -621,23 +628,21 @@ XMLReader* ReaderMgr::createReader( const   XMLCh* const        baseURI
     //
     if (fEntityHandler)
     {
-        if (!fEntityHandler->expandSystemId(sysId, expSysId))
-            expSysId.set(sysId);
+        if (!fEntityHandler->expandSystemId(normalizedURI, expSysId))
+            expSysId.set(normalizedURI);
     }
      else
     {
-        expSysId.set(sysId);
+        expSysId.set(normalizedURI);
     }
 
     // Call the entity resolver interface to get an input source
     srcToFill = 0;
     if (fEntityHandler)
     {
-        srcToFill = fEntityHandler->resolveEntity
-        (
-            pubId
-            , expSysId.getRawBuffer()
-        );
+        XMLResourceIdentifier resourceIdentifier(XMLResourceIdentifier::ExternalEntity,
+                            expSysId.getRawBuffer(), XMLUni::fgZeroLenString, pubId, baseURI);
+        srcToFill = fEntityHandler->resolveEntity(&resourceIdentifier);
     }
 
     //
@@ -647,40 +652,39 @@ XMLReader* ReaderMgr::createReader( const   XMLCh* const        baseURI
     if (!srcToFill)
     {
         LastExtEntityInfo lastInfo;
-        getLastExtEntityInfo(lastInfo);
 
-        try
+        const XMLCh* baseuri=baseURI;
+        if(!baseuri || !*baseuri)
         {
-            XMLURL urlTmp((!baseURI || !*baseURI) ? lastInfo.systemId : baseURI, expSysId.getRawBuffer());
-
-            if (urlTmp.isRelative())
-            {
-                ThrowXML
-                (
-                    MalformedURLException
-                    , XMLExcepts::URL_NoProtocolPresent
-                );
-            }
-            else {
-                if (fStandardUriConformant && urlTmp.hasInvalidChar())
-                    ThrowXML(MalformedURLException, XMLExcepts::URL_MalformedURL);
-                srcToFill = new (fMemoryManager) URLInputSource(urlTmp, fMemoryManager);
-            }
+            getLastExtEntityInfo(lastInfo);
+            baseuri = lastInfo.systemId;
         }
 
-        catch(const MalformedURLException& e)
+        XMLURL urlTmp(fMemoryManager);
+        if ((!urlTmp.setURL(baseuri, expSysId.getRawBuffer(), urlTmp)) ||
+            (urlTmp.isRelative()))
         {
-            // Its not a URL, so lets assume its a local file name if non-standard uri is allowed
             if (!fStandardUriConformant)
+            {
+                XMLBuffer resolvedSysId(1023, fMemoryManager);
+                XMLUri::normalizeURI(expSysId.getRawBuffer(), resolvedSysId);
+
                 srcToFill = new (fMemoryManager) LocalFileInputSource
                 (
-                    lastInfo.systemId
-                    , expSysId.getRawBuffer()
+                    baseuri
+                    , resolvedSysId.getRawBuffer()
                     , fMemoryManager
                 );
+            }
             else
-                throw e;
+                ThrowXMLwithMemMgr(MalformedURLException, XMLExcepts::URL_MalformedURL, fMemoryManager);            
         }
+        else
+        {
+            if (fStandardUriConformant && urlTmp.hasInvalidChar())
+                ThrowXMLwithMemMgr(MalformedURLException, XMLExcepts::URL_MalformedURL, fMemoryManager);
+            srcToFill = new (fMemoryManager) URLInputSource(urlTmp, fMemoryManager);
+        }        
     }
 
     // Put a janitor on the input source
@@ -789,17 +793,6 @@ XMLEntityDecl* ReaderMgr::getCurrentEntity()
 }
 
 
-const XMLReader* ReaderMgr::getCurrentReader() const
-{
-    return fCurReader;
-}
-
-
-XMLReader* ReaderMgr::getCurrentReader()
-{
-    return fCurReader;
-}
-
 unsigned int ReaderMgr::getReaderDepth() const
 {
     // If the stack doesn't exist, its obviously zero
