@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2002,2003 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2002,2003-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
-  * $Id: WFXMLScanner.cpp,v 1.20 2004/02/11 12:42:50 cargilld Exp $
+  * $Id: WFXMLScanner.cpp,v 1.25 2004/09/28 21:27:38 peiyongz Exp $
  */
 
 
@@ -1496,26 +1456,53 @@ bool WFXMLScanner::scanStartTagNS(bool& gotData)
         );
     }
 
-    // check for duplicate namespace attributes:
-    // by checking for qualified names with the same local part and with prefixes 
-    // which have been bound to namespace names that are identical. 
-    XMLAttr* loopAttr;
-    XMLAttr* curAtt;
-    for (unsigned int attrIndex=0; attrIndex < attCount-1; attrIndex++) {
-        loopAttr = fAttrList->elementAt(attrIndex);
-        for (unsigned int curAttrIndex = attrIndex+1; curAttrIndex < attCount; curAttrIndex++) {
-            curAtt = fAttrList->elementAt(curAttrIndex);
-            if (curAtt->getURIId() == loopAttr->getURIId() &&
-                XMLString::equals(curAtt->getName(), loopAttr->getName())) {
-                emitError
-                ( 
-                    XMLErrs::AttrAlreadyUsedInSTag
-                        , curAtt->getName()
-                        , elemDecl->getFullName()
-                );
+    if(attCount) {
+
+        //
+        // Decide if to use hash table to do duplicate checking
+        //
+        bool toUseHashTable = false;
+        setAttrDupChkRegistry(attCount, toUseHashTable);
+
+        // check for duplicate namespace attributes:
+        // by checking for qualified names with the same local part and with prefixes 
+        // which have been bound to namespace names that are identical. 
+        XMLAttr* loopAttr;
+        XMLAttr* curAtt;
+        for (unsigned int attrIndex=0; attrIndex < attCount-1; attrIndex++) {
+            loopAttr = fAttrList->elementAt(attrIndex);
+
+            if (!toUseHashTable)
+            {
+                for (unsigned int curAttrIndex = attrIndex+1; curAttrIndex < attCount; curAttrIndex++) {
+                    curAtt = fAttrList->elementAt(curAttrIndex);
+                    if (curAtt->getURIId() == loopAttr->getURIId() &&
+                        XMLString::equals(curAtt->getName(), loopAttr->getName())) {
+                        emitError
+                            ( 
+                            XMLErrs::AttrAlreadyUsedInSTag
+                            , curAtt->getName()
+                            , elemDecl->getFullName()
+                            );
+                    }
+                }
             }
-        }
-    }  
+            else 
+            {
+                if (fAttrDupChkRegistry->containsKey((void*)loopAttr->getName(), loopAttr->getURIId()))
+                {
+                    emitError
+                    ( 
+                    XMLErrs::AttrAlreadyUsedInSTag
+                    , loopAttr->getName()
+                    , elemDecl->getFullName()
+                    );
+                }
+
+                fAttrDupChkRegistry->put((void*)loopAttr->getName(), loopAttr->getURIId(), loopAttr);
+            }
+        }  
+    }
 
     // Resolve the qualified name to a URI.
     unsigned int uriId = resolvePrefix
@@ -1750,7 +1737,10 @@ bool WFXMLScanner::scanAttValue(const XMLCh* const attrName
             toFill.append(nextCh);
 
             if (secondCh)
-               toFill.append(secondCh);
+            {
+                toFill.append(secondCh);
+                secondCh=0;
+            }
         }
     }
     catch(const EndOfEntityException&)
@@ -2041,7 +2031,10 @@ void WFXMLScanner::scanCharData(XMLBuffer& toUse)
                 toUse.append(nextCh);
 
                 if (secondCh)
+                {
                     toUse.append(secondCh);
+                    secondCh=0;
+                }
             }
         }
         catch(const EndOfEntityException& toCatch)
@@ -2060,6 +2053,10 @@ void WFXMLScanner::scanCharData(XMLBuffer& toUse)
     sendCharData(toUse);
 }
 
+InputSource* WFXMLScanner::resolveSystemId(const XMLCh* const)
+{
+    return 0;
+}
 
 //  This method will scan a general/character entity ref. It will either
 //  expand a char ref and return it directly, or push a reader for a general
