@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2003 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: XMLReader.cpp,v 1.19 2004/01/29 11:46:30 cargilld Exp $
+ * $Id: XMLReader.cpp,v 1.25 2004/09/29 00:24:01 knoaman Exp $
  */
 
 // ---------------------------------------------------------------------------
@@ -66,13 +26,11 @@
 #include <xercesc/util/BinInputStream.hpp>
 #include <xercesc/util/PlatformUtils.hpp>
 #include <xercesc/util/RuntimeException.hpp>
-#include <xercesc/util/TranscodingException.hpp>
 #include <xercesc/util/TransService.hpp>
 #include <xercesc/util/XMLEBCDICTranscoder.hpp>
 #include <xercesc/util/XMLString.hpp>
 #include <xercesc/util/Janitor.hpp>
 
-
 XERCES_CPP_NAMESPACE_BEGIN
 
 // ---------------------------------------------------------------------------
@@ -321,6 +279,7 @@ XMLReader::XMLReader(const  XMLCh* const          pubId
     {
         // This represents no data from the source
         fCharSizeBuf[fCharsAvail] = 0;
+        fCharOfsBuf[fCharsAvail] = 0;
         fCharBuf[fCharsAvail++] = chSpace;
     }
 }
@@ -416,6 +375,7 @@ XMLReader::XMLReader(const  XMLCh* const          pubId
     {
         // This represents no data from the source
         fCharSizeBuf[fCharsAvail] = 0;
+        fCharOfsBuf[fCharsAvail] = 0;
         fCharBuf[fCharsAvail++] = chSpace;
     }
 }
@@ -443,11 +403,15 @@ unsigned int XMLReader::getSrcOffset() const
     //  Take the current source offset and add in the sizes that we've
     //  eaten from the source so far.
     //
-    unsigned int offset = fSrcOfsBase;
-    for (unsigned int index = 0; index < fCharIndex; index++)
-        offset += fCharSizeBuf[index];
+    if( fCharIndex == 0 ) {
+        return fSrcOfsBase;
+    }
 
-    return offset;
+    if( fCharIndex < fCharsAvail ) {
+        return (fSrcOfsBase + fCharOfsBuf[fCharIndex]);
+    }
+
+    return (fSrcOfsBase + fCharOfsBuf[fCharIndex-1] + fCharSizeBuf[fCharIndex-1]);
 }
 
 
@@ -578,6 +542,17 @@ bool XMLReader::refreshCharBuffer()
                     fCharIndex++;
                 }
             }
+            // If there's a utf-8 BOM  (0xEF 0xBB 0xBF), skip past it.
+            else {
+                const char* asChars = (const char*)fRawByteBuf;
+                if ((fRawBytesAvail > XMLRecognizer::fgUTF8BOMLen )&&
+                    (XMLString::compareNString(  asChars
+                    , XMLRecognizer::fgUTF8BOM
+                    , XMLRecognizer::fgUTF8BOMLen) == 0) && !startInd)
+                {
+                    fCharIndex += XMLRecognizer::fgUTF8BOMLen;
+                }
+            }
         }
     }
 
@@ -589,6 +564,15 @@ bool XMLReader::refreshCharBuffer()
     if (!fCharsAvail)
         fNoMore = true;
 
+    //  Calculate fCharOfsBuf using the elements from fCharBufSize
+    if (fCalculateSrcOfs)
+    {
+        fCharOfsBuf[0] = 0;
+        for (unsigned int index = 1; index < fCharsAvail; ++index) {
+            fCharOfsBuf[index] = fCharOfsBuf[index-1]+fCharSizeBuf[index-1];
+        }
+    }
+
     return (fCharsAvail != 0);
 }
 
@@ -695,42 +679,7 @@ bool XMLReader::getSpaces(XMLBuffer& toFill)
                 // Eat this char
                 fCharIndex++;
 
-                //
-                //  Ok, we've got some whitespace here. So we have to store
-                //  it. But we have to normalize it and update the line and
-                //  column info along the way.
-                //
-                if (curCh == chCR)
-                {
-                    fCurCol = 1;
-                    fCurLine++;
-
-                    //
-                    //  If not already internalized, then convert it to an
-                    //  LF and eat any following LF.
-                    //
-                    if (fSource == Source_External)
-                    {
-                        if ((fCharIndex < fCharsAvail) || refreshCharBuffer())
-                        {
-                            if (fCharBuf[fCharIndex] == chLF
-                                || ((fCharBuf[fCharIndex] == chNEL) && fNEL))
-                                fCharIndex++;
-                        }
-                        curCh = chLF;
-                    }
-                }
-                 else if (curCh == chLF
-                          || ((curCh == chNEL || curCh == chLineSeparator) && fNEL))
-                {
-                    curCh = chLF;
-                    fCurCol = 1;
-                    fCurLine++;
-                }
-                 else
-                {
-                    fCurCol++;
-                }
+                handleEOL(curCh, false);
 
                 // Ok we can add this guy to our buffer
                 toFill.append(curCh);
@@ -773,42 +722,7 @@ bool XMLReader::getUpToCharOrWS(XMLBuffer& toFill, const XMLCh toCheck)
                 // Eat this char
                 fCharIndex++;
 
-                //
-                //  Ok, we've got some whitespace here. So we have to store
-                //  it. But we have to normalize it and update the line and
-                //  column info along the way.
-                //
-                if (curCh == chCR)
-                {
-                    fCurCol = 1;
-                    fCurLine++;
-
-                    //
-                    //  If not already internalized, then convert it to an
-                    //  LF and eat any following LF.
-                    //
-                    if (fSource == Source_External)
-                    {
-                        if ((fCharIndex < fCharsAvail) || refreshCharBuffer())
-                        {
-                            if (fCharBuf[fCharIndex] == chLF
-                                || ((fCharBuf[fCharIndex] == chNEL) && fNEL))
-                                fCharIndex++;
-                        }
-                        curCh = chLF;
-                    }
-                }
-                 else if (curCh == chLF
-                          || ((curCh == chNEL || curCh == chLineSeparator) && fNEL))
-                {
-                    curCh = chLF;
-                    fCurCol = 1;
-                    fCurLine++;
-                }
-                 else
-                {
-                    fCurCol++;
-                }
+                handleEOL(curCh, false);
 
                 // Add it to our buffer
                 toFill.append(curCh);
@@ -853,7 +767,7 @@ bool XMLReader::skipIfQuote(XMLCh& chGotten)
 }
 
 
-bool XMLReader::skipSpaces(bool& skippedSomething)
+bool XMLReader::skipSpaces(bool& skippedSomething, bool inDecl)
 {
     // Remember the current line and column
     XMLSSize_t    orgLine = fCurLine;
@@ -874,36 +788,8 @@ bool XMLReader::skipSpaces(bool& skippedSomething)
                 // Get the current char out of the buffer and eat it
                 XMLCh curCh = fCharBuf[fCharIndex++];
 
-                //  Ok, we've got some whitespace here. So we have to store
-                //  it. But we have to normalize it and update the line and
-                //  column info along the way.
-                if (curCh == chCR)
-                {
-                    fCurCol = 1;
-                    fCurLine++;
+                handleEOL(curCh, inDecl);
 
-                    //  If not already internalized, then convert it to an
-                    //  LF and eat any following LF.
-                    if (fSource == Source_External)
-                    {
-                        if ((fCharIndex < fCharsAvail) || refreshCharBuffer())
-                        {
-                            if (fCharBuf[fCharIndex] == chLF
-                                || ((fCharBuf[fCharIndex] == chNEL) && fNEL))
-                                fCharIndex++;
-                        }
-                    }
-                }
-                else if (curCh == chLF
-                         || ((curCh == chNEL || curCh == chLineSeparator) && fNEL))
-                {
-                    fCurCol = 1;
-                    fCurLine++;
-                }
-                else
-                {
-                    fCurCol++;
-                }
             }
             else
             {
@@ -924,7 +810,6 @@ bool XMLReader::skipSpaces(bool& skippedSomething)
     return false;
 }
 
-
 bool XMLReader::skippedChar(const XMLCh toSkip)
 {
     //
@@ -973,31 +858,8 @@ bool XMLReader::skippedSpace()
         // Eat the character
         fCharIndex++;
 
-        if (curCh == chCR)
-        {
-            fCurLine++;
-            fCurCol = 1;
+        handleEOL((XMLCh&)curCh, false);
 
-            if (fSource == Source_External)
-            {
-                if ((fCharIndex < fCharsAvail) || refreshCharBuffer())
-                {
-                    if (fCharBuf[fCharIndex] == chLF
-                        || ((fCharBuf[fCharIndex] == chNEL) && fNEL))
-                        fCharIndex++;
-                }
-            }
-        }
-         else if (curCh == chLF
-                  || ((curCh == chNEL || curCh == chLineSeparator) && fNEL))
-        {
-            fCurLine++;
-            fCurCol = 1;
-        }
-         else
-        {
-            fCurCol++;
-        }
         return true;
     }
     return false;
@@ -1427,11 +1289,13 @@ void XMLReader::doInitDecode()
             if (fRawBytesAvail < 2)
                 break;
 
+            unsigned int postBOMIndex = 0;
             const UTF16Ch* asUTF16 = (const UTF16Ch*)&fRawByteBuf[fRawBufIndex];
             if ((*asUTF16 == chUnicodeMarker) || (*asUTF16 == chSwappedUnicodeMarker))
             {
                 fRawBufIndex += sizeof(UTF16Ch);
                 asUTF16++;
+                postBOMIndex = fRawBufIndex;
             }
 
             //  First check that there are enough raw bytes for there to even
@@ -1439,7 +1303,7 @@ void XMLReader::doInitDecode()
             //
             if (fRawBytesAvail - fRawBufIndex < XMLRecognizer::fgUTF16PreLen)
             {
-                fRawBufIndex = 0;
+                fRawBufIndex = postBOMIndex;
                 break;
             }
 
@@ -1451,7 +1315,7 @@ void XMLReader::doInitDecode()
             {
                 if (memcmp(asUTF16, XMLRecognizer::fgUTF16BPre, XMLRecognizer::fgUTF16PreLen))
                 {
-                    fRawBufIndex = 0;
+                    fRawBufIndex = postBOMIndex;
                     break;
                 }
             }
@@ -1459,7 +1323,7 @@ void XMLReader::doInitDecode()
             {
                 if (memcmp(asUTF16, XMLRecognizer::fgUTF16LPre, XMLRecognizer::fgUTF16PreLen))
                 {
-                    fRawBufIndex = 0;
+                    fRawBufIndex = postBOMIndex;
                     break;
                 }
             }
@@ -1536,6 +1400,15 @@ void XMLReader::doInitDecode()
     //
     if ((fType == Type_PE) && (fRefFrom == RefFrom_NonLiteral))
         fCharBuf[fCharsAvail++] = chSpace;
+    
+    //  Calculate fCharOfsBuf buffer using the elements from fCharBufSize
+    if (fCalculateSrcOfs)
+    {
+        fCharOfsBuf[0] = 0;
+        for (unsigned int index = 1; index < fCharsAvail; ++index) {
+            fCharOfsBuf[index] = fCharOfsBuf[index-1]+fCharSizeBuf[index-1];
+        }
+    }
 }
 
 
