@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2002 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2002,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: XMLScanner.cpp,v 1.62 2004/01/29 11:46:30 cargilld Exp $
+ * $Id: XMLScanner.cpp,v 1.73 2004/09/30 15:20:14 peiyongz Exp $
  */
 
 
@@ -163,7 +123,8 @@ static XMLMsgLoader& gScannerMsgLoader()
 XMLScanner::XMLScanner(XMLValidator* const valToAdopt,
                        GrammarResolver* const grammarResolver,
                        MemoryManager* const manager)
-    : fStandardUriConformant(false)
+    : fBufferSize(1024 * 1024)
+    , fStandardUriConformant(false)
     , fCalculateSrcOfs(false)
     , fDoNamespaces(false)
     , fExitOnFirstFatal(true)
@@ -175,10 +136,13 @@ XMLScanner::XMLScanner(XMLValidator* const valToAdopt,
     , fValidatorFromUser(false)
     , fDoSchema(false)
     , fSchemaFullChecking(false)
+    , fIdentityConstraintChecking(true)
     , fToCacheGrammar(false)
     , fUseCachedGrammar(false)
     , fLoadExternalDTD(true)
     , fNormalizeData(true)
+    , fGenerateSyntheticAnnotations(false)
+    , fValidateAnnotations(false)
     , fErrorCount(0)
     , fEntityExpansionLimit(0)
     , fEntityExpansionCount(0)
@@ -194,6 +158,7 @@ XMLScanner::XMLScanner(XMLValidator* const valToAdopt,
     , fScannerId(0)
     , fSequenceId(0)
     , fAttrList(0)
+    , fAttrDupChkRegistry(0)
     , fDocHandler(0)
     , fDocTypeHandler(0)
     , fEntityHandler(0)
@@ -240,7 +205,9 @@ XMLScanner::XMLScanner( XMLDocumentHandler* const  docHandler
                           , XMLValidator* const      valToAdopt
                           , GrammarResolver* const   grammarResolver
                           , MemoryManager* const     manager)
-    : fStandardUriConformant(false)
+
+    : fBufferSize(1024 * 1024)
+    , fStandardUriConformant(false)
     , fCalculateSrcOfs(false)
     , fDoNamespaces(false)
     , fExitOnFirstFatal(true)
@@ -252,10 +219,13 @@ XMLScanner::XMLScanner( XMLDocumentHandler* const  docHandler
     , fValidatorFromUser(false)
     , fDoSchema(false)
     , fSchemaFullChecking(false)
+    , fIdentityConstraintChecking(true)
     , fToCacheGrammar(false)
     , fUseCachedGrammar(false)
 	, fLoadExternalDTD(true)
     , fNormalizeData(true)
+    , fGenerateSyntheticAnnotations(false)
+    , fValidateAnnotations(false)
     , fErrorCount(0)
     , fEntityExpansionLimit(0)
     , fEntityExpansionCount(0)
@@ -271,6 +241,7 @@ XMLScanner::XMLScanner( XMLDocumentHandler* const  docHandler
     , fScannerId(0)
     , fSequenceId(0)
     , fAttrList(0)
+    , fAttrDupChkRegistry(0)
     , fDocHandler(docHandler)
     , fDocTypeHandler(docTypeHandler)
     , fEntityHandler(entityHandler)
@@ -313,6 +284,7 @@ XMLScanner::XMLScanner( XMLDocumentHandler* const  docHandler
 XMLScanner::~XMLScanner()
 {
     delete fAttrList;
+    delete fAttrDupChkRegistry;
     delete fValidationContext;
     fMemoryManager->deallocate(fRootElemName);//delete [] fRootElemName;
     fMemoryManager->deallocate(fExternalSchemaLocation);//delete [] fExternalSchemaLocation;
@@ -698,6 +670,7 @@ void XMLScanner::setParseSettings(XMLScanner* const refScanner)
     setStandardUriConformant(refScanner->getStandardUriConformant());
     setExitOnFirstFatal(refScanner->getExitOnFirstFatal());
     setValidationConstraintFatal(refScanner->getValidationConstraintFatal());
+    setIdentityConstraintChecking(refScanner->getIdentityConstraintChecking());
     setValidationSchemaFullChecking(refScanner->getValidationSchemaFullChecking());
     cacheGrammarFromParse(refScanner->isCachingGrammarFromParse());
     useCachedGrammarInParse(refScanner->isUsingCachedGrammarInParse());
@@ -744,6 +717,9 @@ void XMLScanner::commonInit()
     fUIntPool[0] = (unsigned int *)fMemoryManager->allocate(sizeof(unsigned int) << 6);
     memset(fUIntPool[0], 0, sizeof(unsigned int) << 6);
     fUIntPool[1] = 0;
+
+    // Register self as handler for XMLBufferFull events on the CDATA buffer
+    fCDataBuf.setFullHandler(this, fBufferSize);
 }
 
 
@@ -1168,6 +1144,11 @@ void XMLScanner::scanPI()
             , targetPtr
        );
     }
+
+    //mark PI is seen within the current element
+    if (! fElemStack.isEmpty())
+        fElemStack.setCommentOrPISeen();
+
 }
 
 //  Scans all the input from the start of the file to the root element.
@@ -1332,7 +1313,7 @@ void XMLScanner::scanXMLDecl(const DeclTypes type)
     while (true)
     {
         // Skip any spaces
-        const unsigned int spaceCount = fReaderMgr.skipPastSpaces();
+        const unsigned int spaceCount = fReaderMgr.skipPastSpaces(true);
 
         // If we are looking at a question mark, then break out
         if (fReaderMgr.lookingAtChar(chQuestion))
@@ -1367,7 +1348,7 @@ void XMLScanner::scanXMLDecl(const DeclTypes type)
 
         //  Scan for an equal's sign. If we don't find it, issue an error
         //  but keep trying to go on.
-        if (!scanEq())
+        if (!scanEq(true))
             emitError(XMLErrs::ExpectedEqSign);
 
         //  Get a quote string into the buffer for the string that we are
@@ -1736,6 +1717,36 @@ void XMLScanner::setURIStringPool(XMLStringPool* const stringPool)
 //  XMLScanner: Private helper methods
 // ---------------------------------------------------------------------------
 
+/***
+ * In reusing grammars (cacheing grammar from parse, or use cached grammar), internal
+ * dtd is allowed conditionally.
+ *
+ * In the case of cacheing grammar from parse, it is NOT allowed.
+ *
+ * In the case of use cached grammar,
+ *   if external dtd is present and it is parsed before, then it is not allowed,
+ *   otherwise it is allowed.
+ *
+ ***/
+void XMLScanner::checkInternalDTD(bool hasExtSubset, const XMLCh* const sysId)
+{
+    if (fToCacheGrammar)
+        ThrowXMLwithMemMgr(RuntimeException, XMLExcepts::Val_CantHaveIntSS, fMemoryManager);
+
+    if (fUseCachedGrammar && hasExtSubset )
+    {
+        InputSource* sysIdSrc = resolveSystemId(sysId);
+        Janitor<InputSource> janSysIdSrc(sysIdSrc);
+        Grammar* grammar = fGrammarResolver->getGrammar(sysIdSrc->getSystemId());
+
+        if (grammar && grammar->getGrammarType() == Grammar::DTDGrammarType) 
+        {
+            ThrowXMLwithMemMgr(RuntimeException, XMLExcepts::Val_CantHaveIntSS, fMemoryManager);
+        }
+    }
+
+}
+
 //  This method is called after the content scan to insure that all the
 //  ID/IDREF attributes match up (i.e. that all IDREFs refer to IDs.) This is
 //  an XML 1.0 rule, so we can do here in the core.
@@ -2014,6 +2025,7 @@ bool XMLScanner::scanCharRef(XMLCh& toFill, XMLCh& second)
 //  it to.
 void XMLScanner::scanComment()
 {
+
     enum States
     {
         InText
@@ -2119,17 +2131,22 @@ void XMLScanner::scanComment()
             bbComment.getRawBuffer()
         );
     }
+
+    //mark comment is seen within the current element
+    if (! fElemStack.isEmpty())
+        fElemStack.setCommentOrPISeen();
+
 }
 
 
 //  Most equal signs can have white space around them, so this little guy
 //  just makes the calling code cleaner by eating whitespace.
-bool XMLScanner::scanEq()
+bool XMLScanner::scanEq(bool inDecl)
 {
-    fReaderMgr.skipPastSpaces();
+    fReaderMgr.skipPastSpaces(inDecl);
     if (fReaderMgr.skippedChar(chEqual))
     {
-        fReaderMgr.skipPastSpaces();
+        fReaderMgr.skipPastSpaces(inDecl);
         return true;
     }
     return false;
