@@ -1,61 +1,51 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2002 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2002,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
  * $Log: XMLScanner.hpp,v $
+ * Revision 1.42  2004/09/29 21:23:34  peiyongz
+ * default implementation provided
+ *
+ * Revision 1.41  2004/09/29 19:00:02  peiyongz
+ * [jira1207] --patch from Dan Rosen
+ *
+ * Revision 1.40  2004/09/28 21:27:38  peiyongz
+ * Optimized duplicated attributes checking for large number of attributes
+ *
+ * Revision 1.39  2004/09/28 02:14:13  cargilld
+ * Add support for validating annotations.
+ *
+ * Revision 1.38  2004/09/23 01:09:55  cargilld
+ * Add support for generating synthetic XSAnnotations.  When a schema component has non-schema attributes and no child attributes create a synthetic XSAnnotation (under feature control) so the non-schema attributes can be recovered under PSVI.
+ *
+ * Revision 1.37  2004/09/08 13:56:14  peiyongz
+ * Apache License Version 2.0
+ *
+ * Revision 1.36  2004/06/14 15:18:53  peiyongz
+ * Consolidated End Of Line Handling
+ *
+ * Revision 1.35  2004/04/13 18:57:54  peiyongz
+ * Unrelavant comment removal
+ *
+ * Revision 1.34  2004/04/13 16:56:58  peiyongz
+ * IdentityConstraintHandler
+ *
+ * Revision 1.33  2004/04/07 14:15:12  peiyongz
+ * allow internalDTD (conditionally) with grammar reusing
+ *
  * Revision 1.32  2003/12/31 15:40:00  cargilld
  * Release memory when an error is encountered.
  *
@@ -348,7 +338,7 @@ struct PSVIElemContext
 //  This is the mondo scanner class, which does the vast majority of the
 //  work of parsing. It handles reading in input and spitting out events
 //  to installed handlers.
-class XMLPARSER_EXPORT XMLScanner : public XMemory
+class XMLPARSER_EXPORT XMLScanner : public XMemory, public XMLBufferFullHandler
 {
 public :
     // -----------------------------------------------------------------------
@@ -451,6 +441,16 @@ public :
         , const char* const         text4 = 0
     );
 
+    // -----------------------------------------------------------------------
+    //  Implementation of XMLBufferFullHandler interface
+    // -----------------------------------------------------------------------
+
+    virtual bool bufferFull(XMLBuffer& toSend)
+    {
+        sendCharData(toSend);
+        return true;
+    }
+
     // -----------------------------------------------------------------------
     //  Public pure virtual methods
     // -----------------------------------------------------------------------
@@ -487,6 +487,7 @@ public :
     ValSchemes getValidationScheme() const;
     bool getDoSchema() const;
     bool getValidationSchemaFullChecking() const;
+    bool getIdentityConstraintChecking() const;
     const XMLEntityHandler* getEntityHandler() const;
     XMLEntityHandler* getEntityHandler();
     const XMLErrorReporter* getErrorReporter() const;
@@ -537,6 +538,9 @@ public :
     unsigned int getPrefixId(const XMLCh* const prefix) const;
     const XMLCh* getPrefixForId(unsigned int prefId) const;
 
+    bool getGenerateSyntheticAnnotations() const;
+    bool getValidateAnnotations() const;
+
     // -----------------------------------------------------------------------
     //  Getter methods
     // -----------------------------------------------------------------------
@@ -614,6 +618,7 @@ public :
     void setValidator(XMLValidator* const valToAdopt);
     void setDoSchema(const bool doSchema);
     void setValidationSchemaFullChecking(const bool schemaFullChecking);
+    void setIdentityConstraintChecking(const bool identityConstraintChecking);
     void setHasNoDTD(const bool hasNoDTD);
     void cacheGrammarFromParse(const bool newValue);
     void useCachedGrammarInParse(const bool newValue);
@@ -628,6 +633,10 @@ public :
     void setCalculateSrcOfs(const bool newValue);
     void setParseSettings(XMLScanner* const refScanner);
     void setStandardUriConformant(const bool newValue);
+    void setInputBufferSize(const size_t bufferSize);
+
+    void setGenerateSyntheticAnnotations(const bool newValue);
+    void setValidateAnnotations(const bool newValue);
 
     // -----------------------------------------------------------------------
     //  Mutator methods
@@ -715,12 +724,15 @@ protected:
     virtual void scanReset(const InputSource& src) = 0;
     virtual void sendCharData(XMLBuffer& toSend) = 0;
 
+    //return owned by the caller
+    virtual InputSource* resolveSystemId(const XMLCh* const sysId) {return 0;};
+
     // -----------------------------------------------------------------------
     //  Protected scanning methods
     // -----------------------------------------------------------------------
     bool scanCharRef(XMLCh& toFill, XMLCh& second);
     void scanComment();
-    bool scanEq();
+    bool scanEq(bool inDecl = false);
     void scanMiscellaneous();
     void scanPI();
     void scanProlog();
@@ -729,6 +741,7 @@ protected:
     // -----------------------------------------------------------------------
     //  Private helper methods
     // -----------------------------------------------------------------------
+    void checkInternalDTD(bool hasExtSubset, const XMLCh* const sysId);
     void checkIDRefs();
     bool isLegalToken(const XMLPScanToken& toCheck);
     XMLTokens senseNextToken(unsigned int& orgReader);
@@ -738,9 +751,19 @@ protected:
     void resetUIntPool();
     void recreateUIntPool();
 
+    inline
+    void setAttrDupChkRegistry
+         (
+            const unsigned int &attrNumber
+          ,       bool         &toUseHashTable
+         );
+
     // -----------------------------------------------------------------------
     //  Data members
     //
+    //  fBufferSize
+    //      Maximum input buffer size
+    //
     //  fAttrList
     //      Every time we get a new element start tag, we have to pass to
     //      the document handler the attributes found. To make it more
@@ -847,6 +870,11 @@ protected:
     //      This flag indicates whether the client code wants full Schema
     //      constraint checking.
     //
+    //  fIdentityConstraintChecking
+    //      This flag indicates whether the client code wants Identity
+    //      Constraint checking, defaulted to true to maintain backward
+    //      compatibility (to minimize supprise)
+    //
     //  fAttName
     //  fAttValue
     //  fCDataBuf
@@ -953,7 +981,9 @@ protected:
     //
     //  fMemoryManager
     //      Pluggable memory manager for dynamic allocation/deallocation.
+    //
     // -----------------------------------------------------------------------
+    size_t                      fBufferSize;
     bool                        fStandardUriConformant;
     bool                        fCalculateSrcOfs;
     bool                        fDoNamespaces;
@@ -966,10 +996,13 @@ protected:
     bool                        fValidatorFromUser;
     bool                        fDoSchema;
     bool                        fSchemaFullChecking;
+    bool                        fIdentityConstraintChecking;
     bool                        fToCacheGrammar;
     bool                        fUseCachedGrammar;
     bool                        fLoadExternalDTD;
     bool                        fNormalizeData;
+    bool                        fGenerateSyntheticAnnotations;
+    bool                        fValidateAnnotations;
     int                         fErrorCount;
     unsigned int                fEntityExpansionLimit;
     unsigned int                fEntityExpansionCount;
@@ -985,6 +1018,7 @@ protected:
     XMLUInt32                   fScannerId;
     XMLUInt32                   fSequenceId;
     RefVectorOf<XMLAttr>*       fAttrList;
+    RefHash2KeysTableOf<XMLAttr>*  fAttrDupChkRegistry;    
     XMLDocumentHandler*         fDocHandler;
     DocTypeHandler*             fDocTypeHandler;
     XMLEntityHandler*           fEntityHandler;
@@ -1190,6 +1224,11 @@ inline bool XMLScanner::getValidationSchemaFullChecking() const
     return fSchemaFullChecking;
 }
 
+inline bool XMLScanner::getIdentityConstraintChecking() const
+{
+    return fIdentityConstraintChecking;
+}
+
 inline int XMLScanner::getErrorCount()
 {
     return fErrorCount;
@@ -1310,6 +1349,16 @@ inline const XMLCh* XMLScanner::getPrefixForId(unsigned int prefId) const
     return fElemStack.getPrefixForId(prefId);
 }
 
+inline bool XMLScanner::getGenerateSyntheticAnnotations() const
+{
+    return fGenerateSyntheticAnnotations;
+}
+
+inline bool XMLScanner::getValidateAnnotations() const
+{
+    return fValidateAnnotations;
+}
+
 // ---------------------------------------------------------------------------
 //  XMLScanner: Setter methods
 // ---------------------------------------------------------------------------
@@ -1382,6 +1431,11 @@ inline void XMLScanner::setValidationSchemaFullChecking(const bool schemaFullChe
     fSchemaFullChecking = schemaFullChecking;
 }
 
+inline void XMLScanner::setIdentityConstraintChecking(const bool identityConstraintChecking)
+{
+    fIdentityConstraintChecking = identityConstraintChecking;
+}
+
 inline void XMLScanner::setHasNoDTD(const bool hasNoDTD)
 {
     fHasNoDTD = hasNoDTD;
@@ -1458,6 +1512,22 @@ inline void XMLScanner::setStandardUriConformant(const bool newValue)
     fReaderMgr.setStandardUriConformant(newValue);
 }
 
+inline void XMLScanner::setGenerateSyntheticAnnotations(const bool newValue)
+{
+    fGenerateSyntheticAnnotations = newValue;
+}
+
+inline void XMLScanner::setValidateAnnotations(const bool newValue)
+{
+    fValidateAnnotations = newValue;
+}
+
+inline void XMLScanner::setInputBufferSize(const size_t bufferSize)
+{
+    fBufferSize = bufferSize;
+    fCDataBuf.setFullHandler(this, fBufferSize);
+}
+
 // ---------------------------------------------------------------------------
 //  XMLScanner: Mutator methods
 // ---------------------------------------------------------------------------
@@ -1490,6 +1560,29 @@ inline void XMLScanner::resetValidationContext()
     fEntityDeclPoolRetrieved = false;
 }
 
+inline void XMLScanner::setAttrDupChkRegistry(const unsigned int &attrNumber
+                                            ,       bool         &toUseHashTable)
+{
+   // once the attribute exceed 20, we use hash table to check duplication
+    if (attrNumber > 20)
+   {
+        toUseHashTable = true;
+
+        if (!fAttrDupChkRegistry)
+        {
+            fAttrDupChkRegistry = new (fMemoryManager) RefHash2KeysTableOf<XMLAttr>
+            (
+              2*attrNumber+1, false, new (fMemoryManager)HashXMLCh(), fMemoryManager
+            );
+        }
+        else
+        {
+            fAttrDupChkRegistry->removeAll();
+        }
+    }
+
+}
+
 XERCES_CPP_NAMESPACE_END
 
 #endif
