@@ -1,61 +1,35 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2003 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2003,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
  * $Log: XSerializeEngine.hpp,v $
+ * Revision 1.18  2004/09/08 13:56:14  peiyongz
+ * Apache License Version 2.0
+ *
+ * Revision 1.17  2004/03/05 22:21:45  peiyongz
+ * readBytes()/writeBytes between BinOutputStream/BinInputStream and
+ * XSerializeEngine will always be the full size of the buffer to maintain the exact
+ * position for aligned data.
+ *
+ * Revision 1.16  2004/03/01 23:19:03  peiyongz
+ * Grant XSerializeEngine access to GrammarPool
+ *
+ * Revision 1.15  2004/02/20 20:57:39  peiyongz
+ * Bug#27046: path from David Bertoni
+ *
  * Revision 1.14  2004/02/11 20:38:50  peiyongz
  * Fix to bug#26864, thanks to David Bertoni.
  *
@@ -98,26 +72,29 @@
  * Revision 1.1  2003/09/18 18:31:24  peiyongz
  * OSU: Object Serialization Utilities
  *
- * $Id: XSerializeEngine.hpp,v 1.14 2004/02/11 20:38:50 peiyongz Exp $
+ * $Id: XSerializeEngine.hpp,v 1.18 2004/09/08 13:56:14 peiyongz Exp $
  *
  */
 
 #if !defined(XSERIALIZE_ENGINE_HPP)
 #define XSERIALIZE_ENGINE_HPP
 
-#include <xercesc/framework/BinOutputStream.hpp>
-#include <xercesc/util/BinInputStream.hpp>
 #include <xercesc/util/RefHashTableOf.hpp>
 #include <xercesc/util/ValueVectorOf.hpp>
-#include <xercesc/internal/XSerializationException.hpp>
 #include <xercesc/util/XMLExceptMsgs.hpp>
 
+#include <xercesc/internal/XSerializationException.hpp>
+
 XERCES_CPP_NAMESPACE_BEGIN
 
 class XSerializable;
 class XProtoType;
 class MemoryManager;
 class XSerializedObjectId;
+class BinOutputStream;
+class BinInputStream;
+class XMLGrammarPool;
+class XMLStringPool;
 
 class XMLUTIL_EXPORT XSerializeEngine
 {
@@ -129,9 +106,6 @@ public:
     
 
     static const bool toReadBufferLen;
-    static int defaultBufferLen;
-    static int defaultDataLen;
-
 
     typedef unsigned int   XSerializedObjectId_t;
 
@@ -143,6 +117,46 @@ public:
     ~XSerializeEngine();
 
     /***
+      *
+      *  Constructor for de-serialization(loading)
+      *
+      *  Application needs to make sure that the instance of
+      *  BinInputStream, persists beyond the life of this
+      *  SerializeEngine.
+      *
+      *  Param
+      *     inStream         input stream
+      *     gramPool         Grammar Pool
+      *     bufSize          the size of the internal buffer
+      *
+      ***/
+    XSerializeEngine(BinInputStream*         inStream
+                   , XMLGrammarPool* const   gramPool
+                   , unsigned long           bufSize = 8192 );
+
+
+    /***
+      *
+      *  Constructor for serialization(storing)
+      *
+      *  Application needs to make sure that the instance of
+      *  BinOutputStream, persists beyond the life of this
+      *  SerializeEngine.
+      *
+      *  Param
+      *     outStream        output stream
+      *     gramPool         Grammar Pool
+      *     bufSize          the size of the internal buffer
+      *
+      ***/
+    XSerializeEngine(BinOutputStream*        outStream
+                   , XMLGrammarPool* const   gramPool
+                   , unsigned long           bufSize = 8192 );
+
+
+    /***
+      *
+      *  Deprecated
       *
       *  Constructor for de-serialization(loading)
       *
@@ -160,7 +174,10 @@ public:
                    , MemoryManager* const    manager = XMLPlatformUtils::fgMemoryManager
                    , unsigned long           bufSize = 8192 );
 
+    
     /***
+      *
+      *  Deprecated
       *
       *  Constructor for serialization(storing)
       *
@@ -207,6 +224,24 @@ public:
       ***/
     inline bool isLoading() const;
 
+    /***
+      *
+      *  Get the GrammarPool
+      *
+      *  Return: XMLGrammarPool
+      *
+      ***/
+    XMLGrammarPool* getGrammarPool() const;
+
+    /***
+      *
+      *  Get the StringPool
+      *
+      *  Return: XMLStringPool
+      *
+      ***/
+    XMLStringPool* getStringPool() const;
+
     /***
       *
       *  Get the embeded Memory Manager
@@ -214,7 +249,7 @@ public:
       *  Return: MemoryManager
       *
       ***/
-    inline MemoryManager* getMemoryManager() const;
+    MemoryManager* getMemoryManager() const;
 
     /***
       *
@@ -381,10 +416,39 @@ public:
       *
       ***/
            void           readString(XMLCh*&        toRead
-                                   , int&           bufferLen    = defaultBufferLen
-                                   , int&           dataLen      = defaultDataLen
+                                   , int&           bufferLen
+                                   , int&           dataLen
                                    , bool           toReadBufLen = false);
 
+     /***
+       *
+       *  Read a stream of XMLCh from the internal buffer.
+       *
+       *  Read the bufferLen first if requested, then the length
+       *  of the stream followed by the stream.
+       *
+       *  Param
+       *     toRead:       the pointer to the buffer to hold the XMLCh stream
+       *     bufferLen:    the size of the buffer created
+       *
+       *  Return:
+       *
+       ***/
+            inline void     readString(XMLCh*&        toRead
+                                    , int&            bufferLen);
+ 
+     /***
+       *
+       *  Read a stream of XMLCh from the internal buffer.
+       *
+       *  Param
+       *     toRead:       the pointer to the buffer to hold the XMLCh stream
+       *
+       *  Return:
+       *
+       ***/
+            inline void      readString(XMLCh*&        toRead);
+
     /***
       *
       *  Read a stream of XMLByte from the internal buffer.
@@ -402,11 +466,46 @@ public:
       *
       ***/
            void           readString(XMLByte*&      toRead
-                                   , int&           bufferLen    = defaultBufferLen
-                                   , int&           dataLen      = defaultDataLen
+                                   , int&           bufferLen
+                                   , int&           dataLen
                                    , bool           toReadBufLen = false);
 
 
+     /***
+       *
+       *  Read a stream of XMLByte from the internal buffer.
+       *
+       *  Read the bufferLen first if requested, then the length
+       *  of the stream followed by the stream.
+       *
+       *  Param
+       *     toRead:       the pointer to the buffer to hold the XMLByte stream
+       *     bufferLen:    the size of the buffer created
+       *
+       *  Return:
+       *
+       ***/
+            inline void       readString(XMLByte*&      toRead
+                                       , int&           bufferLen);
+ 
+     /***
+       *
+       *  Read a stream of XMLByte from the internal buffer.
+       *
+       *  Read the bufferLen first if requested, then the length
+       *  of the stream followed by the stream.
+       *
+       *  Param
+       *     toRead:       the pointer to the buffer to hold the XMLByte stream
+       *     bufferLen:    the size of the buffer created
+       *     dataLen:       the length of the stream
+       *     toReadBufLen: specify if the bufferLen need to be read or not
+       *
+       *  Return:
+       *
+       ***/
+            inline void       readString(XMLByte*&      toRead);
+
     /***
       *
       *  Check if the template object has been stored or not
@@ -529,7 +628,7 @@ private:
 
     inline void           checkAndFlushBuffer(int bytesNeedToWrite);
 
-           void           fillBuffer(int bytesNeedToRead);
+           void           fillBuffer();
 
            void           flushBuffer();
 
@@ -570,9 +669,9 @@ private:
     //  fStoreLoad: 
     //               Indicator: storing(serialization) or loading(de-serialization)
     //
-    //  fMemoryManager:
-    //               used to allocate memory for internal consumption and/or
-    //               allocate memory for object created in de-serialization.
+    //  fGrammarPool:
+    //               Thw owning GrammarPool which instantiate this SerializeEngine 
+    //               instance
     //
     //  fInputStream:
     //               Binary stream to read from (de-serialization), provided
@@ -606,8 +705,8 @@ private:
     //
     //  fMapCount:
     // -------------------------------------------------------------------------------
-    const short                            fStoreLoad;   
-    MemoryManager*   const                 fMemoryManager;
+    const short                            fStoreLoad;  
+    XMLGrammarPool*  const                 fGrammarPool;
     BinInputStream*  const                 fInputStream;
     BinOutputStream* const                 fOutputStream;
 
@@ -654,11 +753,6 @@ inline bool XSerializeEngine::isLoading() const
     return (fStoreLoad == mode_Load);
 }
 
-inline MemoryManager* XSerializeEngine::getMemoryManager() const
-{
-    return fMemoryManager;
-}
-
 inline XSerializeEngine& operator<<(XSerializeEngine&       serEng
                                   , XSerializable* const    serObj)
 {
@@ -683,7 +777,7 @@ inline void XSerializeEngine::Assert(bool toEval
 {
     if (!toEval)
     {
-        ThrowXMLwithMemMgr(XSerializationException, toThrow, fMemoryManager);  
+        ThrowXMLwithMemMgr(XSerializationException, toThrow, getMemoryManager());  
     }
 
 }
@@ -718,6 +812,34 @@ inline void XSerializeEngine::allignBufCur()
     fBufCur+=allignAdjust();
 }
 
+inline void XSerializeEngine::readString(XMLCh*&        toRead
+                                       , int&           bufferLen)
+{
+    int  dummyDataLen;                
+    readString(toRead, bufferLen, dummyDataLen);
+}
+
+inline void XSerializeEngine::readString(XMLCh*&        toRead)
+{
+    int  dummyBufferLen;
+    int  dummyDataLen;
+    readString(toRead, dummyBufferLen, dummyDataLen);
+}
+
+inline void XSerializeEngine::readString(XMLByte*&      toRead
+                                       , int&           bufferLen)
+{
+    int  dummyDataLen;
+    readString(toRead, bufferLen, dummyDataLen);
+}
+
+inline void XSerializeEngine::readString(XMLByte*&      toRead)
+{
+    int  dummyBufferLen;
+    int  dummyDataLen;
+    readString(toRead, dummyBufferLen, dummyDataLen);
+}
+
 /***
  *  Ought to be nested class
  ***/
