@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2002, 2003 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 2001, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2002, 2003,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: AbstractDOMParser.hpp,v 1.27 2004/01/29 11:46:32 cargilld Exp $
+ * $Id: AbstractDOMParser.hpp,v 1.35 2004/09/28 02:14:14 cargilld Exp $
  *
  */
 #if !defined(ABSTRACTDOMPARSER_HPP)
@@ -71,6 +31,7 @@
 #include <xercesc/dom/DOMDocumentType.hpp>
 #include <xercesc/validators/DTD/DTDElementDecl.hpp>
 #include <xercesc/framework/XMLBufferMgr.hpp>
+#include <xercesc/framework/psvi/PSVIHandler.hpp>
 
 XERCES_CPP_NAMESPACE_BEGIN
 
@@ -95,6 +56,7 @@ class PARSERS_EXPORT AbstractDOMParser :
     , public XMLErrorReporter
     , public XMLEntityHandler
     , public DocTypeHandler
+    , public PSVIHandler
 {
 public :
     // -----------------------------------------------------------------------
@@ -116,6 +78,7 @@ public :
         , Val_Always
         , Val_Auto
     };
+
     //@}
 
 
@@ -225,6 +188,18 @@ public :
       */
     bool getValidationSchemaFullChecking() const;
 
+    /** Get the identity constraint checking' flag
+      *
+      * This method returns the state of the parser's identity constraint
+      * checking flag.
+      *
+      * @return true, if the parser is currently configured to
+      *         have identity constraint checking, false otherwise.
+      *
+      * @see setIdentityConstraintChecking
+      */
+    bool getIdentityConstraintChecking() const;
+
     /** Get error count from the last parse operation.
       *
       * This method returns the error count from the last parse
@@ -422,6 +397,39 @@ public :
       */
     const PSVIHandler* getPSVIHandler() const;
 
+    /** Get the 'associate schema info' flag
+      *
+      * This method returns the flag that specifies whether
+      * the parser is storing schema informations in the element 
+      * and attribute nodes in the DOM tree being produced.
+      *
+      * @return  The state of the associate schema info flag.
+      * @see #setCreateSchemaInfo
+      */
+    bool  getCreateSchemaInfo() const;
+
+    /** Get the 'generate synthetic annotations' flag
+      *    
+      * @return true, if the parser is currently configured to
+      *         generate synthetic annotations, false otherwise.
+      *         A synthetic XSAnnotation is created when a schema
+      *         component has non-schema attributes but has no
+      *         child annotations so that the non-schema attributes
+      *         can be recovered under PSVI.
+      *
+      * @see #setGenerateSyntheticAnnotations
+      */
+    bool getGenerateSyntheticAnnotations() const;
+
+    /** Get the 'validate annotations' flag
+      *    
+      * @return true, if the parser is currently configured to
+      *         validate annotations, false otherwise.
+      *
+      * @see #setValidateAnnotations
+      */
+    bool getValidateAnnotations() const;
+
     //@}
 
 
@@ -431,6 +439,27 @@ public :
 
     /** @name Setter methods */
     //@{
+    /** set the 'generate synthetic annotations' flag
+      *    
+      * @param newValue The value for specifying whether Synthetic Annotations
+      *        should be generated or not.
+      *         A synthetic XSAnnotation is created when a schema
+      *         component has non-schema attributes but has no
+      *         child annotations so that the non-schema attributes
+      *         can be recovered under PSVI.
+      *
+      * @see #getGenerateSyntheticAnnotations
+      */
+    void setGenerateSyntheticAnnotations(const bool newValue);
+
+    /** set the 'validlate annotations' flag
+      *    
+      * @param newValue The value for specifying whether Annotations
+      *        should be validated or not.
+      *
+      * @see #getValidateAnnotations
+      */
+    void setValidateAnnotations(const bool newValue);
 
     /** Set the 'do namespaces' flag
       *
@@ -583,6 +612,21 @@ public :
       */
     void setValidationSchemaFullChecking(const bool schemaFullChecking);
 
+    /**
+      * This method allows users to enable or disable the parser's identity
+      * constraint checks.
+      *
+      * <p>By default, the parser does identity constraint checks. 
+      *    The default value is true.</p>
+      *
+      * @param newState The value specifying whether the parser should
+      *                 do identity constraint checks or not in the
+      *                 input XML document.
+      *
+      * @see #getIdentityConstraintChecking
+      */
+    void setIdentityConstraintChecking(const bool newState);
+
     /**
       * This method allows the user to specify a list of schemas to use.
       * If the targetNamespace of a schema specified using this method matches
@@ -742,6 +786,17 @@ public :
       */
     virtual void setPSVIHandler(PSVIHandler* const handler);
 
+    /** Set the 'associate schema info' flag
+      *
+      * This method allows users to specify whether 
+      * the parser should store schema informations in the element 
+      * and attribute nodes in the DOM tree being produced.
+      *
+      * @return  The state of the associate schema info flag.
+      * @see #getCreateSchemaInfo
+      */
+    void  setCreateSchemaInfo(const bool newState);
+
     //@}
 
 
@@ -955,6 +1010,55 @@ public :
 
     //@}
 
+    // -----------------------------------------------------------------------
+    //  Implementation of the PSVIHandler interface.
+    // -----------------------------------------------------------------------
+    
+    /** @name Implementation of the PSVIHandler interface. */
+    //@{
+
+    /** Receive notification of the PSVI properties of an element.
+      * The scanner will issue this call after the XMLDocumentHandler
+      * endElement call.  Since the scanner will issue the psviAttributes
+      * call immediately after reading the start tag of an element, all element
+      * content will be effectively bracketed by these two calls.
+      * @param  localName The name of the element whose end tag was just
+      *                     parsed.
+      * @param  uri       The namespace to which the element is bound
+      * @param  elementInfo    Object containing the element's PSVI properties
+      */
+    virtual void handleElementPSVI
+    (
+        const   XMLCh* const            localName 
+        , const XMLCh* const            uri
+        ,       PSVIElement *           elementInfo
+    );
+
+    virtual void handlePartialElementPSVI
+    (
+        const   XMLCh* const            localName 
+        , const XMLCh* const            uri
+        ,       PSVIElement *           elementInfo
+    );
+    /**
+      * Enables PSVI information about attributes to be passed back to the
+      * application.  This callback will be made on *all*
+      * elements; on elements with no attributes, the final parameter will
+      * be null.
+      * @param  localName The name of the element upon which start tag 
+      *          these attributes were encountered.
+      * @param  uri       The namespace to which the element is bound
+      * @param  psviAttributes   Object containing the attributes' PSVI properties
+      *          with information to identify them.
+      */
+    virtual void handleAttributesPSVI
+    (
+        const   XMLCh* const            localName 
+        , const XMLCh* const            uri
+        ,       PSVIAttributeList *     psviAttributes
+    );
+    //@}
+
     // -----------------------------------------------------------------------
     //  Implementation of the XMLDocumentHandler interface.
     // -----------------------------------------------------------------------
@@ -1151,8 +1255,8 @@ public :
       * This method is used to report the XML decl scanned by the parser.
       * Refer to the XML specification to see the meaning of parameters.
       *
-      * <b><font color="#FF0000">This method is a no-op for this DOM
-      * implementation.</font></b>
+      * <b>This method is a no-op for this DOM
+      * implementation.</b>
       *
       * @param versionStr A const pointer to a Unicode string representing
       *                   version string value.
@@ -1177,7 +1281,7 @@ public :
       * This event will be fired immediately after the
       * endElement() event that signifies the end of the element
       * to which it applies; no other events will intervene.
-      * This method is <emEXPERIMENTAL</em> and may change, disappear 
+      * This method is <em>EXPERIMENTAL</em> and may change, disappear 
       * or become pure virtual at any time.
       *
       * This corresponds to a part of the information required by DOM Core
@@ -1189,7 +1293,7 @@ public :
       * @param  typeURI         namespace of the type that actually validated
       *                         the content of the element corresponding to the
       *                         most recent endElement() callback
-      * @experimental
+      * @deprecated
       */
     virtual void elementTypeInfo
     (
@@ -1553,6 +1657,9 @@ protected:
     //      The grammar pool passed from external application (through derivatives).
     //      which could be 0, not owned.
     //
+    //  fCreateSchemaInfo
+    //      Indicates whether element and attributes will have schema info associated
+    //
     // -----------------------------------------------------------------------
     bool                          fCreateEntityReferenceNodes;
     bool                          fIncludeIgnorableWhitespace;
@@ -1560,6 +1667,7 @@ protected:
     bool                          fParseInProgress;
     bool                          fCreateCommentNodes;
     bool                          fDocumentAdoptedByUser;
+    bool                          fCreateSchemaInfo;
     XMLScanner*                   fScanner;
     XMLCh*                        fImplementationFeatures;
     DOMNode*                      fCurrentParent;
@@ -1627,6 +1735,11 @@ inline const PSVIHandler* AbstractDOMParser::getPSVIHandler() const
 {
     return fPSVIHandler;
 }
+
+inline bool AbstractDOMParser::getCreateSchemaInfo() const
+{
+    return fCreateSchemaInfo;
+}
 // ---------------------------------------------------------------------------
 //  AbstractDOMParser: Setter methods
 // ---------------------------------------------------------------------------
