@@ -1,57 +1,17 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2002, 2003 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 2001, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2002, 2003,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /**
@@ -59,7 +19,7 @@
 *  handler with the scanner. In these handler methods, appropriate DOM nodes
 *  are created and added to the DOM tree.
 *
-* $Id: DOMBuilderImpl.cpp,v 1.34 2004/01/29 11:46:32 cargilld Exp $
+* $Id: DOMBuilderImpl.cpp,v 1.41 2004/09/28 04:40:08 cargilld Exp $
 *
 */
 
@@ -156,7 +116,7 @@ void DOMBuilderImpl::setXMLEntityResolver(XMLEntityResolver* const handler)
 
 void DOMBuilderImpl::setFilter(DOMBuilderFilter* const)
 {
-    throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0);
+    throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0, getMemoryManager());
 }
 
 
@@ -211,12 +171,12 @@ void DOMBuilderImpl::setFeature(const XMLCh* const name, const bool state)
              XMLString::compareIString(name, XMLUni::fgDOMInfoset) == 0 ||
              XMLString::compareIString(name, XMLUni::fgDOMCanonicalForm) == 0 ) {
         if (state)
-            throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0);
+            throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0, getMemoryManager());
     }
     else if (XMLString::compareIString(name, XMLUni::fgDOMNamespaceDeclarations) == 0 ||
              XMLString::compareIString(name, XMLUni::fgDOMCDATASections) == 0 ) {
         if (!state)
-            throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0);
+            throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0, getMemoryManager());
     }
     else if (XMLString::compareIString(name, XMLUni::fgXercesSchema) == 0)
     {
@@ -267,8 +227,25 @@ void DOMBuilderImpl::setFeature(const XMLCh* const name, const bool state)
     {
         getScanner()->setStandardUriConformant(state);
     }
+    else if (XMLString::compareIString(name, XMLUni::fgXercesDOMHasPSVIInfo) == 0)
+    {
+        setCreateSchemaInfo(state);
+    }
+    else if (XMLString::compareIString(name, XMLUni::fgXercesGenerateSyntheticAnnotations) == 0)
+    {
+        getScanner()->setGenerateSyntheticAnnotations(state);
+    }
+    else if (XMLString::compareIString(name, XMLUni::fgXercesValidateAnnotations) == 0)
+    {
+        getScanner()->setValidateAnnotations(state);
+    }
+    else if (XMLString::compareIString(name, XMLUni::fgXercesIdentityConstraintChecking) == 0)
+    {
+        getScanner()->setIdentityConstraintChecking(state);
+    }
+
     else {
-        throw DOMException(DOMException::NOT_FOUND_ERR, 0);
+        throw DOMException(DOMException::NOT_FOUND_ERR, 0, getMemoryManager());
     }
 }
 
@@ -317,6 +294,11 @@ bool DOMBuilderImpl::getFeature(const XMLCh* const name) const
         return getValidationSchemaFullChecking();
     }
 
+    else if (XMLString::compareIString(name, XMLUni::fgXercesIdentityConstraintChecking) == 0)
+    {
+        return getIdentityConstraintChecking();
+    }
+
     else if (XMLString::compareIString(name, XMLUni::fgXercesLoadExternalDTD) == 0)
     {
         return getLoadExternalDTD();
@@ -349,8 +331,19 @@ bool DOMBuilderImpl::getFeature(const XMLCh* const name) const
     else if(XMLString::compareIString(name, XMLUni::fgXercesUserAdoptsDOMDocument) == 0) {
         return fUserAdoptsDocument;
     }
+    else if (XMLString::compareIString(name, XMLUni::fgXercesDOMHasPSVIInfo) == 0) {
+        return getCreateSchemaInfo();
+    }
+    else if (XMLString::compareIString(name, XMLUni::fgXercesGenerateSyntheticAnnotations) == 0)
+    {
+        return getScanner()->getGenerateSyntheticAnnotations();
+    }
+    else if (XMLString::compareIString(name, XMLUni::fgXercesValidateAnnotations) == 0)
+    {
+        return getScanner()->getValidateAnnotations();
+    }
     else {
-        throw DOMException(DOMException::NOT_FOUND_ERR, 0);
+        throw DOMException(DOMException::NOT_FOUND_ERR, 0, getMemoryManager());
     }
 
     return false;
@@ -368,7 +361,12 @@ bool DOMBuilderImpl::canSetFeature(const XMLCh* const name, const bool state) co
         (XMLString::compareIString(name, XMLUni::fgDOMWhitespaceInElementContent) == 0) ||
         (XMLString::compareIString(name, XMLUni::fgXercesUserAdoptsDOMDocument) == 0) ||
         (XMLString::compareIString(name, XMLUni::fgXercesCalculateSrcOfs) == 0) ||
-        (XMLString::compareIString(name, XMLUni::fgXercesStandardUriConformant) == 0)) {
+        (XMLString::compareIString(name, XMLUni::fgXercesStandardUriConformant) == 0) ||
+        (XMLString::compareIString(name, XMLUni::fgXercesDOMHasPSVIInfo) == 0) ||
+        (XMLString::compareIString(name, XMLUni::fgXercesValidateAnnotations) == 0) ||
+        (XMLString::compareIString(name, XMLUni::fgXercesGenerateSyntheticAnnotations) == 0) ||
+        (XMLString::compareIString(name, XMLUni::fgXercesIdentityConstraintChecking) == 0)
+       ) {
         return true;
     }
 
@@ -424,7 +422,7 @@ void DOMBuilderImpl::setProperty(const XMLCh* const name, void* value)
     }
 
     else
-      throw DOMException(DOMException::NOT_FOUND_ERR, 0);
+      throw DOMException(DOMException::NOT_FOUND_ERR, 0, getMemoryManager());
 }
 
 
@@ -437,7 +435,7 @@ void* DOMBuilderImpl::getProperty(const XMLCh* const name) const
     else if (XMLString::compareIString(name, XMLUni::fgXercesSecurityManager) == 0)
         return (void*)getSecurityManager();
     else
-        throw DOMException(DOMException::NOT_FOUND_ERR, 0);
+        throw DOMException(DOMException::NOT_FOUND_ERR, 0, getMemoryManager());
     return 0;
 }
 
@@ -489,7 +487,7 @@ void DOMBuilderImpl::parseWithContext(const DOMInputSource&,
                                       DOMNode* const,
                                       const short)
 {
-    throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0);
+    throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0, getMemoryManager());
 }
 
 
