@@ -1,61 +1,110 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
  * $Log: SAXParser.hpp,v $
+ * Revision 1.36  2004/09/29 19:28:12  cargilld
+ * Mark SAXParser as deprecated.
+ *
+ * Revision 1.35  2004/09/29 19:00:29  peiyongz
+ * [jira1207] --patch from Dan Rosen
+ *
+ * Revision 1.34  2004/09/28 02:14:14  cargilld
+ * Add support for validating annotations.
+ *
+ * Revision 1.33  2004/09/23 01:09:55  cargilld
+ * Add support for generating synthetic XSAnnotations.  When a schema component has non-schema attributes and no child attributes create a synthetic XSAnnotation (under feature control) so the non-schema attributes can be recovered under PSVI.
+ *
+ * Revision 1.32  2004/09/08 13:56:18  peiyongz
+ * Apache License Version 2.0
+ *
+ * Revision 1.31  2004/09/02 19:08:09  cargilld
+ * Fix API Doc warning message
+ *
+ * Revision 1.30  2004/04/13 18:58:36  peiyongz
+ * correct comment
+ *
+ * Revision 1.29  2004/04/13 16:53:26  peiyongz
+ * get/setIdentityConstraintChecking
+ *
+ * Revision 1.28  2003/12/01 23:23:26  neilg
+ * fix for bug 25118; thanks to Jeroen Witmond
+ *
+ * Revision 1.27  2003/11/06 15:30:07  neilg
+ * first part of PSVI/schema component model implementation, thanks to David Cargill.  This covers setting the PSVIHandler on parser objects, as well as implementing XSNotation, XSSimpleTypeDefinition, XSIDCDefinition, and most of XSWildcard, XSComplexTypeDefinition, XSElementDeclaration, XSAttributeDeclaration and XSAttributeUse.
+ *
+ * Revision 1.26  2003/10/30 21:37:31  knoaman
+ * Enhanced Entity Resolver Support. Thanks to David Cargill.
+ *
+ * Revision 1.25  2003/10/20 13:41:10  amassari
+ * Added getGrammarResolver API
+ *
+ * Revision 1.24  2003/06/20 18:55:54  peiyongz
+ * Stateless Grammar Pool :: Part I
+ *
+ * Revision 1.23  2003/05/15 18:26:50  knoaman
+ * Partial implementation of the configurable memory manager.
+ *
+ * Revision 1.22  2003/04/17 21:58:50  neilg
+ * Adding a new property,
+ * http://apache.org/xml/properties/security-manager, with
+ * appropriate getSecurityManager/setSecurityManager methods on DOM
+ * and SAX parsers.  Also adding a new SecurityManager class.
+ *
+ * The purpose of these modifications is to permit applications a
+ * means to have the parser reject documents whose processing would
+ * otherwise consume large amounts of system resources.  Malicious
+ * use of such documents could be used to launch a denial-of-service
+ * attack against a system running the parser.  Initially, the
+ * SecurityManager only knows about attacks that can result from
+ * exponential entity expansion; this is the only known attack that
+ * involves processing a single XML document.  Other, simlar attacks
+ * can be launched if arbitrary schemas may be parsed; there already
+ * exist means (via use of the EntityResolver interface) by which
+ * applications can deny processing of untrusted schemas.  In future,
+ * the SecurityManager will be expanded to take these other exploits
+ * into account.
+ *
+ * Add support for the SecurityManager
+ * 
+ * Revision 1.21  2003/03/07 18:09:17  tng
+ * Return a reference instead of void for operator=
+ *
+ * Revision 1.20  2003/02/04 19:27:43  knoaman
+ * Performance: use global buffer to eliminate repetitive memory creation/deletion.
+ *
+ * Revision 1.19  2003/01/09 19:07:08  tng
+ * [Bug 15802] Add "const" qualifier to getURIText.
+ *
+ * Revision 1.18  2003/01/03 20:09:36  tng
+ * New feature StandardUriConformant to force strict standard uri conformance.
+ *
+ * Revision 1.17  2002/12/30 20:15:51  knoaman
+ * Make calculate src offset option false by default.
+ *
+ * Revision 1.16  2002/12/23 15:23:18  knoaman
+ * Added a public api to various parsers to return the src offset within the input
+ * source.
+ *
+ * Revision 1.15  2002/12/04 01:57:09  knoaman
+ * Scanner re-organization.
+ *
+ * Revision 1.14  2002/11/04 14:57:03  tng
+ * C++ Namespace Support.
+ *
  * Revision 1.13  2002/08/14 15:20:38  knoaman
  * [Bug 3111] Problem with LexicalHandler::startDTD() and LexicalHandler::endDTD().
  *
@@ -185,15 +234,24 @@
 #include <xercesc/framework/XMLElementDecl.hpp>
 #include <xercesc/framework/XMLEntityHandler.hpp>
 #include <xercesc/framework/XMLErrorReporter.hpp>
+#include <xercesc/framework/XMLBuffer.hpp>
+#include <xercesc/util/SecurityManager.hpp>
 #include <xercesc/validators/DTD/DocTypeHandler.hpp>
 
+XERCES_CPP_NAMESPACE_BEGIN
+
+
 class DocumentHandler;
 class EntityResolver;
 class XMLPScanToken;
 class XMLScanner;
 class XMLValidator;
 class Grammar;
-
+class GrammarResolver;
+class XMLGrammarPool;
+class XMLEntityResolver;
+class XMLResourceIdentifier;
+class PSVIHandler;
 
 /**
   * This class implements the SAX 'Parser' interface and should be
@@ -203,15 +261,20 @@ class Grammar;
   *
   * <p>It can be used to instantiate a validating or non-validating
   * parser, by setting a member flag.</p>
+  *
+  * @deprecated This interface has been replaced by the SAX2
+  *             interface, which includes Namespace support.
+  *             See SAX2XMLReader for more information.
   */
 
 class PARSERS_EXPORT SAXParser :
 
-    public Parser
+    public XMemory
+    , public Parser
     , public XMLDocumentHandler
     , public XMLErrorReporter
     , public XMLEntityHandler
-    , public DocTypeHandler
+    , public DocTypeHandler    
 {
 public :
     // -----------------------------------------------------------------------
@@ -242,8 +305,16 @@ public :
       * validation.
       * @param valToAdopt Pointer to the validator instance to use. The
       *                   parser is responsible for freeing the memory.
+      * @param manager    Pointer to the memory manager to be used to
+      *                   allocate objects.
+      * @param gramPool   The collection of cached grammers.
       */
-    SAXParser(XMLValidator* const valToAdopt = 0);
+    SAXParser
+    (
+          XMLValidator*   const valToAdopt = 0
+        , MemoryManager*  const manager = XMLPlatformUtils::fgMemoryManager
+        , XMLGrammarPool* const gramPool = 0 
+    );
 
     /**
       * Destructor
@@ -289,6 +360,22 @@ public :
       */
     const EntityResolver* getEntityResolver() const;
 
+    /**
+      * This method returns the installed entity resolver. Suitable
+      * for 'lvalue' usages.
+      *
+      * @return The pointer to the installed entity resolver object.
+      */
+    XMLEntityResolver* getXMLEntityResolver();
+
+    /**
+      * This method returns the installed entity resolver. Suitable
+      * for 'rvalue' usages.
+      *
+      * @return A const pointer to the installed entity resolver object.
+      */
+    const XMLEntityResolver* getXMLEntityResolver() const;
+
     /**
       * This method returns the installed error handler. Suitable
       * for 'lvalue' usages.
@@ -305,6 +392,22 @@ public :
       */
     const ErrorHandler* getErrorHandler() const;
 
+    /**
+      * This method returns the installed PSVI handler. Suitable
+      * for 'lvalue' usages.
+      *
+      * @return The pointer to the installed PSVI handler object.
+      */
+    PSVIHandler* getPSVIHandler();
+
+    /**
+      * This method returns the installed PSVI handler. Suitable
+      * for 'rvalue' usages.
+      *
+      * @return A const pointer to the installed PSVI handler object.
+      */
+    const PSVIHandler* getPSVIHandler() const;
+
     /**
       * This method returns a reference to the parser's installed
       * validator.
@@ -346,6 +449,18 @@ public :
       */
     bool getValidationSchemaFullChecking() const;
 
+    /** Get the 'identity constraint checking' flag
+      *
+      * This method returns the state of the parser's identity constraint
+      * checking flag.
+      *
+      * @return true, if the parser is currently configured to
+      *         have identity constraint checking, false otherwise.
+      *
+      * @see #setIdentityConstraintChecking
+      */
+    bool getIdentityConstraintChecking() const;
+
     /** Get error count from the last parse operation.
       *
       * This method returns the error count from the last parse
@@ -434,6 +549,23 @@ public :
       */
     XMLCh* getExternalNoNamespaceSchemaLocation() const;
 
+   /** Get the SecurityManager instance attached to this parser.
+      *
+      * This method returns the security manager 
+      * that was specified using setSecurityManager.
+      *
+      * The SecurityManager instance must have been specified by the application; 
+      * this should not be deleted until after the parser has been deleted (or
+      * a new SecurityManager instance has been supplied to the parser).
+      * 
+      * @return a pointer to the SecurityManager instance 
+      *         specified externally.  A null pointer is returned if nothing
+      *         was specified externally.
+      *
+      * @see #setSecurityManager(const SecurityManager* const)
+      */
+    SecurityManager* getSecurityManager() const;
+
     /** Get the 'Loading External DTD' flag
       *
       * This method returns the state of the parser's loading external DTD
@@ -471,6 +603,31 @@ public :
       */
     bool isUsingCachedGrammarInParse() const;
 
+    /**
+      * Get the 'calculate src offset flag'
+      *
+      * This method returns the state of the parser's src offset calculation
+      * when parsing an XML document.
+      *
+      * @return true, if the parser is currently configured to
+      *         calculate src offsets, false otherwise.
+      *
+      * @see #setCalculateSrcOfs
+      */
+    bool getCalculateSrcOfs() const;
+
+    /**
+      * Get the 'force standard uri flag'
+      *
+      * This method returns the state if the parser forces standard uri
+      *
+      * @return true, if the parser is currently configured to
+      *         force standard uri, i.e. malformed uri will be rejected.
+      *
+      * @see #setStandardUriConformant
+      */
+    bool getStandardUriConformant() const;
+
     /**
      * Retrieve the grammar that is associated with the specified namespace key
      *
@@ -491,8 +648,37 @@ public :
      *
      * @param uriId id of the string in the URI string pool.
      * @return URI string corresponding to the URI id.
-     */    
-    const XMLCh* getURIText(unsigned int uriId);
+     */
+    const XMLCh* getURIText(unsigned int uriId) const;
+
+    /**
+     * Returns the current src offset within the input source.
+     *
+     * @return offset within the input source
+     */
+    unsigned int getSrcOffset() const;
+
+    /** Get the 'generate synthetic annotations' flag
+      *    
+      * @return true, if the parser is currently configured to
+      *         generate synthetic annotations, false otherwise.
+      *         A synthetic XSAnnotation is created when a schema
+      *         component has non-schema attributes but has no
+      *         child annotations so that the non-schema attributes
+      *         can be recovered under PSVI.
+      *
+      * @see #setGenerateSyntheticAnnotations
+      */
+    bool getGenerateSyntheticAnnotations() const;
+
+    /** Get the 'validate annotations' flag
+      *    
+      * @return true, if the parser is currently configured to
+      *         validate annotations, false otherwise.
+      *
+      * @see #setValidateAnnotations
+      */
+    bool getValidateAnnotations() const;
 
     //@}
 
@@ -503,6 +689,27 @@ public :
 
     /** @name Setter methods */
     //@{
+    /** set the 'generate synthetic annotations' flag
+      *    
+      * @param newValue The value for specifying whether Synthetic Annotations
+      *        should be generated or not.
+      *        A synthetic XSAnnotation is created when a schema
+      *        component has non-schema attributes but has no
+      *        child annotations.
+      *
+      * @see #getGenerateSyntheticAnnotations
+      */
+    void setGenerateSyntheticAnnotations(const bool newValue);
+
+    /** set the 'validate annotations' flag
+      *    
+      * @param newValue The value for specifying whether annotations
+      *        should be validate or not.
+      *
+      * @see #getValidateAnnotations
+      */
+    void setValidateAnnotations(const bool newValue);
+
     /**
       * This method allows users to enable or disable the parser's
       * namespace processing. When set to true, parser starts enforcing
@@ -571,6 +778,19 @@ public :
       */
     void setValidationSchemaFullChecking(const bool schemaFullChecking);
 
+    /**
+      * This method allows the user to turn identity constraint checking on/off.
+      * Only takes effect if Schema validation is enabled.
+      * If turned off, identity constraint checking is not done.
+      *
+      * The parser's default state is: true.
+      *
+      * @param identityConstraintChecking True to turn on identity constraint checking.
+      *
+      * @see #getIdentityConstraintChecking
+      */
+    void setIdentityConstraintChecking(const bool identityConstraintChecking);
+
     /**
       * This method allows users to set the parser's behaviour when it
       * encounters the first fatal error. If set to true, the parser
@@ -667,6 +887,23 @@ public :
       */
     void setExternalNoNamespaceSchemaLocation(const char* const noNamespaceSchemaLocation);
 
+    /**
+      * This allows an application to set a SecurityManager on
+      * the parser; this object stores information that various
+      * components use to limit their consumption of system
+      * resources while processing documents.
+      *
+      * If this method is called more than once, only the last one takes effect.
+      * It may not be reset during a parse.
+      *
+      *
+      * @param securityManager  the SecurityManager instance to
+      * be used by this parser
+      *
+      * @see #getSecurityManager
+      */
+    void setSecurityManager(SecurityManager* const securityManager);
+
     /** Set the 'Loading External DTD' flag
       *
       * This method allows users to enable or disable the loading of external DTD.
@@ -724,6 +961,52 @@ public :
       */
     void useCachedGrammarInParse(const bool newState);
 
+    /** Enable/disable src offset calculation
+      *
+      * This method allows users to enable/disable src offset calculation.
+      * Disabling the calculation will improve performance.
+      *
+      * The parser's default state is: false.
+      *
+      * @param newState The value specifying whether we should enable or
+      *                 disable src offset calculation
+      *
+      * @see #getCalculateSrcOfs
+      */
+    void setCalculateSrcOfs(const bool newState);
+
+    /** Force standard uri
+      *
+      * This method allows users to tell the parser to force standard uri conformance.
+      *
+      * The parser's default state is: false.
+      *
+      * @param newState The value specifying whether the parser should reject malformed URI.
+      *
+      * @see #getStandardUriConformant
+      */
+    void setStandardUriConformant(const bool newState);
+
+    /** Set the scanner to use when scanning the XML document
+      *
+      * This method allows users to set the scanner to use
+      * when scanning a given XML document.
+      *
+      * @param scannerName The name of the desired scanner
+      */
+    void useScanner(const XMLCh* const scannerName);
+
+    /** Set maximum input buffer size
+      *
+      * This method allows users to limit the size of buffers used in parsing
+      * XML character data. The effect of setting this size is to limit the
+      * size of a ContentHandler::characters() call.
+      *
+      * The parser's default input buffer size is 1 megabyte.
+      *
+      * @param bufferSize The maximum input buffer size
+      */
+    void setInputBufferSize(const size_t bufferSize);
 
     //@}
 
@@ -1093,11 +1376,27 @@ public :
       */
     virtual void setErrorHandler(ErrorHandler* const handler);
 
+    /**
+      * This method installs the user specified PSVI handler on
+      * the parser.
+      *
+      * @param handler A pointer to the PSVI handler to be called
+      *                when the parser comes across 'PSVI' events
+      *                as per the schema specification.
+      *
+      * @see Parser#setPSVIHandler
+      */
+    virtual void setPSVIHandler(PSVIHandler* const handler);
+
     /**
       * This method installs the user specified entity resolver on the
       * parser. It allows applications to trap and redirect calls to
       * external entities.
       *
+      * <i>Any previously set entity resolver is merely dropped, since the parser
+      * does not own them.  If both setEntityResolver and setXMLEntityResolver
+      * are called, then the last one is used.</i>
+      *
       * @param resolver A pointer to the entity resolver to be called
       *                 when the parser comes across references to
       *                 entities in the XML file.
@@ -1105,6 +1404,24 @@ public :
       * @see Parser#setEntityResolver
       */
     virtual void setEntityResolver(EntityResolver* const resolver);
+
+    /**
+      * This method installs the user specified entity resolver on the
+      * parser. It allows applications to trap and redirect calls to
+      * external entities.
+      *
+      * <i>Any previously set entity resolver is merely dropped, since the parser
+      * does not own them.  If both setEntityResolver and setXMLEntityResolver
+      * are called, then the last one is used.</i>
+      *
+      * @param resolver A pointer to the entity resolver to be called
+      *                 when the parser comes across references to
+      *                 entities in the XML file.
+      *
+      * @see Parser#setXMLEntityResolver
+      */
+    virtual void setXMLEntityResolver(XMLEntityResolver* const resolver);
+
     //@}
 
 
@@ -1329,8 +1646,8 @@ public :
       * This method is used to report the XML decl scanned by the parser.
       * Refer to the XML specification to see the meaning of parameters.
       *
-      * <b><font color="#FF0000">This method is a no-op for this SAX driver
-      * implementation.</font></b>
+      * <b>This method is a no-op for this SAX driver
+      * implementation.</b>
       *
       * @param versionStr A const pointer to a Unicode string representing
       *                   version string value.
@@ -1397,8 +1714,8 @@ public :
       * This method allows the user installed Error Handler
       * callback to 'reset' itself.
       *
-      * <b><font color="#FF0000">This method is a no-op for this SAX driver
-      * implementation.</font></b>
+      * <b>This method is a no-op for this SAX driver
+      * implementation.</b>
       *
       */
     virtual void resetErrors();
@@ -1415,8 +1732,8 @@ public :
       * This method is used to indicate the end of parsing of an external
       * entity file.
       *
-      * <b><font color="#FF0000">This method is a no-op for this SAX driver
-      * implementation.</font></b>
+      * <b>This method is a no-op for this SAX driver
+      * implementation.</b>
       *
       * @param inputSource A const reference to the InputSource object
       *                    which points to the XML file being parsed.
@@ -1429,8 +1746,8 @@ public :
       * process any system id's of enternal entities encountered in
       * the XML file being parsed, such as redirection etc.
       *
-      * <b><font color="#FF0000">This method always returns 'false'
-      * for this SAX driver implementation.</font></b>
+      * <b>This method always returns 'false'
+      * for this SAX driver implementation.</b>
       *
       * @param systemId  A const pointer to an Unicode string representing
       *                  the system id scanned by the parser.
@@ -1448,8 +1765,8 @@ public :
       * This method allows the installed XMLEntityHandler to reset
       * itself.
       *
-      * <b><font color="#FF0000">This method is a no-op for this SAX driver
-      * implementation.</font></b>
+      * <b>This method is a no-op for this SAX driver
+      * implementation.</b>
       */
     virtual void resetEntities();
 
@@ -1459,6 +1776,8 @@ public :
       * can implement 'redirection' via this callback. The driver
       * should call the SAX EntityHandler 'resolveEntity' method.
       *
+      * @deprecated This method is no longer called (the other resolveEntity one is).
+      *
       * @param publicId A const pointer to a Unicode string representing the
       *                 public id of the entity just parsed.
       * @param systemId A const pointer to a Unicode string representing the
@@ -1480,12 +1799,33 @@ public :
         , const XMLCh* const    baseURI = 0
     );
 
+    /** Resolve a public/system id
+      *
+      * This method allows a user installed entity handler to further
+      * process any pointers to external entities. The applications can
+      * implement 'redirection' via this callback.  
+      *
+      * @param resourceIdentifier An object containing the type of
+      *        resource to be resolved and the associated data members
+      *        corresponding to this type.
+      * @return The value returned by the user installed resolveEntity
+      *         method or NULL otherwise to indicate no processing was done.
+      *         The returned InputSource is owned by the parser which is
+      *         responsible to clean up the memory.
+      * @see XMLEntityHandler
+      * @see XMLEntityResolver
+      */
+    virtual InputSource* resolveEntity
+    (
+        XMLResourceIdentifier* resourceIdentifier
+    );
+
     /**
       * This method is used to indicate the start of parsing an
       * external entity file.
       *
-      * <b><font color="#FF0000">This method is a no-op for this SAX driver
-      * implementation.</font></b>
+      * <b>This method is a no-op for this SAX driver
+      * implementation.</b>
       *
       * @param inputSource A const reference to the InputSource object
       *                    which points to the external entity
@@ -1503,8 +1843,8 @@ public :
     /**
       * This method is used to report an attribute definition.
       *
-      * <b><font color="#FF0000">This method is a no-op for this SAX
-      * driver implementation.</font></b>
+      * <b>This method is a no-op for this SAX
+      * driver implementation.</b>
       *
       * @param elemDecl A const reference to the object containing information
       *                 about the element whose attribute definition was just
@@ -1524,8 +1864,8 @@ public :
     /**
       * This method is used to report a comment occurring within the DTD.
       *
-      * <b><font color="#FF0000">This method is a no-op for this SAX driver
-      * implementation.</font></b>
+      * <b>This method is a no-op for this SAX driver
+      * implementation.</b>
       *
       * @param comment  A const pointer to a Unicode string representing the
       *                 text of the comment just parsed.
@@ -1538,8 +1878,8 @@ public :
     /**
       * This method is used to report the DOCTYPE declaration.
       *
-      * <b><font color="#FF0000">This method is a no-op for this SAX driver
-      * implementation.</font></b>
+      * <b>This method is a no-op for this SAX driver
+      * implementation.</b>
       *
       * @param elemDecl A const reference to the object containing information
       *                 about the root element definition declaration of the
@@ -1566,8 +1906,8 @@ public :
       * This method is used to report any PI declarations
       * occurring inside the DTD definition block.
       *
-      * <b><font color="#FF0000">This method is a no-op for this SAX driver
-      * implementation.</font></b>
+      * <b>This method is a no-op for this SAX driver
+      * implementation.</b>
       *
       * @param target A const pointer to a Unicode string representing the
       *               target of the PI declaration.
@@ -1585,8 +1925,8 @@ public :
       * This method is used to report any whitespaces
       * occurring inside the DTD definition block.
       *
-      * <b><font color="#FF0000">This method is a no-op for this SAX driver
-      * implementation.</font></b>
+      * <b>This method is a no-op for this SAX driver
+      * implementation.</b>
       *
       * @param chars  A const pointer to a Unicode string representing the
       *               whitespace characters.
@@ -1602,8 +1942,8 @@ public :
       * This method is used to report an element declarations
       * successfully scanned by the parser.
       *
-      * <b><font color="#FF0000">This method is a no-op for this SAX driver
-      * implementation.</font></b>
+      * <b>This method is a no-op for this SAX driver
+      * implementation.</b>
       *
       * @param decl   A const reference to the object containing element
       *               declaration information.
@@ -1620,8 +1960,8 @@ public :
       * This method is used to report the end of an attribute
       * list declaration for an element.
       *
-      * <b><font color="#FF0000">This method is a no-op for this SAX driver
-      * implementation.</font></b>
+      * <b>This method is a no-op for this SAX driver
+      * implementation.</b>
       *
       * @param elemDecl A const reference to the object containing element
       *                 declaration information.
@@ -1634,16 +1974,16 @@ public :
     /**
       * This method is used to report the end of the internal subset.
       *
-      * <b><font color="#FF0000">This method is a no-op for this SAX driver
-      * implementation.</font></b>
+      * <b>This method is a no-op for this SAX driver
+      * implementation.</b>
       */
     virtual void endIntSubset();
 
     /**
       * This method is used to report the end of the external subset.
       *
-      * <b><font color="#FF0000">This method is a no-op for this SAX driver
-      * implementation.</font></b>
+      * <b>This method is a no-op for this SAX driver
+      * implementation.</b>
       */
     virtual void endExtSubset();
 
@@ -1696,8 +2036,8 @@ public :
       * This method is used to indicate the start of an element's attribute
       * list declaration.
       *
-      * <b><font color="#FF0000">This method is a no-op for this SAX driver
-      * implementation.</font></b>
+      * <b>This method is a no-op for this SAX driver
+      * implementation.</b>
       *
       * @param elemDecl A const reference to the object containing element
       *                 declaration information.
@@ -1710,16 +2050,16 @@ public :
     /**
       * This method is used indicate the start of the internal subset.
       *
-      * <b><font color="#FF0000">This method is a no-op for this SAX driver
-      * implementation.</font></b>
+      * <b>This method is a no-op for this SAX driver
+      * implementation.</b>
       */
     virtual void startIntSubset();
 
     /**
       * This method is used indicate the start of the external subset.
       *
-      * <b><font color="#FF0000">This method is a no-op for this SAX driver
-      * implementation.</font></b>
+      * <b>This method is a no-op for this SAX driver
+      * implementation.</b>
       */
     virtual void startExtSubset();
 
@@ -1727,8 +2067,8 @@ public :
       * This method is used to report the TextDecl. Refer to the XML
       * specification for the syntax of a TextDecl.
       *
-      * <b><font color="#FF0000">This method is a no-op for this SAX driver
-      * implementation.</font></b>
+      * <b>This method is a no-op for this SAX driver
+      * implementation.</b>
       *
       * @param versionStr A const pointer to a Unicode string representing
       *                   the version number of the 'version' clause.
@@ -1789,14 +2129,25 @@ protected :
       */
     const XMLScanner& getScanner() const;
 
+    /** Get the Grammar resolver
+      *
+      * This provides derived classes with access to the grammar resolver.
+      */
+    GrammarResolver* getGrammarResolver() const;
+
 
 private:
     // -----------------------------------------------------------------------
     //  Unimplemented constructors and operators
     // -----------------------------------------------------------------------
     SAXParser(const SAXParser&);
-    void operator=(const SAXParser&);
+    SAXParser& operator=(const SAXParser&);
 
+    // -----------------------------------------------------------------------
+    //  Initialize/Cleanup methods
+    // -----------------------------------------------------------------------
+    void initialize();
+    void cleanUp();
 
     // -----------------------------------------------------------------------
     //  Private data members
@@ -1823,6 +2174,9 @@ private:
     //  fErrorHandler
     //      The installed SAX error handler, if any. Null if none.
     //
+    //  fPSVIHandler
+    //      The installed PSVI handler, if any. Null if none.
+    //
     //  fAdvDHCount
     //  fAdvDHList
     //  fAdvDHListSize
@@ -1844,18 +2198,30 @@ private:
     //      The scanner being used by this parser. It is created internally
     //      during construction.
     //
+    //   fGrammarPool
+    //      The grammar pool passed from external application (through derivatives).
+    //      which could be 0, not owned.
+    //
     // -----------------------------------------------------------------------
-    VecAttrListImpl         fAttrList;
-    DocumentHandler*        fDocHandler;
-    DTDHandler*             fDTDHandler;
-    unsigned int            fElemDepth;
-    EntityResolver*         fEntityResolver;
-    ErrorHandler*           fErrorHandler;
-    unsigned int            fAdvDHCount;
-    XMLDocumentHandler**    fAdvDHList;
-    unsigned int            fAdvDHListSize;
-    bool                    fParseInProgress;
-    XMLScanner*             fScanner;
+    bool                 fParseInProgress;
+    unsigned int         fElemDepth;
+    unsigned int         fAdvDHCount;
+    unsigned int         fAdvDHListSize;
+    VecAttrListImpl      fAttrList;
+    DocumentHandler*     fDocHandler;
+    DTDHandler*          fDTDHandler;
+    EntityResolver*      fEntityResolver;
+    XMLEntityResolver*   fXMLEntityResolver;
+    ErrorHandler*        fErrorHandler;
+    PSVIHandler*         fPSVIHandler;
+    XMLDocumentHandler** fAdvDHList;
+    XMLScanner*          fScanner;
+    GrammarResolver*     fGrammarResolver;
+    XMLStringPool*       fURIStringPool;
+    XMLValidator*        fValidator;
+    MemoryManager*       fMemoryManager;
+    XMLGrammarPool*      fGrammarPool;
+    XMLBuffer            fElemQNameBuf;
 };
 
 
@@ -1877,6 +2243,16 @@ inline EntityResolver* SAXParser::getEntityResolver()
     return fEntityResolver;
 }
 
+inline XMLEntityResolver* SAXParser::getXMLEntityResolver()
+{
+    return fXMLEntityResolver;
+}
+
+inline const XMLEntityResolver* SAXParser::getXMLEntityResolver() const
+{
+    return fXMLEntityResolver;
+}
+
 inline const EntityResolver* SAXParser::getEntityResolver() const
 {
     return fEntityResolver;
@@ -1892,9 +2268,26 @@ inline const ErrorHandler* SAXParser::getErrorHandler() const
     return fErrorHandler;
 }
 
+inline PSVIHandler* SAXParser::getPSVIHandler()
+{
+    return fPSVIHandler;
+}
+
+inline const PSVIHandler* SAXParser::getPSVIHandler() const
+{
+    return fPSVIHandler;
+}
+
 inline const XMLScanner& SAXParser::getScanner() const
 {
     return *fScanner;
 }
 
+inline GrammarResolver* SAXParser::getGrammarResolver() const
+{
+    return fGrammarResolver;
+}
+
+XERCES_CPP_NAMESPACE_END
+
 #endif
