@@ -1,61 +1,27 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2003 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
  * $Log: SAXParseException.cpp,v $
+ * Revision 1.6  2004/09/08 13:56:19  peiyongz
+ * Apache License Version 2.0
+ *
+ * Revision 1.5  2003/08/13 15:43:24  knoaman
+ * Use memory manager when creating SAX exceptions.
+ *
  * Revision 1.4  2003/04/21 21:07:38  knoaman
  * Use XMLString::release to prepare for configurable memory manager.
  *
@@ -102,12 +68,13 @@ XERCES_CPP_NAMESPACE_BEGIN
 //  SAXParseException: Constructors and Destructor
 // ---------------------------------------------------------------------------
 SAXParseException::SAXParseException(const  XMLCh* const    message
-                                    , const Locator&        locator) :
-    SAXException(message)
+                                    , const Locator&        locator
+                                    , MemoryManager* const  manager) :
+    SAXException(message, manager)
     , fColumnNumber(locator.getColumnNumber())
     , fLineNumber(locator.getLineNumber())
-    , fPublicId(XMLString::replicate(locator.getPublicId()))
-    , fSystemId(XMLString::replicate(locator.getSystemId()))
+    , fPublicId(XMLString::replicate(locator.getPublicId(), manager))
+    , fSystemId(XMLString::replicate(locator.getSystemId(), manager))
 {
 }
 
@@ -115,12 +82,13 @@ SAXParseException::SAXParseException(const  XMLCh* const    message
                                     , const XMLCh* const    publicId
                                     , const XMLCh* const    systemId
                                     , const XMLSSize_t      lineNumber
-                                    , const XMLSSize_t      columnNumber) :
-    SAXException(message)
+                                    , const XMLSSize_t      columnNumber
+                                    , MemoryManager* const  manager) :
+    SAXException(message, manager)
     , fColumnNumber(columnNumber)
     , fLineNumber(lineNumber)
-    , fPublicId(XMLString::replicate(publicId))
-    , fSystemId(XMLString::replicate(systemId))
+    , fPublicId(XMLString::replicate(publicId, manager))
+    , fSystemId(XMLString::replicate(systemId, manager))
 {
 }
 
@@ -132,14 +100,14 @@ SAXParseException::SAXParseException(const SAXParseException& toCopy) :
     , fPublicId(0)
     , fSystemId(0)
 {
-    fPublicId = XMLString::replicate(toCopy.fPublicId);
-    fSystemId = XMLString::replicate(toCopy.fSystemId);
+    fPublicId = XMLString::replicate(toCopy.fPublicId, toCopy.fMemoryManager);
+    fSystemId = XMLString::replicate(toCopy.fSystemId, toCopy.fMemoryManager);
 }
 
 SAXParseException::~SAXParseException()
 {
-    XMLString::release(&fPublicId);
-    XMLString::release(&fSystemId);
+    fMemoryManager->deallocate(fPublicId);//XMLString::release(&fPublicId);
+    fMemoryManager->deallocate(fSystemId);//XMLString::release(&fSystemId);
 }
 
 
@@ -152,14 +120,15 @@ SAXParseException::operator=(const SAXParseException& toAssign)
     if (this == &toAssign)
         return *this;
 
+    fMemoryManager->deallocate(fPublicId);//XMLString::release(&fPublicId);
+    fMemoryManager->deallocate(fSystemId);//XMLString::release(&fSystemId);
+
     this->SAXException::operator =(toAssign);
     fColumnNumber = toAssign.fColumnNumber;
     fLineNumber = toAssign.fLineNumber;
 
-    XMLString::release(&fPublicId);
-    XMLString::release(&fSystemId);
-    fPublicId = XMLString::replicate(toAssign.fPublicId);
-    fSystemId = XMLString::replicate(toAssign.fSystemId);
+    fPublicId = XMLString::replicate(toAssign.fPublicId, fMemoryManager);
+    fSystemId = XMLString::replicate(toAssign.fSystemId, fMemoryManager);
 
     return *this;
 }
