@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 2001, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2001,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: Base64.hpp,v 1.8 2003/12/17 00:18:35 cargilld Exp $
+ * $Id: Base64.hpp,v 1.13 2004/09/08 13:56:21 peiyongz Exp $
  */
 
 #ifndef BASE64_HPP
@@ -80,6 +40,12 @@ class XMLUTIL_EXPORT Base64
 {
 public :
 
+    enum Conformance
+    {
+        Conf_RFC2045
+      , Conf_Schema
+    };
+
     //@{
 
     /**
@@ -102,7 +68,7 @@ public :
      */
     static XMLByte* encode(const XMLByte* const inputData
                          , const unsigned int   inputLength
-                         , unsigned int*        outputLength                         
+                         , unsigned int*        outputLength
                          , MemoryManager* const memMgr = 0);
 
     /**
@@ -116,15 +82,19 @@ public :
      * the returned buffer.
      *
      * @param inputData Base64 data in XMLByte stream.
-     * @param outputLength Length of decoded XMLByte stream.
+     * @param decodedLength Length of decoded XMLByte stream.
      * @param memMgr client provided memory manager
+     * @param conform conformance specified
      * @return Decoded binary data in XMLByte stream,
      *      or NULL if input data can not be decoded.
      * @see   XMLString::release(XMLByte**)
      */
-    static XMLByte* decode(const XMLByte* const inputData
-                         , unsigned int*        outputLength                         
-                         , MemoryManager* const memMgr = 0);
+    static XMLByte* decode(
+                           const XMLByte*        const   inputData
+                         ,       unsigned int*           decodedLength
+                         ,       MemoryManager*  const   memMgr = 0
+                         ,       Conformance             conform = Conf_RFC2045
+                          );
 
     /**
      * Decodes Base64 data into XMLCh
@@ -137,15 +107,19 @@ public :
      * the returned buffer.
      *
      * @param inputData Base64 data in XMLCh stream.
-     * @param outputLength Length of decoded XMLCh stream
+     * @param decodedLength Length of decoded XMLCh stream
      * @param memMgr client provided memory manager
+     * @param conform conformance specified
      * @return Decoded binary data in XMLCh stream,
      *      or NULL if input data can not be decoded.
      * @see   XMLString::release(XMLCh**)
      */
-    static XMLCh* decode(const XMLCh* const   inputData
-                       , unsigned int*        outputLength
-                       , MemoryManager* const memMgr = 0);
+    static XMLCh* decode(
+                         const XMLCh*          const    inputData
+                       ,       unsigned int*            decodedLength
+                       ,       MemoryManager*  const    memMgr = 0
+                       ,       Conformance              conform = Conf_RFC2045
+                        );
 
     /**
      * Get data length
@@ -154,20 +128,55 @@ public :
      * containing encoded data.
      *
      * @param inputData Base64 data in XMLCh stream.
+     * @param memMgr client provided memory manager
+     * @param conform conformance specified
      * @return Length of decoded data,
 	 *      or -1 if input data can not be decoded.
      */
-    static int getDataLength(const XMLCh* const inputData
-        , MemoryManager* const memMgr = 0);
+    static int getDataLength(
+                             const XMLCh*         const  inputData
+                            ,      MemoryManager* const  memMgr = 0
+                            ,      Conformance           conform = Conf_RFC2045
+                             );
 
     //@}
 
+     /**
+     * get canonical representation
+     *
+     * Caller is responsible for the proper deallcation
+     * of the string returned.
+     * 
+     * @param inputData A string containing the Base64
+     * @param memMgr client provided memory manager
+     * @param conform conformance specified
+     *
+     * return: the canonical representation of the Base64
+     *         if it is a valid Base64
+     *         0 otherwise
+     */
+
+    static XMLCh* getCanonicalRepresentation
+                  (
+                      const XMLCh*          const inputData
+                    ,       MemoryManager*  const memMgr = 0
+                    ,       Conformance           conform = Conf_RFC2045
+                  );
+
 private :
 
     // -----------------------------------------------------------------------
     //  Helper methods
     // -----------------------------------------------------------------------
 
+    static XMLByte* decode(
+                           const XMLByte*        const   inputData
+                         ,       unsigned int*           outputLength
+                         ,       XMLByte*&               canRepData
+                         ,       MemoryManager*  const   memMgr = 0
+                         ,       Conformance             conform = Conf_RFC2045
+                          );
+
     static void init();
 
     static bool isData(const XMLByte& octet);
