@@ -1,61 +1,28 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2000 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2000,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
  * $Log: BinFileInputStream.cpp,v $
+ * Revision 1.5  2004/09/08 13:56:21  peiyongz
+ * Apache License Version 2.0
+ *
+ * Revision 1.4  2003/12/17 13:58:02  cargilld
+ * Platform update for memory management so that the static memory manager (one
+ * used to call Initialize) is only for static data.
+ *
  * Revision 1.3  2003/05/16 03:11:22  knoaman
  * Partial implementation of the configurable memory manager.
  *
@@ -102,37 +69,42 @@ XERCES_CPP_NAMESPACE_BEGIN
 // ---------------------------------------------------------------------------
 //  BinFileInputStream: Constructors and Destructor
 // ---------------------------------------------------------------------------
-BinFileInputStream::BinFileInputStream(const XMLCh* const fileName) :
+BinFileInputStream::BinFileInputStream(const XMLCh* const fileName
+                                       , MemoryManager* const manager) :
 
     fSource(0)
+  , fMemoryManager(manager)
 {
     // Try to open the file
-    fSource = XMLPlatformUtils::openFile(fileName);
+    fSource = XMLPlatformUtils::openFile(fileName, manager);
 }
 
 BinFileInputStream::BinFileInputStream(const char* const fileName,
                                        MemoryManager* const manager) :
 
     fSource(0)
+  , fMemoryManager(manager)
 {
     // Transcode the file name and put a janitor on the temp buffer
     XMLCh* realName = XMLString::transcode(fileName, manager);
     ArrayJanitor<XMLCh> janName(realName, manager);
 
     // Try to open the file
-    fSource = XMLPlatformUtils::openFile(realName);
+    fSource = XMLPlatformUtils::openFile(realName, manager);
 }
 
-BinFileInputStream::BinFileInputStream(const FileHandle toAdopt) :
+BinFileInputStream::BinFileInputStream(const FileHandle toAdopt
+                                       , MemoryManager* const manager) :
 
     fSource(toAdopt)
+  , fMemoryManager(manager)
 {
 }
 
 BinFileInputStream::~BinFileInputStream()
 {
     if (fSource)
-        XMLPlatformUtils::closeFile(fSource);
+        XMLPlatformUtils::closeFile(fSource, fMemoryManager);
 }
 
 
@@ -141,7 +113,7 @@ BinFileInputStream::~BinFileInputStream()
 // ---------------------------------------------------------------------------
 unsigned int BinFileInputStream::getSize() const
 {
-    return XMLPlatformUtils::fileSize(fSource);
+    return XMLPlatformUtils::fileSize(fSource, fMemoryManager);
 }
 
 
@@ -150,7 +122,7 @@ unsigned int BinFileInputStream::getSize() const
 // ---------------------------------------------------------------------------
 void BinFileInputStream::reset()
 {
-    XMLPlatformUtils::resetFile(fSource);
+    XMLPlatformUtils::resetFile(fSource, fMemoryManager);
 }
 
 
@@ -159,7 +131,7 @@ void BinFileInputStream::reset()
 // ---------------------------------------------------------------------------
 unsigned int BinFileInputStream::curPos() const
 {
-    return XMLPlatformUtils::curFilePos(fSource);
+    return XMLPlatformUtils::curFilePos(fSource, fMemoryManager);
 }
 
 unsigned int
@@ -170,7 +142,7 @@ BinFileInputStream::readBytes(          XMLByte* const  toFill
     //  Read up to the maximum bytes requested. We return the number
     //  actually read.
     //
-    return XMLPlatformUtils::readFileBuffer(fSource, maxToRead, toFill);
+    return XMLPlatformUtils::readFileBuffer(fSource, maxToRead, toFill, fMemoryManager);
 }
 
 XERCES_CPP_NAMESPACE_END
