@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2000 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2000,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: MacOSPlatformUtils.cpp,v 1.18 2003/05/21 02:43:07 jberry Exp $
+ * $Id: MacOSPlatformUtils.cpp,v 1.28 2004/09/08 13:56:40 peiyongz Exp $
  */
 
 
@@ -68,6 +28,7 @@
 #include <cstdio>
 #include <memory>
 #include <algorithm>
+#include <unistd.h>
 
 #if defined(__APPLE__)
     //	Include from Frameworks Headers under ProjectBuilder
@@ -142,6 +103,9 @@ bool	XMLParsePathToFSSpec_Classic(const XMLCh* const pathName, FSSpec& spec, Mem
 //   This flag indicates whether the file system APIs meet our minimum
 //   requirements.
 //
+//  gMacOSXOrBetter
+//   The system version is >= 10.
+//
 // gHasFSSpecAPIs
 //   True if the FSSpecAPIs are available. These are required.
 //
@@ -169,8 +133,12 @@ bool	XMLParsePathToFSSpec_Classic(const XMLCh* const pathName, FSSpec& spec, Mem
 //
 // gUsePosixFiles
 //   True if we're using XMLMacPosixFile rather than XMLMacCarbonFile.
+//
+// gUseGETCWD
+//   True if we can rely on getcwd to get the current directory path.
 //----------------------------------------------------------------------------
 bool gFileSystemCompatible	= false;
+bool gMacOSXOrBetter		= false;
 bool gHasFSSpecAPIs			= false;
 bool gHasFS2TBAPIs			= false;
 bool gHasHFSPlusAPIs		= false;
@@ -178,6 +146,7 @@ bool gHasFSPathAPIs			= false;
 bool gPathAPIsUsePosixPaths	= false;
 bool gHasMPAPIs				= false;
 bool gUsePosixFiles			= false;
+bool gUseGETCWD				= false;
 
 
 // ---------------------------------------------------------------------------
@@ -197,30 +166,35 @@ XMLPlatformUtils::panic(const PanicHandler::PanicReasons reason)
 //  XMLPlatformUtils: File Methods
 // ---------------------------------------------------------------------------
 unsigned int
-XMLPlatformUtils::curFilePos(const FileHandle theFile)
+XMLPlatformUtils::curFilePos(const FileHandle theFile
+                             , MemoryManager* const manager)
 {
 	return reinterpret_cast<XMLMacAbstractFile*>(theFile)->currPos();
 }
 
 void
-XMLPlatformUtils::closeFile(const FileHandle theFile)
+XMLPlatformUtils::closeFile(const FileHandle theFile
+                            , MemoryManager* const manager)
 {
     reinterpret_cast<XMLMacAbstractFile*>(theFile)->close();
+	delete reinterpret_cast<XMLMacAbstractFile*>(theFile);
 }
 
 unsigned int
-XMLPlatformUtils::fileSize(const FileHandle theFile)
+XMLPlatformUtils::fileSize(const FileHandle theFile
+                           , MemoryManager* const manager)
 {
     return reinterpret_cast<XMLMacAbstractFile*>(theFile)->size();
 }
 
 
 FileHandle
-XMLPlatformUtils::openFile(const char* const fileName)
+XMLPlatformUtils::openFile(const char* const fileName
+                           , MemoryManager* const manager)
 {
     // Check to make sure the file system is in a state where we can use it
     if (!gFileSystemCompatible)
-        ThrowXML1(XMLPlatformUtilsException, XMLExcepts::File_CouldNotOpenFile, fileName);
+        ThrowXMLwithMemMgr1(XMLPlatformUtilsException, XMLExcepts::File_CouldNotOpenFile, fileName, manager);
 
     Janitor<XMLMacAbstractFile> file(XMLMakeMacFile());
     
@@ -229,11 +203,11 @@ XMLPlatformUtils::openFile(const char* const fileName)
 
 
 FileHandle
-XMLPlatformUtils::openFile(const XMLCh* const fileName)
+XMLPlatformUtils::openFile(const XMLCh* const fileName, MemoryManager* const manager)
 {
     // Check to make sure the file system is in a state where we can use it
     if (!gFileSystemCompatible)
-        ThrowXML1(XMLPlatformUtilsException, XMLExcepts::File_CouldNotOpenFile, fileName);
+        ThrowXMLwithMemMgr1(XMLPlatformUtilsException, XMLExcepts::File_CouldNotOpenFile, fileName, manager);
 
     Janitor<XMLMacAbstractFile> file(XMLMakeMacFile());
 
@@ -242,11 +216,12 @@ XMLPlatformUtils::openFile(const XMLCh* const fileName)
 
 
 FileHandle
-XMLPlatformUtils::openFileToWrite(const char* const fileName)
+XMLPlatformUtils::openFileToWrite(const char* const fileName
+                                  , MemoryManager* const manager)
 {
     // Check to make sure the file system is in a state where we can use it
     if (!gFileSystemCompatible)
-        ThrowXML1(XMLPlatformUtilsException, XMLExcepts::File_CouldNotOpenFile, fileName);
+        ThrowXMLwithMemMgr1(XMLPlatformUtilsException, XMLExcepts::File_CouldNotOpenFile, fileName, manager);
 
     Janitor<XMLMacAbstractFile> file(XMLMakeMacFile());
 
@@ -255,11 +230,12 @@ XMLPlatformUtils::openFileToWrite(const char* const fileName)
 
 
 FileHandle
-XMLPlatformUtils::openFileToWrite(const XMLCh* const fileName)
+XMLPlatformUtils::openFileToWrite(const XMLCh* const fileName
+                                  , MemoryManager* const manager)
 {
     // Check to make sure the file system is in a state where we can use it
     if (!gFileSystemCompatible)
-        ThrowXML1(XMLPlatformUtilsException, XMLExcepts::File_CouldNotOpenFile, fileName);
+        ThrowXMLwithMemMgr1(XMLPlatformUtilsException, XMLExcepts::File_CouldNotOpenFile, fileName, manager);
 
     Janitor<XMLMacAbstractFile> file(XMLMakeMacFile());
 
@@ -268,10 +244,10 @@ XMLPlatformUtils::openFileToWrite(const XMLCh* const fileName)
 
 
 FileHandle
-XMLPlatformUtils::openStdInHandle()
+XMLPlatformUtils::openStdInHandle(MemoryManager* const manager)
 {
     XMLCh stdinStr[] = {chLatin_s, chLatin_t, chLatin_d, chLatin_i, chLatin_n, chNull};
-    ThrowXML1(XMLPlatformUtilsException, XMLExcepts::File_CouldNotOpenFile, stdinStr);
+    ThrowXMLwithMemMgr1(XMLPlatformUtilsException, XMLExcepts::File_CouldNotOpenFile, stdinStr, manager);
     return NULL;
 }
 
@@ -279,7 +255,8 @@ XMLPlatformUtils::openStdInHandle()
 unsigned int
 XMLPlatformUtils::readFileBuffer(   const FileHandle      theFile
                                  ,  const unsigned int    toRead
-                                 ,        XMLByte* const  toFill)
+                                 ,        XMLByte* const  toFill
+                                 ,  MemoryManager* const  manager)
 {
     return reinterpret_cast<XMLMacAbstractFile*>(theFile)->read(toRead, toFill);
 }
@@ -288,14 +265,16 @@ XMLPlatformUtils::readFileBuffer(   const FileHandle      theFile
 void
 XMLPlatformUtils::writeBufferToFile(   const   FileHandle   theFile
                                     ,  const long		    toWrite
-                                    ,  const XMLByte* const toFlush)
+                                    ,  const XMLByte* const toFlush
+                                    ,  MemoryManager* const manager)
 {
     return reinterpret_cast<XMLMacAbstractFile*>(theFile)->write(toWrite, toFlush);
 }
 
 
 void
-XMLPlatformUtils::resetFile(FileHandle theFile)
+XMLPlatformUtils::resetFile(FileHandle theFile
+                            , MemoryManager* const manager)
 {
     reinterpret_cast<XMLMacAbstractFile*>(theFile)->reset();
 }
@@ -332,7 +311,8 @@ XMLPlatformUtils::getFullPath(const XMLCh* const srcPath,
 
 
 bool
-XMLPlatformUtils::isRelative(const XMLCh* const toCheck)
+XMLPlatformUtils::isRelative(const XMLCh* const toCheck
+                             , MemoryManager* const manager)
 {
     return (toCheck[0] != L'/');
 }
@@ -342,14 +322,19 @@ XMLCh* XMLPlatformUtils::getCurrentDirectory(MemoryManager* const manager)
 {
 	//	Get a newly allocated path to the current directory
 	FSSpec spec;
+
+	//  Parse to path to determine current directory: this allows the
+	//  path parsing routines to determine best way to find the current
+	//  directory.
+	XMLCh curDirPath[] = { '.', 0 };
 	XMLCh* path =
-		(noErr == FSMakeFSSpec(0, 0, NULL, &spec))
+		(XMLParsePathToFSSpec(curDirPath, spec, manager))
 			? XMLCreateFullPathFromFSSpec(spec, manager)
 			: NULL;
 			
     if (!path)
-		 ThrowXML(XMLPlatformUtilsException,
-	           XMLExcepts::File_CouldNotGetBasePathName);
+		 ThrowXMLwithMemMgr(XMLPlatformUtilsException,
+	           XMLExcepts::File_CouldNotGetBasePathName, manager);
 	           
 	return path;
 }
@@ -515,6 +500,11 @@ XMLPlatformUtils::platformInit()
 
 	//	Detect available functions
 	
+	//  Check whether we're on OS X
+	gMacOSXOrBetter			= noErr == Gestalt(gestaltSystemVersion, &value)
+							  && value >= 0x00001000
+							  ;
+	
     //	Look for file system services
     if (noErr == Gestalt(gestaltFSAttr, &value))
     {
@@ -541,9 +531,15 @@ XMLPlatformUtils::platformInit()
 	#if __MSL__ && (__MSL__ < 0x08000 || _MSL_CARBON_FILE_APIS)
 	gUsePosixFiles			= false;
 	#else
-	gUsePosixFiles			= noErr == Gestalt(gestaltSystemVersion, &value)
-							  && value >= 0x00001000
-							  ;
+	gUsePosixFiles			= gMacOSXOrBetter;
+	#endif
+	
+	//  Determine whether to use getcwd or not. We use it only if we're not using MSL,
+	//  and we're on a Mac OS X system.
+	#if __MSL__
+	gUseGETCWD				= false;
+	#else
+	gUseGETCWD				= gMacOSXOrBetter;
 	#endif
 
     //	Look for MP
@@ -794,29 +790,41 @@ XMLParsePathToFSRef_X(const XMLCh* const pathName, FSRef& ref, MemoryManager* co
 	
 	//	If it's a relative path, pre-pend the current directory to the path.
 	//	FSPathMakeRef doesn't deal with relativity on the front of the path
-	if (*p != '/')
+	if (*p != '/' && kMaxMacStaticPathChars > pathLen)
 	{
 		//	Right justify the user path to make room for the pre-pended path
 		std::memmove(p + kMaxMacStaticPathChars - pathLen, p, pathLen);
+		*p = '\0';
 				
 		//	Get the current directory
-        FSSpec spec;
-		if (err == noErr)
-			err = FSMakeFSSpec(0, 0, NULL, &spec);
-        if (err == noErr)
-            err = FSpMakeFSRef(&spec, &ref);
-		
-		//	Get pathname to the current directory
-		if (err == noErr)
-			err = FSRefMakePath(&ref, reinterpret_cast<UInt8*>(p), kMaxMacStaticPathChars - pathLen - 1);	// leave room for one '/'
-		std::size_t prefixLen = std::strlen(p);
-			
-		//	Now munge the two paths back together
-		if (err == noErr)
+		if (gUseGETCWD)
 		{
-			p[prefixLen++] = '/';
-			std::memmove(p + prefixLen, p + kMaxMacStaticPathChars - pathLen, pathLen);
+			//	Get current directory path, leaving room for one '/' after
+			if (err == noErr)
+				getcwd(p, kMaxMacStaticPathChars - pathLen - 1);
 		}
+		else
+		{
+			//	Get current directory path, leaving room for one '/' after
+
+			//	We quiz the carbon file manager for the current directory.
+			//	Note that carbon defaults its concept of the current directory
+			//  to the location of the executable.
+	        FSSpec spec;
+			if (err == noErr)
+				err = FSMakeFSSpec(0, 0, NULL, &spec);
+	        if (err == noErr)
+	            err = FSpMakeFSRef(&spec, &ref);
+			
+			//	Get current directory path, leaving room for one '/' after
+			if (err == noErr)
+				err = FSRefMakePath(&ref, reinterpret_cast<UInt8*>(p), kMaxMacStaticPathChars - pathLen - 1);
+		}
+					
+		//	Now munge the two paths back together
+		std::size_t prefixLen = std::strlen(p);
+		p[prefixLen++] = '/';
+		std::memmove(p + prefixLen, p + kMaxMacStaticPathChars - pathLen, pathLen);
 		
 		//	We now have a path from an absolute starting point
 	}
@@ -899,7 +907,7 @@ XMLParsePathToFSRef_Classic(const XMLCh* const pathName, FSRef& ref, MemoryManag
             err = FSpMakeFSRef(&spec, &ref);
     }
 
-    // ref now refers to the a parent directory: parse the rest of the path
+    // ref now refers to the parent directory: parse the rest of the path
     while (err == noErr && *p)
     {
         switch (*p)
