@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2002 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: OS390PlatformUtils.cpp,v 1.10 2003/05/15 18:37:48 knoaman Exp $
+ * $Id: OS390PlatformUtils.cpp,v 1.19 2004/09/08 13:56:41 peiyongz Exp $
  */
 
 
@@ -91,6 +51,7 @@
 #include    <xercesc/util/PanicHandler.hpp>
 #include    "Path390.hpp"
 #include    "FileHandleImpl.hpp"
+#include    <xercesc/util/OutOfMemoryException.hpp>
 
 #if defined (XML_USE_ICU_TRANSCODER)
     #include <xercesc/util/Transcoders/ICU/ICUTransService.hpp>
@@ -135,6 +96,10 @@ void XMLPlatformUtils::platformInit()
    {
      XMLPlatformUtils::recognizeNEL(true);
    }
+   catch(const OutOfMemoryException&)
+   {
+     throw;
+   }
    catch (...)
    {
       panic(PanicHandler::Panic_SystemInit);
@@ -157,6 +122,10 @@ void XMLPlatformUtils::platformInit()
             isPosixEnabled = true;
       }
    }
+   catch(const OutOfMemoryException&)
+   {
+      throw;
+   }
    catch (...)
    {
       panic(PanicHandler::Panic_SystemInit);
@@ -195,10 +164,13 @@ XMLMsgLoader* XMLPlatformUtils::loadAMsgSet(const XMLCh* const msgDomain)
         retVal = new InMemMsgLoader(msgDomain);
 #endif
     }
-
+    catch(const OutOfMemoryException&)
+    {
+        throw;
+    }
     catch(...)
     {
-   panic(PanicHandler::Panic_CantLoadMsgDomain);
+        panic(PanicHandler::Panic_CantLoadMsgDomain);
     }
     return retVal;
 }
@@ -241,7 +213,8 @@ void XMLPlatformUtils::panic(const PanicHandler::PanicReasons reason)
 // ---------------------------------------------------------------------------
 static void emptyBuffer(XMLByte* writeBuffer,
                         size_t   bytesToWrite,
-                        FileHandleImpl* fhiPtr)
+                        FileHandleImpl* fhiPtr
+                        , MemoryManager* const manager)
 {
      FILE* fileHandle = (FILE*)fhiPtr->getHandle();
      size_t bytesThisWrite = 0;
@@ -273,7 +246,7 @@ static void emptyBuffer(XMLByte* writeBuffer,
         bytesThisWrite = fwrite(writeBuffer, sizeof(XMLByte), bytesThisPass, fileHandle);
 
         if (ferror(fileHandle))
-           ThrowXML(XMLPlatformUtilsException, XMLExcepts::File_CouldNotWriteToFile);
+           ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotWriteToFile, manager);
 
         bytesToWrite -= bytesThisWrite;
         writeBuffer += bytesThisWrite;
@@ -283,7 +256,8 @@ static void emptyBuffer(XMLByte* writeBuffer,
 }
 
 
-static FileHandleImpl* openRead(char* tmpFileName)
+static FileHandleImpl* openRead(char* tmpFileName
+                                , MemoryManager* const manager)
 {
      FileHandleImpl* retVal;
      FILE* fileHandle = 0;
@@ -301,8 +275,8 @@ static FileHandleImpl* openRead(char* tmpFileName)
         optionBufferSize += (strlen(pathobj.getfopenParms()) + 1);
      }
 
-     char* optionBuffer = (char*) fgMemoryManager->allocate(optionBufferSize * sizeof(char));//new char[optionBufferSize];
-     ArrayJanitor<char> janText((char*)optionBuffer, fgMemoryManager);
+     char* optionBuffer = (char*) manager->allocate(optionBufferSize * sizeof(char));//new char[optionBufferSize];
+     ArrayJanitor<char> janText((char*)optionBuffer, manager);
      strcpy(optionBuffer,"rb");
 
      // Build the options buffer
@@ -322,7 +296,7 @@ static FileHandleImpl* openRead(char* tmpFileName)
      // of the FileHandleImpl class.
 
      fileHandle = fopen(pathobj.getfopenPath(), optionBuffer);
-     retVal = new FileHandleImpl(fileHandle, _FHI_READ, pathobj.isRecordType());
+     retVal = new (manager) FileHandleImpl(fileHandle, _FHI_READ, pathobj.isRecordType(), 0, manager);
 
      // temp fix for HFS files with "type=record" specified
      // close the file and re-open it without the fopen options
@@ -335,12 +309,12 @@ static FileHandleImpl* openRead(char* tmpFileName)
         fldata_rc = fldata(fileHandle, pathobj.getfopenPath(), &fileinfo);
 
         if (fldata_rc)
-           ThrowXML(XMLPlatformUtilsException, XMLExcepts::File_CouldNotReadFromFile);
+           ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotReadFromFile, manager);
 
         if (fileinfo.__dsorgHFS)
         {
            if (fclose(fileHandle))
-              ThrowXML(XMLPlatformUtilsException, XMLExcepts::File_CouldNotCloseFile);
+              ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotCloseFile, manager);
 
            fileHandle=fopen(pathobj.getfopenPath(), "rb");
            retVal->setHandle(fileHandle);
@@ -360,11 +334,11 @@ static FileHandleImpl* openRead(char* tmpFileName)
     //     path/path2/filename.ext  => //path.path2.ext(filename)
     //     path/path2/filename      => //path.path2.filename
 
-    char* datasetName = (char*) fgMemoryManager->allocate
+    char* datasetName = (char*) manager->allocate
     (
         (strlen(tmpFileName) + 5) * sizeof(char)
     );//new char[ strlen(tmpFileName) + 5 ];
-    ArrayJanitor<char> janText1((char*)datasetName, fgMemoryManager);
+    ArrayJanitor<char> janText1((char*)datasetName, manager);
     char *datasetPos = datasetName, *tmpPos = tmpFileName;
 
     // We are in EBCDIC mode here
@@ -450,12 +424,12 @@ static FileHandleImpl* openRead(char* tmpFileName)
                fldata_rc = fldata(fileHandle, srcName, &fileinfo);
 
                if (fldata_rc)
-                 ThrowXML(XMLPlatformUtilsException, XMLExcepts::File_CouldNotReadFromFile);
+                 ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotReadFromFile, manager);
 
                if (fileinfo.__dsorgHFS)
                {
                   if (fclose(fileHandle))
-                     ThrowXML(XMLPlatformUtilsException, XMLExcepts::File_CouldNotCloseFile);
+                     ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotCloseFile, manager);
 
                   fileHandle=fopen(srcName, "rb");
                   retVal->setHandle(fileHandle);
@@ -482,7 +456,8 @@ static FileHandleImpl* openRead(char* tmpFileName)
 }
 
 
-static FileHandleImpl* openWrite(char* tmpFileName)
+static FileHandleImpl* openWrite(char* tmpFileName
+                                 , MemoryManager* const manager)
 {
     FileHandleImpl* retVal;
     FILE* fileHandle = 0;
@@ -502,8 +477,8 @@ static FileHandleImpl* openWrite(char* tmpFileName)
     if (pathobj.getfopenParms())
        optionBufferSize += (strlen(pathobj.getfopenParms()) + 1);
 
-    char* optionBuffer = (char*) fgMemoryManager->allocate((optionBufferSize) * sizeof(char));//new char[optionBufferSize];
-    ArrayJanitor<char> janText((char*)optionBuffer, fgMemoryManager);
+    char* optionBuffer = (char*) manager->allocate((optionBufferSize) * sizeof(char));//new char[optionBufferSize];
+    ArrayJanitor<char> janText((char*)optionBuffer, manager);
     strcpy(optionBuffer,"wb");
 
     // Build the options buffer
@@ -530,7 +505,7 @@ static FileHandleImpl* openWrite(char* tmpFileName)
        fldata_rc = fldata(fileHandle, pathobj.getfopenPath(), &fileinfo);
 
        if (fldata_rc)
-          ThrowXML(XMLPlatformUtilsException, XMLExcepts::File_CouldNotWriteToFile);
+          ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotWriteToFile, manager);
 
        fileLrecl = fileinfo.__maxreclen;
 
@@ -541,7 +516,7 @@ static FileHandleImpl* openWrite(char* tmpFileName)
        if (fileinfo.__dsorgHFS)
        {
           if (fclose(fileHandle))
-            ThrowXML(XMLPlatformUtilsException, XMLExcepts::File_CouldNotCloseFile);
+            ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotCloseFile, manager);
 
           fileHandle=fopen(pathobj.getfopenPath(), "wb");
 
@@ -558,7 +533,7 @@ static FileHandleImpl* openWrite(char* tmpFileName)
     if (fileHandle == NULL)
        retVal = 0;
     else
-       retVal = new FileHandleImpl(fileHandle, _FHI_WRITE, isTypeRecord,fileLrecl);
+       retVal = new (manager) FileHandleImpl(fileHandle, _FHI_WRITE, isTypeRecord,fileLrecl, manager);
 
     return retVal;
 }
@@ -567,7 +542,8 @@ static FileHandleImpl* openWrite(char* tmpFileName)
 // ---------------------------------------------------------------------------
 //  XMLPlatformUtils: File Methods
 // ---------------------------------------------------------------------------
-unsigned int XMLPlatformUtils::curFilePos(FileHandle theFile)
+unsigned int XMLPlatformUtils::curFilePos(FileHandle theFile
+                                          , MemoryManager* const manager)
 {
     // Get the current position
     FileHandleImpl* fhiPtr = (FileHandleImpl*) theFile;
@@ -575,12 +551,13 @@ unsigned int XMLPlatformUtils::curFilePos(FileHandle theFile)
     int curPos = ftell(fileHandle);
 
     if (curPos == -1)
-       ThrowXML(XMLPlatformUtilsException, XMLExcepts::File_CouldNotGetSize);
+       ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotGetSize, manager);
 
     return (unsigned int)curPos;
 }
 
-void XMLPlatformUtils::closeFile(FileHandle theFile)
+void XMLPlatformUtils::closeFile(FileHandle theFile
+                                 , MemoryManager* const manager)
 {
     FileHandleImpl* fhiPtr = (FileHandleImpl*) theFile;
     FILE* fileHandle = (FILE*)fhiPtr->getHandle();
@@ -597,13 +574,13 @@ void XMLPlatformUtils::closeFile(FileHandle theFile)
     {
         XMLByte* tmpFlush = fhiPtr->getStgBufferPtr();
         size_t bytesToWrite = fhiPtr->getNextByte();
-        emptyBuffer(tmpFlush, bytesToWrite,fhiPtr);
+        emptyBuffer(tmpFlush, bytesToWrite, fhiPtr, manager);
     }
 
     // Do the regular close stuff ....
 
     if (fclose(fileHandle))
-       ThrowXML(XMLPlatformUtilsException, XMLExcepts::File_CouldNotCloseFile);
+       ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotCloseFile, manager);
 
     // Delete the instance of the FileHandleImpl class (this will free the
     // staging buffer for us)
@@ -612,7 +589,8 @@ void XMLPlatformUtils::closeFile(FileHandle theFile)
 
 }
 
-unsigned int XMLPlatformUtils::fileSize(FileHandle theFile)
+unsigned int XMLPlatformUtils::fileSize(FileHandle theFile
+                                        , MemoryManager* const manager)
 {
     // Get the current position
     FileHandleImpl* fhiPtr = (FileHandleImpl*) theFile;
@@ -620,73 +598,78 @@ unsigned int XMLPlatformUtils::fileSize(FileHandle theFile)
     long  int curPos = ftell(fileHandle);
 
     if (curPos == -1)
-       ThrowXML(XMLPlatformUtilsException, XMLExcepts::File_CouldNotGetCurPos);
+       ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotGetCurPos, manager);
 
     // Seek to the end and save that value for return
-     if (fseek(fileHandle, 0, SEEK_END))
-        ThrowXML(XMLPlatformUtilsException, XMLExcepts::File_CouldNotSeekToEnd);
+    if (fseek(fileHandle, 0, SEEK_END))
+       ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotSeekToEnd, manager);
 
     long int retVal = ftell(fileHandle);
 
     if (retVal == -1)
-       ThrowXML(XMLPlatformUtilsException, XMLExcepts::File_CouldNotSeekToEnd);
+       ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotSeekToEnd, manager);
 
 
     // And put the pointer back
     if (fseek(fileHandle, curPos, SEEK_SET) )
-       ThrowXML(XMLPlatformUtilsException, XMLExcepts::File_CouldNotSeekToPos);
+       ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotSeekToPos, manager);
 
     return (unsigned int)retVal;
 }
 
-FileHandle XMLPlatformUtils::openFile(const XMLCh* const fileName)
+FileHandle XMLPlatformUtils::openFile(const XMLCh* const fileName
+                                      , MemoryManager* const manager)
 {
-    char* tmpFileName = XMLString::transcode(fileName, fgMemoryManager);
-    ArrayJanitor<char> janText((char*)tmpFileName, fgMemoryManager);
+    char* tmpFileName = XMLString::transcode(fileName, manager);
+    ArrayJanitor<char> janText((char*)tmpFileName, manager);
 
-    return openRead(tmpFileName);
+    return openRead(tmpFileName, manager);
 }
 
 
-FileHandle XMLPlatformUtils::openFile(const char* const fileName)
+FileHandle XMLPlatformUtils::openFile(const char* const fileName
+                                      , MemoryManager* const manager)
 {
-    char* tmpFileName = (char*) fgMemoryManager->allocate
+    char* tmpFileName = (char*) manager->allocate
     (
         (strlen(fileName) + 1) * sizeof(char)
     );//new char[strlen(fileName) + 1];
-    ArrayJanitor<char> janText((char*)tmpFileName, fgMemoryManager);
+    ArrayJanitor<char> janText((char*)tmpFileName, manager);
     strcpy(tmpFileName,fileName);
 
-    return openRead(tmpFileName);
+    return openRead(tmpFileName, manager);
 }
 
 
-FileHandle XMLPlatformUtils::openFileToWrite(const XMLCh* const fileName)
+FileHandle XMLPlatformUtils::openFileToWrite(const XMLCh* const fileName
+                                             , MemoryManager* const manager)
 {
-    char* tmpFileName = XMLString::transcode(fileName, fgMemoryManager);
-    ArrayJanitor<char> janText((char*)tmpFileName, fgMemoryManager);
+    char* tmpFileName = XMLString::transcode(fileName, manager);
+    ArrayJanitor<char> janText((char*)tmpFileName, manager);
 
-    return openWrite(tmpFileName);
+    return openWrite(tmpFileName, manager);
 }
 
 
-FileHandle XMLPlatformUtils::openFileToWrite(const char* const fileName)
+FileHandle XMLPlatformUtils::openFileToWrite(const char* const fileName
+                                             , MemoryManager* const manager)
 {
-    char* tmpFileName = (char*) fgMemoryManager->allocate
+    char* tmpFileName = (char*) manager->allocate
     (
         (strlen(fileName) + 1) * sizeof(char)
     );//new char[strlen(fileName) + 1];
-    ArrayJanitor<char> janText((char*)tmpFileName, fgMemoryManager);
+    ArrayJanitor<char> janText((char*)tmpFileName, manager);
     strcpy(tmpFileName,fileName);
 
-    return openWrite(tmpFileName);
+    return openWrite(tmpFileName, manager);
 }
 
 
 void
 XMLPlatformUtils::writeBufferToFile( FileHandle     const  theFile
                                    , long                  toWrite
-                                   , const XMLByte* const  toFlush)
+                                   , const XMLByte* const  toFlush
+                                   , MemoryManager* const  manager)
 {
     FileHandleImpl* fhiPtr = (FileHandleImpl*) theFile;
     FILE* fileHandle = (FILE*)fhiPtr->getHandle();
@@ -736,7 +719,7 @@ XMLPlatformUtils::writeBufferToFile( FileHandle     const  theFile
              inputBufferPtr += stageThisAdd;
              stageBufferAddPtr += stageThisAdd;
              stageToWrite = stageBufferAddPtr - stageBufferStartPtr;
-             emptyBuffer(stageBufferStartPtr, stageToWrite, fhiPtr);
+             emptyBuffer(stageBufferStartPtr, stageToWrite, fhiPtr, manager);
              stageBufferAddPtr = stageBufferStartPtr;
              stageBufferNextByte = 0;
           }
@@ -761,7 +744,7 @@ XMLPlatformUtils::writeBufferToFile( FileHandle     const  theFile
     // Normal type of write, just write data to disk ...
 
     else
-       emptyBuffer(tmpFlush, toWrite, fhiPtr);
+       emptyBuffer(tmpFlush, toWrite, fhiPtr, manager);
 
   return;
 }
@@ -770,7 +753,8 @@ XMLPlatformUtils::writeBufferToFile( FileHandle     const  theFile
 unsigned int
 XMLPlatformUtils::readFileBuffer(  FileHandle      theFile
                                 , const unsigned int    toRead
-                                , XMLByte* const  toFill)
+                                , XMLByte* const  toFill
+                                , MemoryManager* const manager)
 {
     FileHandleImpl* fhiPtr = (FileHandleImpl*) theFile;
     FILE* fileHandle = (FILE*)fhiPtr->getHandle();
@@ -786,7 +770,7 @@ XMLPlatformUtils::readFileBuffer(  FileHandle      theFile
        noOfItemsRead = fread( (void*) toFill, 1, toRead, fileHandle);
 
        if(ferror(fileHandle))
-          ThrowXML(XMLPlatformUtilsException, XMLExcepts::File_CouldNotReadFromFile);
+          ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotReadFromFile, manager);
 
        if (isTypeRecord)
        {
@@ -830,13 +814,14 @@ XMLPlatformUtils::readFileBuffer(  FileHandle      theFile
 }
 
 
-void XMLPlatformUtils::resetFile(FileHandle theFile)
+void XMLPlatformUtils::resetFile(FileHandle theFile
+                                 , MemoryManager* const manager)
 {
     // Seek to the start of the file
     FileHandleImpl* fhiPtr = (FileHandleImpl*) theFile;
     FILE* fileHandle = (FILE*)fhiPtr->getHandle();
     if (fseek(fileHandle, 0, SEEK_SET) )
-   ThrowXML(XMLPlatformUtilsException, XMLExcepts::File_CouldNotResetFile);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotResetFile, manager);
 }
 
 // ---------------------------------------------------------------------------
@@ -847,33 +832,53 @@ XMLCh* XMLPlatformUtils::getFullPath(const XMLCh* const srcPath,
 {
 
     //
-    //  NOTE: THe path provided has always already been opened successfully,
+    //  NOTE: The path provided has always already been opened successfully,
     //  so we know that its not some pathological freaky path. It comes in
-    //  in native format, and goes out as Unicode always
+    //  in Unicode, and goes out as Unicode always
     //
-    char* newSrc = XMLString::transcode(srcPath, fgMemoryManager);
-    ArrayJanitor<char> janText(newSrc, fgMemoryManager);
+    char* newSrc = XMLString::transcode(srcPath, manager);
+    ArrayJanitor<char> janText(newSrc, manager);
 
     Path390 pathobj;
     pathobj.setPath(newSrc);
 
-    char* retPath = 0;
-    // Use a local buffer that is big enough for the largest legal path
-    char *absPath = (char*) fgMemoryManager->allocate((_POSIX_PATH_MAX) * sizeof(char));//new char[_POSIX_PATH_MAX];
-    ArrayJanitor<char> janText2(absPath, fgMemoryManager);
+    // Check if this is a relative path that we care about ....
+    // If it is, then use getCurrentDirectory and append
+    // the relative part passed in to those results
+    if ( (pathobj.isRelative()) && 
+         ( (pathobj.getPathType() == PATH390_HFS) ||
+           (pathobj.getPathType() == PATH390_OTHER) ) )
+       { 
+          XMLCh* curDir = getCurrentDirectory(manager);
+          ArrayJanitor<XMLCh> janText1(curDir, manager);
 
-    if ( (pathobj.getPathType() == PATH390_HFS) || (pathobj.getPathType() == PATH390_OTHER) ) {
-       //get the absolute path
-       char* retPath = realpath(pathobj.getfopenPath(), absPath);
-       if (!retPath) {
-          ThrowXML(XMLPlatformUtilsException, XMLExcepts::File_CouldNotGetBasePathName);
-          }
-       return XMLString::transcode(absPath, manager);
-    }
+          int curDirLen = XMLString::stringLen(curDir);
+          int srcPathLen = XMLString::stringLen(srcPath);
+
+          XMLCh* fullPath = (XMLCh*) manager->allocate
+          (
+             (curDirLen + srcPathLen + 2) * sizeof(XMLCh)
+          );
+
+          // Copy the current directory to the new buffer, then
+          // follow it by a slash, then add relative path after that.  
+          XMLString::copyString(fullPath, curDir);
+          fullPath[curDirLen] = chForwardSlash;
+          XMLString::copyString(&fullPath[curDirLen +1], srcPath);
+
+          // get rid of the redundant stuff
+          removeDotSlash(fullPath);
+          removeDotDotSlash(fullPath);
+        
+          return fullPath;
+        }
+
+    // Just return what they sent in since it wasn't relative
     return XMLString::transcode(newSrc, manager);
 }
 
-bool XMLPlatformUtils::isRelative(const XMLCh* const toCheck)
+bool XMLPlatformUtils::isRelative(const XMLCh* const toCheck
+                                  , MemoryManager* const manager)
 {
     // Check for pathological case of empty path
     if (!toCheck[0])
@@ -903,8 +908,8 @@ bool XMLPlatformUtils::isRelative(const XMLCh* const toCheck)
          return false;
     }
 
-    char* tmpFileName = XMLString::transcode(toCheck, fgMemoryManager);
-    ArrayJanitor<char> janText((char*)tmpFileName, fgMemoryManager);
+    char* tmpFileName = XMLString::transcode(toCheck, manager);
+    ArrayJanitor<char> janText((char*)tmpFileName, manager);
     Path390 pathobj;
     pathobj.setPath(tmpFileName);
 
@@ -916,14 +921,16 @@ bool XMLPlatformUtils::isRelative(const XMLCh* const toCheck)
 XMLCh* XMLPlatformUtils::getCurrentDirectory(MemoryManager* const manager)
 {
 
-    /*** 
-     *  REVISIT:
-     * 
-     *   To be implemented later
-    ***/
+    // Use a local buffer that is big enough for the largest legal path
+    char *absPath = (char*) manager->allocate((_POSIX_PATH_MAX+1) * sizeof(char));
+    ArrayJanitor<char> janText2(absPath, manager);
+    if (getcwd(absPath, _POSIX_PATH_MAX) == NULL) 
+    {
+       ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotGetBasePathName, manager);
+    }
+        
+    return XMLString::transcode(absPath, manager);
 
-    XMLCh curDir[]={ chPeriod, chForwardSlash, chNull};
-    return getFullPath(curDir, manager);
 }
 
 inline bool XMLPlatformUtils::isAnySlash(XMLCh c) 
@@ -955,16 +962,16 @@ void XMLPlatformUtils::closeMutex(void* const mtxHandle)
     if (mtxHandle == NULL)
         return;
     if (isPosixEnabled) {
-    if (pthread_mutex_destroy( (pthread_mutex_t*)mtxHandle))
-    {
-   ThrowXML(XMLPlatformUtilsException, XMLExcepts::Mutex_CouldNotDestroy);
-    }
-    if ( (pthread_mutex_t*)mtxHandle)
-        delete (pthread_mutex_t*) mtxHandle;
+        if (pthread_mutex_destroy( (pthread_mutex_t*)mtxHandle))
+        {
+            ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::Mutex_CouldNotDestroy, fgMemoryManager);
+        }
+        if ( (pthread_mutex_t*)mtxHandle)
+            delete (pthread_mutex_t*) mtxHandle;
     } // __isPosixOn
     else {
-    if ( (int*)mtxHandle)
-        delete (int*) mtxHandle;
+        if ( (int*)mtxHandle)
+            delete (int*) mtxHandle;
     }
 }
 void XMLPlatformUtils::lockMutex(void* const mtxHandle)
@@ -972,18 +979,18 @@ void XMLPlatformUtils::lockMutex(void* const mtxHandle)
     if (mtxHandle == NULL)
         return;
     if (isPosixEnabled) {
-    if (pthread_mutex_lock( (pthread_mutex_t*)mtxHandle))
-    {
-   ThrowXML(XMLPlatformUtilsException, XMLExcepts::Mutex_CouldNotLock);
-    }
+        if (pthread_mutex_lock( (pthread_mutex_t*)mtxHandle))
+        {
+            ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::Mutex_CouldNotLock, fgMemoryManager);
+        }
     } // __isPosixOn
     else {
-   int locked = 1, unlocked;
+        int locked = 1, unlocked;
 
-    do {
-        unlocked = 0;
-        compareAndSwap( (void**) &mtxHandle, (void*) locked, (void*) unlocked );
-    } while( unlocked != 0 );
+        do {
+            unlocked = 0;
+            compareAndSwap( (void**) &mtxHandle, (void*) locked, (void*) unlocked );
+        } while( unlocked != 0 );
     }
     return;
 
@@ -994,7 +1001,7 @@ void* XMLPlatformUtils::makeMutex()
     pthread_mutex_t* mutex = new pthread_mutex_t;
     if (mutex == NULL)
     {
-   ThrowXML(XMLPlatformUtilsException, XMLExcepts::Mutex_CouldNotCreate);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::Mutex_CouldNotCreate, fgMemoryManager);
     }
 
     pthread_mutexattr_t*  attr = new pthread_mutexattr_t;
@@ -1002,8 +1009,8 @@ void* XMLPlatformUtils::makeMutex()
     pthread_mutexattr_setkind_np(attr, __MUTEX_RECURSIVE);
     if (pthread_mutex_init(mutex, attr))
     {
-        ThrowXML(XMLPlatformUtilsException,
-                XMLExcepts::Mutex_CouldNotCreate);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException,
+                XMLExcepts::Mutex_CouldNotCreate, fgMemoryManager);
     }
     pthread_mutexattr_destroy(attr);
     delete attr;
@@ -1022,14 +1029,14 @@ void XMLPlatformUtils::unlockMutex(void* const mtxHandle)
     if (mtxHandle == NULL)
         return;
     if (isPosixEnabled) {
-    if (pthread_mutex_unlock( (pthread_mutex_t*)mtxHandle))
-    {
-   ThrowXML(XMLPlatformUtilsException, XMLExcepts::Mutex_CouldNotUnlock);
-    }
+        if (pthread_mutex_unlock( (pthread_mutex_t*)mtxHandle))
+        {
+            ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::Mutex_CouldNotUnlock, fgMemoryManager);
+        }
     } // __isPosixOn
     else {
-   if (*(int*) mtxHandle == 0 )
-   *(int*) mtxHandle = 0;
+        if (*(int*) mtxHandle == 0 )
+            *(int*) mtxHandle = 0;
     }
 }
 
@@ -1090,13 +1097,13 @@ int XMLPlatformUtils::atomicDecrement(int &location)
 }
 
 
-FileHandle XMLPlatformUtils::openStdInHandle()
+FileHandle XMLPlatformUtils::openStdInHandle(MemoryManager* const manager)
 {
      FileHandleImpl* retVal;
      FILE* fileHandle = 0;
      fileHandle = fdopen(dup(0), "rb");
      if (fileHandle)
-        retVal = new FileHandleImpl(fileHandle, _FHI_READ, _FHI_NOT_TYPE_RECORD);
+        retVal = new (manager) FileHandleImpl(fileHandle, _FHI_READ, _FHI_NOT_TYPE_RECORD, 0, manager);
      else
         retVal = 0;
 
