@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2002 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2002,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: Win32PlatformUtils.cpp,v 1.21 2003/11/01 20:24:22 amassari Exp $
+ * $Id: Win32PlatformUtils.cpp,v 1.25 2004/09/08 13:56:43 peiyongz Exp $
  */
 
 // ---------------------------------------------------------------------------
@@ -167,42 +127,46 @@ static bool isBackSlash(XMLCh c) {
            c == chWonSign;
 }
 
-unsigned int XMLPlatformUtils::curFilePos(FileHandle theFile)
+unsigned int XMLPlatformUtils::curFilePos(FileHandle theFile
+                                          , MemoryManager* const manager)
 {
     // Get the current position
     const unsigned int curPos = ::SetFilePointer(theFile, 0, 0, FILE_CURRENT);
     if (curPos == 0xFFFFFFFF)
-        ThrowXML(XMLPlatformUtilsException, XMLExcepts::File_CouldNotGetCurPos);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotGetCurPos, manager);
 
     return curPos;
 }
 
-void XMLPlatformUtils::closeFile(FileHandle theFile)
+void XMLPlatformUtils::closeFile(FileHandle theFile
+                                 , MemoryManager* const manager)
 {
     if (!::CloseHandle(theFile))
-        ThrowXML(XMLPlatformUtilsException, XMLExcepts::File_CouldNotCloseFile);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotCloseFile, manager);
 }
 
-unsigned int XMLPlatformUtils::fileSize(FileHandle theFile)
+unsigned int XMLPlatformUtils::fileSize(FileHandle theFile
+                                        , MemoryManager* const manager)
 {
     // Get the current position
     const unsigned int curPos = ::SetFilePointer(theFile, 0, 0, FILE_CURRENT);
     if (curPos == 0xFFFFFFFF)
-        ThrowXML(XMLPlatformUtilsException, XMLExcepts::File_CouldNotGetCurPos);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotGetCurPos, manager);
 
     // Seek to the end and save that value for return
     const unsigned int retVal = ::SetFilePointer(theFile, 0, 0, FILE_END);
     if (retVal == 0xFFFFFFFF)
-        ThrowXML(XMLPlatformUtilsException, XMLExcepts::File_CouldNotSeekToEnd);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotSeekToEnd, manager);
 
     // And put the pointer back
     if (::SetFilePointer(theFile, curPos, 0, FILE_BEGIN) == 0xFFFFFFFF)
-        ThrowXML(XMLPlatformUtilsException, XMLExcepts::File_CouldNotSeekToPos);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotSeekToPos, manager);
 
     return retVal;
 }
 
-FileHandle XMLPlatformUtils::openFile(const char* const fileName)
+FileHandle XMLPlatformUtils::openFile(const char* const fileName
+                                      , MemoryManager* const manager)
 {
     FileHandle retVal = ::CreateFileA
     (
@@ -221,7 +185,8 @@ FileHandle XMLPlatformUtils::openFile(const char* const fileName)
     return retVal;
 }
 
-FileHandle XMLPlatformUtils::openFile(const XMLCh* const fileName)
+FileHandle XMLPlatformUtils::openFile(const XMLCh* const fileName
+                                      , MemoryManager* const manager)
 {
     // Watch for obvious wierdness
     if (!fileName)
@@ -292,7 +257,7 @@ FileHandle XMLPlatformUtils::openFile(const XMLCh* const fileName)
     //
     if (*srcPtr)
     {
-        tmpUName = XMLString::replicate(nameToOpen, fgMemoryManager);
+        tmpUName = XMLString::replicate(nameToOpen, manager);
 
         XMLCh* tmpPtr = tmpUName;
         while (*tmpPtr)
@@ -324,7 +289,7 @@ FileHandle XMLPlatformUtils::openFile(const XMLCh* const fileName)
         //  We are Win 95 / 98.  Take the Unicode file name back to (char *)
         //    so that we can open it.
         //
-        char* tmpName = XMLString::transcode(nameToOpen, fgMemoryManager);
+        char* tmpName = XMLString::transcode(nameToOpen, manager);
         retVal = ::CreateFileA
             (
             tmpName
@@ -335,11 +300,11 @@ FileHandle XMLPlatformUtils::openFile(const XMLCh* const fileName)
             , FILE_FLAG_SEQUENTIAL_SCAN
             , 0
             );
-        fgMemoryManager->deallocate(tmpName);//delete [] tmpName;
+        manager->deallocate(tmpName);//delete [] tmpName;
     }
 
     if (tmpUName)
-        fgMemoryManager->deallocate(tmpUName);//delete [] tmpUName;
+        manager->deallocate(tmpUName);//delete [] tmpUName;
 
     if (retVal == INVALID_HANDLE_VALUE)
         return 0;
@@ -347,7 +312,8 @@ FileHandle XMLPlatformUtils::openFile(const XMLCh* const fileName)
     return retVal;
 }
 
-FileHandle XMLPlatformUtils::openFileToWrite(const char* const fileName)
+FileHandle XMLPlatformUtils::openFileToWrite(const char* const fileName
+                                             , MemoryManager* const manager)
 {
     FileHandle retVal = ::CreateFileA
     (
@@ -366,7 +332,8 @@ FileHandle XMLPlatformUtils::openFileToWrite(const char* const fileName)
     return retVal;
 }
 
-FileHandle XMLPlatformUtils::openFileToWrite(const XMLCh* const fileName)
+FileHandle XMLPlatformUtils::openFileToWrite(const XMLCh* const fileName
+                                             , MemoryManager* const manager)
 {
     // Watch for obvious wierdness
     if (!fileName)
@@ -408,7 +375,7 @@ FileHandle XMLPlatformUtils::openFileToWrite(const XMLCh* const fileName)
     //
     if (*srcPtr)
     {
-        tmpUName = XMLString::replicate(fileName, fgMemoryManager);
+        tmpUName = XMLString::replicate(fileName, manager);
 
         XMLCh* tmpPtr = tmpUName;
         while (*tmpPtr)
@@ -440,7 +407,7 @@ FileHandle XMLPlatformUtils::openFileToWrite(const XMLCh* const fileName)
         //  We are Win 95 / 98.  Take the Unicode file name back to (char *)
         //    so that we can open it.
         //
-        char* tmpName = XMLString::transcode(nameToOpen, fgMemoryManager);
+        char* tmpName = XMLString::transcode(nameToOpen, manager);
         retVal = ::CreateFileA
             (
             tmpName
@@ -451,11 +418,11 @@ FileHandle XMLPlatformUtils::openFileToWrite(const XMLCh* const fileName)
             , FILE_ATTRIBUTE_NORMAL
             , 0
             );
-        fgMemoryManager->deallocate(tmpName);//delete [] tmpName;
+        manager->deallocate(tmpName);//delete [] tmpName;
     }
 
     if (tmpUName)
-        fgMemoryManager->deallocate(tmpUName);//delete [] tmpUName;
+        manager->deallocate(tmpUName);//delete [] tmpUName;
 
     if (retVal == INVALID_HANDLE_VALUE)
         return 0;
@@ -463,7 +430,7 @@ FileHandle XMLPlatformUtils::openFileToWrite(const XMLCh* const fileName)
     return retVal;
 }
 
-FileHandle XMLPlatformUtils::openStdInHandle()
+FileHandle XMLPlatformUtils::openStdInHandle(MemoryManager* const manager)
 {
     //
     //  Get the standard input handle. Duplicate it and return that copy
@@ -474,7 +441,7 @@ FileHandle XMLPlatformUtils::openStdInHandle()
     HANDLE stdInOrg = ::GetStdHandle(STD_INPUT_HANDLE);
     if (stdInOrg == INVALID_HANDLE_VALUE) {
         XMLCh stdinStr[] = {chLatin_s, chLatin_t, chLatin_d, chLatin_i, chLatin_n, chNull};
-        ThrowXML1(XMLPlatformUtilsException, XMLExcepts::File_CouldNotOpenFile, stdinStr);
+        ThrowXMLwithMemMgr1(XMLPlatformUtilsException, XMLExcepts::File_CouldNotOpenFile, stdinStr, manager);
     }
 
     HANDLE retHandle;
@@ -488,7 +455,7 @@ FileHandle XMLPlatformUtils::openStdInHandle()
         , FALSE
         , DUPLICATE_SAME_ACCESS))
     {
-        ThrowXML(XMLPlatformUtilsException, XMLExcepts::File_CouldNotDupHandle);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotDupHandle, manager);
     }
     return retHandle;
 }
@@ -497,7 +464,8 @@ FileHandle XMLPlatformUtils::openStdInHandle()
 unsigned int
 XMLPlatformUtils::readFileBuffer(       FileHandle      theFile
                                 , const unsigned int    toRead
-                                ,       XMLByte* const  toFill)
+                                ,       XMLByte* const  toFill
+                                , MemoryManager* const  manager)
 {
     unsigned long bytesRead = 0;
     if (!::ReadFile(theFile, toFill, toRead, &bytesRead, 0))
@@ -507,7 +475,7 @@ XMLPlatformUtils::readFileBuffer(       FileHandle      theFile
         //  means no more data from the pipe, so return zero.
         //
         if (::GetLastError() != ERROR_BROKEN_PIPE)
-            ThrowXML(XMLPlatformUtilsException, XMLExcepts::File_CouldNotReadFromFile);
+            ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotReadFromFile, manager);
     }
     return (unsigned int)bytesRead;
 }
@@ -515,7 +483,8 @@ XMLPlatformUtils::readFileBuffer(       FileHandle      theFile
 void
 XMLPlatformUtils::writeBufferToFile( FileHandle     const  theFile
                                    , long                  toWrite
-                                   , const XMLByte* const  toFlush)
+                                   , const XMLByte* const  toFlush
+                                   , MemoryManager* const  manager)
 {
     if (!theFile        ||
         (toWrite <= 0 ) ||
@@ -528,7 +497,7 @@ XMLPlatformUtils::writeBufferToFile( FileHandle     const  theFile
     while (true)
     {
         if (!::WriteFile(theFile, tmpFlush, toWrite, &bytesWritten, 0))
-            ThrowXML(XMLPlatformUtilsException, XMLExcepts::File_CouldNotWriteToFile);
+            ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotWriteToFile, manager);
 
         if (bytesWritten < (unsigned long) toWrite) //incomplete write
         {
@@ -543,11 +512,13 @@ XMLPlatformUtils::writeBufferToFile( FileHandle     const  theFile
     return;
 }
 
-void XMLPlatformUtils::resetFile(FileHandle theFile)
+void XMLPlatformUtils::resetFile(FileHandle theFile
+                                 , MemoryManager* const manager)
 {
     // Seek to the start of the file
     if (::SetFilePointer(theFile, 0, 0, FILE_BEGIN) == 0xFFFFFFFF)
-        ThrowXML(XMLPlatformUtilsException, XMLExcepts::File_CouldNotResetFile);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotResetFile, manager);
+
 }
 
 
@@ -594,7 +565,8 @@ XMLCh* XMLPlatformUtils::getFullPath(const XMLCh* const srcPath,
     }
 }
 
-bool XMLPlatformUtils::isRelative(const XMLCh* const toCheck)
+bool XMLPlatformUtils::isRelative(const XMLCh* const toCheck
+                                  , MemoryManager* const manager)
 {
     // Check for pathological case of empty path
     if (!toCheck[0])
