@@ -1,61 +1,36 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2002 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2002-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
  * $Log: CygwinTransService.cpp,v $
+ * Revision 1.13  2004/09/08 13:56:43  peiyongz
+ * Apache License Version 2.0
+ *
+ * Revision 1.12  2004/01/19 16:06:56  amassari
+ * WideCharToMultiByte and MultiByteToWideChar return 0 on failure, not -1
+ *
+ * Revision 1.11  2004/01/13 16:34:22  cargilld
+ * Misc memory management changes.
+ *
+ * Revision 1.10  2003/12/24 15:24:15  cargilld
+ * More updates to memory management so that the static memory manager.
+ *
+ * Revision 1.9  2003/11/08 23:37:00  neilg
+ * fix for bug 24287 by Abe Backus.
+ *
  * Revision 1.8  2003/05/17 16:32:17  knoaman
  * Memory manager implementation : transcoder update.
  *
@@ -587,7 +562,7 @@ int CygwinTransService::auxCompareString( const XMLCh* const comp1
     // Strings are equal until proven otherwise.
     while ( ( countChar < maxChars ) && ( !theResult ) )
     {
-        theResult = (int)(args[1][countChar]) - (int)(args[0][countChar]);
+        theResult = (int)(args[0][countChar]) - (int)(args[1][countChar]);
         ++countChar;
     }
 
@@ -825,19 +800,20 @@ CygwinTranscoder::transcodeFrom(  const XMLByte* const      srcData
         {
             if (toEat == 1)
             {
-                XMLCh tmpBuf[16];
-                XMLString::binToText((unsigned int)(*inPtr), tmpBuf, 16, 16);
-                ThrowXML2
+                XMLCh tmpBuf[17];
+                XMLString::binToText((unsigned int)(*inPtr), tmpBuf, 16, 16, getMemoryManager());
+                ThrowXMLwithMemMgr2
                 (
                     TranscodingException
                     , XMLExcepts::Trans_BadSrcCP
                     , tmpBuf
                     , getEncodingName()
+                    , getMemoryManager()
                 );
             }
             else
             {
-                ThrowXML(TranscodingException, XMLExcepts::Trans_BadSrcSeq);
+                ThrowXMLwithMemMgr(TranscodingException, XMLExcepts::Trans_BadSrcSeq, getMemoryManager());
             }
         }
 
@@ -906,14 +882,15 @@ CygwinTranscoder::transcodeTo(const  XMLCh* const   srcData
         //
         if (usedDef && (options == UnRep_Throw))
         {
-            XMLCh tmpBuf[16];
-            XMLString::binToText((unsigned int)*srcPtr, tmpBuf, 16, 16);
-            ThrowXML2
+            XMLCh tmpBuf[17];
+            XMLString::binToText((unsigned int)*srcPtr, tmpBuf, 16, 16, getMemoryManager());
+            ThrowXMLwithMemMgr2
             (
                 TranscodingException
                 , XMLExcepts::Trans_Unrepresentable
                 , tmpBuf
                 , getEncodingName()
+                , getMemoryManager()
             );
         }
 
@@ -998,27 +975,23 @@ CygwinLCPTranscoder::~CygwinLCPTranscoder()
 // ---------------------------------------------------------------------------
 //  CygwinLCPTranscoder: Implementation of the virtual transcoder interface
 // ---------------------------------------------------------------------------
-unsigned int CygwinLCPTranscoder::calcRequiredSize(const char* const srcText)
+unsigned int CygwinLCPTranscoder::calcRequiredSize(const char* const srcText
+                                                   , MemoryManager* const manager)
 {
     if (!srcText)
         return 0;
 
-    const unsigned int retVal = ::MultiByteToWideChar(CP_ACP, MB_PRECOMPOSED, srcText, -1, NULL, 0);
-    if (retVal == (unsigned int)-1)
-        return 0;
-    return retVal;
+    return ::MultiByteToWideChar(CP_ACP, MB_PRECOMPOSED, srcText, -1, NULL, 0);
 }
 
 
-unsigned int CygwinLCPTranscoder::calcRequiredSize(const XMLCh* const srcText)
+unsigned int CygwinLCPTranscoder::calcRequiredSize(const XMLCh* const srcText
+                                                   , MemoryManager* const manager)
 {
     if (!srcText)
         return 0;
 
-    const unsigned int retVal = ::WideCharToMultiByte(CP_ACP, 0, (LPCWSTR)srcText, -1, NULL, 0, NULL, NULL);
-    if (retVal == (unsigned int)-1)
-        return 0;
-    return retVal;
+    return ::WideCharToMultiByte(CP_ACP, 0, (LPCWSTR)srcText, -1, NULL, 0, NULL, NULL);
 }
 
 
@@ -1032,7 +1005,7 @@ char* CygwinLCPTranscoder::transcode(const XMLCh* const toTranscode)
     {
         // Calc the needed size
         const unsigned int neededLen = ::WideCharToMultiByte(CP_ACP, 0, (LPCWSTR)toTranscode, -1, NULL, 0, NULL, NULL);
-        if (neededLen == (unsigned int)-1)
+        if (neededLen == 0)
             return 0;
 
         // Allocate a buffer of that size plus one for the null and transcode
@@ -1062,7 +1035,7 @@ char* CygwinLCPTranscoder::transcode(const XMLCh* const toTranscode,
     {
         // Calc the needed size
         const unsigned int neededLen = ::WideCharToMultiByte(CP_ACP, 0, (LPCWSTR)toTranscode, -1, NULL, 0, NULL, NULL);
-        if (neededLen == (unsigned int)-1)
+        if (neededLen == 0)
             return 0;
 
         // Allocate a buffer of that size plus one for the null and transcode
@@ -1092,7 +1065,7 @@ XMLCh* CygwinLCPTranscoder::transcode(const char* const toTranscode)
     {
         // Calculate the buffer size required
         const unsigned int neededLen = ::MultiByteToWideChar(CP_ACP, MB_PRECOMPOSED, toTranscode, -1, NULL, 0);
-        if (neededLen == (unsigned int)-1)
+        if (neededLen == 0)
             return 0;
 
         // Allocate a buffer of that size plus one for the null and transcode
@@ -1121,7 +1094,7 @@ XMLCh* CygwinLCPTranscoder::transcode(const char* const toTranscode,
     {
         // Calculate the buffer size required
         const unsigned int neededLen = ::MultiByteToWideChar(CP_ACP, MB_PRECOMPOSED, toTranscode, -1, NULL, 0);
-        if (neededLen == (unsigned int)-1)
+        if (neededLen == 0)
             return 0;
 
         // Allocate a buffer of that size plus one for the null and transcode
@@ -1142,7 +1115,8 @@ XMLCh* CygwinLCPTranscoder::transcode(const char* const toTranscode,
 
 bool CygwinLCPTranscoder::transcode( const   char* const    toTranscode
                                     ,       XMLCh* const    toFill
-                                    , const unsigned int    maxChars)
+                                    , const unsigned int    maxChars
+                                    , MemoryManager* const  manager)
 {
     // Check for a couple of psycho corner cases
     if (!toTranscode || !maxChars)
@@ -1158,7 +1132,7 @@ bool CygwinLCPTranscoder::transcode( const   char* const    toTranscode
     }
 
     // This one has a fixed size output, so try it and if it fails it fails
-    if ( size_t(-1) == ::MultiByteToWideChar(CP_ACP, MB_PRECOMPOSED, toTranscode, -1, (LPWSTR)toFill, maxChars + 1) )
+    if ( 0 == ::MultiByteToWideChar(CP_ACP, MB_PRECOMPOSED, toTranscode, -1, (LPWSTR)toFill, maxChars + 1) )
         return false;
     return true;
 }
@@ -1166,7 +1140,8 @@ bool CygwinLCPTranscoder::transcode( const   char* const    toTranscode
 
 bool CygwinLCPTranscoder::transcode( const  XMLCh* const    toTranscode
                                     ,       char* const     toFill
-                                    , const unsigned int    maxBytes)
+                                    , const unsigned int    maxBytes
+                                    , MemoryManager* const  manager)
 {
     // Watch for a couple of pyscho corner cases
     if (!toTranscode || !maxBytes)
@@ -1182,7 +1157,7 @@ bool CygwinLCPTranscoder::transcode( const  XMLCh* const    toTranscode
     }
 
     // This one has a fixed size output, so try it and if it fails it fails
-    if ( size_t(-1) == ::WideCharToMultiByte(CP_ACP, 0, (LPCWSTR)toTranscode, -1, toFill, maxBytes + 1, NULL, NULL) )
+    if ( 0 == ::WideCharToMultiByte(CP_ACP, 0, (LPCWSTR)toTranscode, -1, toFill, maxBytes + 1, NULL, NULL) )
         return false;
 
     // Cap it off just in case
