@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2000 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: ICUTransService.cpp,v 1.11 2003/08/31 18:10:08 neilg Exp $
+ * $Id: ICUTransService.cpp,v 1.16 2004/09/08 13:56:44 peiyongz Exp $
  */
 
 
@@ -78,7 +38,6 @@
     #include <unicode/uclean.h>
 #endif
 
-
 #if !defined(XML_OS390) && !defined(XML_AS400) && !defined(XML_HPUX) && !defined(XML_PTX)
 // Forward reference the symbol which points to the ICU converter data.
 #if (U_ICU_VERSION_MAJOR_NUM < 2)
@@ -96,8 +55,21 @@ static const XMLCh gMyServiceId[] =
     chLatin_I, chLatin_C, chLatin_U, chNull
 };
 
+static const XMLCh gS390Id[] =
+{
+    chLatin_S, chDigit_3, chDigit_9, chDigit_0, chNull
+};
 
+static const XMLCh gs390Id[] =
+{
+    chLatin_s, chDigit_3, chDigit_9, chDigit_0, chNull
+};
 
+static const XMLCh gswaplfnlId[] =
+{
+    chComma, chLatin_s, chLatin_w, chLatin_a, chLatin_p,
+    chLatin_l, chLatin_f, chLatin_n, chLatin_l, chNull
+};
 // ---------------------------------------------------------------------------
 //  Local functions
 // ---------------------------------------------------------------------------
@@ -341,6 +313,25 @@ makeNewXMLTranscoder(const  XMLCh* const            encodingName
                     , const unsigned int            blockSize
                     ,       MemoryManager* const    manager)
 {
+    //  
+    //  For encodings that end with "s390" we need to strip off the "s390" 
+    //  from the encoding name and add ",swaplfnl" to the encoding name	
+    //  that we pass into ICU on the ucnv_openU.  
+    //  
+    XMLCh* encodingNameToUse = (XMLCh*) encodingName;
+    XMLCh* workBuffer = 0;
+
+    if ( (XMLString::endsWith(encodingNameToUse, gs390Id)) ||
+         (XMLString::endsWith(encodingNameToUse, gS390Id)) )
+    {
+       int workBufferSize = (XMLString::stringLen(encodingNameToUse) + XMLString::stringLen(gswaplfnlId) - XMLString::stringLen(gS390Id) + 1);
+       workBuffer = (XMLCh*) manager->allocate(workBufferSize * sizeof(XMLCh));
+       int moveSize = XMLString::stringLen(encodingNameToUse) - XMLString::stringLen(gS390Id);
+       XMLString::moveChars(workBuffer, encodingNameToUse, moveSize);
+       XMLString::moveChars((workBuffer + moveSize), gswaplfnlId, XMLString::stringLen(gswaplfnlId));
+       encodingNameToUse = workBuffer;
+    }
+
     //
     //  If UChar and XMLCh are not the same size, then we have premassage the
     //  encoding name into a UChar type string.
@@ -349,15 +340,16 @@ makeNewXMLTranscoder(const  XMLCh* const            encodingName
     UChar* tmpName = 0;
     if (sizeof(UChar) == sizeof(XMLCh))
     {
-        actualName = (const UChar*)encodingName;
+        actualName = (const UChar*)encodingNameToUse;
     }
     else
     {
-        tmpName = convertToUChar(encodingName, 0, XMLPlatformUtils::fgMemoryManager);
+        tmpName = convertToUChar(encodingNameToUse, 0, manager);
         actualName = tmpName;
     }
 
-    ArrayJanitor<UChar> janTmp(tmpName, XMLPlatformUtils::fgMemoryManager);
+    ArrayJanitor<UChar> janTmp(tmpName, manager);
+    ArrayJanitor<XMLCh> janTmp1(workBuffer, manager);
 
     UErrorCode uerr = U_ZERO_ERROR;
     UConverter* converter = ucnv_openU(actualName, &uerr);
@@ -470,19 +462,20 @@ ICUTranscoder::transcodeFrom(const  XMLByte* const          srcData
 
         if (fFixed)
         {
-            XMLCh tmpBuf[16];
-            XMLString::binToText((unsigned int)(*startTarget), tmpBuf, 16, 16);
-            ThrowXML2
+            XMLCh tmpBuf[17];
+            XMLString::binToText((unsigned int)(*startTarget), tmpBuf, 16, 16, getMemoryManager());
+            ThrowXMLwithMemMgr2
             (
                 TranscodingException
                 , XMLExcepts::Trans_BadSrcCP
                 , tmpBuf
                 , getEncodingName()
+                , getMemoryManager()
             );
         }
         else
         {
-            ThrowXML(TranscodingException, XMLExcepts::Trans_BadSrcSeq);
+            ThrowXMLwithMemMgr(TranscodingException, XMLExcepts::Trans_BadSrcSeq, getMemoryManager());
         }
     }
 
@@ -499,7 +492,7 @@ ICUTranscoder::transcodeFrom(const  XMLByte* const          srcData
     //
     if (fFixed)
     {
-        const unsigned char fillSize = (unsigned char)ucnv_getMaxCharSize(fConverter);;
+        const unsigned char fillSize = (unsigned char)ucnv_getMaxCharSize(fConverter);
         memset(charSizes, fillSize, maxChars);
     }
      else
@@ -630,14 +623,15 @@ ICUTranscoder::transcodeTo( const   XMLCh* const    srcData
 
     if (!res)
     {
-        XMLCh tmpBuf[16];
-        XMLString::binToText((unsigned int)*startSrc, tmpBuf, 16, 16);
-        ThrowXML2
+        XMLCh tmpBuf[17];
+        XMLString::binToText((unsigned int)*startSrc, tmpBuf, 16, 16, getMemoryManager());
+        ThrowXMLwithMemMgr2
         (
             TranscodingException
             , XMLExcepts::Trans_Unrepresentable
             , tmpBuf
             , getEncodingName()
+            , getMemoryManager()
         );
     }
 
@@ -747,7 +741,8 @@ ICULCPTranscoder::~ICULCPTranscoder()
 // ---------------------------------------------------------------------------
 //  ICULCPTranscoder: Constructors and Destructor
 // ---------------------------------------------------------------------------
-unsigned int ICULCPTranscoder::calcRequiredSize(const XMLCh* const srcText)
+unsigned int ICULCPTranscoder::calcRequiredSize(const XMLCh* const srcText
+                                                , MemoryManager* const manager)
 {
     if (!srcText)
         return 0;
@@ -778,8 +773,8 @@ unsigned int ICULCPTranscoder::calcRequiredSize(const XMLCh* const srcText)
     else
     {
         // Copy the source to a local temp
-        UChar* tmpBuf = convertToUChar(srcText, 0, XMLPlatformUtils::fgMemoryManager);
-        ArrayJanitor<UChar> janTmp(tmpBuf, XMLPlatformUtils::fgMemoryManager);
+        UChar* tmpBuf = convertToUChar(srcText, 0, manager);
+        ArrayJanitor<UChar> janTmp(tmpBuf, manager);
 
         // Use a faux scope to synchronize while we do this
         {
@@ -803,7 +798,8 @@ unsigned int ICULCPTranscoder::calcRequiredSize(const XMLCh* const srcText)
     return (unsigned int)targetCap;
 }
 
-unsigned int ICULCPTranscoder::calcRequiredSize(const char* const srcText)
+unsigned int ICULCPTranscoder::calcRequiredSize(const char* const srcText
+                                                , MemoryManager* const manager)
 {
     if (!srcText)
         return 0;
@@ -1220,7 +1216,8 @@ XMLCh* ICULCPTranscoder::transcode(const char* const toTranscode,
 
 bool ICULCPTranscoder::transcode(const  char* const     toTranscode
                                 ,       XMLCh* const    toFill
-                                , const unsigned int    maxChars)
+                                , const unsigned int    maxChars
+                                , MemoryManager* const  manager)
 {
     // Check for a couple of psycho corner cases
     if (!toTranscode || !maxChars)
@@ -1246,7 +1243,7 @@ bool ICULCPTranscoder::transcode(const  char* const     toTranscode
     if (sizeof(XMLCh) == sizeof(UChar))
         targetBuf = (UChar*)toFill;
     else
-        targetBuf = (UChar*) XMLPlatformUtils::fgMemoryManager->allocate
+        targetBuf = (UChar*) manager->allocate
         (
             (maxChars + 1) * sizeof(UChar)
         );//new UChar[maxChars + 1];
@@ -1272,7 +1269,7 @@ bool ICULCPTranscoder::transcode(const  char* const     toTranscode
     if (U_FAILURE(err))
     {
         if (targetBuf != (UChar*)toFill)
-            XMLPlatformUtils::fgMemoryManager->deallocate(targetBuf);//delete [] targetBuf;
+            manager->deallocate(targetBuf);//delete [] targetBuf;
         return false;
     }
 
@@ -1286,7 +1283,7 @@ bool ICULCPTranscoder::transcode(const  char* const     toTranscode
         *outPtr = 0;
 
         // And delete the temp buffer
-        XMLPlatformUtils::fgMemoryManager->deallocate(targetBuf);//delete [] targetBuf;
+        manager->deallocate(targetBuf);//delete [] targetBuf;
     }
 
     return true;
@@ -1295,7 +1292,8 @@ bool ICULCPTranscoder::transcode(const  char* const     toTranscode
 
 bool ICULCPTranscoder::transcode(   const   XMLCh* const    toTranscode
                                     ,       char* const     toFill
-                                    , const unsigned int    maxChars)
+                                    , const unsigned int    maxChars
+                                    , MemoryManager* const  manager)
 {
     // Watch for a few psycho corner cases
     if (!toTranscode || !maxChars)
@@ -1323,12 +1321,12 @@ bool ICULCPTranscoder::transcode(   const   XMLCh* const    toTranscode
      else
     {
         // Allocate a non-const temp buf, but store it also in the actual
-        ncActual = convertToUChar(toTranscode, 0, XMLPlatformUtils::fgMemoryManager);
+        ncActual = convertToUChar(toTranscode, 0, manager);
         actualSrc = ncActual;
     }
 
     // Insure that the temp buffer, if any, gets cleaned up via the nc pointer
-    ArrayJanitor<UChar> janTmp(ncActual, XMLPlatformUtils::fgMemoryManager);
+    ArrayJanitor<UChar> janTmp(ncActual, manager);
 
     //
     //  Use a faux block to enforce a lock on the converter while we do this.
