@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2000 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2000,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: MacOSUnicodeConverter.hpp,v 1.10 2003/12/24 15:24:15 cargilld Exp $
+ * $Id: MacOSUnicodeConverter.hpp,v 1.12 2004/09/08 13:56:46 peiyongz Exp $
  */
 
 #ifndef MACOSUNICODECONVERTER_HPP
@@ -63,6 +23,7 @@
 
 #include <cstddef>
 #include <xercesc/util/TransService.hpp>
+#include <xercesc/util/Mutexes.hpp>
 
 #if defined(__APPLE__)
     //	Framework includes from ProjectBuilder
@@ -131,6 +92,14 @@ protected :
         , const unsigned int            blockSize
         ,       MemoryManager* const    manager
     );
+    virtual XMLTranscoder* makeNewXMLTranscoder
+    (
+        const   XMLCh* const            encodingName
+        ,       XMLTransService::Codes& resValue
+        , const unsigned int            blockSize
+        ,		TextEncoding			textEncoding
+        ,       MemoryManager* const    manager
+    );
 
     //	Sniff for available functionality
     static bool IsMacOSUnicodeConverterSupported(void);
@@ -139,6 +108,9 @@ protected :
 private :
 	friend class XMLPlatformUtils;
 	
+	static const XMLCh fgMyServiceId[];			// Name of the our unicode converter
+	static const XMLCh fgMacLCPEncodingName[];	// Name of the LCP transcoder we create
+
 	bool	mHasUnicodeCollation;	// True if unicode collation is available
 	
     // -----------------------------------------------------------------------
@@ -151,6 +123,10 @@ private :
     //  Private methods
     // -----------------------------------------------------------------------
 	void ConvertWideToNarrow(const XMLCh* wide, char* narrow, std::size_t maxChars);
+	
+	//  Figure out what text encoding to use for LCP transcoder
+	TextEncoding discoverLCPEncoding();
+
 };
 
 
@@ -169,8 +145,8 @@ public :
     // -----------------------------------------------------------------------
     MacOSTranscoder(
 	    const XMLCh* const		encodingName,
-	    TextToUnicodeInfo		textToUnicodeInfo,
-	    UnicodeToTextInfo		unicodeToTextInfo,
+	    TECObjectRef			textToUnicode,
+	    TECObjectRef			unicodeToText,
 	    const unsigned int		blockSize,
 	    MemoryManager* const    manager = XMLPlatformUtils::fgMemoryManager
 		);
@@ -218,8 +194,8 @@ private :
     // -----------------------------------------------------------------------
     //  Private members
     // -----------------------------------------------------------------------
-    TextToUnicodeInfo	mTextToUnicodeInfo;
-    UnicodeToTextInfo	mUnicodeToTextInfo;
+    TECObjectRef	mTextToUnicode;
+    TECObjectRef	mUnicodeToText;
 };
 
 
@@ -236,7 +212,7 @@ public :
     // -----------------------------------------------------------------------
     //  Constructors and Destructor
     // -----------------------------------------------------------------------
-    MacOSLCPTranscoder(TextToUnicodeInfo textToUnicodeInfo, UnicodeToTextInfo unicodeToTextInfo);
+    MacOSLCPTranscoder(XMLTranscoder* const	transcoder, MemoryManager* const manager);
     ~MacOSLCPTranscoder();
 
 
@@ -291,8 +267,9 @@ private :
     // -----------------------------------------------------------------------
     //  Private data members
     // -----------------------------------------------------------------------
-    TextToUnicodeInfo	mTextToUnicodeInfo;
-    UnicodeToTextInfo	mUnicodeToTextInfo;
+    XMLTranscoder* const	mTranscoder;
+	MemoryManager* const	mManager;
+	XMLMutex				mMutex;			// Mutex to enable rentrancy of LCP transcoder
  };
 
 XERCES_CPP_NAMESPACE_END
