@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2002-2004 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2002-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: Uniconv390TransService.cpp,v 1.6 2004/02/06 15:02:41 cargilld Exp $
+ * $Id: Uniconv390TransService.cpp,v 1.8 2004/09/08 13:56:46 peiyongz Exp $
  */
 
 
@@ -90,6 +50,17 @@
 #include <locale.h>
 #include <xercesc/util/regx/XMLUniCharacter.hpp>
 
+#include <xercesc/util/XML88591Transcoder.hpp>
+#include <xercesc/util/XMLASCIITranscoder.hpp>
+#include <xercesc/util/XMLChTranscoder.hpp>
+#include <xercesc/util/XMLEBCDICTranscoder.hpp>
+#include <xercesc/util/XMLIBM1047Transcoder.hpp>
+#include <xercesc/util/XMLIBM1140Transcoder.hpp>
+#include <xercesc/util/XMLUCS4Transcoder.hpp>
+#include <xercesc/util/XMLUTF8Transcoder.hpp>
+#include <xercesc/util/XMLUTF16Transcoder.hpp>
+#include <xercesc/util/XMLWin1252Transcoder.hpp>
+
 XERCES_CPP_NAMESPACE_BEGIN
 
 // debug printfs.... I'll take these out after function test.
@@ -234,7 +205,7 @@ Uniconv390TransService::~Uniconv390TransService()
    }
    if (fICUService) {
     delete  fICUService;
-   } 
+   }
 }
 
 // ---------------------------------------------------------------------------
@@ -526,247 +497,497 @@ DBGPRINTF3("makeNewXMLTranscoder() encoding=%s blocksize=%d\n",localname,blockSi
 // ---------------------------------------------------------------------------
 void Uniconv390TransService::initTransService()
 {
-    //
-    //  A stupid way to increment the fCurCount inside the RefVectorOf
-    //
-    for (unsigned int i = 0; i < XMLRecognizer::Encodings_Count; i++)
-        gMappingsRecognizer->addElement(0);
+    // Need to first check if the translate instruction is supported
+    // by this processor ... if it is use the new intrinsics.
 
-    //
-    //  Add in the magical mapping for the native XMLCh transcoder. This
-    //  is used for internal entities.
-    //
-    gMappingsRecognizer->setElementAt(new ENameMapFor<XMLChTranscoder>(XMLUni::fgXMLChEncodingString), XMLRecognizer::XERCES_XMLCH);
-    gMappings->put((void*)XMLUni::fgXMLChEncodingString, new ENameMapFor<XMLChTranscoder>(XMLUni::fgXMLChEncodingString));
+    if (((*(int*) 200) & 0x00001000) != 0)
+       {
+       //
+       //  A stupid way to increment the fCurCount inside the RefVectorOf
+       //
+       for (unsigned int i = 0; i < XMLRecognizer::Encodings_Count; i++)
+           gMappingsRecognizer->addElement(0);
 
-    //
-    //  Add in our mappings for ASCII.
-    //
-    gMappingsRecognizer->setElementAt(new ENameMapFor<XMLASCIITranscoder390>(XMLUni::fgUSASCIIEncodingString), XMLRecognizer::US_ASCII);
-    gMappings->put((void*)XMLUni::fgUSASCIIEncodingString, new ENameMapFor<XMLASCIITranscoder390>(XMLUni::fgUSASCIIEncodingString));
-    gMappings->put((void*)XMLUni::fgUSASCIIEncodingString2, new ENameMapFor<XMLASCIITranscoder390>(XMLUni::fgUSASCIIEncodingString2));
-    gMappings->put((void*)XMLUni::fgUSASCIIEncodingString3, new ENameMapFor<XMLASCIITranscoder390>(XMLUni::fgUSASCIIEncodingString3));
-    gMappings->put((void*)XMLUni::fgUSASCIIEncodingString4, new ENameMapFor<XMLASCIITranscoder390>(XMLUni::fgUSASCIIEncodingString4));
+       //
+       //  Add in the magical mapping for the native XMLCh transcoder. This
+       //  is used for internal entities.
+       //
+       gMappingsRecognizer->setElementAt(new ENameMapFor<XMLChTranscoder>(XMLUni::fgXMLChEncodingString), XMLRecognizer::XERCES_XMLCH);
+       gMappings->put((void*)XMLUni::fgXMLChEncodingString, new ENameMapFor<XMLChTranscoder>(XMLUni::fgXMLChEncodingString));
+
+       //
+       //  Add in our mappings for ASCII.
+       //
+       gMappingsRecognizer->setElementAt(new ENameMapFor<XMLASCIITranscoder390>(XMLUni::fgUSASCIIEncodingString), XMLRecognizer::US_ASCII);
+       gMappings->put((void*)XMLUni::fgUSASCIIEncodingString, new ENameMapFor<XMLASCIITranscoder390>(XMLUni::fgUSASCIIEncodingString));
+       gMappings->put((void*)XMLUni::fgUSASCIIEncodingString2, new ENameMapFor<XMLASCIITranscoder390>(XMLUni::fgUSASCIIEncodingString2));
+       gMappings->put((void*)XMLUni::fgUSASCIIEncodingString3, new ENameMapFor<XMLASCIITranscoder390>(XMLUni::fgUSASCIIEncodingString3));
+       gMappings->put((void*)XMLUni::fgUSASCIIEncodingString4, new ENameMapFor<XMLASCIITranscoder390>(XMLUni::fgUSASCIIEncodingString4));
 
 
-    //
-    //  Add in our mappings for UTF-8
-    //
-    gMappingsRecognizer->setElementAt(new ENameMapFor<XMLUTF8Transcoder390>(XMLUni::fgUTF8EncodingString), XMLRecognizer::UTF_8);
-    gMappings->put((void*)XMLUni::fgUTF8EncodingString, new ENameMapFor<XMLUTF8Transcoder390>(XMLUni::fgUTF8EncodingString));
-    gMappings->put((void*)XMLUni::fgUTF8EncodingString2, new ENameMapFor<XMLUTF8Transcoder390>(XMLUni::fgUTF8EncodingString2));
+       //
+       //  Add in our mappings for UTF-8
+       //
+       gMappingsRecognizer->setElementAt(new ENameMapFor<XMLUTF8Transcoder390>(XMLUni::fgUTF8EncodingString), XMLRecognizer::UTF_8);
+       gMappings->put((void*)XMLUni::fgUTF8EncodingString, new ENameMapFor<XMLUTF8Transcoder390>(XMLUni::fgUTF8EncodingString));
+       gMappings->put((void*)XMLUni::fgUTF8EncodingString2, new ENameMapFor<XMLUTF8Transcoder390>(XMLUni::fgUTF8EncodingString2));
 
-    //
-    //  Add in our mappings for Latin1
-    //
-    gMappings->put((void*)XMLUni::fgISO88591EncodingString, new ENameMapFor<XML88591Transcoder390>(XMLUni::fgISO88591EncodingString));
-    gMappings->put((void*)XMLUni::fgISO88591EncodingString2, new ENameMapFor<XML88591Transcoder390>(XMLUni::fgISO88591EncodingString2));
-    gMappings->put((void*)XMLUni::fgISO88591EncodingString3, new ENameMapFor<XML88591Transcoder390>(XMLUni::fgISO88591EncodingString3));
-    gMappings->put((void*)XMLUni::fgISO88591EncodingString4, new ENameMapFor<XML88591Transcoder390>(XMLUni::fgISO88591EncodingString4));
-    gMappings->put((void*)XMLUni::fgISO88591EncodingString5, new ENameMapFor<XML88591Transcoder390>(XMLUni::fgISO88591EncodingString5));
-    gMappings->put((void*)XMLUni::fgISO88591EncodingString6, new ENameMapFor<XML88591Transcoder390>(XMLUni::fgISO88591EncodingString6));
-    gMappings->put((void*)XMLUni::fgISO88591EncodingString7, new ENameMapFor<XML88591Transcoder390>(XMLUni::fgISO88591EncodingString7));
-    gMappings->put((void*)XMLUni::fgISO88591EncodingString8, new ENameMapFor<XML88591Transcoder390>(XMLUni::fgISO88591EncodingString8));
-    gMappings->put((void*)XMLUni::fgISO88591EncodingString9, new ENameMapFor<XML88591Transcoder390>(XMLUni::fgISO88591EncodingString9));
-    gMappings->put((void*)XMLUni::fgISO88591EncodingString10, new ENameMapFor<XML88591Transcoder390>(XMLUni::fgISO88591EncodingString10));
-    gMappings->put((void*)XMLUni::fgISO88591EncodingString11, new ENameMapFor<XML88591Transcoder390>(XMLUni::fgISO88591EncodingString11));
-    gMappings->put((void*)XMLUni::fgISO88591EncodingString12, new ENameMapFor<XML88591Transcoder390>(XMLUni::fgISO88591EncodingString12));
+       //
+       //  Add in our mappings for Latin1
+       //
+       gMappings->put((void*)XMLUni::fgISO88591EncodingString, new ENameMapFor<XML88591Transcoder390>(XMLUni::fgISO88591EncodingString));
+       gMappings->put((void*)XMLUni::fgISO88591EncodingString2, new ENameMapFor<XML88591Transcoder390>(XMLUni::fgISO88591EncodingString2));
+       gMappings->put((void*)XMLUni::fgISO88591EncodingString3, new ENameMapFor<XML88591Transcoder390>(XMLUni::fgISO88591EncodingString3));
+       gMappings->put((void*)XMLUni::fgISO88591EncodingString4, new ENameMapFor<XML88591Transcoder390>(XMLUni::fgISO88591EncodingString4));
+       gMappings->put((void*)XMLUni::fgISO88591EncodingString5, new ENameMapFor<XML88591Transcoder390>(XMLUni::fgISO88591EncodingString5));
+       gMappings->put((void*)XMLUni::fgISO88591EncodingString6, new ENameMapFor<XML88591Transcoder390>(XMLUni::fgISO88591EncodingString6));
+       gMappings->put((void*)XMLUni::fgISO88591EncodingString7, new ENameMapFor<XML88591Transcoder390>(XMLUni::fgISO88591EncodingString7));
+       gMappings->put((void*)XMLUni::fgISO88591EncodingString8, new ENameMapFor<XML88591Transcoder390>(XMLUni::fgISO88591EncodingString8));
+       gMappings->put((void*)XMLUni::fgISO88591EncodingString9, new ENameMapFor<XML88591Transcoder390>(XMLUni::fgISO88591EncodingString9));
+       gMappings->put((void*)XMLUni::fgISO88591EncodingString10, new ENameMapFor<XML88591Transcoder390>(XMLUni::fgISO88591EncodingString10));
+       gMappings->put((void*)XMLUni::fgISO88591EncodingString11, new ENameMapFor<XML88591Transcoder390>(XMLUni::fgISO88591EncodingString11));
+       gMappings->put((void*)XMLUni::fgISO88591EncodingString12, new ENameMapFor<XML88591Transcoder390>(XMLUni::fgISO88591EncodingString12));
 
-    //
-    //  Add in our mappings for UTF-16 and UCS-4, little endian
-    //
-    bool swapped = false;
+       //
+       //  Add in our mappings for UTF-16 and UCS-4, little endian
+       //
+       bool swapped = false;
 
-    #if defined(ENDIANMODE_BIG)
-    swapped = true;
-    #endif
-    gMappingsRecognizer->setElementAt(new EEndianNameMapFor<XMLUTF16Transcoder>(XMLUni::fgUTF16LEncodingString, swapped), XMLRecognizer::UTF_16L);
-    gMappings->put
-    (
-		(void*)XMLUni::fgUTF16LEncodingString,
-        new EEndianNameMapFor<XMLUTF16Transcoder>
-        (
-            XMLUni::fgUTF16LEncodingString
-            , swapped
-        )
-    );
+       #if defined(ENDIANMODE_BIG)
+       swapped = true;
+       #endif
+       gMappingsRecognizer->setElementAt(new EEndianNameMapFor<XMLUTF16Transcoder>(XMLUni::fgUTF16LEncodingString, swapped), XMLRecognizer::UTF_16L);
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUTF16LEncodingString,
+           new EEndianNameMapFor<XMLUTF16Transcoder>
+           (
+               XMLUni::fgUTF16LEncodingString
+               , swapped
+           )
+       );
 
-    gMappings->put
-    (
-		(void*)XMLUni::fgUTF16LEncodingString2,
-        new EEndianNameMapFor<XMLUTF16Transcoder>
-        (
-            XMLUni::fgUTF16LEncodingString2
-            , swapped
-        )
-    );
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUTF16LEncodingString2,
+           new EEndianNameMapFor<XMLUTF16Transcoder>
+           (
+               XMLUni::fgUTF16LEncodingString2
+               , swapped
+           )
+       );
 
-    gMappingsRecognizer->setElementAt(new EEndianNameMapFor<XMLUCS4Transcoder>(XMLUni::fgUCS4LEncodingString, swapped), XMLRecognizer::UCS_4L);
-    gMappings->put
-    (
-		(void*)XMLUni::fgUCS4LEncodingString,
-        new EEndianNameMapFor<XMLUCS4Transcoder>
-        (
-            XMLUni::fgUCS4LEncodingString
-            , swapped
-        )
-    );
+       gMappingsRecognizer->setElementAt(new EEndianNameMapFor<XMLUCS4Transcoder>(XMLUni::fgUCS4LEncodingString, swapped), XMLRecognizer::UCS_4L);
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUCS4LEncodingString,
+           new EEndianNameMapFor<XMLUCS4Transcoder>
+           (
+               XMLUni::fgUCS4LEncodingString
+               , swapped
+           )
+       );
 
-    gMappings->put
-    (
-		(void*)XMLUni::fgUCS4LEncodingString2,
-        new EEndianNameMapFor<XMLUCS4Transcoder>
-        (
-            XMLUni::fgUCS4LEncodingString2
-            , swapped
-        )
-    );
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUCS4LEncodingString2,
+           new EEndianNameMapFor<XMLUCS4Transcoder>
+           (
+               XMLUni::fgUCS4LEncodingString2
+               , swapped
+           )
+       );
 
-    //
-    //  Add in our mappings for UTF-16 and UCS-4, big endian
-    //
-    swapped = false;
-    #if defined(ENDIANMODE_LITTLE)
-    swapped = true;
-    #endif
-    gMappingsRecognizer->setElementAt(new EEndianNameMapFor<XMLUTF16Transcoder>(XMLUni::fgUTF16BEncodingString, swapped), XMLRecognizer::UTF_16B);
-    gMappings->put
-    (
-		(void*)XMLUni::fgUTF16BEncodingString,
-        new EEndianNameMapFor<XMLUTF16Transcoder>
-        (
-            XMLUni::fgUTF16BEncodingString
-            , swapped
-        )
-    );
+       //
+       //  Add in our mappings for UTF-16 and UCS-4, big endian
+       //
+       swapped = false;
+       #if defined(ENDIANMODE_LITTLE)
+       swapped = true;
+       #endif
+       gMappingsRecognizer->setElementAt(new EEndianNameMapFor<XMLUTF16Transcoder>(XMLUni::fgUTF16BEncodingString, swapped), XMLRecognizer::UTF_16B);
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUTF16BEncodingString,
+           new EEndianNameMapFor<XMLUTF16Transcoder>
+           (
+               XMLUni::fgUTF16BEncodingString
+               , swapped
+           )
+       );
 
-    gMappings->put
-    (
-		(void*)XMLUni::fgUTF16BEncodingString2,
-        new EEndianNameMapFor<XMLUTF16Transcoder>
-        (
-            XMLUni::fgUTF16BEncodingString2
-            , swapped
-        )
-    );
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUTF16BEncodingString2,
+           new EEndianNameMapFor<XMLUTF16Transcoder>
+           (
+               XMLUni::fgUTF16BEncodingString2
+               , swapped
+           )
+       );
 
-    gMappingsRecognizer->setElementAt(new EEndianNameMapFor<XMLUCS4Transcoder>(XMLUni::fgUCS4BEncodingString, swapped), XMLRecognizer::UCS_4B);
-    gMappings->put
-    (
-		(void*)XMLUni::fgUCS4BEncodingString,
-        new EEndianNameMapFor<XMLUCS4Transcoder>
-        (
-            XMLUni::fgUCS4BEncodingString
-            , swapped
-        )
-    );
+       gMappingsRecognizer->setElementAt(new EEndianNameMapFor<XMLUCS4Transcoder>(XMLUni::fgUCS4BEncodingString, swapped), XMLRecognizer::UCS_4B);
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUCS4BEncodingString,
+           new EEndianNameMapFor<XMLUCS4Transcoder>
+           (
+               XMLUni::fgUCS4BEncodingString
+               , swapped
+           )
+       );
 
-    gMappings->put
-    (
-		(void*)XMLUni::fgUCS4BEncodingString2,
-        new EEndianNameMapFor<XMLUCS4Transcoder>
-        (
-            XMLUni::fgUCS4BEncodingString2
-            , swapped
-        )
-    );
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUCS4BEncodingString2,
+           new EEndianNameMapFor<XMLUCS4Transcoder>
+           (
+               XMLUni::fgUCS4BEncodingString2
+               , swapped
+           )
+       );
 
-    //
-    //  Add in our mappings for UTF-16 and UCS-4 which does not indicate endian
-    //  assumes the same endian encoding as the OS
-    //
+       //
+       //  Add in our mappings for UTF-16 and UCS-4 which does not indicate endian
+       //  assumes the same endian encoding as the OS
+       //
 
-    gMappings->put
-    (
-		(void*)XMLUni::fgUTF16EncodingString,
-        new EEndianNameMapFor<XMLUTF16Transcoder>
-        (
-            XMLUni::fgUTF16EncodingString
-            , false
-        )
-    );
-    gMappings->put
-    (
-		(void*)XMLUni::fgUTF16EncodingString2,
-        new EEndianNameMapFor<XMLUTF16Transcoder>
-        (
-            XMLUni::fgUTF16EncodingString2
-            , false
-        )
-    );
-    gMappings->put
-    (
-		(void*)XMLUni::fgUTF16EncodingString3,
-        new EEndianNameMapFor<XMLUTF16Transcoder>
-        (
-            XMLUni::fgUTF16EncodingString3
-            , false
-        )
-    );
-    gMappings->put
-    (
-		(void*)XMLUni::fgUTF16EncodingString4,
-        new EEndianNameMapFor<XMLUTF16Transcoder>
-        (
-            XMLUni::fgUTF16EncodingString4
-            , false
-        )
-    );
-    gMappings->put
-    (
-		(void*)XMLUni::fgUCS4EncodingString,
-        new EEndianNameMapFor<XMLUCS4Transcoder>
-        (
-            XMLUni::fgUCS4EncodingString
-            , false
-        )
-    );
-    gMappings->put
-    (
-		(void*)XMLUni::fgUCS4EncodingString2,
-        new EEndianNameMapFor<XMLUCS4Transcoder>
-        (
-            XMLUni::fgUCS4EncodingString2
-            , false
-        )
-    );
-    gMappings->put
-    (
-		(void*)XMLUni::fgUCS4EncodingString3,
-        new EEndianNameMapFor<XMLUCS4Transcoder>
-        (
-            XMLUni::fgUCS4EncodingString3
-            , false
-        )
-    );
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUTF16EncodingString,
+           new EEndianNameMapFor<XMLUTF16Transcoder>
+           (
+               XMLUni::fgUTF16EncodingString
+               , false
+           )
+       );
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUTF16EncodingString2,
+           new EEndianNameMapFor<XMLUTF16Transcoder>
+           (
+               XMLUni::fgUTF16EncodingString2
+               , false
+           )
+       );
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUTF16EncodingString3,
+           new EEndianNameMapFor<XMLUTF16Transcoder>
+           (
+               XMLUni::fgUTF16EncodingString3
+               , false
+           )
+       );
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUTF16EncodingString4,
+           new EEndianNameMapFor<XMLUTF16Transcoder>
+           (
+               XMLUni::fgUTF16EncodingString4
+               , false
+           )
+       );
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUCS4EncodingString,
+           new EEndianNameMapFor<XMLUCS4Transcoder>
+           (
+               XMLUni::fgUCS4EncodingString
+               , false
+           )
+       );
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUCS4EncodingString2,
+           new EEndianNameMapFor<XMLUCS4Transcoder>
+           (
+               XMLUni::fgUCS4EncodingString2
+               , false
+           )
+       );
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUCS4EncodingString3,
+           new EEndianNameMapFor<XMLUCS4Transcoder>
+           (
+               XMLUni::fgUCS4EncodingString3
+               , false
+           )
+       );
 
-    //
-    //  Add in our mappings for IBM037, and the one alias we support for
-    //  it, which is EBCDIC-CP-US.
-    //
-    gMappingsRecognizer->setElementAt(new ENameMapFor<XMLEBCDICTranscoder390>(XMLUni::fgEBCDICEncodingString), XMLRecognizer::EBCDIC);
-    gMappings->put((void*)XMLUni::fgIBM037EncodingString, new ENameMapFor<XMLEBCDICTranscoder390>(XMLUni::fgIBM037EncodingString));
-    gMappings->put((void*)XMLUni::fgIBM037EncodingString2, new ENameMapFor<XMLEBCDICTranscoder390>(XMLUni::fgIBM037EncodingString2));
+       //
+       //  Add in our mappings for IBM037, and the one alias we support for
+       //  it, which is EBCDIC-CP-US.
+       //
+       gMappingsRecognizer->setElementAt(new ENameMapFor<XMLEBCDICTranscoder390>(XMLUni::fgEBCDICEncodingString), XMLRecognizer::EBCDIC);
+       gMappings->put((void*)XMLUni::fgIBM037EncodingString, new ENameMapFor<XMLEBCDICTranscoder390>(XMLUni::fgIBM037EncodingString));
+       gMappings->put((void*)XMLUni::fgIBM037EncodingString2, new ENameMapFor<XMLEBCDICTranscoder390>(XMLUni::fgIBM037EncodingString2));
 
 
-    //hhe
-    gMappings->put((void*)XMLUni::fgIBM1047EncodingString, new ENameMapFor<XMLIBM1047Transcoder390>(XMLUni::fgIBM1047EncodingString));
-    gMappings->put((void*)XMLUni::fgIBM1047EncodingString2, new ENameMapFor<XMLIBM1047Transcoder390>(XMLUni::fgIBM1047EncodingString2));
+       //hhe
+       gMappings->put((void*)XMLUni::fgIBM1047EncodingString, new ENameMapFor<XMLIBM1047Transcoder390>(XMLUni::fgIBM1047EncodingString));
+       gMappings->put((void*)XMLUni::fgIBM1047EncodingString2, new ENameMapFor<XMLIBM1047Transcoder390>(XMLUni::fgIBM1047EncodingString2));
 
-    //
-    //  Add in our mappings for IBM037 with Euro update, i.e. IBM1140. It
-    //  has alias IBM01140, the one suggested by IANA
-    //
-    gMappings->put((void*)XMLUni::fgIBM1140EncodingString, new ENameMapFor<XMLIBM1140Transcoder390>(XMLUni::fgIBM1140EncodingString));
-    gMappings->put((void*)XMLUni::fgIBM1140EncodingString2, new ENameMapFor<XMLIBM1140Transcoder390>(XMLUni::fgIBM1140EncodingString2));
-    gMappings->put((void*)XMLUni::fgIBM1140EncodingString3, new ENameMapFor<XMLIBM1140Transcoder390>(XMLUni::fgIBM1140EncodingString3));
-    gMappings->put((void*)XMLUni::fgIBM1140EncodingString4, new ENameMapFor<XMLIBM1140Transcoder390>(XMLUni::fgIBM1140EncodingString4));
+       //
+       //  Add in our mappings for IBM037 with Euro update, i.e. IBM1140. It
+       //  has alias IBM01140, the one suggested by IANA
+       //
+       gMappings->put((void*)XMLUni::fgIBM1140EncodingString, new ENameMapFor<XMLIBM1140Transcoder390>(XMLUni::fgIBM1140EncodingString));
+       gMappings->put((void*)XMLUni::fgIBM1140EncodingString2, new ENameMapFor<XMLIBM1140Transcoder390>(XMLUni::fgIBM1140EncodingString2));
+       gMappings->put((void*)XMLUni::fgIBM1140EncodingString3, new ENameMapFor<XMLIBM1140Transcoder390>(XMLUni::fgIBM1140EncodingString3));
+       gMappings->put((void*)XMLUni::fgIBM1140EncodingString4, new ENameMapFor<XMLIBM1140Transcoder390>(XMLUni::fgIBM1140EncodingString4));
 
-    //
-    //  Add in our mappings for Windows-1252. We don't have any aliases for
-    //  this one, so there is just one mapping.
-    //
-    gMappings->put((void*)XMLUni::fgWin1252EncodingString, new ENameMapFor<XMLWin1252Transcoder390>(XMLUni::fgWin1252EncodingString));
+       //
+       //  Add in our mappings for Windows-1252. We don't have any aliases for
+       //  this one, so there is just one mapping.
+       //
+       gMappings->put((void*)XMLUni::fgWin1252EncodingString, new ENameMapFor<XMLWin1252Transcoder390>(XMLUni::fgWin1252EncodingString));
+    } // use new intrinsics
+    else // use old intrinsics
+    {
+       //
+       //  A stupid way to increment the fCurCount inside the RefVectorOf
+       //
+       for (unsigned int i = 0; i < XMLRecognizer::Encodings_Count; i++)
+           gMappingsRecognizer->addElement(0);
+
+       //
+       //  Add in the magical mapping for the native XMLCh transcoder. This
+       //  is used for internal entities.
+       //
+       gMappingsRecognizer->setElementAt(new ENameMapFor<XMLChTranscoder>(XMLUni::fgXMLChEncodingString), XMLRecognizer::XERCES_XMLCH);
+       gMappings->put((void*)XMLUni::fgXMLChEncodingString, new ENameMapFor<XMLChTranscoder>(XMLUni::fgXMLChEncodingString));
+
+       //
+       //  Add in our mappings for ASCII.
+       //
+       gMappingsRecognizer->setElementAt(new ENameMapFor<XMLASCIITranscoder>(XMLUni::fgUSASCIIEncodingString), XMLRecognizer::US_ASCII);
+       gMappings->put((void*)XMLUni::fgUSASCIIEncodingString, new ENameMapFor<XMLASCIITranscoder>(XMLUni::fgUSASCIIEncodingString));
+       gMappings->put((void*)XMLUni::fgUSASCIIEncodingString2, new ENameMapFor<XMLASCIITranscoder>(XMLUni::fgUSASCIIEncodingString2));
+       gMappings->put((void*)XMLUni::fgUSASCIIEncodingString3, new ENameMapFor<XMLASCIITranscoder>(XMLUni::fgUSASCIIEncodingString3));
+       gMappings->put((void*)XMLUni::fgUSASCIIEncodingString4, new ENameMapFor<XMLASCIITranscoder>(XMLUni::fgUSASCIIEncodingString4));
+
+
+       //
+       //  Add in our mappings for UTF-8
+       //
+       gMappingsRecognizer->setElementAt(new ENameMapFor<XMLUTF8Transcoder>(XMLUni::fgUTF8EncodingString), XMLRecognizer::UTF_8);
+       gMappings->put((void*)XMLUni::fgUTF8EncodingString, new ENameMapFor<XMLUTF8Transcoder>(XMLUni::fgUTF8EncodingString));
+       gMappings->put((void*)XMLUni::fgUTF8EncodingString2, new ENameMapFor<XMLUTF8Transcoder>(XMLUni::fgUTF8EncodingString2));
+
+       //
+       //  Add in our mappings for Latin1
+       //
+       gMappings->put((void*)XMLUni::fgISO88591EncodingString, new ENameMapFor<XML88591Transcoder>(XMLUni::fgISO88591EncodingString));
+       gMappings->put((void*)XMLUni::fgISO88591EncodingString2, new ENameMapFor<XML88591Transcoder>(XMLUni::fgISO88591EncodingString2));
+       gMappings->put((void*)XMLUni::fgISO88591EncodingString3, new ENameMapFor<XML88591Transcoder>(XMLUni::fgISO88591EncodingString3));
+       gMappings->put((void*)XMLUni::fgISO88591EncodingString4, new ENameMapFor<XML88591Transcoder>(XMLUni::fgISO88591EncodingString4));
+       gMappings->put((void*)XMLUni::fgISO88591EncodingString5, new ENameMapFor<XML88591Transcoder>(XMLUni::fgISO88591EncodingString5));
+       gMappings->put((void*)XMLUni::fgISO88591EncodingString6, new ENameMapFor<XML88591Transcoder>(XMLUni::fgISO88591EncodingString6));
+       gMappings->put((void*)XMLUni::fgISO88591EncodingString7, new ENameMapFor<XML88591Transcoder>(XMLUni::fgISO88591EncodingString7));
+       gMappings->put((void*)XMLUni::fgISO88591EncodingString8, new ENameMapFor<XML88591Transcoder>(XMLUni::fgISO88591EncodingString8));
+       gMappings->put((void*)XMLUni::fgISO88591EncodingString9, new ENameMapFor<XML88591Transcoder>(XMLUni::fgISO88591EncodingString9));
+       gMappings->put((void*)XMLUni::fgISO88591EncodingString10, new ENameMapFor<XML88591Transcoder>(XMLUni::fgISO88591EncodingString10));
+       gMappings->put((void*)XMLUni::fgISO88591EncodingString11, new ENameMapFor<XML88591Transcoder>(XMLUni::fgISO88591EncodingString11));
+       gMappings->put((void*)XMLUni::fgISO88591EncodingString12, new ENameMapFor<XML88591Transcoder>(XMLUni::fgISO88591EncodingString12));
+
+       //
+       //  Add in our mappings for UTF-16 and UCS-4, little endian
+       //
+       bool swapped = false;
+
+       #if defined(ENDIANMODE_BIG)
+       swapped = true;
+       #endif
+       gMappingsRecognizer->setElementAt(new EEndianNameMapFor<XMLUTF16Transcoder>(XMLUni::fgUTF16LEncodingString, swapped), XMLRecognizer::UTF_16L);
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUTF16LEncodingString,
+           new EEndianNameMapFor<XMLUTF16Transcoder>
+           (
+               XMLUni::fgUTF16LEncodingString
+               , swapped
+           )
+       );
+
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUTF16LEncodingString2,
+           new EEndianNameMapFor<XMLUTF16Transcoder>
+           (
+               XMLUni::fgUTF16LEncodingString2
+               , swapped
+           )
+       );
+
+       gMappingsRecognizer->setElementAt(new EEndianNameMapFor<XMLUCS4Transcoder>(XMLUni::fgUCS4LEncodingString, swapped), XMLRecognizer::UCS_4L);
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUCS4LEncodingString,
+           new EEndianNameMapFor<XMLUCS4Transcoder>
+           (
+               XMLUni::fgUCS4LEncodingString
+               , swapped
+           )
+       );
+
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUCS4LEncodingString2,
+           new EEndianNameMapFor<XMLUCS4Transcoder>
+           (
+               XMLUni::fgUCS4LEncodingString2
+               , swapped
+           )
+       );
+
+       //
+       //  Add in our mappings for UTF-16 and UCS-4, big endian
+       //
+       swapped = false;
+       #if defined(ENDIANMODE_LITTLE)
+       swapped = true;
+       #endif
+       gMappingsRecognizer->setElementAt(new EEndianNameMapFor<XMLUTF16Transcoder>(XMLUni::fgUTF16BEncodingString, swapped), XMLRecognizer::UTF_16B);
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUTF16BEncodingString,
+           new EEndianNameMapFor<XMLUTF16Transcoder>
+           (
+               XMLUni::fgUTF16BEncodingString
+               , swapped
+           )
+       );
+
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUTF16BEncodingString2,
+           new EEndianNameMapFor<XMLUTF16Transcoder>
+           (
+               XMLUni::fgUTF16BEncodingString2
+               , swapped
+           )
+       );
+
+       gMappingsRecognizer->setElementAt(new EEndianNameMapFor<XMLUCS4Transcoder>(XMLUni::fgUCS4BEncodingString, swapped), XMLRecognizer::UCS_4B);
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUCS4BEncodingString,
+           new EEndianNameMapFor<XMLUCS4Transcoder>
+           (
+               XMLUni::fgUCS4BEncodingString
+               , swapped
+           )
+       );
+
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUCS4BEncodingString2,
+           new EEndianNameMapFor<XMLUCS4Transcoder>
+           (
+               XMLUni::fgUCS4BEncodingString2
+               , swapped
+           )
+       );
+
+       //
+       //  Add in our mappings for UTF-16 and UCS-4 which does not indicate endian
+       //  assumes the same endian encoding as the OS
+       //
+
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUTF16EncodingString,
+           new EEndianNameMapFor<XMLUTF16Transcoder>
+           (
+               XMLUni::fgUTF16EncodingString
+               , false
+           )
+       );
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUTF16EncodingString2,
+           new EEndianNameMapFor<XMLUTF16Transcoder>
+           (
+               XMLUni::fgUTF16EncodingString2
+               , false
+           )
+       );
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUTF16EncodingString3,
+           new EEndianNameMapFor<XMLUTF16Transcoder>
+           (
+               XMLUni::fgUTF16EncodingString3
+               , false
+           )
+       );
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUTF16EncodingString4,
+           new EEndianNameMapFor<XMLUTF16Transcoder>
+           (
+               XMLUni::fgUTF16EncodingString4
+               , false
+           )
+       );
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUCS4EncodingString,
+           new EEndianNameMapFor<XMLUCS4Transcoder>
+           (
+               XMLUni::fgUCS4EncodingString
+               , false
+           )
+       );
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUCS4EncodingString2,
+           new EEndianNameMapFor<XMLUCS4Transcoder>
+           (
+               XMLUni::fgUCS4EncodingString2
+               , false
+           )
+       );
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUCS4EncodingString3,
+           new EEndianNameMapFor<XMLUCS4Transcoder>
+           (
+               XMLUni::fgUCS4EncodingString3
+               , false
+           )
+       );
+
+       //
+       //  Add in our mappings for IBM037, and the one alias we support for
+       //  it, which is EBCDIC-CP-US.
+       //
+       gMappingsRecognizer->setElementAt(new ENameMapFor<XMLEBCDICTranscoder>(XMLUni::fgEBCDICEncodingString), XMLRecognizer::EBCDIC);
+       gMappings->put((void*)XMLUni::fgIBM037EncodingString, new ENameMapFor<XMLEBCDICTranscoder>(XMLUni::fgIBM037EncodingString));
+       gMappings->put((void*)XMLUni::fgIBM037EncodingString2, new ENameMapFor<XMLEBCDICTranscoder>(XMLUni::fgIBM037EncodingString2));
+
+
+       //hhe
+       gMappings->put((void*)XMLUni::fgIBM1047EncodingString, new ENameMapFor<XMLIBM1047Transcoder>(XMLUni::fgIBM1047EncodingString));
+       gMappings->put((void*)XMLUni::fgIBM1047EncodingString2, new ENameMapFor<XMLIBM1047Transcoder>(XMLUni::fgIBM1047EncodingString2));
+
+       //
+       //  Add in our mappings for IBM037 with Euro update, i.e. IBM1140. It
+       //  has alias IBM01140, the one suggested by IANA
+       //
+       gMappings->put((void*)XMLUni::fgIBM1140EncodingString, new ENameMapFor<XMLIBM1140Transcoder>(XMLUni::fgIBM1140EncodingString));
+       gMappings->put((void*)XMLUni::fgIBM1140EncodingString2, new ENameMapFor<XMLIBM1140Transcoder>(XMLUni::fgIBM1140EncodingString2));
+       gMappings->put((void*)XMLUni::fgIBM1140EncodingString3, new ENameMapFor<XMLIBM1140Transcoder>(XMLUni::fgIBM1140EncodingString3));
+       gMappings->put((void*)XMLUni::fgIBM1140EncodingString4, new ENameMapFor<XMLIBM1140Transcoder>(XMLUni::fgIBM1140EncodingString4));
+
+       //
+       //  Add in our mappings for Windows-1252. We don't have any aliases for
+       //  this one, so there is just one mapping.
+       //
+       gMappings->put((void*)XMLUni::fgWin1252EncodingString, new ENameMapFor<XMLWin1252Transcoder>(XMLUni::fgWin1252EncodingString));
+    } // use old intrinsics
 
 }//end initTransService()
 
