@@ -1,62 +1,46 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 2001, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2001,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: XMLAbstractDoubleFloat.hpp,v 1.15 2003/10/15 14:50:01 peiyongz Exp $
+ * $Id: XMLAbstractDoubleFloat.hpp,v 1.24 2004/09/09 20:09:30 peiyongz Exp $
  * $Log: XMLAbstractDoubleFloat.hpp,v $
+ * Revision 1.24  2004/09/09 20:09:30  peiyongz
+ * getDataOverflowed()
+ *
+ * Revision 1.23  2004/09/08 13:56:23  peiyongz
+ * Apache License Version 2.0
+ *
+ * Revision 1.22  2004/09/02 19:08:09  cargilld
+ * Fix API Doc warning message
+ *
+ * Revision 1.21  2004/08/11 16:50:47  peiyongz
+ * getValue()/isDataConverted()
+ *
+ * Revision 1.20  2004/01/29 11:48:46  cargilld
+ * Code cleanup changes to get rid of various compiler diagnostic messages.
+ *
+ * Revision 1.19  2004/01/13 19:50:56  peiyongz
+ * remove parseContent()
+ *
+ * Revision 1.17  2003/12/17 00:18:35  cargilld
+ * Update to memory management so that the static memory manager (one used to call Initialize) is only for static data.
+ *
+ * Revision 1.16  2003/12/11 21:38:12  peiyongz
+ * support for Canonical Representation for Datatype
+ *
  * Revision 1.15  2003/10/15 14:50:01  peiyongz
  * Bugzilla#22821: locale-sensitive function used to validate 'double' type, patch
  * from jsweeney@spss.com (Jeff Sweeney)
@@ -171,6 +155,12 @@ public:
 
     virtual ~XMLAbstractDoubleFloat();
 
+    static XMLCh* getCanonicalRepresentation
+                        (
+                          const XMLCh*         const rawData
+                        ,       MemoryManager* const memMgr = XMLPlatformUtils::fgMemoryManager
+                        );
+
     /**
      *
      *  Deprecated: please use getRawData
@@ -186,6 +176,12 @@ public:
 
     MemoryManager*        getMemoryManager() const;
 
+    inline  bool          isDataConverted()  const;
+
+    inline  bool          isDataOverflowed()  const;
+
+    inline  double        getValue() const;
+
     /***
      *
      * The decimal point delimiter for the schema double/float type is
@@ -218,12 +214,14 @@ protected:
 	 *
 	 * @param   lValue the object to compare with.
 	 * @param   rValue the object to compare against.
+     * @param manager The MemoryManager to use to allocate objects
 	 * @return  <code>true</code> if the objects are the same;
 	 *          <code>false</code> otherwise.
 	 */
 
     static int            compareValues(const XMLAbstractDoubleFloat* const lValue
-                                      , const XMLAbstractDoubleFloat* const rValue);
+                                      , const XMLAbstractDoubleFloat* const rValue
+                                      , MemoryManager* const manager);
 
     //
     // to be overwritten by derived class
@@ -244,8 +242,8 @@ private:
 
     inline bool           isSpecialValue() const;
 
-    static int            compareSpecial(const XMLAbstractDoubleFloat* const specialValue
-                                       , const XMLAbstractDoubleFloat* const normalValue);
+    static int            compareSpecial(const XMLAbstractDoubleFloat* const specialValue                                       
+                                       , MemoryManager* const manager);
 
     void                  formatString();
 
@@ -253,6 +251,7 @@ protected:
     double                  fValue;
     LiteralType             fType;
     bool                    fDataConverted;
+    bool                    fDataOverflowed;
 
 private:
     int                     fSign;
@@ -268,6 +267,7 @@ private:
     //
     XMLCh*                  fFormattedString;
     MemoryManager*          fMemoryManager;
+
 };
 
 inline bool XMLAbstractDoubleFloat::isSpecialValue() const
@@ -280,6 +280,21 @@ inline MemoryManager* XMLAbstractDoubleFloat::getMemoryManager() const
     return fMemoryManager;
 }
 
+inline bool XMLAbstractDoubleFloat::isDataConverted() const
+{
+    return fDataConverted;
+}
+
+inline bool XMLAbstractDoubleFloat::isDataOverflowed() const
+{
+    return fDataOverflowed;
+}
+
+inline double XMLAbstractDoubleFloat::getValue() const
+{
+    return fValue;
+}
+
 XERCES_CPP_NAMESPACE_END
 
 #endif
