@@ -1,62 +1,31 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 2001, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2001,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: XMLDateTime.hpp,v 1.17 2004/01/29 11:48:47 cargilld Exp $
+ * $Id: XMLDateTime.hpp,v 1.20 2004/09/08 13:56:24 peiyongz Exp $
  * $Log: XMLDateTime.hpp,v $
+ * Revision 1.20  2004/09/08 13:56:24  peiyongz
+ * Apache License Version 2.0
+ *
+ * Revision 1.19  2004/08/31 20:50:50  peiyongz
+ * Parse/keep milisecond as double to retain precision.
+ *
+ * Revision 1.18  2004/08/11 16:48:55  peiyongz
+ * Allow XSValue access
+ *
  * Revision 1.17  2004/01/29 11:48:47  cargilld
  * Code cleanup changes to get rid of various compiler diagnostic messages.
  *
@@ -131,6 +100,8 @@
 
 XERCES_CPP_NAMESPACE_BEGIN
 
+class XSValue;
+
 class XMLUTIL_EXPORT XMLDateTime : public XMLNumber
 {
 public:
@@ -143,7 +114,7 @@ public:
         Hour       ,
         Minute     ,
         Second     ,
-        MiliSecond ,
+        MiliSecond ,  //not to be used directly
         utc        ,
         TOTAL_SIZE
     };
@@ -246,6 +217,7 @@ private:
     // Constant data
     // -----------------------------------------------------------------------
 	//
+
     enum timezoneIndex
     {
         hh = 0,
@@ -316,6 +288,9 @@ private:
 
     int                   parseIntYear(const int end) const;
 
+    double                parseMiliSecond(const int start
+                                        , const int end) const;
+
     // -----------------------------------------------------------------------
     // validator and normalizer
     // -----------------------------------------------------------------------
@@ -359,7 +334,13 @@ private:
     int          fEnd;
     int          fBufferMaxLen;
     XMLCh*       fBuffer;
+
+    double       fMiliSecond;
+    bool         fHasTime;
+
     MemoryManager* fMemoryManager;
+
+    friend class XSValue;
 };
 
 inline void XMLDateTime::setBuffer(const XMLCh* const aString)
@@ -385,6 +366,8 @@ inline void XMLDateTime::reset()
     for ( int i=0; i < TOTAL_SIZE; i++ )
         fValue[i] = 0;
 
+    fMiliSecond   = 0;
+    fHasTime      = false;
     fTimeZone[hh] = fTimeZone[mm] = 0;
     fStart = fEnd = 0;
 
@@ -397,6 +380,8 @@ inline void XMLDateTime::copy(const XMLDateTime& rhs)
     for ( int i = 0; i < TOTAL_SIZE; i++ )
         fValue[i] = rhs.fValue[i];
 
+    fMiliSecond   = rhs.fMiliSecond;
+    fHasTime      = rhs.fHasTime;
     fTimeZone[hh] = rhs.fTimeZone[hh];
     fTimeZone[mm] = rhs.fTimeZone[mm];
     fStart = rhs.fStart;
