@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2004 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: XMLString.cpp,v 1.31 2004/01/13 17:12:34 cargilld Exp $
+ * $Id: XMLString.cpp,v 1.37 2004/09/28 09:35:05 amassari Exp $
  */
 
 
@@ -66,18 +26,22 @@
 #include <ctype.h>
 #include <stdlib.h>
 #include <errno.h>
+
+#include <xercesc/util/XMLString.hpp>
 #include <xercesc/util/ArrayIndexOutOfBoundsException.hpp>
 #include <xercesc/util/IllegalArgumentException.hpp>
 #include <xercesc/util/NumberFormatException.hpp>
+#include <xercesc/util/OutOfMemoryException.hpp>
+#include <xercesc/util/RuntimeException.hpp>
+#include <xercesc/util/TranscodingException.hpp>
+
 #include <xercesc/util/Janitor.hpp>
 #include <xercesc/util/PlatformUtils.hpp>
 #include <xercesc/util/RefArrayVectorOf.hpp>
-#include <xercesc/util/RuntimeException.hpp>
 #include <xercesc/util/TransService.hpp>
-#include <xercesc/util/TranscodingException.hpp>
-#include <xercesc/util/XMLString.hpp>
 #include <xercesc/util/XMLUniDefs.hpp>
 #include <xercesc/util/XMLUni.hpp>
+#include <xercesc/util/XMLUri.hpp>
 #include <xercesc/internal/XMLReader.hpp>
 
 XERCES_CPP_NAMESPACE_BEGIN
@@ -373,7 +337,7 @@ int XMLString::indexOf( const   char* const     toSearch
     const unsigned int len = strlen(toSearch);
 
     // Make sure the start index is within the XMLString bounds
-	if ((int)fromIndex > len-1)
+	if ((int)fromIndex > ((int)len)-1)
         ThrowXMLwithMemMgr(ArrayIndexOutOfBoundsException, XMLExcepts::Str_StartIndexPastEnd, manager);
 
     for (unsigned int i = fromIndex; i < len; i++)
@@ -668,6 +632,50 @@ void XMLString::subString(char* const targetStr, const char* const srcStr
     targetStr[copySize] = 0;
 }
 
+bool XMLString::isValidNOTATION(const XMLCh*         const name
+                              ,       MemoryManager* const manager )
+{
+    //
+    //  NOTATATION: <URI>:<localPart>
+    //  where URI is optional
+    //        ':' and localPart must be present
+    //
+    int nameLen = XMLString::stringLen(name);
+    int colPos = XMLString::lastIndexOf(name, chColon);
+
+    if ((colPos == -1)         ||      // no ':'
+        (colPos == nameLen - 1)  )     // <URI>':'
+        return false;
+
+    // Examine URI
+    if (colPos > 0)
+    {
+        XMLCh* temp = (XMLCh*) &(name[colPos]);
+        *temp = 0;
+
+        try
+        {            
+            XMLUri  newURI(name, manager); // no relative uri support here
+            *temp = chColon;
+        }
+        catch(const OutOfMemoryException&)
+        {
+            *temp = chColon;
+            return false;
+        }
+        catch (...)
+        {
+            *temp = chColon;
+            return false;
+        }
+    }
+
+    // Examine localpart
+    return XMLString::isValidNCName(&(name[colPos+1]));
+
+}
+
+
 /**
   * Deprecated: isValidNCName
   *    Check first char, and then the rest of the name char.
@@ -1166,16 +1174,17 @@ int XMLString::patternMatch(  const XMLCh* const    toSearch
 
     while (*srcPtr)
     {
-        if ( !(*srcPtr++ == pattern[patnIndex++]))
+        if ( !(*srcPtr++ == pattern[patnIndex]))
         {
             patnIndex = 0;
             srcPtr = ++patnStart;
         }
         else
         {
-            if (patnIndex == patnLen)
+            if (++patnIndex == patnLen)
                 // full pattern match found
                 return (srcPtr - patnLen - toSearch);
+
         }
     }
 
@@ -1771,6 +1780,23 @@ void XMLString::removeWS(XMLCh* const toConvert
     return;
 }
 
+void XMLString::removeChar(const XMLCh*     const srcString
+                         , const XMLCh&           toRemove
+                         ,       XMLBuffer&       dstBuffer)
+{
+    const XMLCh* pszSrc = srcString;
+    XMLCh c;
+
+    dstBuffer.reset();
+
+    while (c=*pszSrc++) 
+    {
+        if (c != toRemove) 
+            dstBuffer.append(c);
+
+    }
+}
+
 /**
  * Fixes a platform dependent absolute path filename to standard URI form.
  * 1. Windows: fix 'x:' to 'file:///x:' and convert any backslash to forward slash
