@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2003 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: XMLUni.hpp,v 1.33 2004/01/29 11:48:47 cargilld Exp $
+ * $Id: XMLUni.hpp,v 1.40 2004/09/28 02:14:14 cargilld Exp $
  */
 
 
@@ -191,6 +151,7 @@ public :
     static const XMLCh fgXMLNSURIName[];
     static const XMLCh fgXMLErrDomain[];
     static const XMLCh fgXMLURIName[];
+    static const XMLCh fgInfosetURIName[];
     static const XMLCh fgYesString[];
     static const XMLCh fgZeroLenString[];
     static const XMLCh fgDTDEntityString[];
@@ -203,6 +164,7 @@ public :
     static const XMLCh fgIGXMLScanner[];
     static const XMLCh fgSGXMLScanner[];
     static const XMLCh fgDGXMLScanner[];
+    static const XMLCh fgXSAXMLScanner[];
     static const XMLCh fgCDataStart[];
     static const XMLCh fgCDataEnd[];
 
@@ -244,6 +206,7 @@ public :
     static const XMLCh fgXercesDynamic[];
     static const XMLCh fgXercesSchema[];
     static const XMLCh fgXercesSchemaFullChecking[];
+    static const XMLCh fgXercesIdentityConstraintChecking[];
     static const XMLCh fgXercesSchemaExternalSchemaLocation[];
     static const XMLCh fgXercesSchemaExternalNoNameSpaceSchemaLocation[];
     static const XMLCh fgXercesSecurityManager[];
@@ -257,6 +220,10 @@ public :
     static const XMLCh fgXercesParserUseDocumentFromImplementation[];
     static const XMLCh fgXercesCalculateSrcOfs[];
     static const XMLCh fgXercesStandardUriConformant[];
+    static const XMLCh fgXercesDOMHasPSVIInfo[];
+    static const XMLCh fgXercesGenerateSyntheticAnnotations[];
+    static const XMLCh fgXercesValidateAnnotations[];
+
 
     // SAX2 features/properties names
     static const XMLCh fgSAX2CoreValidation[];
@@ -292,10 +259,36 @@ public :
     static const XMLCh fgDOMWRTBOM[];
     static const XMLCh fgDOMXMLDeclaration[];
 
+    // Private interface names
+    static const XMLCh fgXercescInterfacePSVITypeInfo[];
 
     // Locale
     static const char  fgXercescDefaultLocale[];
 
+    // Default Exception String
+    static const XMLCh  fgDefErrMsg[];
+
+    // Datatype
+    static const XMLCh fgValueZero[];
+    static const XMLCh fgNegOne[];
+    static const XMLCh fgValueOne[];
+    static const XMLCh fgLongMaxInc[];
+    static const XMLCh fgLongMinInc[];
+    static const XMLCh fgIntMaxInc[];
+    static const XMLCh fgIntMinInc[];
+    static const XMLCh fgShortMaxInc[];
+    static const XMLCh fgShortMinInc[];
+    static const XMLCh fgByteMaxInc[];
+    static const XMLCh fgByteMinInc[];
+    static const XMLCh fgULongMaxInc[];
+    static const XMLCh fgUIntMaxInc[];
+    static const XMLCh fgUShortMaxInc[];
+    static const XMLCh fgUByteMaxInc[];
+    static const XMLCh fgLangPattern[];
+
+    static const XMLCh fgBooleanValueSpace[][32];
+    static const unsigned int fgBooleanValueSpaceArraySize;
+        
 private:
     // -----------------------------------------------------------------------
     //  Unimplemented constructors and operators
