@@ -1,61 +1,30 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 2001, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2001,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
  * $Log: ParserForXMLSchema.cpp,v $
+ * Revision 1.9  2004/09/08 13:56:47  peiyongz
+ * Apache License Version 2.0
+ *
+ * Revision 1.8  2004/01/29 11:51:21  cargilld
+ * Code cleanup changes to get rid of various compiler diagnostic messages.
+ *
+ * Revision 1.7  2003/12/17 00:18:37  cargilld
+ * Update to memory management so that the static memory manager (one used to call Initialize) is only for static data.
+ *
  * Revision 1.6  2003/05/15 18:42:54  knoaman
  * Partial implementation of the configurable memory manager.
  *
@@ -179,14 +148,14 @@ Token* ParserForXMLSchema::processParen() {
     Token* retTok = getTokenFactory()->createParenthesis(parseRegx(true), 0);
 
     if (getState() != REGX_T_RPAREN) {
-        ThrowXML(ParseException, XMLExcepts::Parser_Factor1);
+        ThrowXMLwithMemMgr(ParseException, XMLExcepts::Parser_Factor1, getMemoryManager());
     }
 
     processNext();
     return retTok;
 }
 
-RangeToken* ParserForXMLSchema::parseCharacterClass(const bool useNRange) {
+RangeToken* ParserForXMLSchema::parseCharacterClass(const bool) {
 
     setParseContext(S_INBRACKETS);
     processNext();
@@ -253,12 +222,11 @@ RangeToken* ParserForXMLSchema::parseCharacterClass(const bool useNRange) {
                 break;
             case chLatin_p:
             case chLatin_P:
-                {
-                    int start = getOffset();
+                {                    
                     RangeToken* tok2 = processBacksolidus_pP(ch);
 
                     if (tok2 == 0) {
-                        ThrowXML(ParseException,XMLExcepts::Parser_Atom5);
+                        ThrowXMLwithMemMgr(ParseException,XMLExcepts::Parser_Atom5, getMemoryManager());
                     }
 
                     tok->mergeRanges(tok2);
@@ -281,7 +249,7 @@ RangeToken* ParserForXMLSchema::parseCharacterClass(const bool useNRange) {
             tok->subtractRanges(rangeTok);
 
             if (getState() != REGX_T_CHAR || getCharData() != chCloseSquare) {
-                ThrowXML(ParseException,XMLExcepts::Parser_CC5);
+                ThrowXMLwithMemMgr(ParseException,XMLExcepts::Parser_CC5, getMemoryManager());
             }
             break;
         } // end if REGX_T_XMLSCHEMA...
@@ -296,7 +264,7 @@ RangeToken* ParserForXMLSchema::parseCharacterClass(const bool useNRange) {
                     || ch == chDash)) {
                 // '[', ']', '-' not allowed and should be esacaped
                 XMLCh chStr[] = { ch, chNull };
-                ThrowXML2(ParseException,XMLExcepts::Parser_CC6, chStr, chStr);
+                ThrowXMLwithMemMgr2(ParseException,XMLExcepts::Parser_CC6, chStr, chStr, getMemoryManager());
             }
 
             if (getState() != REGX_T_CHAR || getCharData() != chDash) {
@@ -306,13 +274,13 @@ RangeToken* ParserForXMLSchema::parseCharacterClass(const bool useNRange) {
 
                 processNext();
                 if ((type = getState()) == REGX_T_EOF)
-                    ThrowXML(ParseException,XMLExcepts::Parser_CC2);
+                    ThrowXMLwithMemMgr(ParseException,XMLExcepts::Parser_CC2, getMemoryManager());
 
                 if ((type == REGX_T_CHAR && getCharData() == chCloseSquare)
                     || type == REGX_T_XMLSCHEMA_CC_SUBTRACTION) {
 
                     static const XMLCh dashStr[] = { chDash, chNull};
-                    ThrowXML2(ParseException, XMLExcepts::Parser_CC6, dashStr, dashStr);
+                    ThrowXMLwithMemMgr2(ParseException, XMLExcepts::Parser_CC6, dashStr, dashStr, getMemoryManager());
                 }
                 else {
 
@@ -325,7 +293,7 @@ RangeToken* ParserForXMLSchema::parseCharacterClass(const bool useNRange) {
                             || rangeEnd == chCloseSquare
                             || rangeEnd == chDash)
                             // '[', ']', '-' not allowed and should be esacaped
-                            ThrowXML2(ParseException, XMLExcepts::Parser_CC6, rangeEndStr, rangeEndStr);
+                            ThrowXMLwithMemMgr2(ParseException, XMLExcepts::Parser_CC6, rangeEndStr, rangeEndStr, getMemoryManager());
                     }
                     else if (type == REGX_T_BACKSOLIDUS) {
                         rangeEnd = decodeEscaped();
@@ -335,7 +303,7 @@ RangeToken* ParserForXMLSchema::parseCharacterClass(const bool useNRange) {
 
                     if (ch > rangeEnd) {
                         XMLCh chStr[] = { ch, chNull };
-                        ThrowXML2(ParseException,XMLExcepts::Parser_Ope3, rangeEndStr, chStr);
+                        ThrowXMLwithMemMgr2(ParseException,XMLExcepts::Parser_Ope3, rangeEndStr, chStr, getMemoryManager());
                     }
 
                     tok->addRange(ch, rangeEnd);
@@ -346,7 +314,7 @@ RangeToken* ParserForXMLSchema::parseCharacterClass(const bool useNRange) {
     }
 
     if (getState() == REGX_T_EOF)
-        ThrowXML(ParseException,XMLExcepts::Parser_CC2);
+        ThrowXMLwithMemMgr(ParseException,XMLExcepts::Parser_CC2, getMemoryManager());
 
     tok->sortRanges();
     tok->compactRanges();
@@ -363,27 +331,27 @@ XMLInt32 ParserForXMLSchema::processCInCharacterClass(RangeToken* const tok,
     return -1;
 }
 
-Token* ParserForXMLSchema::processLook(const unsigned short tokType) {
+Token* ParserForXMLSchema::processLook(const unsigned short) {
 
-    ThrowXML(RuntimeException, XMLExcepts::Regex_NotSupported);
+    ThrowXMLwithMemMgr(RuntimeException, XMLExcepts::Regex_NotSupported, getMemoryManager());
     return 0; // for compilers that complain about no return value
 }
 
 Token* ParserForXMLSchema::processBacksolidus_A() {
 
-    ThrowXML(RuntimeException, XMLExcepts::Regex_NotSupported);
+    ThrowXMLwithMemMgr(RuntimeException, XMLExcepts::Regex_NotSupported, getMemoryManager());
     return 0; // for compilers that complain about no return value
 }
 
 Token* ParserForXMLSchema::processBacksolidus_B() {
 
-    ThrowXML(RuntimeException, XMLExcepts::Regex_NotSupported);
+    ThrowXMLwithMemMgr(RuntimeException, XMLExcepts::Regex_NotSupported, getMemoryManager());
     return 0; // for compilers that complain about no return value
 }
 
 Token* ParserForXMLSchema::processBacksolidus_b() {
 
-    ThrowXML(RuntimeException, XMLExcepts::Regex_NotSupported);
+    ThrowXMLwithMemMgr(RuntimeException, XMLExcepts::Regex_NotSupported, getMemoryManager());
     return 0; // for compilers that complain about no return value
 }
 
@@ -401,13 +369,13 @@ Token* ParserForXMLSchema::processBacksolidus_c() {
 
 Token* ParserForXMLSchema::processBacksolidus_g() {
 
-    ThrowXML(RuntimeException, XMLExcepts::Regex_NotSupported);
+    ThrowXMLwithMemMgr(RuntimeException, XMLExcepts::Regex_NotSupported, getMemoryManager());
     return 0; // for compilers that complain about no return value
 }
 
 Token* ParserForXMLSchema::processBacksolidus_gt() {
 
-    ThrowXML(RuntimeException, XMLExcepts::Regex_NotSupported);
+    ThrowXMLwithMemMgr(RuntimeException, XMLExcepts::Regex_NotSupported, getMemoryManager());
     return 0; // for compilers that complain about no return value
 }
 
@@ -425,61 +393,61 @@ Token* ParserForXMLSchema::processBacksolidus_i() {
 
 Token* ParserForXMLSchema::processBacksolidus_lt() {
 
-    ThrowXML(RuntimeException, XMLExcepts::Regex_NotSupported);
+    ThrowXMLwithMemMgr(RuntimeException, XMLExcepts::Regex_NotSupported, getMemoryManager());
     return 0; // for compilers that complain about no return value
 }
 
 Token* ParserForXMLSchema::processBacksolidus_X() {
 
-    ThrowXML(RuntimeException, XMLExcepts::Regex_NotSupported);
+    ThrowXMLwithMemMgr(RuntimeException, XMLExcepts::Regex_NotSupported, getMemoryManager());
     return 0; // for compilers that complain about no return value
 }
 
 Token* ParserForXMLSchema::processBacksolidus_Z() {
 
-    ThrowXML(RuntimeException, XMLExcepts::Regex_NotSupported);
+    ThrowXMLwithMemMgr(RuntimeException, XMLExcepts::Regex_NotSupported, getMemoryManager());
     return 0; // for compilers that complain about no return value
 }
 
 Token* ParserForXMLSchema::processBacksolidus_z() {
 
-    ThrowXML(RuntimeException, XMLExcepts::Regex_NotSupported);
+    ThrowXMLwithMemMgr(RuntimeException, XMLExcepts::Regex_NotSupported, getMemoryManager());
     return 0; // for compilers that complain about no return value
 }
 
 Token* ParserForXMLSchema::processBackReference() {
 
-    ThrowXML(RuntimeException, XMLExcepts::Regex_NotSupported);
+    ThrowXMLwithMemMgr(RuntimeException, XMLExcepts::Regex_NotSupported, getMemoryManager());
     return 0; // for compilers that complain about no return value
 }
 
 Token* ParserForXMLSchema::processCondition() {
 
-    ThrowXML(RuntimeException, XMLExcepts::Regex_NotSupported);
+    ThrowXMLwithMemMgr(RuntimeException, XMLExcepts::Regex_NotSupported, getMemoryManager());
     return 0; // for compilers that complain about no return value
 }
 
 Token* ParserForXMLSchema::processIndependent() {
 
-    ThrowXML(RuntimeException, XMLExcepts::Regex_NotSupported);
+    ThrowXMLwithMemMgr(RuntimeException, XMLExcepts::Regex_NotSupported, getMemoryManager());
     return 0; // for compilers that complain about no return value
 }
 
 Token* ParserForXMLSchema::processModifiers() {
 
-    ThrowXML(RuntimeException, XMLExcepts::Regex_NotSupported);
+    ThrowXMLwithMemMgr(RuntimeException, XMLExcepts::Regex_NotSupported, getMemoryManager());
     return 0; // for compilers that complain about no return value
 }
 
 Token* ParserForXMLSchema::processParen2() {
 
-    ThrowXML(RuntimeException, XMLExcepts::Regex_NotSupported);
+    ThrowXMLwithMemMgr(RuntimeException, XMLExcepts::Regex_NotSupported, getMemoryManager());
     return 0; // for compilers that complain about no return value
 }
 
 RangeToken* ParserForXMLSchema::parseSetOperations() {
 
-    ThrowXML(RuntimeException, XMLExcepts::Regex_NotSupported);
+    ThrowXMLwithMemMgr(RuntimeException, XMLExcepts::Regex_NotSupported, getMemoryManager());
     return 0; // for compilers that complain about no return value
 }
 
@@ -517,7 +485,7 @@ Token* ParserForXMLSchema::getTokenForShorthand(const XMLInt32 ch) {
 // ---------------------------------------------------------------------------
 //  ParserForXMLSchema: Helper methods
 // ---------------------------------------------------------------------------
-bool ParserForXMLSchema::checkQuestion(const int off) {
+bool ParserForXMLSchema::checkQuestion(const int) {
 
     return false;
 }
@@ -526,7 +494,7 @@ bool ParserForXMLSchema::checkQuestion(const int off) {
 XMLInt32 ParserForXMLSchema::decodeEscaped() {
 
     if (getState() != REGX_T_BACKSOLIDUS)
-        ThrowXML(ParseException,XMLExcepts::Parser_Next1);;
+        ThrowXMLwithMemMgr(ParseException,XMLExcepts::Parser_Next1, getMemoryManager());
 
     XMLInt32 ch = getCharData();
 
@@ -557,9 +525,8 @@ XMLInt32 ParserForXMLSchema::decodeEscaped() {
         break;
     default:
 		{
-        XMLCh chString[] = {chBackSlash, ch, chNull};
-        chString[1] = ch;
-        ThrowXML1(ParseException,XMLExcepts::Parser_Process2, chString);
+        XMLCh chString[] = {chBackSlash, ch, chNull};        
+        ThrowXMLwithMemMgr1(ParseException,XMLExcepts::Parser_Process2, chString, getMemoryManager());
         }
     }
 
