@@ -1,61 +1,30 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2003 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
  * $Log: DTDScanner.hpp,v $
+ * Revision 1.11  2004/09/08 13:56:50  peiyongz
+ * Apache License Version 2.0
+ *
+ * Revision 1.10  2004/01/29 11:52:30  cargilld
+ * Code cleanup changes to get rid of various compiler diagnostic messages.
+ *
+ * Revision 1.9  2003/07/10 19:50:12  peiyongz
+ * Stateless Grammar: create grammar components with grammarPool's memory Manager
+ *
  * Revision 1.8  2003/05/16 21:43:19  knoaman
  * Memory manager implementation: Modify constructors to pass in the memory manager.
  *
@@ -147,6 +116,7 @@ public:
     (
           DTDGrammar*           dtdGrammar
         , DocTypeHandler* const docTypeHandler
+        , MemoryManager* const  grammarPoolMemoryManager
         , MemoryManager* const  manager = XMLPlatformUtils::fgMemoryManager
     );
     virtual ~DTDScanner();
@@ -185,15 +155,19 @@ public:
     );
 
 private:
+    // -----------------------------------------------------------------------
+    // Unimplemented constructors and operators
+    // -----------------------------------------------------------------------
+    DTDScanner(const DTDScanner &);
+    DTDScanner& operator = (const  DTDScanner&);
+
     // -----------------------------------------------------------------------
     //  Private DTD scanning methods. These are all in XMLValidator2.cpp
     // -----------------------------------------------------------------------
     bool checkForPERef
     (
-        const   bool    spaceRequired
-        , const bool    inLiteral
+          const bool    inLiteral
         , const bool    inMarkup
-        , const bool    throwEndOfExt = false
     );
     bool expandPERef
     (
@@ -223,7 +197,7 @@ private:
     void scanElementDecl();
     void scanEntityDecl();
     bool scanEntityDef();
-    bool scanEntityLiteral(XMLBuffer& toFill, const bool isPE);
+    bool scanEntityLiteral(XMLBuffer& toFill);
     bool scanEntityDef(DTDEntityDecl& decl, const bool isPEDecl);
     EntityExpRes scanEntityRef(XMLCh& firstCh, XMLCh& secondCh, bool& escaped);
     bool scanEnumeration
@@ -298,6 +272,7 @@ private:
     //      declaration
     // -----------------------------------------------------------------------
     MemoryManager*                  fMemoryManager;
+    MemoryManager*                  fGrammarPoolMemoryManager;
     DocTypeHandler*                 fDocTypeHandler;
     DTDAttDef*                      fDumAttDef;
     DTDElementDecl*                 fDumElemDecl;
