@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2001,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: DTDValidator.cpp,v 1.20 2004/02/03 16:41:25 peiyongz Exp $
+ * $Id: DTDValidator.cpp,v 1.24 2004/09/08 13:56:50 peiyongz Exp $
  */
 
 
@@ -315,7 +275,7 @@ DTDValidator::validateAttrValue(const   XMLAttDef*      attDef
         {
             // If its not, emit and error but try to keep going
             if (!getReaderMgr()->getCurrentReader()->isFirstNameChar(*valPtr))
-                emitError(XMLValid::AttrValNotName, fullName);
+                emitError(XMLValid::AttrValNotName, valPtr, fullName);
             valPtr++;
         }
 
@@ -326,13 +286,22 @@ DTDValidator::validateAttrValue(const   XMLAttDef*      attDef
             //  If we hit a whitespace, its either a break between two
             //  or more values, or an error if we have a single value.
             //
-            if (getReaderMgr()->getCurrentReader()->isWhitespace(*valPtr))
+            //
+            //   XML1.0-3rd
+            //
+            //   [6]   Names   ::=   Name (#x20 Name)*
+            //   [8]   Nmtokens   ::=   Nmtoken (#x20 Nmtoken)*
+            //
+            //   only and only ONE #x20 is allowed to be the delimiter
+            //
+            if (*valPtr==chSpace)
             {
                 if (!multipleValues)
                 {
                     emitError(XMLValid::NoMultipleValues, fullName);
                     return;
                 }
+
                 break;
             }
 
@@ -346,7 +315,7 @@ DTDValidator::validateAttrValue(const   XMLAttDef*      attDef
 
             if (!getReaderMgr()->getCurrentReader()->isNameChar(*valPtr))
             {
-                emitError(XMLValid::AttrValNotName, fullName);
+                emitError(XMLValid::AttrValNotName, valPtr, fullName);
                 return;
             }
             valPtr++;
@@ -412,7 +381,7 @@ DTDValidator::validateAttrValue(const   XMLAttDef*      attDef
             if (decl)
             {
                 if (!decl->isUnparsed())
-                    emitError(XMLValid::BadEntityRefAttr, fullName);
+                    emitError(XMLValid::BadEntityRefAttr, pszTmpVal, fullName);
             }
              else
             {
@@ -435,7 +404,7 @@ DTDValidator::validateAttrValue(const   XMLAttDef*      attDef
             //  this value will be legal since it matches one of them.
             //
             if (!XMLString::isInList(pszTmpVal, enumList))
-                emitError(XMLValid::DoesNotMatchEnumList, fullName);
+                emitError(XMLValid::DoesNotMatchEnumList, pszTmpVal, fullName);
         }
 
         // If not doing multiple values, then we are done
@@ -523,8 +492,24 @@ void DTDValidator::preContentValidation(bool reuseGrammar,
         //  3) That for any notation types, that their lists
         //      of possible values refer to declared notations.
         //
+        //  4) XML1.0(3rd edition)
+        //
+        //     Validity constraint: One Notation Per Element Type
+        //     An element type MUST NOT have more than one NOTATION attribute specified.
+        //
+        //     Validity constraint: No Notation on Empty Element
+        //     For compatibility, an attribute of type NOTATION MUST NOT be declared on an element declared EMPTY.
+        //
+        //     Validity constraint: No Duplicate Tokens
+        //     The notation names in a single NotationType attribute declaration, as well as 
+        //     the NmTokens in a single Enumeration attribute declaration, MUST all be distinct.
+        //
+
         XMLAttDefList& attDefList = curElem.getAttDefList();
         bool seenId = false;
+        bool seenNOTATION = false;
+        bool elemEmpty = (curElem.getModelType() == DTDElementDecl::Empty);
+
         for(unsigned int i=0; i<attDefList.getAttDefCount(); i++)
         {
             const XMLAttDef& curAttDef = attDefList.getAttDef(i);
@@ -543,55 +528,51 @@ void DTDValidator::preContentValidation(bool reuseGrammar,
 
                 seenId = true;
             }
-             else if (curAttDef.getType() == XMLAttDef::Notation && curAttDef.getEnumeration())
+             else if (curAttDef.getType() == XMLAttDef::Notation)
             {
-                //
-                //  We need to verify that all of its possible values
-                //  (in the enum list) refer to valid notations.
-                //
-                XMLCh* list = XMLString::replicate(curAttDef.getEnumeration(), getScanner()->getMemoryManager());
-                ArrayJanitor<XMLCh> janList(list, getScanner()->getMemoryManager());
-
-                //
-                //  Search forward for a space or a null. If a null,
-                //  we are done. If a space, cap it and look it up.
-                //
-                bool    breakFlag = false;
-                XMLCh*  listPtr = list;
-                XMLCh*  lastPtr = listPtr;
-                while (true)
+                if (seenNOTATION)
                 {
-                    while (*listPtr && (*listPtr != chSpace))
-                        listPtr++;
+                    emitError
+                    (
+                        XMLValid::ElemOneNotationAttr
+                      , curElem.getFullName()
+                    );
 
-                    //
-                    //  If at the end, indicate we need to break after
-                    //  this one. Else, cap it off here.
-                    //
-                    if (!*listPtr)
-                        breakFlag = true;
-                    else
-                        *listPtr = chNull;
-
-                    if (!fDTDGrammar->getNotationDecl(lastPtr))
-                    {
-                        emitError
-                        (
-                            XMLValid::UnknownNotRefAttr
-                            , curAttDef.getFullName()
-                            , lastPtr
-                        );
-                    }
-
-                    // Break out if we hit the end last time
-                    if (breakFlag)
-                        break;
-
-                    // Else move upwards and try again
-                    listPtr++;
-                    lastPtr = listPtr;
+                    break;
                 }
-            }
+
+                seenNOTATION = true;
+
+                // no notation attribute on empty element
+                if (elemEmpty)
+                {
+                    emitError
+                   (
+                      XMLValid::EmptyElemNotationAttr
+                    , curElem.getFullName()
+                    , curAttDef.getFullName()
+                    );
+
+                    break;
+                }
+
+                //go through enumeration list to check
+                // distinct 
+                // notation declaration
+                if (curAttDef.getEnumeration())
+                {
+                    checkTokenList(curAttDef, true);
+                }
+             }
+             else if (curAttDef.getType() == XMLAttDef::Enumeration )
+             {
+                //go through enumeration list to check
+                // distinct only
+                if (curAttDef.getEnumeration())
+                {
+                    checkTokenList(curAttDef, false);
+                }
+             }
 
             // If it has a default/fixed value, then validate it
             if (validateDefAttr && curAttDef.getValue())
@@ -640,4 +621,69 @@ void DTDValidator::postParseValidation()
     //
 }
 
+//
+//  We need to verify that all of its possible values
+//  (in the enum list) 
+//   is distinct and
+//   refer to valid notations if toValidateNotation is set on
+//
+void DTDValidator::checkTokenList(const XMLAttDef&  curAttDef
+                                ,       bool        toValidateNotation)
+{
+
+    XMLCh* list = XMLString::replicate(curAttDef.getEnumeration(), getScanner()->getMemoryManager());
+    ArrayJanitor<XMLCh> janList(list, getScanner()->getMemoryManager());
+
+    //
+    //  Search forward for a space or a null. If a null,
+    //  we are done. If a space, cap it and look it up.
+    //
+    bool    breakFlag = false;
+    XMLCh*  listPtr = list;
+    XMLCh*  lastPtr = listPtr;
+    while (true)
+    {
+        while (*listPtr && (*listPtr != chSpace))
+            listPtr++;
+
+        //
+        //  If at the end, indicate we need to break after
+        //  this one. Else, cap it off here.
+        //
+        if (!*listPtr)
+            breakFlag = true;
+        else
+            *listPtr++ = chNull;
+
+        //distinction check
+        //there should be no same token found in the remaining list
+        if (XMLString::isInList(lastPtr, listPtr))
+        {
+            emitError
+                (
+                XMLValid::AttrDupToken
+                , curAttDef.getFullName()
+                , lastPtr
+                );
+        }
+
+        if (toValidateNotation && !fDTDGrammar->getNotationDecl(lastPtr))
+        {
+            emitError
+                (
+                XMLValid::UnknownNotRefAttr
+                , curAttDef.getFullName()
+                , lastPtr
+                );
+        }
+
+        // Break out if we hit the end last time
+        if (breakFlag)
+            break;
+
+        // Else move upwards and try again
+        lastPtr = listPtr;
+    }
+}
+
 XERCES_CPP_NAMESPACE_END
