@@ -1,74 +1,29 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2001,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: ContentSpecNode.cpp,v 1.8 2003/05/18 14:02:06 knoaman Exp $
+ * $Id: ContentSpecNode.cpp,v 1.13 2004/09/08 13:56:51 peiyongz Exp $
  */
 
 
 // ---------------------------------------------------------------------------
 //  Includes
 // ---------------------------------------------------------------------------
-#include <xercesc/util/Janitor.hpp>
-#include <xercesc/util/XMLUniDefs.hpp>
-#include <xercesc/util/XMLUni.hpp>
-#include <xercesc/framework/XMLNotationDecl.hpp>
 #include <xercesc/framework/XMLBuffer.hpp>
 #include <xercesc/validators/common/ContentSpecNode.hpp>
-#include <xercesc/validators/DTD/DTDValidator.hpp>
 #include <xercesc/validators/schema/SchemaSymbols.hpp>
 
 XERCES_CPP_NAMESPACE_BEGIN
@@ -83,30 +38,27 @@ XERCES_CPP_NAMESPACE_BEGIN
 
 ContentSpecNode::ContentSpecNode(const ContentSpecNode& toCopy) :
     fMemoryManager(toCopy.fMemoryManager)
+    , fElement(0)
+    , fElementDecl(toCopy.fElementDecl)
+    , fFirst(0)
+    , fSecond(0)
+    , fType(toCopy.fType)
+    , fAdoptFirst(true)
+    , fAdoptSecond(true)
+    , fMinOccurs(toCopy.fMinOccurs)
+    , fMaxOccurs(toCopy.fMaxOccurs)
 {
     const QName* tempElement = toCopy.getElement();
     if (tempElement)
         fElement = new (fMemoryManager) QName(*tempElement);
-    else
-        fElement = 0;
 
     const ContentSpecNode *tmp = toCopy.getFirst();
     if (tmp)
         fFirst = new (fMemoryManager) ContentSpecNode(*tmp);
-    else
-        fFirst = 0;
 
     tmp = toCopy.getSecond();
     if (tmp)
         fSecond = new (fMemoryManager) ContentSpecNode(*tmp);
-    else
-        fSecond = 0;
-
-    fType = toCopy.getType();
-    fAdoptFirst = true;
-    fAdoptSecond = true;
-    fMinOccurs = toCopy.getMinOccurs();
-    fMaxOccurs = toCopy.getMaxOccurs();
 }
 
 // ---------------------------------------------------------------------------
@@ -139,7 +91,7 @@ static void formatNode( const   ContentSpecNode* const      curNode
     }
 
     // Now handle our type
-    switch(curType)
+    switch(curType & 0x0f)
     {
         case ContentSpecNode::Leaf :
             if (curNode->getElement()->getURI() == XMLElementDecl::fgPCDataElemId)
@@ -237,9 +189,9 @@ int ContentSpecNode::getMinTotalRange() const {
 
     int min = fMinOccurs;
 
-    if (fType == ContentSpecNode::Sequence
+    if ((fType & 0x0f) == ContentSpecNode::Sequence
         || fType == ContentSpecNode::All
-        || fType == ContentSpecNode::Choice) {
+        || (fType & 0x0f) == ContentSpecNode::Choice) {
 
         int minFirst = fFirst->getMinTotalRange();
 
@@ -247,7 +199,7 @@ int ContentSpecNode::getMinTotalRange() const {
 
             int minSecond = fSecond->getMinTotalRange();
 
-            if (fType == ContentSpecNode::Choice) {
+            if ((fType & 0x0f) == ContentSpecNode::Choice) {
                 min = min * ((minFirst < minSecond)? minFirst : minSecond);
             }
             else {
@@ -269,9 +221,9 @@ int ContentSpecNode::getMaxTotalRange() const {
          return SchemaSymbols::XSD_UNBOUNDED;
     }
 
-    if (fType == ContentSpecNode::Sequence
+    if ((fType & 0x0f) == ContentSpecNode::Sequence
         || fType == ContentSpecNode::All
-        || fType == ContentSpecNode::Choice) {
+        || (fType & 0x0f) == ContentSpecNode::Choice) {
 
         int maxFirst = fFirst->getMaxTotalRange();
 
@@ -288,7 +240,7 @@ int ContentSpecNode::getMaxTotalRange() const {
             }
             else {
 
-                if (fType == ContentSpecNode::Choice) {
+                if ((fType & 0x0f) == ContentSpecNode::Choice) {
                     max = max * (maxFirst > maxSecond) ? maxFirst : maxSecond;
                 }
                 else {
@@ -304,5 +256,50 @@ int ContentSpecNode::getMaxTotalRange() const {
     return max;
 }
 
+/***
+ * Support for Serialization/De-serialization
+ ***/
+
+IMPL_XSERIALIZABLE_TOCREATE(ContentSpecNode)
+
+void ContentSpecNode::serialize(XSerializeEngine& serEng)
+{
+    /***
+     *  Since fElement, fFirst, fSecond are NOT created by the default 
+     *  constructor, we need to create them dynamically.
+     ***/
+
+    if (serEng.isStoring())
+    {
+        serEng<<fElement;
+        XMLElementDecl::storeElementDecl(serEng, fElementDecl);
+        serEng<<fFirst;
+        serEng<<fSecond;
+
+        serEng<<(int)fType;
+        serEng<<fAdoptFirst;
+        serEng<<fAdoptSecond;
+        serEng<<fMinOccurs;
+        serEng<<fMaxOccurs;
+    }
+    else
+    {
+        serEng>>fElement;
+        fElementDecl = XMLElementDecl::loadElementDecl(serEng);
+        serEng>>fFirst;
+        serEng>>fSecond;
+
+        int type;
+        serEng>>type;
+        fType = (NodeTypes)type;
+
+        serEng>>fAdoptFirst;
+        serEng>>fAdoptSecond;
+        serEng>>fMinOccurs;
+        serEng>>fMaxOccurs;
+    }
+
+}
+
 XERCES_CPP_NAMESPACE_END
 
