@@ -1,61 +1,36 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2001,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
  * $Log: ContentSpecNode.hpp,v $
+ * Revision 1.12  2004/09/08 13:56:51  peiyongz
+ * Apache License Version 2.0
+ *
+ * Revision 1.11  2004/01/29 11:51:21  cargilld
+ * Code cleanup changes to get rid of various compiler diagnostic messages.
+ *
+ * Revision 1.10  2003/11/20 17:52:14  knoaman
+ * PSVI: store element declaration (leaf nodes)
+ *
+ * Revision 1.9  2003/11/07 17:08:11  knoaman
+ * For PSVI support, distinguish wildcard elements with namespace lists.
+ *
+ * Revision 1.8  2003/09/26 18:29:27  peiyongz
+ * Implement serialization/deserialization
+ *
  * Revision 1.7  2003/05/18 14:02:06  knoaman
  * Memory manager implementation: pass per instance manager.
  *
@@ -167,13 +142,15 @@
 #include <xercesc/framework/XMLElementDecl.hpp>
 #include <xercesc/framework/MemoryManager.hpp>
 
+#include <xercesc/internal/XSerializable.hpp>
+
 XERCES_CPP_NAMESPACE_BEGIN
 
 class XMLBuffer;
 class Grammar;
 
 
-class ContentSpecNode : public XMemory
+class XMLUTIL_EXPORT ContentSpecNode : public XSerializable, public XMemory
 {
 public :
     // -----------------------------------------------------------------------
@@ -191,9 +168,12 @@ public :
         , Any_Other
         , Any_NS = 8
         , All = 9
+        , Any_NS_Choice = 20
+        , ModelGroupSequence = 21
         , Any_Lax = 22
         , Any_Other_Lax = 23
         , Any_NS_Lax = 24
+        , ModelGroupChoice = 36
         , Any_Skip = 38
         , Any_Other_Skip = 39
         , Any_NS_Skip = 40
@@ -212,6 +192,11 @@ public :
         , MemoryManager* const manager = XMLPlatformUtils::fgMemoryManager
     );
     ContentSpecNode
+    (
+        XMLElementDecl* const elemDecl
+        , MemoryManager* const manager = XMLPlatformUtils::fgMemoryManager
+    );
+    ContentSpecNode
     (
         QName* const toAdopt
         , const bool copyQName
@@ -234,6 +219,8 @@ public :
     // -----------------------------------------------------------------------
     QName* getElement();
     const QName* getElement() const;
+    XMLElementDecl* getElementDecl();
+    const XMLElementDecl* getElementDecl() const;
     ContentSpecNode* getFirst();
     const ContentSpecNode* getFirst() const;
     ContentSpecNode* getSecond();
@@ -268,12 +255,16 @@ public :
     int  getMinTotalRange() const;
     int  getMaxTotalRange() const;
 
+    /***
+     * Support for Serialization/De-serialization
+     ***/
+    DECL_XSERIALIZABLE(ContentSpecNode)
 
 private :
     // -----------------------------------------------------------------------
     //  Unimplemented constructors and operators
     // -----------------------------------------------------------------------
-
+    ContentSpecNode& operator=(const ContentSpecNode&);
 
 
     // -----------------------------------------------------------------------
@@ -314,6 +305,7 @@ private :
     // -----------------------------------------------------------------------
     MemoryManager*      fMemoryManager;
     QName*              fElement;
+    XMLElementDecl*     fElementDecl;
     ContentSpecNode*    fFirst;
     ContentSpecNode*    fSecond;
     NodeTypes           fType;
@@ -330,6 +322,7 @@ inline ContentSpecNode::ContentSpecNode(MemoryManager* const manager) :
 
     fMemoryManager(manager)
     , fElement(0)
+    , fElementDecl(0)
     , fFirst(0)
     , fSecond(0)
     , fType(ContentSpecNode::Leaf)
@@ -346,6 +339,7 @@ ContentSpecNode::ContentSpecNode(QName* const element,
 
     fMemoryManager(manager)
     , fElement(0)
+    , fElementDecl(0)
     , fFirst(0)
     , fSecond(0)
     , fType(ContentSpecNode::Leaf)
@@ -358,6 +352,25 @@ ContentSpecNode::ContentSpecNode(QName* const element,
         fElement = new (fMemoryManager) QName(*element);
 }
 
+inline
+ContentSpecNode::ContentSpecNode(XMLElementDecl* const elemDecl,
+                                 MemoryManager* const manager) :
+
+    fMemoryManager(manager)
+    , fElement(0)
+    , fElementDecl(elemDecl)
+    , fFirst(0)
+    , fSecond(0)
+    , fType(ContentSpecNode::Leaf)
+    , fAdoptFirst(true)
+    , fAdoptSecond(true)
+    , fMinOccurs(1)
+    , fMaxOccurs(1)
+{
+    if (elemDecl)
+        fElement = new (manager) QName(*(elemDecl->getElementName()));
+}
+
 inline
 ContentSpecNode::ContentSpecNode( QName* const element
                                 , const bool copyQName
@@ -365,6 +378,7 @@ ContentSpecNode::ContentSpecNode( QName* const element
 
     fMemoryManager(manager)
     , fElement(0)
+    , fElementDecl(0)
     , fFirst(0)
     , fSecond(0)
     , fType(ContentSpecNode::Leaf)
@@ -394,6 +408,7 @@ ContentSpecNode::ContentSpecNode(const  NodeTypes              type
 
     fMemoryManager(manager)
     , fElement(0)
+    , fElementDecl(0)
     , fFirst(firstAdopt)
     , fSecond(secondAdopt)
     , fType(type)
@@ -404,7 +419,6 @@ ContentSpecNode::ContentSpecNode(const  NodeTypes              type
 {
 }
 
-
 inline ContentSpecNode::~ContentSpecNode()
 {
     // Delete our children, which cause recursive cleanup
@@ -432,6 +446,16 @@ inline const QName* ContentSpecNode::getElement() const
     return fElement;
 }
 
+inline XMLElementDecl* ContentSpecNode::getElementDecl()
+{
+    return fElementDecl;
+}
+
+inline const XMLElementDecl* ContentSpecNode::getElementDecl() const
+{
+    return fElementDecl;
+}
+
 inline ContentSpecNode* ContentSpecNode::getFirst()
 {
     return fFirst;
