@@ -1,61 +1,39 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2001,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
  * $Log: DFAContentModel.cpp,v $
+ * Revision 1.13  2004/09/16 13:32:03  amassari
+ * Updated error message for UPA to also state the complex type that is failing the test
+ *
+ * Revision 1.12  2004/09/08 13:56:51  peiyongz
+ * Apache License Version 2.0
+ *
+ * Revision 1.11  2004/01/29 11:51:21  cargilld
+ * Code cleanup changes to get rid of various compiler diagnostic messages.
+ *
+ * Revision 1.10  2003/12/17 00:18:38  cargilld
+ * Update to memory management so that the static memory manager (one used to call Initialize) is only for static data.
+ *
+ * Revision 1.9  2003/11/20 18:12:20  knoaman
+ * Use a bitwise operation to check the node type.
+ *
+ * Revision 1.8  2003/11/07 17:08:11  knoaman
+ * For PSVI support, distinguish wildcard elements with namespace lists.
+ *
  * Revision 1.7  2003/05/18 14:02:06  knoaman
  * Memory manager implementation: pass per instance manager.
  *
@@ -245,6 +223,7 @@ DFAContentModel::DFAContentModel( const bool             dtd
     , fHeadNode(0)
     , fLeafCount(0)
     , fLeafList(0)
+    , fLeafListType(0)
     , fTransTable(0)
     , fTransTableSize(0)
     , fDTD(dtd)
@@ -271,6 +250,7 @@ DFAContentModel::DFAContentModel( const bool             dtd
     , fHeadNode(0)
     , fLeafCount(0)
     , fLeafList(0)
+    , fLeafListType(0)
     , fTransTable(0)
     , fTransTableSize(0)
     , fDTD(dtd)
@@ -312,7 +292,7 @@ DFAContentModel::~DFAContentModel()
 int
 DFAContentModel::validateContent( QName** const        children
                                 , const unsigned int   childCount
-                                , const unsigned int   emptyNamespaceId) const
+                                , const unsigned int) const
 {
     //
     //  If there are no children, then either we fail on the 0th element
@@ -422,7 +402,7 @@ DFAContentModel::validateContent( QName** const        children
 
 int DFAContentModel::validateContentSpecial(QName** const          children
                                             , const unsigned int      childCount
-                                            , const unsigned int      emptyNamespaceId
+                                            , const unsigned int
                                             , GrammarResolver*  const pGrammarResolver
                                             , XMLStringPool*    const pStringPool) const
 {
@@ -717,8 +697,7 @@ void DFAContentModel::buildDFA(ContentSpecNode* const curNode)
 
         for (unsigned int leafIndex = 0; leafIndex < fLeafCount; leafIndex++)
         {
-            const QName* leaf = fLeafList[leafIndex]->getElement();
-            const int leafType = fLeafListType[leafIndex];
+            const QName* leaf = fLeafList[leafIndex]->getElement();            
             if (fDTD) {
                 if (XMLString::equals(leaf->getRawName(), elementRawName)) {
                     fLeafSorter[fSortCount++] = leafIndex;
@@ -1090,8 +1069,8 @@ CMNode* DFAContentModel::buildSyntaxTree(ContentSpecNode* const curNode)
         ContentSpecNode* leftNode = curNode->getFirst();
         ContentSpecNode* rightNode = curNode->getSecond();
 
-        if ((curType == ContentSpecNode::Choice)
-        ||   (curType == ContentSpecNode::Sequence))
+        if (((curType & 0x0f) == ContentSpecNode::Choice)
+        ||   ((curType & 0x0f) == ContentSpecNode::Sequence))
         {
             //
             //  Recurse on both children, and return a binary op node with the
@@ -1122,7 +1101,7 @@ CMNode* DFAContentModel::buildSyntaxTree(ContentSpecNode* const curNode)
         }
          else
         {
-            ThrowXML(RuntimeException, XMLExcepts::CM_UnknownCMSpecType);
+            ThrowXMLwithMemMgr(RuntimeException, XMLExcepts::CM_UnknownCMSpecType, fMemoryManager);
         }
     }
     return retNode;
@@ -1134,13 +1113,13 @@ void DFAContentModel::calcFollowList(CMNode* const curNode)
     // Get the spec type of the passed node
     const ContentSpecNode::NodeTypes curType = curNode->getType();
 
-    if (curType == ContentSpecNode::Choice)
+    if ((curType & 0x0f) == ContentSpecNode::Choice)
     {
         // Just recurse
         calcFollowList(((CMBinaryOp*)curNode)->getLeft());
         calcFollowList(((CMBinaryOp*)curNode)->getRight());
     }
-     else if (curType == ContentSpecNode::Sequence)
+    else if ((curType & 0x0f) == ContentSpecNode::Sequence)
     {
         // Recurse before we process this node
         calcFollowList(((CMBinaryOp*)curNode)->getLeft());
@@ -1246,8 +1225,8 @@ int DFAContentModel::postTreeBuildInit(         CMNode* const   nodeCur
         fLeafListType[newIndex] = curType;
         ++newIndex;
     }
-    else if ((curType == ContentSpecNode::Choice)
-         ||  (curType == ContentSpecNode::Sequence))
+    else if (((curType & 0x0f) == ContentSpecNode::Choice)
+         ||  ((curType & 0x0f) == ContentSpecNode::Sequence))
     {
         newIndex = postTreeBuildInit(((CMBinaryOp*)nodeCur)->getLeft(), newIndex);
         newIndex = postTreeBuildInit(((CMBinaryOp*)nodeCur)->getRight(), newIndex);
@@ -1284,7 +1263,7 @@ int DFAContentModel::postTreeBuildInit(         CMNode* const   nodeCur
     }
     else
     {
-        ThrowXML(RuntimeException, XMLExcepts::CM_UnknownCMSpecType);
+        ThrowXMLwithMemMgr(RuntimeException, XMLExcepts::CM_UnknownCMSpecType, fMemoryManager);
     }
     return newIndex;
 }
@@ -1295,13 +1274,14 @@ ContentLeafNameTypeVector* DFAContentModel::getContentLeafNameTypeVector() const
 {
    //later change it to return the data member
 	return fLeafNameTypeVector;
-};
+}
 
 void DFAContentModel::checkUniqueParticleAttribution (SchemaGrammar*    const pGrammar,
                                                       GrammarResolver*  const pGrammarResolver,
                                                       XMLStringPool*    const pStringPool,
                                                       XMLValidator*     const pValidator,
-                                                      unsigned int*     const pContentSpecOrgURI)
+                                                      unsigned int*     const pContentSpecOrgURI,
+                                                      const XMLCh*            pComplexTypeName /*= 0*/)
 {
 
     SubstitutionGroupComparator comparator(pGrammarResolver, pStringPool);
@@ -1380,6 +1360,7 @@ void DFAContentModel::checkUniqueParticleAttribution (SchemaGrammar*    const pG
                            buf2.set(fElemMap[k]->getRawName());
 
                        pValidator->emitError(XMLValid::UniqueParticleAttributionFail,
+                                             pComplexTypeName,
                                              buf1.getRawBuffer(),
                                              buf2.getRawBuffer());
                     }
