@@ -1,61 +1,27 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 2001, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2001,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
  * $Log: BooleanDatatypeValidator.cpp,v $
+ * Revision 1.18  2004/09/08 13:56:52  peiyongz
+ * Apache License Version 2.0
+ *
+ * Revision 1.17  2004/08/11 16:52:59  peiyongz
+ * using Literal constants from XMLUni
+ *
  * Revision 1.16  2004/01/29 11:51:22  cargilld
  * Code cleanup changes to get rid of various compiler diagnostic messages.
  *
@@ -135,15 +101,6 @@
 
 XERCES_CPP_NAMESPACE_BEGIN
 
-const int   ARRAYSIZE = 4;
-const XMLCh fgValueSpace[][32] =
-{
-    { chLatin_f, chLatin_a, chLatin_l, chLatin_s, chLatin_e, chNull },
-    { chLatin_t, chLatin_r, chLatin_u, chLatin_e, chNull },
-    { chDigit_0, chNull },
-    { chDigit_1, chNull }
-};
-
 // ---------------------------------------------------------------------------
 //  Constructors and Destructor
 // ---------------------------------------------------------------------------
@@ -237,14 +194,14 @@ void BooleanDatatypeValidator::checkContent( const XMLCh*             const cont
     if (asBase)
         return;
 
-    int   i = 0;
-    for ( ; i < ARRAYSIZE; i++ )
+    unsigned int   i = 0;
+    for ( ; i < XMLUni::fgBooleanValueSpaceArraySize; i++ )
     {
-        if ( XMLString::equals(content, fgValueSpace[i]))
+        if ( XMLString::equals(content, XMLUni::fgBooleanValueSpace[i]))
             break;
     }
 
-    if (i == ARRAYSIZE)
+    if (i == XMLUni::fgBooleanValueSpaceArraySize)
         ThrowXMLwithMemMgr(InvalidDatatypeValueException, XMLExcepts::CM_UnaryOpHadBinType, manager);
         //Not valid boolean type
 
@@ -258,19 +215,19 @@ int BooleanDatatypeValidator::compare(const XMLCh* const lValue
     // 1 == true
     // 0 == false
 
-    if (XMLString::equals(lValue, fgValueSpace[0])||
-        XMLString::equals(lValue, fgValueSpace[2]))
+    if (XMLString::equals(lValue, XMLUni::fgBooleanValueSpace[0])||
+        XMLString::equals(lValue, XMLUni::fgBooleanValueSpace[2]))
     {
-        if (XMLString::equals(rValue, fgValueSpace[0]) ||
-            XMLString::equals(rValue, fgValueSpace[2]))
+        if (XMLString::equals(rValue, XMLUni::fgBooleanValueSpace[0]) ||
+            XMLString::equals(rValue, XMLUni::fgBooleanValueSpace[2]))
             return 0;
     }
     else
-    if (XMLString::equals(lValue, fgValueSpace[1]) ||
-        XMLString::equals(lValue, fgValueSpace[3]))
+    if (XMLString::equals(lValue, XMLUni::fgBooleanValueSpace[1]) ||
+        XMLString::equals(lValue, XMLUni::fgBooleanValueSpace[3]))
     {
-        if (XMLString::equals(rValue, fgValueSpace[1]) ||
-            XMLString::equals(rValue, fgValueSpace[3]))
+        if (XMLString::equals(rValue, XMLUni::fgBooleanValueSpace[1]) ||
+            XMLString::equals(rValue, XMLUni::fgBooleanValueSpace[3]))
             return 0;
     }
 
@@ -308,10 +265,10 @@ const XMLCh* BooleanDatatypeValidator::getCanonicalRepresentation(const XMLCh*
         }
     }
 
-    return ( XMLString::equals(rawData, fgValueSpace[0]) ||
-             XMLString::equals(rawData, fgValueSpace[2])  ) ?
-             XMLString::replicate(fgValueSpace[0], toUse) :
-             XMLString::replicate(fgValueSpace[1], toUse) ;
+    return ( XMLString::equals(rawData, XMLUni::fgBooleanValueSpace[0]) ||
+             XMLString::equals(rawData, XMLUni::fgBooleanValueSpace[2])  ) ?
+             XMLString::replicate(XMLUni::fgBooleanValueSpace[0], toUse) :
+             XMLString::replicate(XMLUni::fgBooleanValueSpace[1], toUse) ;
 
 }
 
