@@ -1,61 +1,30 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 2001, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2001,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
  * $Log: DatatypeValidatorFactory.cpp,v $
+ * Revision 1.29  2004/09/13 21:38:34  peiyongz
+ * getBuiltInBaseValidator
+ *
+ * Revision 1.28  2004/09/08 13:56:52  peiyongz
+ * Apache License Version 2.0
+ *
+ * Revision 1.27  2004/08/11 16:52:59  peiyongz
+ * using Literal constants from XMLUni
+ *
  * Revision 1.26  2004/01/13 16:17:09  knoaman
  * Fo sanity, use class name to qualify method
  *
@@ -271,18 +240,6 @@ const XMLCh fgTokPattern[] =
     chBackSlash, chLatin_c, chPlus, chNull
 };
 
-// http://www.w3.org/2001/05/xmlschema-errata#Errata2
-// E2-25
-//"([a-zA-Z]{1,8})(-[a-zA-Z0-9]{1,8})*"
-const XMLCh fgLangPattern[] =
-{
-    chOpenParen,   chOpenSquare,  chLatin_a, chDash, chLatin_z, chLatin_A, chDash, chLatin_Z,
-    chCloseSquare, chOpenCurly, chDigit_1, chComma, chDigit_8, chCloseCurly, chCloseParen,
-    chOpenParen,   chDash, chOpenSquare, chLatin_a, chDash, chLatin_z, chLatin_A, chDash, chLatin_Z,
-	chDigit_0,     chDash, chDigit_9, chCloseSquare, chOpenCurly, chDigit_1, chComma, chDigit_8,
-    chCloseCurly,  chCloseParen, chAsterisk, chNull
-};
-
 //E2-43
 //[+\-]?[0-9]+
 const XMLCh fgIntegerPattern[] =
@@ -305,91 +262,7 @@ const XMLCh fgNCNamePattern[] =
     chColon, chCloseSquare, chCloseSquare, chAsterisk, chNull
 };
 
-const XMLCh fgValueZero[] =
-{
-    chDigit_0, chNull
-};
 
-const XMLCh fgNegOne[] =
-{
-    chDash, chDigit_1, chNull
-};
-
-const XMLCh fgValueOne[] =
-{
-    chDigit_1, chNull
-};
-
-//"9223372036854775807"
-const XMLCh fgLongMaxInc[] =
-{
-    chDigit_9, chDigit_2, chDigit_2, chDigit_3, chDigit_3, chDigit_7, chDigit_2,
-    chDigit_0, chDigit_3, chDigit_6, chDigit_8, chDigit_5, chDigit_4, chDigit_7,
-    chDigit_7, chDigit_5, chDigit_8, chDigit_0, chDigit_7, chNull
-};
-
-//"-9223372036854775808"
-const XMLCh fgLongMinInc[] =
-{
-    chDash, chDigit_9, chDigit_2, chDigit_2, chDigit_3, chDigit_3, chDigit_7,
-    chDigit_2, chDigit_0, chDigit_3, chDigit_6, chDigit_8, chDigit_5, chDigit_4,
-    chDigit_7, chDigit_7, chDigit_5, chDigit_8, chDigit_0, chDigit_8,  chNull
-};
-
-const XMLCh fgIntMaxInc[] =
-{
-    chDigit_2, chDigit_1, chDigit_4, chDigit_7, chDigit_4, chDigit_8,
-    chDigit_3, chDigit_6, chDigit_4, chDigit_7, chNull
-};
-
-const XMLCh fgIntMinInc[] =
-{
-    chDash, chDigit_2, chDigit_1, chDigit_4, chDigit_7, chDigit_4,
-    chDigit_8, chDigit_3, chDigit_6, chDigit_4, chDigit_8, chNull
-};
-
-const XMLCh fgShortMaxInc[] =
-{
-    chDigit_3, chDigit_2, chDigit_7, chDigit_6, chDigit_7, chNull
-};
-
-const XMLCh fgShortMinInc[] =
-{
-    chDash, chDigit_3, chDigit_2, chDigit_7, chDigit_6, chDigit_8, chNull
-};
-
-const XMLCh fgByteMaxInc[] =
-{
-    chDigit_1, chDigit_2, chDigit_7, chNull
-};
-
-const XMLCh fgByteMinInc[] =
-{
-    chDash, chDigit_1, chDigit_2, chDigit_8, chNull
-};
-
-const XMLCh fgULongMaxInc[] =
-{
-    chDigit_1, chDigit_8, chDigit_4, chDigit_4, chDigit_6, chDigit_7, chDigit_4,
-    chDigit_4, chDigit_0, chDigit_7, chDigit_3, chDigit_7, chDigit_0, chDigit_9,
-    chDigit_5, chDigit_5, chDigit_1, chDigit_6, chDigit_1, chDigit_5, chNull
-};
-
-const XMLCh fgUIntMaxInc[] =
-{
-    chDigit_4, chDigit_2, chDigit_9, chDigit_4, chDigit_9, chDigit_6,
-    chDigit_7, chDigit_2, chDigit_9, chDigit_5, chNull
-};
-
-const XMLCh fgUShortMaxInc[] =
-{
-    chDigit_6, chDigit_5, chDigit_5, chDigit_3, chDigit_5, chNull
-};
-
-const XMLCh fgUByteMaxInc[] =
-{
-    chDigit_2, chDigit_5, chDigit_5, chNull
-};
 
 const XMLCh fgP0Y[] =
 {
@@ -631,7 +504,7 @@ void DatatypeValidatorFactory::expandRegistryToFullSchemaSet()
                 facets = new RefHashTableOf<KVStringPair>(3);
 
                 facets->put((void*) SchemaSymbols::fgELT_PATTERN,
-                            new KVStringPair(SchemaSymbols::fgELT_PATTERN, fgLangPattern));
+                    new KVStringPair(SchemaSymbols::fgELT_PATTERN, XMLUni::fgLangPattern));
 
                 createDatatypeValidator(SchemaSymbols::fgDT_LANGUAGE,
                               getDatatypeValidator(SchemaSymbols::fgDT_TOKEN),
@@ -641,7 +514,7 @@ void DatatypeValidatorFactory::expandRegistryToFullSchemaSet()
                 facets = new RefHashTableOf<KVStringPair>(3);
 
                 facets->put((void*) SchemaSymbols::fgELT_FRACTIONDIGITS,
-                            new KVStringPair(SchemaSymbols::fgELT_FRACTIONDIGITS, fgValueZero));
+                    new KVStringPair(SchemaSymbols::fgELT_FRACTIONDIGITS, XMLUni::fgValueZero));
 
                 facets->put((void*) SchemaSymbols::fgELT_PATTERN,
                             new KVStringPair(SchemaSymbols::fgELT_PATTERN, fgIntegerPattern));
@@ -654,7 +527,7 @@ void DatatypeValidatorFactory::expandRegistryToFullSchemaSet()
                 facets = new RefHashTableOf<KVStringPair>(2);
 
                 facets->put((void*) SchemaSymbols::fgELT_MAXINCLUSIVE,
-                            new KVStringPair(SchemaSymbols::fgELT_MAXINCLUSIVE, fgValueZero));
+                            new KVStringPair(SchemaSymbols::fgELT_MAXINCLUSIVE, XMLUni::fgValueZero));
 
                 createDatatypeValidator(SchemaSymbols::fgDT_NONPOSITIVEINTEGER,
                               getDatatypeValidator(SchemaSymbols::fgDT_INTEGER),
@@ -664,7 +537,7 @@ void DatatypeValidatorFactory::expandRegistryToFullSchemaSet()
                 facets = new RefHashTableOf<KVStringPair>(2);
 
                 facets->put((void*) SchemaSymbols::fgELT_MAXINCLUSIVE,
-    			            new KVStringPair(SchemaSymbols::fgELT_MAXINCLUSIVE,fgNegOne));
+    			            new KVStringPair(SchemaSymbols::fgELT_MAXINCLUSIVE, XMLUni::fgNegOne));
 
                 createDatatypeValidator(SchemaSymbols::fgDT_NEGATIVEINTEGER,
                               getDatatypeValidator(SchemaSymbols::fgDT_NONPOSITIVEINTEGER),
@@ -674,9 +547,9 @@ void DatatypeValidatorFactory::expandRegistryToFullSchemaSet()
                 facets = new RefHashTableOf<KVStringPair>(2);
 
                 facets->put((void*) SchemaSymbols::fgELT_MAXINCLUSIVE,
-                            new KVStringPair(SchemaSymbols::fgELT_MAXINCLUSIVE,fgLongMaxInc));
+                            new KVStringPair(SchemaSymbols::fgELT_MAXINCLUSIVE, XMLUni::fgLongMaxInc));
                 facets->put((void*) SchemaSymbols::fgELT_MININCLUSIVE,
-                            new KVStringPair(SchemaSymbols::fgELT_MININCLUSIVE,fgLongMinInc));
+                            new KVStringPair(SchemaSymbols::fgELT_MININCLUSIVE, XMLUni::fgLongMinInc));
 
                 createDatatypeValidator(SchemaSymbols::fgDT_LONG,
                               getDatatypeValidator(SchemaSymbols::fgDT_INTEGER),
@@ -686,9 +559,9 @@ void DatatypeValidatorFactory::expandRegistryToFullSchemaSet()
                 facets = new RefHashTableOf<KVStringPair>(2);
 
                 facets->put((void*) SchemaSymbols::fgELT_MAXINCLUSIVE,
-                            new KVStringPair(SchemaSymbols::fgELT_MAXINCLUSIVE, fgIntMaxInc));
+                            new KVStringPair(SchemaSymbols::fgELT_MAXINCLUSIVE, XMLUni::fgIntMaxInc));
                 facets->put((void*) SchemaSymbols::fgELT_MININCLUSIVE,
-                            new KVStringPair(SchemaSymbols::fgELT_MININCLUSIVE, fgIntMinInc));
+                            new KVStringPair(SchemaSymbols::fgELT_MININCLUSIVE, XMLUni::fgIntMinInc));
 
                 createDatatypeValidator(SchemaSymbols::fgDT_INT,
                               getDatatypeValidator(SchemaSymbols::fgDT_LONG),
@@ -698,9 +571,9 @@ void DatatypeValidatorFactory::expandRegistryToFullSchemaSet()
                 facets = new RefHashTableOf<KVStringPair>(2);
 
                 facets->put((void*) SchemaSymbols::fgELT_MAXINCLUSIVE,
-                            new KVStringPair(SchemaSymbols::fgELT_MAXINCLUSIVE, fgShortMaxInc));
+                            new KVStringPair(SchemaSymbols::fgELT_MAXINCLUSIVE, XMLUni::fgShortMaxInc));
                 facets->put((void*) SchemaSymbols::fgELT_MININCLUSIVE,
-                            new KVStringPair(SchemaSymbols::fgELT_MININCLUSIVE, fgShortMinInc));
+                            new KVStringPair(SchemaSymbols::fgELT_MININCLUSIVE, XMLUni::fgShortMinInc));
 
                 createDatatypeValidator(SchemaSymbols::fgDT_SHORT,
                               getDatatypeValidator(SchemaSymbols::fgDT_INT),
@@ -710,9 +583,9 @@ void DatatypeValidatorFactory::expandRegistryToFullSchemaSet()
                 facets = new RefHashTableOf<KVStringPair>(2);
 
                 facets->put((void*) SchemaSymbols::fgELT_MAXINCLUSIVE,
-                            new KVStringPair(SchemaSymbols::fgELT_MAXINCLUSIVE, fgByteMaxInc));
+                            new KVStringPair(SchemaSymbols::fgELT_MAXINCLUSIVE, XMLUni::fgByteMaxInc));
                 facets->put((void*) SchemaSymbols::fgELT_MININCLUSIVE,
-                            new KVStringPair(SchemaSymbols::fgELT_MININCLUSIVE, fgByteMinInc));
+                            new KVStringPair(SchemaSymbols::fgELT_MININCLUSIVE, XMLUni::fgByteMinInc));
 
                 createDatatypeValidator(SchemaSymbols::fgDT_BYTE,
                               getDatatypeValidator(SchemaSymbols::fgDT_SHORT),
@@ -722,7 +595,7 @@ void DatatypeValidatorFactory::expandRegistryToFullSchemaSet()
                 facets = new RefHashTableOf<KVStringPair>(2);
 
                 facets->put((void*) SchemaSymbols::fgELT_MININCLUSIVE,
-                            new KVStringPair(SchemaSymbols::fgELT_MININCLUSIVE, fgValueZero));
+                            new KVStringPair(SchemaSymbols::fgELT_MININCLUSIVE, XMLUni::fgValueZero));
 
                 createDatatypeValidator(SchemaSymbols::fgDT_NONNEGATIVEINTEGER,
                               getDatatypeValidator(SchemaSymbols::fgDT_INTEGER),
@@ -732,7 +605,7 @@ void DatatypeValidatorFactory::expandRegistryToFullSchemaSet()
                 facets = new RefHashTableOf<KVStringPair>(2);
 
                 facets->put((void*) SchemaSymbols::fgELT_MAXINCLUSIVE,
-                            new KVStringPair(SchemaSymbols::fgELT_MAXINCLUSIVE, fgULongMaxInc));
+                            new KVStringPair(SchemaSymbols::fgELT_MAXINCLUSIVE, XMLUni::fgULongMaxInc));
 
                 createDatatypeValidator(SchemaSymbols::fgDT_ULONG,
                               getDatatypeValidator(SchemaSymbols::fgDT_NONNEGATIVEINTEGER),
@@ -742,7 +615,7 @@ void DatatypeValidatorFactory::expandRegistryToFullSchemaSet()
                 facets = new RefHashTableOf<KVStringPair>(2);
 
                 facets->put((void*) SchemaSymbols::fgELT_MAXINCLUSIVE,
-                            new KVStringPair(SchemaSymbols::fgELT_MAXINCLUSIVE, fgUIntMaxInc));
+                            new KVStringPair(SchemaSymbols::fgELT_MAXINCLUSIVE, XMLUni::fgUIntMaxInc));
 
                 createDatatypeValidator(SchemaSymbols::fgDT_UINT,
                               getDatatypeValidator(SchemaSymbols::fgDT_ULONG),
@@ -752,7 +625,7 @@ void DatatypeValidatorFactory::expandRegistryToFullSchemaSet()
                 facets = new RefHashTableOf<KVStringPair>(2);
 
                 facets->put((void*) SchemaSymbols::fgELT_MAXINCLUSIVE,
-                            new KVStringPair(SchemaSymbols::fgELT_MAXINCLUSIVE, fgUShortMaxInc));
+                            new KVStringPair(SchemaSymbols::fgELT_MAXINCLUSIVE, XMLUni::fgUShortMaxInc));
 
                 createDatatypeValidator(SchemaSymbols::fgDT_USHORT,
                               getDatatypeValidator(SchemaSymbols::fgDT_UINT),
@@ -762,7 +635,7 @@ void DatatypeValidatorFactory::expandRegistryToFullSchemaSet()
                 facets = new RefHashTableOf<KVStringPair>(2);
 
                 facets->put((void*) SchemaSymbols::fgELT_MAXINCLUSIVE,
-                            new KVStringPair(SchemaSymbols::fgELT_MAXINCLUSIVE, fgUByteMaxInc));
+                            new KVStringPair(SchemaSymbols::fgELT_MAXINCLUSIVE, XMLUni::fgUByteMaxInc));
 
                 createDatatypeValidator(SchemaSymbols::fgDT_UBYTE,
                               getDatatypeValidator(SchemaSymbols::fgDT_USHORT),
@@ -772,7 +645,7 @@ void DatatypeValidatorFactory::expandRegistryToFullSchemaSet()
                 facets = new RefHashTableOf<KVStringPair>(2);
 
                 facets->put((void*) SchemaSymbols::fgELT_MININCLUSIVE,
-                            new KVStringPair(SchemaSymbols::fgELT_MININCLUSIVE, fgValueOne));
+                            new KVStringPair(SchemaSymbols::fgELT_MININCLUSIVE, XMLUni::fgValueOne));
 
                 createDatatypeValidator(SchemaSymbols::fgDT_POSITIVEINTEGER,
                               getDatatypeValidator(SchemaSymbols::fgDT_NONNEGATIVEINTEGER),
@@ -905,6 +778,21 @@ XMLCanRepGroup::CanRepGroup DatatypeValidatorFactory::getCanRepGroup(const Datat
     return XMLCanRepGroup::String;
 }
 
+DatatypeValidator* DatatypeValidatorFactory::getBuiltInBaseValidator(const DatatypeValidator* const dv)
+{
+    DatatypeValidator *curdv = (DatatypeValidator*)dv;
+
+    while (curdv)
+    {
+        if (curdv == getBuiltInRegistry()->get(curdv->getTypeLocalName()))
+            return curdv;
+        else
+            curdv = curdv->getBaseValidator();
+     }
+
+     return 0;
+}
+
 // ---------------------------------------------------------------------------
 //  DatatypeValidatorFactory: factory methods
 // ---------------------------------------------------------------------------
