@@ -1,62 +1,40 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 2001, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2001,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: DoubleDatatypeValidator.cpp,v 1.6 2003/05/18 14:02:07 knoaman Exp $
+ * $Id: DoubleDatatypeValidator.cpp,v 1.14 2004/09/08 13:56:52 peiyongz Exp $
  * $Log: DoubleDatatypeValidator.cpp,v $
+ * Revision 1.14  2004/09/08 13:56:52  peiyongz
+ * Apache License Version 2.0
+ *
+ * Revision 1.13  2004/01/13 20:57:06  peiyongz
+ * revert code back to previous version
+ *
+ * Revision 1.10  2003/12/17 00:18:38  cargilld
+ * Update to memory management so that the static memory manager (one used to call Initialize) is only for static data.
+ *
+ * Revision 1.9  2003/11/12 20:32:03  peiyongz
+ * Statless Grammar: ValidationContext
+ *
+ * Revision 1.8  2003/11/06 15:30:07  neilg
+ * first part of PSVI/schema component model implementation, thanks to David Cargill.  This covers setting the PSVIHandler on parser objects, as well as implementing XSNotation, XSSimpleTypeDefinition, XSIDCDefinition, and most of XSWildcard, XSComplexTypeDefinition, XSElementDeclaration, XSAttributeDeclaration and XSAttributeUse.
+ *
+ * Revision 1.7  2003/10/02 19:21:06  peiyongz
+ * Implementation of Serialization/Deserialization
+ *
  * Revision 1.6  2003/05/18 14:02:07  knoaman
  * Memory manager implementation: pass per instance manager.
  *
@@ -110,7 +88,12 @@ XERCES_CPP_NAMESPACE_BEGIN
 // ---------------------------------------------------------------------------
 DoubleDatatypeValidator::DoubleDatatypeValidator(MemoryManager* const manager)
 :AbstractNumericValidator(0, 0, 0, DatatypeValidator::Double, manager)
-{}
+{
+    setOrdered(XSSimpleTypeDefinition::ORDERED_PARTIAL);
+    setBounded(true);
+    setFinite(true);
+    setNumeric(true);
+}
 
 DoubleDatatypeValidator::DoubleDatatypeValidator(
                           DatatypeValidator*            const baseValidator
@@ -120,7 +103,7 @@ DoubleDatatypeValidator::DoubleDatatypeValidator(
                         , MemoryManager* const                manager)
 :AbstractNumericValidator(baseValidator, facets, finalSet, DatatypeValidator::Double, manager)
 {
-    init(enums);
+    init(enums, manager);
 }
 
 DoubleDatatypeValidator::~DoubleDatatypeValidator()
@@ -130,10 +113,11 @@ DoubleDatatypeValidator::~DoubleDatatypeValidator()
 // Compare methods
 // -----------------------------------------------------------------------
 int DoubleDatatypeValidator::compare(const XMLCh* const lValue
-                                   , const XMLCh* const rValue)
+                                   , const XMLCh* const rValue
+                                   , MemoryManager* const manager)
 {
-    XMLDouble lObj(lValue, fMemoryManager);
-    XMLDouble rObj(rValue, fMemoryManager);
+    XMLDouble lObj(lValue, manager);
+    XMLDouble rObj(rValue, manager);
 
     return compareValues(&lObj, &rObj);
 }
@@ -162,23 +146,6 @@ DoubleDatatypeValidator::DoubleDatatypeValidator(DatatypeValidator*            c
     //do not invoke init here !!!
 }
 
-void DoubleDatatypeValidator::assignAdditionalFacet(const XMLCh* const key
-                                                  , const XMLCh* const)
-{
-    ThrowXML1(InvalidDatatypeFacetException
-            , XMLExcepts::FACET_Invalid_Tag
-            , key);
-}
-
-void DoubleDatatypeValidator::inheritAdditionalFacet()
-{}
-
-void DoubleDatatypeValidator::checkAdditionalFacetConstraints() const
-{}
-
-void DoubleDatatypeValidator::checkAdditionalFacetConstraintsBase() const
-{}
-
 int  DoubleDatatypeValidator::compareValues(const XMLNumber* const lValue
                                           , const XMLNumber* const rValue)
 {
@@ -205,7 +172,7 @@ void  DoubleDatatypeValidator::setMinExclusive(const XMLCh* const value)
     fMinExclusive = new (fMemoryManager) XMLDouble(value, fMemoryManager);
 }
 
-void  DoubleDatatypeValidator::setEnumeration()
+void  DoubleDatatypeValidator::setEnumeration(MemoryManager* const manager)
 {
     // check 4.3.5.c0 must: enumeration values from the value space of base
     //
@@ -225,14 +192,15 @@ void  DoubleDatatypeValidator::setEnumeration()
         {
             for ( i = 0; i < enumLength; i++)
             {
-                numBase->checkContent(fStrEnumeration->elementAt(i), false);
+                numBase->checkContent(fStrEnumeration->elementAt(i), (ValidationContext*)0, false, manager);
             }
         }
         catch (XMLException&)
         {
-            ThrowXML1(InvalidDatatypeFacetException
+            ThrowXMLwithMemMgr1(InvalidDatatypeFacetException
                     , XMLExcepts::FACET_enum_base
-                    , fStrEnumeration->elementAt(i));
+                    , fStrEnumeration->elementAt(i)
+                    , manager);
 
         }
     }
@@ -242,15 +210,15 @@ void  DoubleDatatypeValidator::setEnumeration()
     //
     for ( i = 0; i < enumLength; i++)
     {
-        checkContent(fStrEnumeration->elementAt(i), false);
+        checkContent(fStrEnumeration->elementAt(i), (ValidationContext*)0, false, manager);
     }
 
-    fEnumeration = new (fMemoryManager) RefVectorOf<XMLNumber>(enumLength, true, fMemoryManager);
+    fEnumeration = new (manager) RefVectorOf<XMLNumber>(enumLength, true, manager);
     fEnumerationInherited = false;
 
     for ( i = 0; i < enumLength; i++)
     {
-        fEnumeration->insertElementAt(new (fMemoryManager) XMLDouble(fStrEnumeration->elementAt(i), fMemoryManager), i);
+        fEnumeration->insertElementAt(new (manager) XMLDouble(fStrEnumeration->elementAt(i), manager), i);
     }
 }
 
@@ -258,13 +226,16 @@ void  DoubleDatatypeValidator::setEnumeration()
 // Abstract interface from AbstractNumericValidator
 // -----------------------------------------------------------------------
 
-void DoubleDatatypeValidator::checkContent( const XMLCh* const content, bool asBase)
+void DoubleDatatypeValidator::checkContent(const XMLCh*             const content
+                                          ,      ValidationContext* const context
+                                          ,      bool                     asBase
+                                          ,      MemoryManager*     const manager)
 {
 
     //validate against base validator if any
     DoubleDatatypeValidator *pBase = (DoubleDatatypeValidator*) this->getBaseValidator();
     if (pBase)
-        pBase->checkContent(content, true);
+        pBase->checkContent(content, context, true, manager);
 
     // we check pattern first
     if ( (getFacetsDefined() & DatatypeValidator::FACET_PATTERN ) != 0 )
@@ -276,16 +247,17 @@ void DoubleDatatypeValidator::checkContent( const XMLCh* const content, bool asB
             }
             catch (XMLException &e)
             {
-                ThrowXML1(InvalidDatatypeValueException, XMLExcepts::RethrowError, e.getMessage());
+                ThrowXMLwithMemMgr1(InvalidDatatypeValueException, XMLExcepts::RethrowError, e.getMessage(), fMemoryManager);
             }
         }
 
-        if (getRegex()->matches(content) ==false)
+        if (getRegex()->matches(content, manager) ==false)
         {
-            ThrowXML2(InvalidDatatypeValueException
+            ThrowXMLwithMemMgr2(InvalidDatatypeValueException
                     , XMLExcepts::VALUE_NotMatch_Pattern
                     , content
-                    , getPattern());
+                    , getPattern()
+                    , manager);
         }
     }
 
@@ -295,7 +267,7 @@ void DoubleDatatypeValidator::checkContent( const XMLCh* const content, bool asB
         return;
 
     try {
-        XMLDouble theValue(content, fMemoryManager);
+        XMLDouble theValue(content, manager);
         XMLDouble *theData = &theValue;
 
         if (getEnumeration())
@@ -309,19 +281,45 @@ void DoubleDatatypeValidator::checkContent( const XMLCh* const content, bool asB
             }
 
             if (i == enumLength)
-                ThrowXML1(InvalidDatatypeValueException, XMLExcepts::VALUE_NotIn_Enumeration, content);
+                ThrowXMLwithMemMgr1(InvalidDatatypeValueException, XMLExcepts::VALUE_NotIn_Enumeration, content, manager);
         }
 
-        boundsCheck(theData);
+        boundsCheck(theData, manager);
 
     }
     catch (XMLException &e)
     {
-       ThrowXML1(InvalidDatatypeFacetException, XMLExcepts::RethrowError, e.getMessage());
+       ThrowXMLwithMemMgr1(InvalidDatatypeFacetException, XMLExcepts::RethrowError, e.getMessage(), manager);
     }
 
 }
 
+/***
+ * Support for Serialization/De-serialization
+ ***/
+
+IMPL_XSERIALIZABLE_TOCREATE(DoubleDatatypeValidator)
+
+void DoubleDatatypeValidator::serialize(XSerializeEngine& serEng)
+{
+    /***
+     * Note: 
+     *
+     *     During storing, we need write the specific number
+     *     type info before calling base::serialize().
+     *
+     *     While loading, we do nothing here
+     ***/
+
+    if (serEng.isStoring())
+    {
+        serEng<<(int) (XMLNumber::Double);
+    }
+
+    AbstractNumericValidator::serialize(serEng);
+
+}
+
 XERCES_CPP_NAMESPACE_END
 
 /**
