@@ -1,62 +1,37 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2001,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: NCNameDatatypeValidator.cpp,v 1.5 2003/05/15 18:53:26 knoaman Exp $
+ * $Id: NCNameDatatypeValidator.cpp,v 1.10 2004/09/08 13:56:53 peiyongz Exp $
  * $Log: NCNameDatatypeValidator.cpp,v $
+ * Revision 1.10  2004/09/08 13:56:53  peiyongz
+ * Apache License Version 2.0
+ *
+ * Revision 1.9  2004/01/29 11:51:22  cargilld
+ * Code cleanup changes to get rid of various compiler diagnostic messages.
+ *
+ * Revision 1.8  2003/12/17 00:18:39  cargilld
+ * Update to memory management so that the static memory manager (one used to call Initialize) is only for static data.
+ *
+ * Revision 1.7  2003/11/12 20:32:03  peiyongz
+ * Statless Grammar: ValidationContext
+ *
+ * Revision 1.6  2003/09/30 18:17:53  peiyongz
+ * Implementation of Serialization/Deserialization
+ *
  * Revision 1.5  2003/05/15 18:53:26  knoaman
  * Partial implementation of the configurable memory manager.
  *
@@ -109,7 +84,7 @@ NCNameDatatypeValidator::NCNameDatatypeValidator(
                         , MemoryManager* const                manager)
 :StringDatatypeValidator(baseValidator, facets, finalSet, DatatypeValidator::NCName, manager)
 {
-    init(enums);
+    init(enums, manager);
 }
 
 DatatypeValidator* NCNameDatatypeValidator::newInstance
@@ -138,36 +113,52 @@ NCNameDatatypeValidator::NCNameDatatypeValidator(
 // Compare methods
 // -----------------------------------------------------------------------
 int NCNameDatatypeValidator::compare(const XMLCh* const lValue
-                                   , const XMLCh* const rValue)
+                                   , const XMLCh* const rValue
+                                   ,       MemoryManager*     const)
 {
     return ( XMLString::equals(lValue, rValue)? 0 : -1);
 }
 
-void NCNameDatatypeValidator::validate(const XMLCh* const content)
+void NCNameDatatypeValidator::validate(const XMLCh*             const content
+                                     ,       ValidationContext* const context
+                                     ,       MemoryManager*     const manager)
 {
     // use StringDatatypeValidator (which in turn, invoke
     // the baseValidator) to validate content against
     // facets if any.
     //
-    StringDatatypeValidator::validate(content);
+    StringDatatypeValidator::validate(content, context, manager);
 
     return;
 }
 
-void NCNameDatatypeValidator::checkValueSpace(const XMLCh* const content)
+void NCNameDatatypeValidator::checkValueSpace(const XMLCh* const content
+                                              , MemoryManager* const manager)
 {
     //
     // 3.3.7 check must: "NCName"
     //
     if ( !XMLString::isValidNCName(content))
     {
-        ThrowXML1(InvalidDatatypeValueException
+        ThrowXMLwithMemMgr1(InvalidDatatypeValueException
                 , XMLExcepts::VALUE_Invalid_NCName
-                , content);
+                , content
+                , manager);
     }
 
 }
 
+/***
+ * Support for Serialization/De-serialization
+ ***/
+
+IMPL_XSERIALIZABLE_TOCREATE(NCNameDatatypeValidator)
+
+void NCNameDatatypeValidator::serialize(XSerializeEngine& serEng)
+{
+    StringDatatypeValidator::serialize(serEng);
+}
+
 XERCES_CPP_NAMESPACE_END
 
  /**
