@@ -1,61 +1,36 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 2001, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2001,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
  * $Log: SchemaElementDecl.hpp,v $
+ * Revision 1.22  2004/09/08 13:56:56  peiyongz
+ * Apache License Version 2.0
+ *
+ * Revision 1.21  2004/02/05 18:08:38  cargilld
+ * Code cleanup changes to get rid of various compiler diagnostic messages.
+ *
+ * Revision 1.20  2004/01/29 11:52:31  cargilld
+ * Code cleanup changes to get rid of various compiler diagnostic messages.
+ *
+ * Revision 1.19  2003/12/24 17:42:03  knoaman
+ * Misc. PSVI updates
+ *
+ * Revision 1.18  2003/12/12 18:36:37  peiyongz
+ * getObjectType()
+ *
  * Revision 1.17  2003/11/24 05:21:04  neilg
  * update method documentation
  *
@@ -204,7 +179,6 @@ public :
         , ModelTypes_Count
     };
 
-
     // -----------------------------------------------------------------------
     //  Constructors and Destructor
     // -----------------------------------------------------------------------
@@ -263,6 +237,7 @@ public :
     const SchemaAttDef* getAttWildCard() const;
     SchemaAttDef* getAttWildCard();
     ModelTypes getModelType() const;
+    PSVIDefs::PSVIScope getPSVIScope() const;
     DatatypeValidator* getDatatypeValidator() const;
     int getEnclosingScope() const;
     int getFinalSet() const;
@@ -376,8 +351,12 @@ public :
     // -----------------------------------------------------------------------
     //  Setter methods
     // -----------------------------------------------------------------------
+    /**
+     * @deprecated; not actually used
+     */    
     void setElemId(unsigned int elemId);
     void setModelType(const SchemaElementDecl::ModelTypes toSet);
+    void setPSVIScope(const PSVIDefs::PSVIScope toSet);
     void setDatatypeValidator(DatatypeValidator* newDatatypeValidator);
     void setEnclosingScope(const int enclosingScope);
     void setFinalSet(const int finalSet);
@@ -432,7 +411,15 @@ public :
      ***/
     DECL_XSERIALIZABLE(SchemaElementDecl)
 
+    virtual XMLElementDecl::objectType  getObjectType() const;
+
 private :
+    // -----------------------------------------------------------------------
+    //  Unimplemented constructors and operators
+    // -----------------------------------------------------------------------
+    SchemaElementDecl(const SchemaElementDecl&);
+    SchemaElementDecl& operator=(const SchemaElementDecl&);
+
     // -----------------------------------------------------------------------
     //  Private data members
     //
@@ -504,12 +491,12 @@ private :
 
     // -----------------------------------------------------------------------
     ModelTypes                         fModelType;
+    PSVIDefs::PSVIScope                fPSVIScope;
     DatatypeValidator*                 fDatatypeValidator;
     int                                fEnclosingScope;
     int                                fFinalSet;
     int                                fBlockSet;
-    int                                fMiscFlags;
-    unsigned int                       fElemId;
+    int                                fMiscFlags;    
     XMLCh*                             fDefaultValue;
     ComplexTypeInfo*                   fComplexTypeInfo;
     RefHash2KeysTableOf<SchemaAttDef>* fAttDefs;
@@ -547,7 +534,7 @@ inline const ContentSpecNode* SchemaElementDecl::getContentSpec() const
 }
 
 inline void
-SchemaElementDecl::setContentSpec(ContentSpecNode* toAdopt)
+SchemaElementDecl::setContentSpec(ContentSpecNode*)
 {
     //Handled by complexType
 }
@@ -561,7 +548,7 @@ inline XMLContentModel* SchemaElementDecl::getContentModel()
 }
 
 inline void
-SchemaElementDecl::setContentModel(XMLContentModel* const newModelToAdopt)
+SchemaElementDecl::setContentModel(XMLContentModel* const)
 {
     //Handled by complexType
 }
@@ -579,6 +566,11 @@ inline SchemaElementDecl::ModelTypes SchemaElementDecl::getModelType() const
     return fModelType;
 }
 
+inline PSVIDefs::PSVIScope SchemaElementDecl::getPSVIScope() const
+{
+    return fPSVIScope;
+}
+
 inline DatatypeValidator* SchemaElementDecl::getDatatypeValidator() const
 {
 
@@ -799,9 +791,10 @@ inline const XMLCh* SchemaElementDecl::getDOMTypeInfoUri() const {
 //  SchemaElementDecl: Setter methods
 // ---------------------------------------------------------------------------
 inline void
-SchemaElementDecl::setElemId(unsigned int elemId)
+SchemaElementDecl::setElemId(unsigned int)
 {
-    fElemId = elemId;
+    //there is not getElemId so this is not needed. mark deprecated.
+    //fElemId = elemId;
 }
 
 inline void
@@ -810,6 +803,12 @@ SchemaElementDecl::setModelType(const SchemaElementDecl::ModelTypes toSet)
     fModelType = toSet;
 }
 
+inline void
+SchemaElementDecl::setPSVIScope(const PSVIDefs::PSVIScope toSet)
+{
+    fPSVIScope = toSet;
+}
+
 inline void SchemaElementDecl::setDatatypeValidator(DatatypeValidator* newDatatypeValidator)
 {
     fDatatypeValidator = newDatatypeValidator;
