@@ -1,61 +1,33 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2002 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 2001, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2002,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /**
   * $Log: XSDErrorReporter.cpp,v $
+  * Revision 1.14  2004/09/08 13:56:57  peiyongz
+  * Apache License Version 2.0
+  *
+  * Revision 1.13  2004/07/22 15:37:18  knoaman
+  * Use file static instance instead of local static instance
+  *
+  * Revision 1.12  2004/01/09 22:41:58  knoaman
+  * Use a global static mutex for locking when creating local static mutexes instead of compareAndSwap
+  *
+  * Revision 1.11  2003/12/24 15:24:16  cargilld
+  * More updates to memory management so that the static memory manager.
+  *
   * Revision 1.10  2003/03/09 17:05:01  peiyongz
   * PanicHandler
   *
@@ -111,13 +83,38 @@ XERCES_CPP_NAMESPACE_BEGIN
 // ---------------------------------------------------------------------------
 //  Local static data
 // ---------------------------------------------------------------------------
-static XMLMsgLoader*      gErrMsgLoader = 0;
-static XMLMsgLoader*      gValidMsgLoader = 0;
-
+static XMLMsgLoader*  gErrMsgLoader = 0;
+static XMLMsgLoader*  gValidMsgLoader = 0;
+static XMLMutex*      sErrRprtrMutex = 0;
+static XMLRegisterCleanup errRprtrMutexCleanup;
+static XMLRegisterCleanup cleanupErrMsgLoader;
+static XMLRegisterCleanup cleanupValidMsgLoader;
 
 // ---------------------------------------------------------------------------
 //  Local, static functions
 // ---------------------------------------------------------------------------
+static void reinitErrRprtrMutex()
+{
+    delete sErrRprtrMutex;
+    sErrRprtrMutex = 0;
+}
+
+static XMLMutex& getErrRprtrMutex()
+{
+    if (!sErrRprtrMutex)
+    {
+        XMLMutexLock lockInit(XMLPlatformUtils::fgAtomicMutex);
+
+        if (!sErrRprtrMutex)
+        {
+            sErrRprtrMutex = new XMLMutex;
+            errRprtrMutexCleanup.registerCleanup(reinitErrRprtrMutex);
+        }
+    }
+
+    return *sErrRprtrMutex;
+}
+
 static void reinitErrMsgLoader()
 {
 	delete gErrMsgLoader;
@@ -132,44 +129,39 @@ static void reinitValidMsgLoader()
 
 static XMLMsgLoader* getErrMsgLoader()
 {
-    static XMLRegisterCleanup cleanupErrMsgLoader;
-    if (gErrMsgLoader == 0)
+    if (!gErrMsgLoader)
     {
-        XMLMsgLoader* t = XMLPlatformUtils::loadMsgSet(XMLUni::fgXMLErrDomain);
-        if (!t)
-            XMLPlatformUtils::panic(PanicHandler::Panic_CantLoadMsgDomain);
-        else {
-            if (XMLPlatformUtils::compareAndSwap((void **)&gErrMsgLoader, t, 0) != 0)
-            {
-                delete t;
-            }
+        XMLMutexLock lock(&getErrRprtrMutex());
+
+        if (!gErrMsgLoader)
+        {
+            gErrMsgLoader = XMLPlatformUtils::loadMsgSet(XMLUni::fgXMLErrDomain);
+
+            if (!gErrMsgLoader)
+                XMLPlatformUtils::panic(PanicHandler::Panic_CantLoadMsgDomain);
             else
-            {
                 cleanupErrMsgLoader.registerCleanup(reinitErrMsgLoader);
-            }
         }
     }
+
     return gErrMsgLoader;
 }
 
 
 static XMLMsgLoader* getValidMsgLoader()
 {
-    static XMLRegisterCleanup cleanupValidMsgLoader;
-    if (gValidMsgLoader == 0)
+    if (!gValidMsgLoader)
     {
-        XMLMsgLoader* t = XMLPlatformUtils::loadMsgSet(XMLUni::fgValidityDomain);
-        if (!t)
-            XMLPlatformUtils::panic(PanicHandler::Panic_CantLoadMsgDomain);
-        else {
-            if (XMLPlatformUtils::compareAndSwap((void **)&gValidMsgLoader, t, 0) != 0)
-            {
-                delete t;
-            }
+        XMLMutexLock lock(&getErrRprtrMutex());
+
+        if (!gValidMsgLoader)
+        {
+            gValidMsgLoader = XMLPlatformUtils::loadMsgSet(XMLUni::fgValidityDomain);
+
+            if (!gValidMsgLoader)
+                XMLPlatformUtils::panic(PanicHandler::Panic_CantLoadMsgDomain);
             else
-            {
                 cleanupValidMsgLoader.registerCleanup(reinitValidMsgLoader);
-            }
         }
     }
     return gValidMsgLoader;
@@ -233,7 +225,8 @@ void XSDErrorReporter::emitError(const unsigned int toEmit,
                                  const XMLCh* const text1,
                                  const XMLCh* const text2,
                                  const XMLCh* const text3,
-                                 const XMLCh* const text4)
+                                 const XMLCh* const text4,
+                                 MemoryManager* const manager)
 {
     // Bump the error count if it is not a warning
 //    if (XMLErrs::errorType(toEmit) != XMLErrorReporter::ErrType_Warning)
@@ -254,7 +247,7 @@ void XSDErrorReporter::emitError(const unsigned int toEmit,
         msgLoader = getValidMsgLoader();
     }
 
-    if (!msgLoader->loadMsg(toEmit, errText, maxChars, text1, text2, text3, text4))
+    if (!msgLoader->loadMsg(toEmit, errText, maxChars, text1, text2, text3, text4, manager))
     {
                 // <TBD> Should probably load a default message here
     }
