@@ -1,61 +1,33 @@
 /*
- * The Apache Software License, Version 1.1
+ * Copyright 1999-2000,2004 The Apache Software Foundation.
  * 
- * Copyright (c) 1999-2000 The Apache Software Foundation.  All rights
- * reserved.
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  * 
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
+ *      http://www.apache.org/licenses/LICENSE-2.0
  * 
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer. 
- * 
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- * 
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:  
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- * 
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written 
- *    permission, please contact apache\@apache.org.
- * 
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- * 
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- * 
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
  * $Log: ParserTest_Parser.cpp,v $
+ * Revision 1.12  2004/09/08 13:57:05  peiyongz
+ * Apache License Version 2.0
+ *
+ * Revision 1.11  2003/05/30 13:08:26  gareth
+ * move over to macros for std:: and iostream/iostream.h issues.
+ *
+ * Revision 1.10  2002/02/01 22:45:54  peiyongz
+ * sane_include
+ *
+ * Revision 1.9  2001/11/28 21:15:08  tng
+ * Fix broken ParserTest.
+ *
  * Revision 1.8  2000/03/02 19:55:46  roddey
  * This checkin includes many changes done while waiting for the
  * 1.1.0 code to be finished. I can't list them all here, but a list is
@@ -91,17 +63,17 @@
 // ---------------------------------------------------------------------------
 //  Includes
 // ---------------------------------------------------------------------------
-#include <util/RefVectorOf.hpp>
-#include <util/XMLString.hpp>
-#include <util/XMLUni.hpp>
-#include <internal/XMLReader.hpp>
-#include <internal/XMLScanner.hpp>
-#include <framework/XMLAttr.hpp>
-#include <framework/XMLNotationDecl.hpp>
-#include <framework/XMLValidator.hpp>
-#include <validators/DTD/DTDAttDef.hpp>
-#include <validators/DTD/DTDElementDecl.hpp>
-#include <validators/DTD/DTDEntityDecl.hpp>
+#include <xercesc/util/RefVectorOf.hpp>
+#include <xercesc/util/XMLString.hpp>
+#include <xercesc/util/XMLUni.hpp>
+#include <xercesc/internal/XMLReader.hpp>
+#include <xercesc/internal/XMLScanner.hpp>
+#include <xercesc/framework/XMLAttr.hpp>
+#include <xercesc/framework/XMLNotationDecl.hpp>
+#include <xercesc/framework/XMLValidator.hpp>
+#include <xercesc/validators/DTD/DTDAttDef.hpp>
+#include <xercesc/validators/DTD/DTDElementDecl.hpp>
+#include <xercesc/validators/DTD/DTDEntityDecl.hpp>
 #include "ParserTest.hpp"
 
 #include <stdlib.h>
@@ -153,12 +125,12 @@ void TestParser::docCharacters( const   XMLCh* const    chars
 {
     if (fOutputType == OutputType_Debug)
     {
-        cout << "Got CHARS:\n    Bytes: "
+        XERCES_STD_QUALIFIER cout << "Got CHARS:\n    Bytes: "
              << length << ", CDATA?: "
              << (cdataSection ? "Yes" : "No")
              << "\n"
              << "    SrcOfs: " << fScanner->getSrcOffset()
-             << "\n" << endl;
+             << "\n" << XERCES_STD_QUALIFIER endl;
     }
      else if ((fOutputType == OutputType_JCCanon)
           ||  (fOutputType == OutputType_SunCanon))
@@ -168,10 +140,10 @@ void TestParser::docCharacters( const   XMLCh* const    chars
      else if (fOutputType == OutputType_XML)
     {
         if (cdataSection)
-            cout << "<![CDATA[";
+            XERCES_STD_QUALIFIER cout << "<![CDATA[";
         showChars(chars, length);
         if (cdataSection)
-            cout << "]]>";
+            XERCES_STD_QUALIFIER cout << "]]>";
     }
 }
 
@@ -179,16 +151,16 @@ void TestParser::docComment(const XMLCh* const comment)
 {
     if (fOutputType == OutputType_Debug)
     {
-        cout << "Got document COMMENT:\n    "
+        XERCES_STD_QUALIFIER cout << "Got document COMMENT:\n    "
              << "Text: \"" << StrX(comment) << "\"\n"
              << "    SrcOfs: " << fScanner->getSrcOffset()
-             << "\n" << endl;
+             << "\n" << XERCES_STD_QUALIFIER endl;
     }
      else if (fOutputType == OutputType_XML)
     {
-        cout << "<!--";
+        XERCES_STD_QUALIFIER cout << "<!--";
         showString(comment);
-        cout << "-->";
+        XERCES_STD_QUALIFIER cout << "-->";
     }
 }
 
@@ -197,25 +169,25 @@ void TestParser::docPI( const   XMLCh* const    target
 {
     if (fOutputType == OutputType_Debug)
     {
-        cout << "Got document PI:\n     "
+        XERCES_STD_QUALIFIER cout << "Got document PI:\n     "
              << "Target: \"" << target << '"';
 
         if (XMLString::stringLen(data))
-            cout << ", Data: \"" << StrX(data) << "\"\n";
+            XERCES_STD_QUALIFIER cout << ", Data: \"" << StrX(data) << "\"\n";
 
-        cout << "    SrcOfs: " << fScanner->getSrcOffset()
-             << "\n" << endl;
+        XERCES_STD_QUALIFIER cout << "    SrcOfs: " << fScanner->getSrcOffset()
+             << "\n" << XERCES_STD_QUALIFIER endl;
     }
      else if ((fOutputType == OutputType_XML)
           ||  (fOutputType == OutputType_JCCanon)
           ||  (fOutputType == OutputType_SunCanon))
     {
-        cout << "<?";
+        XERCES_STD_QUALIFIER cout << "<?";
         showString(target);
-        cout << " ";
+        XERCES_STD_QUALIFIER cout << " ";
         if (XMLString::stringLen(data))
-            cout << StrX(data);
-        cout << "?>";
+            XERCES_STD_QUALIFIER cout << StrX(data);
+        XERCES_STD_QUALIFIER cout << "?>";
     }
 }
 
@@ -224,13 +196,13 @@ void TestParser::endDocument()
 {
     if (fOutputType == OutputType_Debug)
     {
-        cout << "Got ENDDOCUMENT:\n"
+        XERCES_STD_QUALIFIER cout << "Got ENDDOCUMENT:\n"
              << "    SrcOfs: " << fScanner->getSrcOffset()
-             << "\n" << endl;
+             << "\n" << XERCES_STD_QUALIFIER endl;
     }
      else if (fOutputType == OutputType_SunCanon)
     {
-        cout << "\r\n";
+        XERCES_STD_QUALIFIER cout << "\r\n";
     }
 }
 
@@ -243,29 +215,29 @@ void TestParser::endElement(const   XMLElementDecl& elemDecl
         if (fDoNamespaces)
         {
             XMLBuffer bufURI;
-            fScanner->getValidator()->getURIText(uriId, bufURI);
+            fScanner->getURIText(uriId, bufURI);
 
-            cout << "Got ENDELEMENT:\n    Name: "
+            XERCES_STD_QUALIFIER cout << "Got ENDELEMENT:\n    Name: "
                  << "{" << StrX(bufURI.getRawBuffer()) << "}"
                  << StrX(elemDecl.getBaseName())
-                 << endl;
+                 << XERCES_STD_QUALIFIER endl;
         }
          else
         {
-            cout << "Got ENDELEMENT:\n    Name: "
-                 << StrX(elemDecl.getFullName()) << endl;
+            XERCES_STD_QUALIFIER cout << "Got ENDELEMENT:\n    Name: "
+                 << StrX(elemDecl.getFullName()) << XERCES_STD_QUALIFIER endl;
         }
 
-        cout << "    SrcOfs: " << fScanner->getSrcOffset()
-             << "\n" << endl;
+        XERCES_STD_QUALIFIER cout << "    SrcOfs: " << fScanner->getSrcOffset()
+             << "\n" << XERCES_STD_QUALIFIER endl;
     }
      else if ((fOutputType == OutputType_XML)
           ||  (fOutputType == OutputType_JCCanon)
           ||  (fOutputType == OutputType_SunCanon))
     {
-        cout << "</";
+        XERCES_STD_QUALIFIER cout << "</";
         showString(elemDecl.getFullName());
-        cout << ">";
+        XERCES_STD_QUALIFIER cout << ">";
     }
 
     // Clear the flag that says we're now inside the root
@@ -277,8 +249,8 @@ void TestParser::endEntityReference(const XMLEntityDecl& entDecl)
 {
     if (fOutputType == OutputType_Debug)
     {
-        cout << "Got ENDENTITYREF:\n    "
-             << "Name: " << StrX(entDecl.getName()) << "\n" << endl;
+        XERCES_STD_QUALIFIER cout << "Got ENDENTITYREF:\n    "
+             << "Name: " << StrX(entDecl.getName()) << "\n" << XERCES_STD_QUALIFIER endl;
     }
 }
 
@@ -288,20 +260,20 @@ void TestParser::ignorableWhitespace(const  XMLCh* const    chars
 {
     if (fOutputType == OutputType_Debug)
     {
-        cout << "Got WHITESPACE:\n    Bytes: "
+        XERCES_STD_QUALIFIER cout << "Got WHITESPACE:\n    Bytes: "
              << length << ", CDATA?: "
              << (cdataSection ? "Yes" : "No")
              << "\n"
              << "    SrcOfs: " << fScanner->getSrcOffset()
-             << "\n" << endl;
+             << "\n" << XERCES_STD_QUALIFIER endl;
     }
      else if (fOutputType == OutputType_XML)
     {
         if (cdataSection)
-            cout << "<![CDATA[";
+            XERCES_STD_QUALIFIER cout << "<![CDATA[";
         showChars(chars, length);
         if (cdataSection)
-            cout << "]]>";
+            XERCES_STD_QUALIFIER cout << "]]>";
     }
      else if ((fOutputType == OutputType_JCCanon)
           ||  (fOutputType == OutputType_SunCanon))
@@ -315,13 +287,13 @@ void TestParser::ignorableWhitespace(const  XMLCh* const    chars
 void TestParser::resetDocument()
 {
     if (fOutputType == OutputType_Debug)
-        cout << "Got RESETDOCUMENT:\n" << endl;
+        XERCES_STD_QUALIFIER cout << "Got RESETDOCUMENT:\n" << XERCES_STD_QUALIFIER endl;
 }
 
 void TestParser::startDocument()
 {
     if (fOutputType == OutputType_Debug)
-        cout << "Got STARTDOCUMENT:\n" << endl;
+        XERCES_STD_QUALIFIER cout << "Got STARTDOCUMENT:\n" << XERCES_STD_QUALIFIER endl;
 }
 
 void
@@ -342,8 +314,8 @@ TestParser::startElement(const  XMLElementDecl&         elemDecl
         XMLBuffer bufURI;
         if (fDoNamespaces)
         {
-            fScanner->getValidator()->getURIText(uriId, bufURI);
-            cout << "Got STARTELEMENT:\n    "
+            fScanner->getURIText(uriId, bufURI);
+            XERCES_STD_QUALIFIER cout << "Got STARTELEMENT:\n    "
                  << " Name: {" << StrX(bufURI.getRawBuffer()) << "}"
                  << StrX(elemDecl.getBaseName())
                  << ", AttCount: " << attCount
@@ -353,7 +325,7 @@ TestParser::startElement(const  XMLElementDecl&         elemDecl
         }
          else
         {
-            cout << "Got STARTELEMENT:\n    Name: "
+            XERCES_STD_QUALIFIER cout << "Got STARTELEMENT:\n    Name: "
                  << StrX(elemDecl.getFullName())
                  << ", AttCount: " << attCount
                  << ", Empty?: "
@@ -361,75 +333,75 @@ TestParser::startElement(const  XMLElementDecl&         elemDecl
                  << "\n";
         }
 
-        cout << "    SrcOfs: " << fScanner->getSrcOffset() << "\n";
+        XERCES_STD_QUALIFIER cout << "    SrcOfs: " << fScanner->getSrcOffset() << "\n";
 
         // If any attributes, then show them
         if (attCount)
         {
-            cout << "    Attrs: ";
+            XERCES_STD_QUALIFIER cout << "    Attrs: ";
             for (unsigned int attInd = 0; attInd < attCount; attInd++)
             {
                 const XMLAttr* curAttr = attrList.elementAt(attInd);
 
                 if (fDoNamespaces)
                 {
-                    fScanner->getValidator()->getURIText(curAttr->getURIId(), bufURI);
-                    cout << "Name=" << "{" << StrX(bufURI.getRawBuffer())
+                    fScanner->getURIText(curAttr->getURIId(), bufURI);
+                    XERCES_STD_QUALIFIER cout << "Name=" << "{" << StrX(bufURI.getRawBuffer())
                          << "}" << StrX(curAttr->getName());
                 }
                  else
                 {
-                    cout << "Name=" << StrX(curAttr->getQName());
+                    XERCES_STD_QUALIFIER cout << "Name=" << StrX(curAttr->getQName());
                 }
 
                 if (curAttr->getSpecified())
-                    cout << " (Explicit)  ";
+                    XERCES_STD_QUALIFIER cout << " (Explicit)  ";
                 else
-                    cout << " (Defaulted) ";
+                    XERCES_STD_QUALIFIER cout << " (Defaulted) ";
 
-                cout << "Value=" << StrX(curAttr->getValue()) << "\n"
+                XERCES_STD_QUALIFIER cout << "Value=" << StrX(curAttr->getValue()) << "\n"
                      << "           ";
             }
         }
 
-        cout << endl;
+        XERCES_STD_QUALIFIER cout << XERCES_STD_QUALIFIER endl;
     }
      else if (fOutputType == OutputType_XML)
     {
-        cout << "<";
+        XERCES_STD_QUALIFIER cout << "<";
         showString(elemDecl.getFullName());
 
         if (attCount)
         {
-            cout << " ";
+            XERCES_STD_QUALIFIER cout << " ";
 
             for (unsigned int index = 0; index < attCount; index++)
             {
                 const XMLAttr* curAttr = attrList.elementAt(index);
                 showString(curAttr->getQName());
-                cout << "=\"";
+                XERCES_STD_QUALIFIER cout << "=\"";
                 showString(curAttr->getValue());
-                cout << "\"";
+                XERCES_STD_QUALIFIER cout << "\"";
 
                 if (index < attCount-1)
-                    cout << " ";
+                    XERCES_STD_QUALIFIER cout << " ";
             }
         }
 
         if (isEmpty)
-            cout << "/>";
+            XERCES_STD_QUALIFIER cout << "/>";
         else
-            cout << ">";
+            XERCES_STD_QUALIFIER cout << ">";
     }
      else if ((fOutputType == OutputType_JCCanon)
           ||  (fOutputType == OutputType_SunCanon))
     {
-        cout << "<";
+        XERCES_STD_QUALIFIER cout << "<";
         showString(elemDecl.getFullName());
 
         if (attCount)
         {
-            cout << " ";
+            XERCES_STD_QUALIFIER cout << " ";
 
             //
             //  Get a list of attribute pointers. The canonical output
@@ -449,25 +421,25 @@ TestParser::startElement(const  XMLElementDecl&         elemDecl
             {
                 const XMLAttr* curAttr = attrTmp[index];
                 showString(curAttr->getQName());
-                cout << "=\"";
+                XERCES_STD_QUALIFIER cout << "=\"";
                 showString(curAttr->getValue());
-                cout << "\"";
+                XERCES_STD_QUALIFIER cout << "\"";
 
                 if (index < attCount-1)
-                    cout << " ";
+                    XERCES_STD_QUALIFIER cout << " ";
             }
             delete [] attrTmp;
         }
 
         if (isEmpty)
         {
-            cout << "></";
+            XERCES_STD_QUALIFIER cout << "></";
             showString(elemDecl.getFullName());
-            cout << ">";
+            XERCES_STD_QUALIFIER cout << ">";
         }
          else
         {
-            cout << ">";
+            XERCES_STD_QUALIFIER cout << ">";
         }
     }
 }
@@ -476,8 +448,8 @@ void TestParser::startEntityReference(const XMLEntityDecl& entDecl)
 {
     if (fOutputType == OutputType_Debug)
     {
-        cout << "Got STARTENTITY:\n    "
-             << "Name: " << StrX(entDecl.getName()) << "\n" << endl;
+        XERCES_STD_QUALIFIER cout << "Got STARTENTITY:\n    "
+             << "Name: " << StrX(entDecl.getName()) << "\n" << XERCES_STD_QUALIFIER endl;
     }
 }
 
@@ -488,29 +460,29 @@ void TestParser::XMLDecl(const  XMLCh* const    versionStr
 {
     if (fOutputType == OutputType_Debug)
     {
-        cout << "Got XMLDECL:\n    "
+        XERCES_STD_QUALIFIER cout << "Got XMLDECL:\n    "
              << "Version:\"" << StrX(versionStr) << "\""
              << " Encoding:\"" << StrX(encodingStr) << "\""
              << " Standalone:\"" << StrX(standaloneStr) << "\""
              << " Auto Encoding:\"" << StrX(autoEncStr) << "\""
              << "\n"
              << "    SrcOfs: " << fScanner->getSrcOffset()
-             << "\n" << endl;
+             << "\n" << XERCES_STD_QUALIFIER endl;
     }
      else if (fOutputType == OutputType_XML)
     {
-        cout << "<?xml";
+        XERCES_STD_QUALIFIER cout << "<?xml";
 
         if (XMLString::stringLen(versionStr))
-            cout << " version=\"" << StrX(versionStr) << '"';
+            XERCES_STD_QUALIFIER cout << " version=\"" << StrX(versionStr) << '"';
 
         if (XMLString::stringLen(encodingStr))
-            cout << " encoding=\"" << StrX(encodingStr) << '"';
+            XERCES_STD_QUALIFIER cout << " encoding=\"" << StrX(encodingStr) << '"';
 
         if (XMLString::stringLen(standaloneStr))
-            cout  << " standlone=\"" << StrX(standaloneStr) << '"';
+            XERCES_STD_QUALIFIER cout  << " standlone=\"" << StrX(standaloneStr) << '"';
 
-        cout << " ?>";
+        XERCES_STD_QUALIFIER cout << " ?>";
     }
 }
 
@@ -524,7 +496,7 @@ void TestParser::attDef(const   DTDElementDecl& elemDecl
 {
     if (fOutputType == OutputType_Debug)
     {
-        cout << "Got ATTDEF:\n    "
+        XERCES_STD_QUALIFIER cout << "Got ATTDEF:\n    "
              << "Name: " << StrX(attDef.getFullName())
              << ", Type: "
              << StrX(XMLAttDef::getAttTypeString(attDef.getType()))
@@ -532,10 +504,10 @@ void TestParser::attDef(const   DTDElementDecl& elemDecl
              << StrX(XMLAttDef::getDefAttTypeString(attDef.getDefaultType()));
 
         if (XMLString::stringLen(attDef.getValue()))
-            cout << ", Value: \"" << StrX(attDef.getValue()) << '"';
+            XERCES_STD_QUALIFIER cout << ", Value: \"" << StrX(attDef.getValue()) << '"';
 
-        cout << "\n    SrcOfs: " << fScanner->getSrcOffset()
-             << "\n" << endl;
+        XERCES_STD_QUALIFIER cout << "\n    SrcOfs: " << fScanner->getSrcOffset()
+             << "\n" << XERCES_STD_QUALIFIER endl;
     }
      else if (fOutputType != OutputType_None)
     {
@@ -544,36 +516,36 @@ void TestParser::attDef(const   DTDElementDecl& elemDecl
 
         if (fIntDTDOutput)
         {
-            cout << StrX(attDef.getFullName()) << " ";
+            XERCES_STD_QUALIFIER cout << StrX(attDef.getFullName()) << " ";
             if (attDef.getType() == XMLAttDef::Enumeration)
             {
-                cout << '(';
+                XERCES_STD_QUALIFIER cout << '(';
                 StrX tmpStr(attDef.getEnumeration());
                 const char* curCh = tmpStr.localForm();
                 while (*curCh)
                 {
                     while (!isspace(*curCh) && *curCh)
-                        cout << *curCh++;
+                        XERCES_STD_QUALIFIER cout << *curCh++;
 
                     if (*curCh)
                     {
-                        cout << '|';
+                        XERCES_STD_QUALIFIER cout << '|';
                         curCh++;
                     }
                 }
-                cout << ')';
+                XERCES_STD_QUALIFIER cout << ')';
             }
              else
             {
-                cout << StrX(XMLAttDef::getAttTypeString(attDef.getType()));
+                XERCES_STD_QUALIFIER cout << StrX(XMLAttDef::getAttTypeString(attDef.getType()));
             }
 
             if (XMLString::stringLen(attDef.getValue()))
-                cout << " \"" << StrX(attDef.getValue()) << '"';
+                XERCES_STD_QUALIFIER cout << " \"" << StrX(attDef.getValue()) << '"';
 
             if (attDef.getDefaultType() != XMLAttDef::Default)
             {
-                cout << " "
+                XERCES_STD_QUALIFIER cout << " "
                      << StrX(XMLAttDef::getDefAttTypeString(attDef.getDefaultType()));
             }
         }
@@ -584,10 +556,10 @@ void TestParser::doctypeComment(const XMLCh* const comment)
 {
     if (fOutputType == OutputType_Debug)
     {
-        cout << "Got DTD COMMENT:\n    "
+        XERCES_STD_QUALIFIER cout << "Got DTD COMMENT:\n    "
              << "Text: \"" << StrX(comment) << "\"\n"
              << "    SrcOfs: " << fScanner->getSrcOffset()
-             << "\n" << endl;
+             << "\n" << XERCES_STD_QUALIFIER endl;
     }
      else if (fOutputType != OutputType_None)
     {
@@ -595,7 +567,7 @@ void TestParser::doctypeComment(const XMLCh* const comment)
             return;
 
         if (fIntDTDOutput)
-            cout << "<!--" << StrX(comment) << "-->";
+            XERCES_STD_QUALIFIER cout << "<!--" << StrX(comment) << "-->";
     }
 }
 
@@ -606,27 +578,27 @@ void TestParser::doctypeDecl(const  DTDElementDecl& elemDecl
 {
     if (fOutputType == OutputType_Debug)
     {
-        cout << "Got DOCTYPE:\n    "
+        XERCES_STD_QUALIFIER cout << "Got DOCTYPE:\n    "
                 << "Root: " << StrX(elemDecl.getFullName());
 
         if (XMLString::stringLen(publicId))
-            cout << ", PUBLIC: " << StrX(publicId);
+            XERCES_STD_QUALIFIER cout << ", PUBLIC: " << StrX(publicId);
 
         if (XMLString::stringLen(systemId))
-            cout << ", SYSTEM: " << StrX(systemId);
+            XERCES_STD_QUALIFIER cout << ", SYSTEM: " << StrX(systemId);
 
-        cout << "\n    SrcOfs: " << fScanner->getSrcOffset()
-             << "\n" << endl;
+        XERCES_STD_QUALIFIER cout << "\n    SrcOfs: " << fScanner->getSrcOffset()
+             << "\n" << XERCES_STD_QUALIFIER endl;
     }
      else if (fOutputType != OutputType_None)
     {
         if (fIntDTDOutput)
         {
-            cout << "<!DOCTYPE " << StrX(elemDecl.getFullName());
+            XERCES_STD_QUALIFIER cout << "<!DOCTYPE " << StrX(elemDecl.getFullName());
             showIds(publicId, systemId);
 
             if (!hasIntSubset)
-                cout << ">";
+                XERCES_STD_QUALIFIER cout << ">";
         }
     }
 }
@@ -636,14 +608,14 @@ void TestParser::doctypePI( const   XMLCh* const    target
 {
     if (fOutputType == OutputType_Debug)
     {
-        cout << "Got DTD PI:\n     "
+        XERCES_STD_QUALIFIER cout << "Got DTD PI:\n     "
                 << "Target: \"" << StrX(target) << '"';
 
         if (XMLString::stringLen(data))
-            cout << ", Data: \"" << StrX(data) << '"';
+            XERCES_STD_QUALIFIER cout << ", Data: \"" << StrX(data) << '"';
 
-        cout << "    SrcOfs: " << fScanner->getSrcOffset()
-             << "\n" << endl;
+        XERCES_STD_QUALIFIER cout << "    SrcOfs: " << fScanner->getSrcOffset()
+             << "\n" << XERCES_STD_QUALIFIER endl;
     }
      else if (fOutputType != OutputType_None)
     {
@@ -652,10 +624,10 @@ void TestParser::doctypePI( const   XMLCh* const    target
 
         if (fIntDTDOutput)
         {
-            cout << "<?" << target;
+            XERCES_STD_QUALIFIER cout << "<?" << target;
             if (XMLString::stringLen(data))
-                cout << " " << StrX(data);
-            cout << "?>";
+                XERCES_STD_QUALIFIER cout << " " << StrX(data);
+            XERCES_STD_QUALIFIER cout << "?>";
         }
     }
 }
@@ -665,10 +637,10 @@ void TestParser::doctypeWhitespace( const   XMLCh* const    chars
 {
     if (fOutputType == OutputType_Debug)
     {
-        cout << "Got DTD Spaces:\n    Bytes: "
+        XERCES_STD_QUALIFIER cout << "Got DTD Spaces:\n    Bytes: "
              << length << "\n"
              << "    SrcOfs: " << fScanner->getSrcOffset()
-             << "\n" << endl;
+             << "\n" << XERCES_STD_QUALIFIER endl;
     }
      else if (fOutputType != OutputType_None)
     {
@@ -685,16 +657,16 @@ void TestParser::elementDecl(const  DTDElementDecl&     decl
 {
     if (fOutputType == OutputType_Debug)
     {
-        cout << "Got ELEMENT DECL:\n    "
+        XERCES_STD_QUALIFIER cout << "Got ELEMENT DECL:\n    "
              << "Name: " << StrX(decl.getFullName());
 
         if (isIgnored)
-            cout << " (Ignored)";
+            XERCES_STD_QUALIFIER cout << " (Ignored)";
 
-        cout << ", Content: "
-             << StrX(decl.getFormattedContentModel(*fScanner->getValidator()))
+        XERCES_STD_QUALIFIER cout << ", Content: "
+             << StrX(decl.getFormattedContentModel())
              << "\n    SrcOfs: " << fScanner->getSrcOffset()
-             << "\n" << endl;
+             << "\n" << XERCES_STD_QUALIFIER endl;
     }
      else if (fOutputType != OutputType_None)
     {
@@ -703,8 +675,8 @@ void TestParser::elementDecl(const  DTDElementDecl&     decl
 
         if (fIntDTDOutput)
         {
-            cout << "<!ELEMENT " << StrX(decl.getFullName()) << " "
-                 << StrX(decl.getFormattedContentModel(*fScanner->getValidator()))
+            XERCES_STD_QUALIFIER cout << "<!ELEMENT " << StrX(decl.getFullName()) << " "
+                 << StrX(decl.getFormattedContentModel())
                  << ">";
         }
     }
@@ -714,10 +686,10 @@ void TestParser::endAttList(const DTDElementDecl& elemDecl)
 {
     if (fOutputType == OutputType_Debug)
     {
-        cout << "Got ENDATTLIST:\n    "
+        XERCES_STD_QUALIFIER cout << "Got ENDATTLIST:\n    "
              << "Name: " << StrX(elemDecl.getFullName()) << "\n"
              << "    SrcOfs: " << fScanner->getSrcOffset()
-             << "\n" << endl;
+             << "\n" << XERCES_STD_QUALIFIER endl;
     }
      else if (fOutputType != OutputType_None)
     {
@@ -725,7 +697,7 @@ void TestParser::endAttList(const DTDElementDecl& elemDecl)
             return;
 
         if (fIntDTDOutput)
-            cout << ">";
+            XERCES_STD_QUALIFIER cout << ">";
     }
 }
 
@@ -733,14 +705,14 @@ void TestParser::endIntSubset()
 {
     if (fOutputType == OutputType_Debug)
     {
-        cout << "Got ENDINTSUBSET\n"
+        XERCES_STD_QUALIFIER cout << "Got ENDINTSUBSET\n"
              << "    SrcOfs: " << fScanner->getSrcOffset()
-             << "\n" << endl;
+             << "\n" << XERCES_STD_QUALIFIER endl;
     }
      else if (fOutputType != OutputType_None)
     {
         if (fIntDTDOutput)
-            cout << "]>";
+            XERCES_STD_QUALIFIER cout << "]>";
     }
 }
 
@@ -748,7 +720,7 @@ void TestParser::endExtSubset()
 {
     fInExtSubset = false;
     if (fOutputType == OutputType_Debug)
-        cout << "Got ENDEXTSUBSET\n" << endl;
+        XERCES_STD_QUALIFIER cout << "Got ENDEXTSUBSET\n" << XERCES_STD_QUALIFIER endl;
 }
 
 void TestParser::entityDecl(const   DTDEntityDecl&  entityDecl
@@ -757,10 +729,10 @@ void TestParser::entityDecl(const   DTDEntityDecl&  entityDecl
 {
     if (fOutputType == OutputType_Debug)
     {
-        cout << "Got ENTITYDECL:\n    "
+        XERCES_STD_QUALIFIER cout << "Got ENTITYDECL:\n    "
              << "Name: " << StrX(entityDecl.getName())
              << (isPEDecl ? " [Parameter Entity]" : " [General Entity]")
-             << "\n" << endl;
+             << "\n" << XERCES_STD_QUALIFIER endl;
     }
      else if (fOutputType != OutputType_None)
     {
@@ -769,17 +741,17 @@ void TestParser::entityDecl(const   DTDEntityDecl&  entityDecl
 
         if (fIntDTDOutput)
         {
-            cout << "<!ENTITY ";
+            XERCES_STD_QUALIFIER cout << "<!ENTITY ";
             if (isPEDecl)
-                cout << "% ";
-            cout << StrX(entityDecl.getName());
-        
+                XERCES_STD_QUALIFIER cout << "% ";
+            XERCES_STD_QUALIFIER cout << StrX(entityDecl.getName());
+
             if (entityDecl.isExternal())
                 showIds(entityDecl.getPublicId(), entityDecl.getSystemId());
              else
-                cout << " \"" << StrX(entityDecl.getValue()) << "\"";
+                XERCES_STD_QUALIFIER cout << " \"" << StrX(entityDecl.getValue()) << "\"";
 
-            cout << ">";
+            XERCES_STD_QUALIFIER cout << ">";
         }
     }
 }
@@ -787,7 +759,7 @@ void TestParser::entityDecl(const   DTDEntityDecl&  entityDecl
 void TestParser::resetDocType()
 {
     if (fOutputType == OutputType_Debug)
-        cout << "Got RESETDOCTYPE:\n" << endl;
+        XERCES_STD_QUALIFIER cout << "Got RESETDOCTYPE:\n" << XERCES_STD_QUALIFIER endl;
 }
 
 void TestParser::notationDecl(  const   XMLNotationDecl&    notDecl
@@ -795,9 +767,9 @@ void TestParser::notationDecl(  const   XMLNotationDecl&    notDecl
 {
     if (fOutputType == OutputType_Debug)
     {
-        cout << "Got NOTATIONDECL:\n    "
+        XERCES_STD_QUALIFIER cout << "Got NOTATIONDECL:\n    "
              << "Name: " << StrX(notDecl.getName())
-             << endl;
+             << XERCES_STD_QUALIFIER endl;
     }
      else if (fOutputType != OutputType_None)
     {
@@ -806,20 +778,20 @@ void TestParser::notationDecl(  const   XMLNotationDecl&    notDecl
 
         if (fIntDTDOutput)
         {
-            cout << "<!NOTATION " << StrX(notDecl.getName()) << " ";
+            XERCES_STD_QUALIFIER cout << "<!NOTATION " << StrX(notDecl.getName()) << " ";
 
             if (!XMLString::stringLen(notDecl.getSystemId()))
-                cout << "PUBLIC ";
+                XERCES_STD_QUALIFIER cout << "PUBLIC ";
             else
-                cout << "SYSTEM ";
+                XERCES_STD_QUALIFIER cout << "SYSTEM ";
 
             if (XMLString::stringLen(notDecl.getPublicId()))
-                cout << "\"" << StrX(notDecl.getPublicId()) << '"';
+                XERCES_STD_QUALIFIER cout << "\"" << StrX(notDecl.getPublicId()) << '"';
 
             if (XMLString::stringLen(notDecl.getSystemId()))
-                cout << " \"" << StrX(notDecl.getSystemId()) << '"';
+                XERCES_STD_QUALIFIER cout << " \"" << StrX(notDecl.getSystemId()) << '"';
 
-            cout << ">";
+            XERCES_STD_QUALIFIER cout << ">";
         }
     }
 }
@@ -828,9 +800,9 @@ void TestParser::startAttList(const DTDElementDecl& elemDecl)
 {
     if (fOutputType == OutputType_Debug)
     {
-        cout << "Got STARTATTLIST:\n    "
+        XERCES_STD_QUALIFIER cout << "Got STARTATTLIST:\n    "
                 << "Name: " << StrX(elemDecl.getFullName())
-                << "\n" << endl;
+                << "\n" << XERCES_STD_QUALIFIER endl;
     }
      else if (fOutputType != OutputType_None)
     {
@@ -838,7 +810,7 @@ void TestParser::startAttList(const DTDElementDecl& elemDecl)
             return;
 
         if (fIntDTDOutput)
-            cout << "<!ATTLIST " << StrX(elemDecl.getFullName());
+            XERCES_STD_QUALIFIER cout << "<!ATTLIST " << StrX(elemDecl.getFullName());
     }
 }
 
@@ -846,12 +818,12 @@ void TestParser::startIntSubset()
 {
     if (fOutputType == OutputType_Debug)
     {
-        cout << "Got STARTINTSUBSET\n" << endl;
+        XERCES_STD_QUALIFIER cout << "Got STARTINTSUBSET\n" << XERCES_STD_QUALIFIER endl;
     }
      else if (fOutputType != OutputType_None)
     {
         if (fIntDTDOutput)
-            cout << " [";
+            XERCES_STD_QUALIFIER cout << " [";
     }
 }
 
@@ -859,7 +831,7 @@ void TestParser::startExtSubset()
 {
     fInExtSubset = true;
     if (fOutputType == OutputType_Debug)
-        cout << "Got STARTEXTSUBSET\n" << endl;
+        XERCES_STD_QUALIFIER cout << "Got STARTEXTSUBSET\n" << XERCES_STD_QUALIFIER endl;
 }
 
 void TestParser::TextDecl(  const   XMLCh* const    versionStr
@@ -867,15 +839,15 @@ void TestParser::TextDecl(  const   XMLCh* const    versionStr
 {
     if (fOutputType == OutputType_Debug)
     {
-        cout << "Got TEXTDECL:\n    ";
+        XERCES_STD_QUALIFIER cout << "Got TEXTDECL:\n    ";
 
         if (XMLString::stringLen(versionStr))
-            cout << "Version: " << StrX(versionStr);
+            XERCES_STD_QUALIFIER cout << "Version: " << StrX(versionStr);
 
         if (XMLString::stringLen(encodingStr))
-            cout << "Encoding: " << StrX(encodingStr);
+            XERCES_STD_QUALIFIER cout << "Encoding: " << StrX(encodingStr);
 
-        cout << "\n" << endl;
+        XERCES_STD_QUALIFIER cout << "\n" << XERCES_STD_QUALIFIER endl;
     }
 }
 
@@ -915,10 +887,10 @@ void TestParser::error( const   unsigned int                errCode
         if (ofs != -1)
             entName = &systemId[ofs + 1];
 
-        cout << lineNum << "/" << colNum
+        XERCES_STD_QUALIFIER cout << lineNum << "/" << colNum
                 << ":" << StrX(entName)
                 << " - " << StrX(text)
-                << endl;
+                << XERCES_STD_QUALIFIER endl;
         return;
     }
 
@@ -931,31 +903,31 @@ void TestParser::error( const   unsigned int                errCode
         typeStr = "ERROR";
     else if (type == XMLErrorReporter::ErrType_Warning)
         typeStr = "WARNING";
-    else if (type == XMLErrorReporter::ErrType_Invalid)
+    else if (type == XMLErrorReporter::ErrType_Error)
         typeStr = "VALIDITY";
 
     // Output the error heading and the error type string
-    cout << "\nError: (" << typeStr;
+    XERCES_STD_QUALIFIER cout << "\nError: (" << typeStr;
 
     // If we have either id, display them
     if (XMLString::stringLen(systemId))
-         cout << ", System Id: " << StrX(systemId);
+         XERCES_STD_QUALIFIER cout << ", System Id: " << StrX(systemId);
 
     if (XMLString::stringLen(publicId))
-        cout << ", Public Id: " << StrX(publicId);
+        XERCES_STD_QUALIFIER cout << ", Public Id: " << StrX(publicId);
 
     // Display the position information
-    cout << ", Line/Col: " << lineNum << "/" << colNum
+    XERCES_STD_QUALIFIER cout << ", Line/Col: " << lineNum << "/" << colNum
          << ")\n";
 
     // And finally the error text
-    cout << StrX(text) << endl;
+    XERCES_STD_QUALIFIER cout << StrX(text) << XERCES_STD_QUALIFIER endl;
 }
 
 void TestParser::resetErrors()
 {
     if (fOutputType == OutputType_Debug)
-        cout << "Got RESETERRORS:\n" << endl;
+        XERCES_STD_QUALIFIER cout << "Got RESETERRORS:\n" << XERCES_STD_QUALIFIER endl;
 }
 
 
@@ -987,7 +959,7 @@ void TestParser::showChars( const   XMLCh* const    chars
         {
             if (index == length)
             {
-                cout << "Missing trailing surrogate\n" << endl;
+                XERCES_STD_QUALIFIER cout << "Missing trailing surrogate\n" << XERCES_STD_QUALIFIER endl;
                 break;
             }
 
@@ -1048,27 +1020,27 @@ void TestParser::showChar(const char toShow, const bool doCan)
     if (doCan)
     {
         if (toShow == chLF)
-            cout << "&#10;";
+            XERCES_STD_QUALIFIER cout << "&#10;";
         else if (toShow == chHTab)
-            cout << "&#9;";
+            XERCES_STD_QUALIFIER cout << "&#9;";
         else if (toShow == chCR)
-            cout << "&#13;";
+            XERCES_STD_QUALIFIER cout << "&#13;";
         else if (toShow == chSingleQuote)
-            cout << "&apos;";
+            XERCES_STD_QUALIFIER cout << "&apos;";
         else if (toShow == chAmpersand)
-            cout << "&amp;";
+            XERCES_STD_QUALIFIER cout << "&amp;";
         else if (toShow == chDoubleQuote)
-            cout << "&quot;";
+            XERCES_STD_QUALIFIER cout << "&quot;";
         else if (toShow == chOpenAngle)
-            cout << "&lt;";
+            XERCES_STD_QUALIFIER cout << "&lt;";
         else if (toShow == chCloseAngle)
-            cout << "&gt;";
+            XERCES_STD_QUALIFIER cout << "&gt;";
         else
-            cout << toShow;
+            XERCES_STD_QUALIFIER cout << toShow;
     }
      else
     {
-        cout << toShow;
+        XERCES_STD_QUALIFIER cout << toShow;
     }
 }
 
@@ -1079,13 +1051,13 @@ TestParser::showIds(const XMLCh* const publicId, const XMLCh* const systemId)
     {
         if (!XMLString::stringLen(publicId))
         {
-            cout << " SYSTEM '" << StrX(systemId) << "'";
+            XERCES_STD_QUALIFIER cout << " SYSTEM '" << StrX(systemId) << "'";
         }
          else
         {
-            cout << " PUBLIC '" << StrX(publicId) << "'";
+            XERCES_STD_QUALIFIER cout << " PUBLIC '" << StrX(publicId) << "'";
             if (systemId)
-                cout << " '" << StrX(systemId) << "'";
+                XERCES_STD_QUALIFIER cout << " '" << StrX(systemId) << "'";
         }
     }
 }
